// Copyright (c) 2013-2016 CoolGames

(function() {
/******************************************************************************
 * Spine Runtimes Software License
 * Version 2.3
 * 
 * Copyright (c) 2013-2015, Esoteric Software
 * All rights reserved.
 * 
 * You are granted a perpetual, non-exclusive, non-sublicensable and
 * non-transferable license to use, install, execute and perform the Spine
 * Runtimes Software (the "Software") and derivative works solely for personal
 * or internal use. Without the written permission of Esoteric Software (see
 * Section 2 of the Spine Software License Agreement), you may not (a) modify,
 * translate, adapt or otherwise create derivative works, improvements of the
 * Software or develop new applications using the Software or (b) remove,
 * delete, alter or obscure any trademarks or any copyright, trademark, patent
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 * 
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

var spine = {
	radDeg: 180 / Math.PI,
	degRad: Math.PI / 180,
	temp: [],
    Float32Array: (typeof(Float32Array) === 'undefined') ? Array : Float32Array,
    Uint16Array: (typeof(Uint16Array) === 'undefined') ? Array : Uint16Array
};

spine.BoneData = function (name, parent) {
	this.name = name;
	this.parent = parent;
};
spine.BoneData.prototype = {
	length: 0,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	inheritScale: true,
	inheritRotation: true,
	flipX: false, flipY: false
};

spine.BlendMode = {
	normal: 0,
	additive: 1,
	multiply: 2,
	screen: 3
};

spine.SlotData = function (name, boneData) {
	this.name = name;
	this.boneData = boneData;
};
spine.SlotData.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	attachmentName: null,
	blendMode: spine.BlendMode.normal
};

spine.IkConstraintData = function (name) {
	this.name = name;
	this.bones = [];
};
spine.IkConstraintData.prototype = {
	target: null,
	bendDirection: 1,
	mix: 1
};

spine.Bone = function (boneData, skeleton, parent) {
	this.data = boneData;
	this.skeleton = skeleton;
	this.parent = parent;
	this.setToSetupPose();
};
spine.Bone.yDown = false;
spine.Bone.prototype = {
	x: 0, y: 0,
	rotation: 0, rotationIK: 0,
	scaleX: 1, scaleY: 1,
	flipX: false, flipY: false,
	m00: 0, m01: 0, worldX: 0, // a b x
	m10: 0, m11: 0, worldY: 0, // c d y
	worldRotation: 0,
	worldScaleX: 1, worldScaleY: 1,
	worldFlipX: false, worldFlipY: false,
	updateWorldTransform: function () {
		var parent = this.parent;
		if (parent) {
			this.worldX = this.x * parent.m00 + this.y * parent.m01 + parent.worldX;
			this.worldY = this.x * parent.m10 + this.y * parent.m11 + parent.worldY;
			if (this.data.inheritScale) {
				this.worldScaleX = parent.worldScaleX * this.scaleX;
				this.worldScaleY = parent.worldScaleY * this.scaleY;
			} else {
				this.worldScaleX = this.scaleX;
				this.worldScaleY = this.scaleY;
			}
			this.worldRotation = this.data.inheritRotation ? (parent.worldRotation + this.rotationIK) : this.rotationIK;
			this.worldFlipX = parent.worldFlipX != this.flipX;
			this.worldFlipY = parent.worldFlipY != this.flipY;
		} else {
			var skeletonFlipX = this.skeleton.flipX, skeletonFlipY = this.skeleton.flipY;
			this.worldX = skeletonFlipX ? -this.x : this.x;
			this.worldY = (skeletonFlipY != spine.Bone.yDown) ? -this.y : this.y;
			this.worldScaleX = this.scaleX;
			this.worldScaleY = this.scaleY;
			this.worldRotation = this.rotationIK;
			this.worldFlipX = skeletonFlipX != this.flipX;
			this.worldFlipY = skeletonFlipY != this.flipY;
		}
		var radians = this.worldRotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		if (this.worldFlipX) {
			this.m00 = -cos * this.worldScaleX;
			this.m01 = sin * this.worldScaleY;
		} else {
			this.m00 = cos * this.worldScaleX;
			this.m01 = -sin * this.worldScaleY;
		}
		if (this.worldFlipY != spine.Bone.yDown) {
			this.m10 = -sin * this.worldScaleX;
			this.m11 = -cos * this.worldScaleY;
		} else {
			this.m10 = sin * this.worldScaleX;
			this.m11 = cos * this.worldScaleY;
		}
	},
	setToSetupPose: function () {
		var data = this.data;
		this.x = data.x;
		this.y = data.y;
		this.rotation = data.rotation;
		this.rotationIK = this.rotation;
		this.scaleX = data.scaleX;
		this.scaleY = data.scaleY;
		this.flipX = data.flipX;
		this.flipY = data.flipY;
	},
	worldToLocal: function (world) {
		var dx = world[0] - this.worldX, dy = world[1] - this.worldY;
		var m00 = this.m00, m10 = this.m10, m01 = this.m01, m11 = this.m11;
		if (this.worldFlipX != (this.worldFlipY != spine.Bone.yDown)) {
			m00 = -m00;
			m11 = -m11;
		}
		var invDet = 1 / (m00 * m11 - m01 * m10);
		world[0] = dx * m00 * invDet - dy * m01 * invDet;
		world[1] = dy * m11 * invDet - dx * m10 * invDet;
	},
	localToWorld: function (local) {
		var localX = local[0], localY = local[1];
		local[0] = localX * this.m00 + localY * this.m01 + this.worldX;
		local[1] = localX * this.m10 + localY * this.m11 + this.worldY;
	}
};

spine.Slot = function (slotData, bone) {
	this.data = slotData;
	this.bone = bone;
	this.setToSetupPose();
};
spine.Slot.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	_attachmentTime: 0,
	attachment: null,
	attachmentVertices: [],
	setAttachment: function (attachment) {
		if (this.attachment == attachment) return;
		this.attachment = attachment;
		this._attachmentTime = this.bone.skeleton.time;
		this.attachmentVertices.length = 0;
	},
	setAttachmentTime: function (time) {
		this._attachmentTime = this.bone.skeleton.time - time;
	},
	getAttachmentTime: function () {
		return this.bone.skeleton.time - this._attachmentTime;
	},
	setToSetupPose: function () {
		var data = this.data;
		this.r = data.r;
		this.g = data.g;
		this.b = data.b;
		this.a = data.a;

		if (!data.attachmentName)
			this.setAttachment(null);
		else {
			var slotDatas = this.bone.skeleton.data.slots;
			for (var i = 0, n = slotDatas.length; i < n; i++) {
				if (slotDatas[i] == data) {
					this.attachment = null;
					this.setAttachment(this.bone.skeleton.getAttachmentBySlotIndex(i, data.attachmentName));
					break;
				}
			}
		}
	}
};

spine.IkConstraint = function (data, skeleton) {
	this.data = data;
	this.mix = data.mix;
	this.bendDirection = data.bendDirection;

	this.bones = [];
	for (var i = 0, n = data.bones.length; i < n; i++)
		this.bones.push(skeleton.findBone(data.bones[i].name));
	this.target = skeleton.findBone(data.target.name);
};
spine.IkConstraint.prototype = {
	apply: function () {
		var target = this.target;
		var bones = this.bones;
		switch (bones.length) {
		case 1:
			spine.IkConstraint.apply1(bones[0], target.worldX, target.worldY, this.mix);
			break;
		case 2:
			spine.IkConstraint.apply2(bones[0], bones[1], target.worldX, target.worldY, this.bendDirection, this.mix);
			break;
		}
	}
};
/** Adjusts the bone rotation so the tip is as close to the target position as possible. The target is specified in the world
 * coordinate system. */
spine.IkConstraint.apply1 = function (bone, targetX, targetY, alpha) {
	var parentRotation = (!bone.data.inheritRotation || !bone.parent) ? 0 : bone.parent.worldRotation;
	var rotation = bone.rotation;
	var rotationIK = Math.atan2(targetY - bone.worldY, targetX - bone.worldX) * spine.radDeg;
	if (bone.worldFlipX != (bone.worldFlipY != spine.Bone.yDown)) rotationIK = -rotationIK;
	rotationIK -= parentRotation;
	bone.rotationIK = rotation + (rotationIK - rotation) * alpha;
};
/** Adjusts the parent and child bone rotations so the tip of the child is as close to the target position as possible. The
 * target is specified in the world coordinate system.
 * @param child Any descendant bone of the parent. */
spine.IkConstraint.apply2 = function (parent, child, targetX, targetY, bendDirection, alpha) {
	var childRotation = child.rotation, parentRotation = parent.rotation;
	if (!alpha) {
		child.rotationIK = childRotation;
		parent.rotationIK = parentRotation;
		return;
	}
	var positionX, positionY, tempPosition = spine.temp;
	var parentParent = parent.parent;
	if (parentParent) {
		tempPosition[0] = targetX;
		tempPosition[1] = targetY;
		parentParent.worldToLocal(tempPosition);
		targetX = (tempPosition[0] - parent.x) * parentParent.worldScaleX;
		targetY = (tempPosition[1] - parent.y) * parentParent.worldScaleY;
	} else {
		targetX -= parent.x;
		targetY -= parent.y;
	}
	if (child.parent == parent) {
		positionX = child.x;
		positionY = child.y;
	} else {
		tempPosition[0] = child.x;
		tempPosition[1] = child.y;
		child.parent.localToWorld(tempPosition);
		parent.worldToLocal(tempPosition);
		positionX = tempPosition[0];
		positionY = tempPosition[1];
	}
	var childX = positionX * parent.worldScaleX, childY = positionY * parent.worldScaleY;
	var offset = Math.atan2(childY, childX);
	var len1 = Math.sqrt(childX * childX + childY * childY), len2 = child.data.length * child.worldScaleX;
	// Based on code by Ryan Juckett with permission: Copyright (c) 2008-2009 Ryan Juckett, http://www.ryanjuckett.com/
	var cosDenom = 2 * len1 * len2;
	if (cosDenom < 0.0001) {
		child.rotationIK = childRotation + (Math.atan2(targetY, targetX) * spine.radDeg - parentRotation - childRotation) * alpha;
		return;
	}
	var cos = (targetX * targetX + targetY * targetY - len1 * len1 - len2 * len2) / cosDenom;
	if (cos < -1)
		cos = -1;
	else if (cos > 1)
		cos = 1;
	var childAngle = Math.acos(cos) * bendDirection;
	var adjacent = len1 + len2 * cos, opposite = len2 * Math.sin(childAngle);
	var parentAngle = Math.atan2(targetY * adjacent - targetX * opposite, targetX * adjacent + targetY * opposite);
	var rotation = (parentAngle - offset) * spine.radDeg - parentRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	parent.rotationIK = parentRotation + rotation * alpha;
	rotation = (childAngle + offset) * spine.radDeg - childRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	child.rotationIK = childRotation + (rotation + parent.worldRotation - child.parent.worldRotation) * alpha;
};

spine.Skin = function (name) {
	this.name = name;
	this.attachments = {};
};
spine.Skin.prototype = {
	addAttachment: function (slotIndex, name, attachment) {
		this.attachments[slotIndex + ":" + name] = attachment;
	},
	getAttachment: function (slotIndex, name) {
		return this.attachments[slotIndex + ":" + name];
	},
	_attachAll: function (skeleton, oldSkin) {
		for (var key in oldSkin.attachments) {
			var colon = key.indexOf(":");
			var slotIndex = parseInt(key.substring(0, colon));
			var name = key.substring(colon + 1);
			var slot = skeleton.slots[slotIndex];
			if (slot.attachment && slot.attachment.name == name) {
				var attachment = this.getAttachment(slotIndex, name);
				if (attachment) slot.setAttachment(attachment);
			}
		}
	}
};

spine.Animation = function (name, timelines, duration) {
	this.name = name;
	this.timelines = timelines;
	this.duration = duration;
};
spine.Animation.prototype = {
	apply: function (skeleton, lastTime, time, loop, events) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, 1);
	},
	mix: function (skeleton, lastTime, time, loop, events, alpha) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, alpha);
	}
};
spine.Animation.binarySearch = function (values, target, step) {
	var low = 0;
	var high = Math.floor(values.length / step) - 2;
	if (!high) return step;
	var current = high >>> 1;
	while (true) {
		if (values[(current + 1) * step] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return (low + 1) * step;
		current = (low + high) >>> 1;
	}
};
spine.Animation.binarySearch1 = function (values, target) {
	var low = 0;
	var high = values.length - 2;
	if (!high) return 1;
	var current = high >>> 1;
	while (true) {
		if (values[current + 1] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return low + 1;
		current = (low + high) >>> 1;
	}
};
spine.Animation.linearSearch = function (values, target, step) {
	for (var i = 0, last = values.length - step; i <= last; i += step)
		if (values[i] > target) return i;
	return -1;
};

spine.Curves = function (frameCount) {
	this.curves = []; // type, x, y, ...
	//this.curves.length = (frameCount - 1) * 19/*BEZIER_SIZE*/;
};
spine.Curves.prototype = {
	setLinear: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 0/*LINEAR*/;
	},
	setStepped: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 1/*STEPPED*/;
	},
	/** Sets the control handle positions for an interpolation bezier curve used to transition from this keyframe to the next.
	 * cx1 and cx2 are from 0 to 1, representing the percent of time between the two keyframes. cy1 and cy2 are the percent of
	 * the difference between the keyframe's values. */
	setCurve: function (frameIndex, cx1, cy1, cx2, cy2) {
		var subdiv1 = 1 / 10/*BEZIER_SEGMENTS*/, subdiv2 = subdiv1 * subdiv1, subdiv3 = subdiv2 * subdiv1;
		var pre1 = 3 * subdiv1, pre2 = 3 * subdiv2, pre4 = 6 * subdiv2, pre5 = 6 * subdiv3;
		var tmp1x = -cx1 * 2 + cx2, tmp1y = -cy1 * 2 + cy2, tmp2x = (cx1 - cx2) * 3 + 1, tmp2y = (cy1 - cy2) * 3 + 1;
		var dfx = cx1 * pre1 + tmp1x * pre2 + tmp2x * subdiv3, dfy = cy1 * pre1 + tmp1y * pre2 + tmp2y * subdiv3;
		var ddfx = tmp1x * pre4 + tmp2x * pre5, ddfy = tmp1y * pre4 + tmp2y * pre5;
		var dddfx = tmp2x * pre5, dddfy = tmp2y * pre5;

		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var curves = this.curves;
		curves[i++] = 2/*BEZIER*/;
		
		var x = dfx, y = dfy;
		for (var n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			curves[i] = x;
			curves[i + 1] = y;
			dfx += ddfx;
			dfy += ddfy;
			ddfx += dddfx;
			ddfy += dddfy;
			x += dfx;
			y += dfy;
		}
	},
	getCurvePercent: function (frameIndex, percent) {
		percent = percent < 0 ? 0 : (percent > 1 ? 1 : percent);
		var curves = this.curves;
		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var type = curves[i];
		if (type === 0/*LINEAR*/) return percent;
		if (type == 1/*STEPPED*/) return 0;
		i++;
		var x = 0;
		for (var start = i, n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			x = curves[i];
			if (x >= percent) {
				var prevX, prevY;
				if (i == start) {
					prevX = 0;
					prevY = 0;
				} else {
					prevX = curves[i - 2];
					prevY = curves[i - 1];
				}
				return prevY + (curves[i + 1] - prevY) * (percent - prevX) / (x - prevX);
			}
		}
		var y = curves[i - 1];
		return y + (1 - y) * (percent - x) / (1 - x); // Last point is 1,1.
	}
};

spine.RotateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, angle, ...
	this.frames.length = frameCount * 2;
};
spine.RotateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, angle) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = angle;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 2]) { // Time is after last frame.
			var amount = bone.data.rotation + frames[frames.length - 1] - bone.rotation;
			while (amount > 180)
				amount -= 360;
			while (amount < -180)
				amount += 360;
			bone.rotation += amount * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 2);
		var prevFrameValue = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 2/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 2 - 1, percent);

		var amount = frames[frameIndex + 1/*FRAME_VALUE*/] - prevFrameValue;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		amount = bone.data.rotation + (prevFrameValue + amount * percent) - bone.rotation;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		bone.rotation += amount * alpha;
	}
};

spine.TranslateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.TranslateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.x += (bone.data.x + frames[frames.length - 2] - bone.x) * alpha;
			bone.y += (bone.data.y + frames[frames.length - 1] - bone.y) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.x += (bone.data.x + prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent - bone.x) * alpha;
		bone.y += (bone.data.y + prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent - bone.y) * alpha;
	}
};

spine.ScaleTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.ScaleTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.scaleX += (bone.data.scaleX * frames[frames.length - 2] - bone.scaleX) * alpha;
			bone.scaleY += (bone.data.scaleY * frames[frames.length - 1] - bone.scaleY) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.scaleX += (bone.data.scaleX * (prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent) - bone.scaleX) * alpha;
		bone.scaleY += (bone.data.scaleY * (prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent) - bone.scaleY) * alpha;
	}
};

spine.ColorTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, r, g, b, a, ...
	this.frames.length = frameCount * 5;
};
spine.ColorTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 5;
	},
	setFrame: function (frameIndex, time, r, g, b, a) {
		frameIndex *= 5;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = r;
		this.frames[frameIndex + 2] = g;
		this.frames[frameIndex + 3] = b;
		this.frames[frameIndex + 4] = a;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var r, g, b, a;
		if (time >= frames[frames.length - 5]) {
			// Time is after last frame.
			var i = frames.length - 1;
			r = frames[i - 3];
			g = frames[i - 2];
			b = frames[i - 1];
			a = frames[i];
		} else {
			// Interpolate between the previous frame and the current frame.
			var frameIndex = spine.Animation.binarySearch(frames, time, 5);
			var prevFrameR = frames[frameIndex - 4];
			var prevFrameG = frames[frameIndex - 3];
			var prevFrameB = frames[frameIndex - 2];
			var prevFrameA = frames[frameIndex - 1];
			var frameTime = frames[frameIndex];
			var percent = 1 - (time - frameTime) / (frames[frameIndex - 5/*PREV_FRAME_TIME*/] - frameTime);
			percent = this.curves.getCurvePercent(frameIndex / 5 - 1, percent);

			r = prevFrameR + (frames[frameIndex + 1/*FRAME_R*/] - prevFrameR) * percent;
			g = prevFrameG + (frames[frameIndex + 2/*FRAME_G*/] - prevFrameG) * percent;
			b = prevFrameB + (frames[frameIndex + 3/*FRAME_B*/] - prevFrameB) * percent;
			a = prevFrameA + (frames[frameIndex + 4/*FRAME_A*/] - prevFrameA) * percent;
		}
		var slot = skeleton.slots[this.slotIndex];
		if (alpha < 1) {
			slot.r += (r - slot.r) * alpha;
			slot.g += (g - slot.g) * alpha;
			slot.b += (b - slot.b) * alpha;
			slot.a += (a - slot.a) * alpha;
		} else {
			slot.r = r;
			slot.g = g;
			slot.b = b;
			slot.a = a;
		}
	}
};

spine.AttachmentTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.attachmentNames = [];
	this.attachmentNames.length = frameCount;
};
spine.AttachmentTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, attachmentName) {
		this.frames[frameIndex] = time;
		this.attachmentNames[frameIndex] = attachmentName;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;

		var frameIndex = time >= frames[frames.length - 1] ? frames.length - 1 : spine.Animation.binarySearch1(frames, time) - 1;
		if (frames[frameIndex] < lastTime) return;

		var attachmentName = this.attachmentNames[frameIndex];
		skeleton.slots[this.slotIndex].setAttachment(
			!attachmentName ? null : skeleton.getAttachmentBySlotIndex(this.slotIndex, attachmentName));
	}
};

spine.EventTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.events = [];
	this.events.length = frameCount;
};
spine.EventTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, event) {
		this.frames[frameIndex] = time;
		this.events[frameIndex] = event;
	},
	/** Fires events for frames > lastTime and <= time. */
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		if (!firedEvents) return;

		var frames = this.frames;
		var frameCount = frames.length;

		if (lastTime > time) { // Fire events after last time for looped animations.
			this.apply(skeleton, lastTime, Number.MAX_VALUE, firedEvents, alpha);
			lastTime = -1;
		} else if (lastTime >= frames[frameCount - 1]) // Last time is after last frame.
			return;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (lastTime < frames[0])
			frameIndex = 0;
		else {
			frameIndex = spine.Animation.binarySearch1(frames, lastTime);
			var frame = frames[frameIndex];
			while (frameIndex > 0) { // Fire multiple events with the same frame.
				if (frames[frameIndex - 1] != frame) break;
				frameIndex--;
			}
		}
		var events = this.events;
		for (; frameIndex < frameCount && time >= frames[frameIndex]; frameIndex++)
			firedEvents.push(events[frameIndex]);
	}
};

spine.DrawOrderTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.drawOrders = [];
	this.drawOrders.length = frameCount;
};
spine.DrawOrderTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, drawOrder) {
		this.frames[frameIndex] = time;
		this.drawOrders[frameIndex] = drawOrder;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (time >= frames[frames.length - 1]) // Time is after last frame.
			frameIndex = frames.length - 1;
		else
			frameIndex = spine.Animation.binarySearch1(frames, time) - 1;

		var drawOrder = skeleton.drawOrder;
		var slots = skeleton.slots;
		var drawOrderToSetupIndex = this.drawOrders[frameIndex];
		if (!drawOrderToSetupIndex) {
			for (var i = 0, n = slots.length; i < n; i++)
				drawOrder[i] = slots[i];
		} else {
			for (var i = 0, n = drawOrderToSetupIndex.length; i < n; i++)
				drawOrder[i] = skeleton.slots[drawOrderToSetupIndex[i]];
		}

	}
};

spine.FfdTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = [];
	this.frames.length = frameCount;
	this.frameVertices = [];
	this.frameVertices.length = frameCount;
};
spine.FfdTimeline.prototype = {
	slotIndex: 0,
	attachment: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, vertices) {
		this.frames[frameIndex] = time;
		this.frameVertices[frameIndex] = vertices;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var slot = skeleton.slots[this.slotIndex];
		if (slot.attachment != this.attachment) return;

		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameVertices = this.frameVertices;
		var vertexCount = frameVertices[0].length;

		var vertices = slot.attachmentVertices;
		if (vertices.length != vertexCount) alpha = 1;
		vertices.length = vertexCount;

		if (time >= frames[frames.length - 1]) { // Time is after last frame.
			var lastVertices = frameVertices[frames.length - 1];
			if (alpha < 1) {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] += (lastVertices[i] - vertices[i]) * alpha;
			} else {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] = lastVertices[i];
			}
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch1(frames, time);
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 1] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex - 1, percent < 0 ? 0 : (percent > 1 ? 1 : percent));

		var prevVertices = frameVertices[frameIndex - 1];
		var nextVertices = frameVertices[frameIndex];

		if (alpha < 1) {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] += (prev + (nextVertices[i] - prev) * percent - vertices[i]) * alpha;
			}
		} else {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] = prev + (nextVertices[i] - prev) * percent;
			}
		}
	}
};

spine.IkConstraintTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, mix, bendDirection, ...
	this.frames.length = frameCount * 3;
};
spine.IkConstraintTimeline.prototype = {
	ikConstraintIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, mix, bendDirection) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = mix;
		this.frames[frameIndex + 2] = bendDirection;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var ikConstraint = skeleton.ikConstraints[this.ikConstraintIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			ikConstraint.mix += (frames[frames.length - 2] - ikConstraint.mix) * alpha;
			ikConstraint.bendDirection = frames[frames.length - 1];
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameMix = frames[frameIndex + -2/*PREV_FRAME_MIX*/];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		var mix = prevFrameMix + (frames[frameIndex + 1/*FRAME_MIX*/] - prevFrameMix) * percent;
		ikConstraint.mix += (mix - ikConstraint.mix) * alpha;
		ikConstraint.bendDirection = frames[frameIndex + -1/*PREV_FRAME_BEND_DIRECTION*/];
	}
};

spine.FlipXTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipXTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipX = frames[frameIndex + 1] != 0;
	}
};

spine.FlipYTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipYTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipY = frames[frameIndex + 1] != 0;
	}
};

spine.SkeletonData = function () {
	this.bones = [];
	this.slots = [];
	this.skins = [];
	this.events = [];
	this.animations = [];
	this.ikConstraints = [];
};
spine.SkeletonData.prototype = {
	name: null,
	defaultSkin: null,
	width: 0, height: 0,
	version: null, hash: null,
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			if (slots[i].name == slotName) return slot[i];
		}
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].name == slotName) return i;
		return -1;
	},
	/** @return May be null. */
	findSkin: function (skinName) {
		var skins = this.skins;
		for (var i = 0, n = skins.length; i < n; i++)
			if (skins[i].name == skinName) return skins[i];
		return null;
	},
	/** @return May be null. */
	findEvent: function (eventName) {
		var events = this.events;
		for (var i = 0, n = events.length; i < n; i++)
			if (events[i].name == eventName) return events[i];
		return null;
	},
	/** @return May be null. */
	findAnimation: function (animationName) {
		var animations = this.animations;
		for (var i = 0, n = animations.length; i < n; i++)
			if (animations[i].name == animationName) return animations[i];
		return null;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].name == ikConstraintName) return ikConstraints[i];
		return null;
	}
};

spine.Skeleton = function (skeletonData) {
	this.data = skeletonData;

	this.bones = [];
	for (var i = 0, n = skeletonData.bones.length; i < n; i++) {
		var boneData = skeletonData.bones[i];
		var parent = !boneData.parent ? null : this.bones[skeletonData.bones.indexOf(boneData.parent)];
		this.bones.push(new spine.Bone(boneData, this, parent));
	}

	this.slots = [];
	this.drawOrder = [];
	for (var i = 0, n = skeletonData.slots.length; i < n; i++) {
		var slotData = skeletonData.slots[i];
		var bone = this.bones[skeletonData.bones.indexOf(slotData.boneData)];
		var slot = new spine.Slot(slotData, bone);
		this.slots.push(slot);
		this.drawOrder.push(slot);
	}
	
	this.ikConstraints = [];
	for (var i = 0, n = skeletonData.ikConstraints.length; i < n; i++)
		this.ikConstraints.push(new spine.IkConstraint(skeletonData.ikConstraints[i], this));

	this.boneCache = [];
	this.updateCache();
};
spine.Skeleton.prototype = {
	x: 0, y: 0,
	skin: null,
	r: 1, g: 1, b: 1, a: 1,
	time: 0,
	flipX: false, flipY: false,
	/** Caches information about bones and IK constraints. Must be called if bones or IK constraints are added or removed. */
	updateCache: function () {
		var ikConstraints = this.ikConstraints;
		var ikConstraintsCount = ikConstraints.length;

		var arrayCount = ikConstraintsCount + 1;
		var boneCache = this.boneCache;
		if (boneCache.length > arrayCount) boneCache.length = arrayCount;
		for (var i = 0, n = boneCache.length; i < n; i++)
			boneCache[i].length = 0;
		while (boneCache.length < arrayCount)
			boneCache[boneCache.length] = [];

		var nonIkBones = boneCache[0];
		var bones = this.bones;

		outer:
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			var current = bone;
			do {
				for (var ii = 0; ii < ikConstraintsCount; ii++) {
					var ikConstraint = ikConstraints[ii];
					var parent = ikConstraint.bones[0];
					var child= ikConstraint.bones[ikConstraint.bones.length - 1];
					while (true) {
						if (current == child) {
							boneCache[ii].push(bone);
							boneCache[ii + 1].push(bone);
							continue outer;
						}
						if (child == parent) break;
						child = child.parent;
					}
				}
				current = current.parent;
			} while (current);
			nonIkBones[nonIkBones.length] = bone;
		}
	},
	/** Updates the world transform for each bone. */
	updateWorldTransform: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			bone.rotationIK = bone.rotation;
		}
		var i = 0, last = this.boneCache.length - 1;
		while (true) {
			var cacheBones = this.boneCache[i];
			for (var ii = 0, nn = cacheBones.length; ii < nn; ii++)
				cacheBones[ii].updateWorldTransform();
			if (i == last) break;
			this.ikConstraints[i].apply();
			i++;
		}
	},
	/** Sets the bones and slots to their setup pose values. */
	setToSetupPose: function () {
		this.setBonesToSetupPose();
		this.setSlotsToSetupPose();
	},
	setBonesToSetupPose: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			bones[i].setToSetupPose();

		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++) {
			var ikConstraint = ikConstraints[i];
			ikConstraint.bendDirection = ikConstraint.data.bendDirection;
			ikConstraint.mix = ikConstraint.data.mix;
		}
	},
	setSlotsToSetupPose: function () {
		var slots = this.slots;
		var drawOrder = this.drawOrder;
		for (var i = 0, n = slots.length; i < n; i++) {
			drawOrder[i] = slots[i];
			slots[i].setToSetupPose(i);
		}
	},
	/** @return May return null. */
	getRootBone: function () {
		return this.bones.length ? this.bones[0] : null;
	},
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return slots[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return i;
		return -1;
	},
	setSkinByName: function (skinName) {
		var skin = this.data.findSkin(skinName);
		if (!skin) throw "Skin not found: " + skinName;
		this.setSkin(skin);
	},
	/** Sets the skin used to look up attachments before looking in the {@link SkeletonData#getDefaultSkin() default skin}. 
	 * Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was 
	 * no old skin, each slot's setup mode attachment is attached from the new skin.
	 * @param newSkin May be null. */
	setSkin: function (newSkin) {
		if (newSkin) {
			if (this.skin)
				newSkin._attachAll(this, this.skin);
			else {
				var slots = this.slots;
				for (var i = 0, n = slots.length; i < n; i++) {
					var slot = slots[i];
					var name = slot.data.attachmentName;
					if (name) {
						var attachment = newSkin.getAttachment(i, name);
						if (attachment) slot.setAttachment(attachment);
					}
				}
			}
		}
		this.skin = newSkin;
	},
	/** @return May be null. */
	getAttachmentBySlotName: function (slotName, attachmentName) {
		return this.getAttachmentBySlotIndex(this.data.findSlotIndex(slotName), attachmentName);
	},
	/** @return May be null. */
	getAttachmentBySlotIndex: function (slotIndex, attachmentName) {
		if (this.skin) {
			var attachment = this.skin.getAttachment(slotIndex, attachmentName);
			if (attachment) return attachment;
		}
		if (this.data.defaultSkin) return this.data.defaultSkin.getAttachment(slotIndex, attachmentName);
		return null;
	},
	/** @param attachmentName May be null. */
	setAttachment: function (slotName, attachmentName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			var slot = slots[i];
			if (slot.data.name == slotName) {
				var attachment = null;
				if (attachmentName) {
					attachment = this.getAttachmentBySlotIndex(i, attachmentName);
					if (!attachment) throw "Attachment not found: " + attachmentName + ", for slot: " + slotName;
				}
				slot.setAttachment(attachment);
				return;
			}
		}
		throw "Slot not found: " + slotName;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].data.name == ikConstraintName) return ikConstraints[i];
		return null;
	},
	update: function (delta) {
		this.time += delta;
	}
};

spine.EventData = function (name) {
	this.name = name;
};
spine.EventData.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.Event = function (data) {
	this.data = data;
};
spine.Event.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.AttachmentType = {
	region: 0,
	boundingbox: 1,
	mesh: 2,
	skinnedmesh: 3
};

spine.RegionAttachment = function (name) {
	this.name = name;
	this.offset = [];
	this.offset.length = 8;
	this.uvs = [];
	this.uvs.length = 8;
};
spine.RegionAttachment.prototype = {
	type: spine.AttachmentType.region,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	width: 0, height: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	setUVs: function (u, v, u2, v2, rotate) {
		var uvs = this.uvs;
		if (rotate) {
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v2;
			uvs[4/*X3*/] = u;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v;
			uvs[0/*X1*/] = u2;
			uvs[1/*Y1*/] = v2;
		} else {
			uvs[0/*X1*/] = u;
			uvs[1/*Y1*/] = v2;
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v;
			uvs[4/*X3*/] = u2;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v2;
		}
	},
	updateOffset: function () {
		var regionScaleX = this.width / this.regionOriginalWidth * this.scaleX;
		var regionScaleY = this.height / this.regionOriginalHeight * this.scaleY;
		var localX = -this.width / 2 * this.scaleX + this.regionOffsetX * regionScaleX;
		var localY = -this.height / 2 * this.scaleY + this.regionOffsetY * regionScaleY;
		var localX2 = localX + this.regionWidth * regionScaleX;
		var localY2 = localY + this.regionHeight * regionScaleY;
		var radians = this.rotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		var localXCos = localX * cos + this.x;
		var localXSin = localX * sin;
		var localYCos = localY * cos + this.y;
		var localYSin = localY * sin;
		var localX2Cos = localX2 * cos + this.x;
		var localX2Sin = localX2 * sin;
		var localY2Cos = localY2 * cos + this.y;
		var localY2Sin = localY2 * sin;
		var offset = this.offset;
		offset[0/*X1*/] = localXCos - localYSin;
		offset[1/*Y1*/] = localYCos + localXSin;
		offset[2/*X2*/] = localXCos - localY2Sin;
		offset[3/*Y2*/] = localY2Cos + localXSin;
		offset[4/*X3*/] = localX2Cos - localY2Sin;
		offset[5/*Y3*/] = localY2Cos + localX2Sin;
		offset[6/*X4*/] = localX2Cos - localYSin;
		offset[7/*Y4*/] = localYCos + localX2Sin;
	},
	computeVertices: function (x, y, bone, vertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var offset = this.offset;
		vertices[0/*X1*/] = offset[0/*X1*/] * m00 + offset[1/*Y1*/] * m01 + x;
		vertices[1/*Y1*/] = offset[0/*X1*/] * m10 + offset[1/*Y1*/] * m11 + y;
		vertices[2/*X2*/] = offset[2/*X2*/] * m00 + offset[3/*Y2*/] * m01 + x;
		vertices[3/*Y2*/] = offset[2/*X2*/] * m10 + offset[3/*Y2*/] * m11 + y;
		vertices[4/*X3*/] = offset[4/*X3*/] * m00 + offset[5/*X3*/] * m01 + x;
		vertices[5/*X3*/] = offset[4/*X3*/] * m10 + offset[5/*X3*/] * m11 + y;
		vertices[6/*X4*/] = offset[6/*X4*/] * m00 + offset[7/*Y4*/] * m01 + x;
		vertices[7/*Y4*/] = offset[6/*X4*/] * m10 + offset[7/*Y4*/] * m11 + y;
	}
};

spine.MeshAttachment = function (name) {
	this.name = name;
};
spine.MeshAttachment.prototype = {
	type: spine.AttachmentType.mesh,
	vertices: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function () {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var bone = slot.bone;
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		var verticesCount = vertices.length;
		if (slot.attachmentVertices.length == verticesCount) vertices = slot.attachmentVertices;
		for (var i = 0; i < verticesCount; i += 2) {
			var vx = vertices[i];
			var vy = vertices[i + 1];
			worldVertices[i] = vx * m00 + vy * m01 + x;
			worldVertices[i + 1] = vx * m10 + vy * m11 + y;
		}
	}
};

spine.SkinnedMeshAttachment = function (name) {
	this.name = name;
};
spine.SkinnedMeshAttachment.prototype = {
	type: spine.AttachmentType.skinnedmesh,
	bones: null,
	weights: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function (u, v, u2, v2, rotate) {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var skeletonBones = slot.bone.skeleton.bones;
		var weights = this.weights;
		var bones = this.bones;

		var w = 0, v = 0, b = 0, f = 0, n = bones.length, nn;
		var wx, wy, bone, vx, vy, weight;
		if (!slot.attachmentVertices.length) {
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3) {
					bone = skeletonBones[bones[v]];
					vx = weights[b];
					vy = weights[b + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		} else {
			var ffd = slot.attachmentVertices;
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3, f += 2) {
					bone = skeletonBones[bones[v]];
					vx = weights[b] + ffd[f];
					vy = weights[b + 1] + ffd[f + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		}
	}
};

spine.BoundingBoxAttachment = function (name) {
	this.name = name;
	this.vertices = [];
};
spine.BoundingBoxAttachment.prototype = {
	type: spine.AttachmentType.boundingbox,
	computeWorldVertices: function (x, y, bone, worldVertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		for (var i = 0, n = vertices.length; i < n; i += 2) {
			var px = vertices[i];
			var py = vertices[i + 1];
			worldVertices[i] = px * m00 + py * m01 + x;
			worldVertices[i + 1] = px * m10 + py * m11 + y;
		}
	}
};

spine.AnimationStateData = function (skeletonData) {
	this.skeletonData = skeletonData;
	this.animationToMixTime = {};
};
spine.AnimationStateData.prototype = {
	defaultMix: 0,
	setMixByName: function (fromName, toName, duration) {
		var from = this.skeletonData.findAnimation(fromName);
		if (!from) throw "Animation not found: " + fromName;
		var to = this.skeletonData.findAnimation(toName);
		if (!to) throw "Animation not found: " + toName;
		this.setMix(from, to, duration);
	},
	setMix: function (from, to, duration) {
		this.animationToMixTime[from.name + ":" + to.name] = duration;
	},
	getMix: function (from, to) {
		var key = from.name + ":" + to.name;
		return this.animationToMixTime.hasOwnProperty(key) ? this.animationToMixTime[key] : this.defaultMix;
	}
};

spine.TrackEntry = function () {};
spine.TrackEntry.prototype = {
	next: null, previous: null,
	animation: null,
	loop: false,
	delay: 0, time: 0, lastTime: -1, endTime: 0,
	timeScale: 1,
	mixTime: 0, mixDuration: 0, mix: 1,
	onStart: null, onEnd: null, onComplete: null, onEvent: null
};

spine.AnimationState = function (stateData) {
	this.data = stateData;
	this.tracks = [];
	this.events = [];
};
spine.AnimationState.prototype = {
	onStart: null,
	onEnd: null,
	onComplete: null,
	onEvent: null,
	timeScale: 1,
	update: function (delta) {
		delta *= this.timeScale;
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			current.time += delta * current.timeScale;
			if (current.previous) {
				var previousDelta = delta * current.previous.timeScale;
				current.previous.time += previousDelta;
				current.mixTime += previousDelta;
			}

			var next = current.next;
			if (next) {
				next.time = current.lastTime - next.delay;
				if (next.time >= 0) this.setCurrent(i, next);
			} else {
				// End non-looping animation when it reaches its end time and there is no next entry.
				if (!current.loop && current.lastTime >= current.endTime) this.clearTrack(i);
			}
		}
	},
	apply: function (skeleton) {
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			this.events.length = 0;

			var time = current.time;
			var lastTime = current.lastTime;
			var endTime = current.endTime;
			var loop = current.loop;
			if (!loop && time > endTime) time = endTime;

			var previous = current.previous;
			if (!previous) {
				if (current.mix == 1)
					current.animation.apply(skeleton, current.lastTime, time, loop, this.events);
				else
					current.animation.mix(skeleton, current.lastTime, time, loop, this.events, current.mix);
			} else {
				var previousTime = previous.time;
				if (!previous.loop && previousTime > previous.endTime) previousTime = previous.endTime;
				previous.animation.apply(skeleton, previousTime, previousTime, previous.loop, null);

				var alpha = current.mixTime / current.mixDuration * current.mix;
				if (alpha >= 1) {
					alpha = 1;
					current.previous = null;
				}
				current.animation.mix(skeleton, current.lastTime, time, loop, this.events, alpha);
			}

			for (var ii = 0, nn = this.events.length; ii < nn; ii++) {
				var event = this.events[ii];
				if (current.onEvent) current.onEvent(i, event);
				if (this.onEvent) this.onEvent(i, event);
			}

			// Check if completed the animation or a loop iteration.
			if (loop ? (lastTime % endTime > time % endTime) : (lastTime < endTime && time >= endTime)) {
				var count = Math.floor(time / endTime);
				if (current.onComplete) current.onComplete(i, count);
				if (this.onComplete) this.onComplete(i, count);
			}

			current.lastTime = current.time;
		}
	},
	clearTracks: function () {
		for (var i = 0, n = this.tracks.length; i < n; i++)
			this.clearTrack(i);
		this.tracks.length = 0; 
	},
	clearTrack: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return;
		var current = this.tracks[trackIndex];
		if (!current) return;

		if (current.onEnd) current.onEnd(trackIndex);
		if (this.onEnd) this.onEnd(trackIndex);

		this.tracks[trackIndex] = null;
	},
	_expandToIndex: function (index) {
		if (index < this.tracks.length) return this.tracks[index];
		while (index >= this.tracks.length)
			this.tracks.push(null);
		return null;
	},
	setCurrent: function (index, entry) {
		var current = this._expandToIndex(index);
		if (current) {
			var previous = current.previous;
			current.previous = null;

			if (current.onEnd) current.onEnd(index);
			if (this.onEnd) this.onEnd(index);

			entry.mixDuration = this.data.getMix(current.animation, entry.animation);
			if (entry.mixDuration > 0) {
				entry.mixTime = 0;
				// If a mix is in progress, mix from the closest animation.
				if (previous && current.mixTime / current.mixDuration < 0.5)
					entry.previous = previous;
				else
					entry.previous = current;
			}
		}

		this.tracks[index] = entry;

		if (entry.onStart) entry.onStart(index);
		if (this.onStart) this.onStart(index);
	},
	setAnimationByName: function (trackIndex, animationName, loop) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.setAnimation(trackIndex, animation, loop);
	},
	/** Set the current animation. Any queued animations are cleared. */
	setAnimation: function (trackIndex, animation, loop) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;
		this.setCurrent(trackIndex, entry);
		return entry;
	},
	addAnimationByName: function (trackIndex, animationName, loop, delay) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.addAnimation(trackIndex, animation, loop, delay);
	},
	/** Adds an animation to be played delay seconds after the current or last queued animation.
	 * @param delay May be <= 0 to use duration of previous animation minus any mix duration plus the negative delay. */
	addAnimation: function (trackIndex, animation, loop, delay) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;

		var last = this._expandToIndex(trackIndex);
		if (last) {
			while (last.next)
				last = last.next;
			last.next = entry;
		} else
			this.tracks[trackIndex] = entry;

		if (delay <= 0) {
			if (last)
				delay += last.endTime - this.data.getMix(last.animation, animation);
			else
				delay = 0;
		}
		entry.delay = delay;

		return entry;
	},
	/** May be null. */
	getCurrent: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return null;
		return this.tracks[trackIndex];
	}
};

spine.SkeletonJson = function (attachmentLoader) {
	this.attachmentLoader = attachmentLoader;
};
spine.SkeletonJson.prototype = {
	scale: 1,
	readSkeletonData: function (root, name) {
		var skeletonData = new spine.SkeletonData();
		skeletonData.name = name;

		// Skeleton.
		var skeletonMap = root["skeleton"];
		if (skeletonMap) {
			skeletonData.hash = skeletonMap["hash"];
			skeletonData.version = skeletonMap["spine"];
			skeletonData.width = skeletonMap["width"] || 0;
			skeletonData.height = skeletonMap["height"] || 0;
		}

		// Bones.
		var bones = root["bones"];
		for (var i = 0, n = bones.length; i < n; i++) {
			var boneMap = bones[i];
			var parent = null;
			if (boneMap["parent"]) {
				parent = skeletonData.findBone(boneMap["parent"]);
				if (!parent) throw "Parent bone not found: " + boneMap["parent"];
			}
			var boneData = new spine.BoneData(boneMap["name"], parent);
			boneData.length = (boneMap["length"] || 0) * this.scale;
			boneData.x = (boneMap["x"] || 0) * this.scale;
			boneData.y = (boneMap["y"] || 0) * this.scale;
			boneData.rotation = (boneMap["rotation"] || 0);
			boneData.scaleX = boneMap.hasOwnProperty("scaleX") ? boneMap["scaleX"] : 1;
			boneData.scaleY = boneMap.hasOwnProperty("scaleY") ? boneMap["scaleY"] : 1;
			boneData.inheritScale = boneMap.hasOwnProperty("inheritScale") ? boneMap["inheritScale"] : true;
			boneData.inheritRotation = boneMap.hasOwnProperty("inheritRotation") ? boneMap["inheritRotation"] : true;
			skeletonData.bones.push(boneData);
		}

		// IK constraints.
		var ik = root["ik"];
		if (ik) {
			for (var i = 0, n = ik.length; i < n; i++) {
				var ikMap = ik[i];
				var ikConstraintData = new spine.IkConstraintData(ikMap["name"]);

				var bones = ikMap["bones"];
				for (var ii = 0, nn = bones.length; ii < nn; ii++) {
					var bone = skeletonData.findBone(bones[ii]);
					if (!bone) throw "IK bone not found: " + bones[ii];
					ikConstraintData.bones.push(bone);
				}

				ikConstraintData.target = skeletonData.findBone(ikMap["target"]);
				if (!ikConstraintData.target) throw "Target bone not found: " + ikMap["target"];

				ikConstraintData.bendDirection = (!ikMap.hasOwnProperty("bendPositive") || ikMap["bendPositive"]) ? 1 : -1;
				ikConstraintData.mix = ikMap.hasOwnProperty("mix") ? ikMap["mix"] : 1;

				skeletonData.ikConstraints.push(ikConstraintData);
			}
		}

		// Slots.
		var slots = root["slots"];
		for (var i = 0, n = slots.length; i < n; i++) {
			var slotMap = slots[i];
			var boneData = skeletonData.findBone(slotMap["bone"]);
			if (!boneData) throw "Slot bone not found: " + slotMap["bone"];
			var slotData = new spine.SlotData(slotMap["name"], boneData);

			var color = slotMap["color"];
			if (color) {
				slotData.r = this.toColor(color, 0);
				slotData.g = this.toColor(color, 1);
				slotData.b = this.toColor(color, 2);
				slotData.a = this.toColor(color, 3);
			}

			slotData.attachmentName = slotMap["attachment"];
			slotData.blendMode = spine.BlendMode[slotMap["blend"] || "normal"];

			skeletonData.slots.push(slotData);
		}

		// Skins.
		var skins = root["skins"];
		for (var skinName in skins) {
			if (!skins.hasOwnProperty(skinName)) continue;
			var skinMap = skins[skinName];
			var skin = new spine.Skin(skinName);
			for (var slotName in skinMap) {
				if (!skinMap.hasOwnProperty(slotName)) continue;
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var slotEntry = skinMap[slotName];
				for (var attachmentName in slotEntry) {
					if (!slotEntry.hasOwnProperty(attachmentName)) continue;
					var attachment = this.readAttachment(skin, attachmentName, slotEntry[attachmentName]);
					if (attachment) skin.addAttachment(slotIndex, attachmentName, attachment);
				}
			}
			skeletonData.skins.push(skin);
			if (skin.name == "default") skeletonData.defaultSkin = skin;
		}

		// Events.
		var events = root["events"];
		for (var eventName in events) {
			if (!events.hasOwnProperty(eventName)) continue;
			var eventMap = events[eventName];
			var eventData = new spine.EventData(eventName);
			eventData.intValue = eventMap["int"] || 0;
			eventData.floatValue = eventMap["float"] || 0;
			eventData.stringValue = eventMap["string"] || null;
			skeletonData.events.push(eventData);
		}

		// Animations.
		var animations = root["animations"];
		for (var animationName in animations) {
			if (!animations.hasOwnProperty(animationName)) continue;
			this.readAnimation(animationName, animations[animationName], skeletonData);
		}

		return skeletonData;
	},
	readAttachment: function (skin, name, map) {
		name = map["name"] || name;

		var type = spine.AttachmentType[map["type"] || "region"];
		var path = map["path"] || name;
		
		var scale = this.scale;
		if (type == spine.AttachmentType.region) {
			var region = this.attachmentLoader.newRegionAttachment(skin, name, path);
			if (!region) return null;
			region.path = path;
			region.x = (map["x"] || 0) * scale;
			region.y = (map["y"] || 0) * scale;
			region.scaleX = map.hasOwnProperty("scaleX") ? map["scaleX"] : 1;
			region.scaleY = map.hasOwnProperty("scaleY") ? map["scaleY"] : 1;
			region.rotation = map["rotation"] || 0;
			region.width = (map["width"] || 0) * scale;
			region.height = (map["height"] || 0) * scale;

			var color = map["color"];
			if (color) {
				region.r = this.toColor(color, 0);
				region.g = this.toColor(color, 1);
				region.b = this.toColor(color, 2);
				region.a = this.toColor(color, 3);
			}

			region.updateOffset();
			return region;
		} else if (type == spine.AttachmentType.mesh) {
			var mesh = this.attachmentLoader.newMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path; 
			mesh.vertices = this.getFloatArray(map, "vertices", scale);
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = this.getFloatArray(map, "uvs", 1);
			mesh.updateUVs();

			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}

			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.skinnedmesh) {
			var mesh = this.attachmentLoader.newSkinnedMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path;

			var uvs = this.getFloatArray(map, "uvs", 1);
			var vertices = this.getFloatArray(map, "vertices", 1);
			var weights = [];
			var bones = [];
			for (var i = 0, n = vertices.length; i < n; ) {
				var boneCount = vertices[i++] | 0;
				bones[bones.length] = boneCount;
				for (var nn = i + boneCount * 4; i < nn; ) {
					bones[bones.length] = vertices[i];
					weights[weights.length] = vertices[i + 1] * scale;
					weights[weights.length] = vertices[i + 2] * scale;
					weights[weights.length] = vertices[i + 3];
					i += 4;
				}
			}
			mesh.bones = bones;
			mesh.weights = weights;
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = uvs;
			mesh.updateUVs();
			
			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}
			
			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.boundingbox) {
			var attachment = this.attachmentLoader.newBoundingBoxAttachment(skin, name);
			var vertices = map["vertices"];
			for (var i = 0, n = vertices.length; i < n; i++)
				attachment.vertices.push(vertices[i] * scale);
			return attachment;
		}
		throw "Unknown attachment type: " + type;
	},
	readAnimation: function (name, map, skeletonData) {
		var timelines = [];
		var duration = 0;

		var slots = map["slots"];
		for (var slotName in slots) {
			if (!slots.hasOwnProperty(slotName)) continue;
			var slotMap = slots[slotName];
			var slotIndex = skeletonData.findSlotIndex(slotName);

			for (var timelineName in slotMap) {
				if (!slotMap.hasOwnProperty(timelineName)) continue;
				var values = slotMap[timelineName];
				if (timelineName == "color") {
					var timeline = new spine.ColorTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var color = valueMap["color"];
						var r = this.toColor(color, 0);
						var g = this.toColor(color, 1);
						var b = this.toColor(color, 2);
						var a = this.toColor(color, 3);
						timeline.setFrame(frameIndex, valueMap["time"], r, g, b, a);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 5 - 5]);

				} else if (timelineName == "attachment") {
					var timeline = new spine.AttachmentTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex++, valueMap["time"], valueMap["name"]);
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);

				} else
					throw "Invalid timeline type for a slot: " + timelineName + " (" + slotName + ")";
			}
		}

		var bones = map["bones"];
		for (var boneName in bones) {
			if (!bones.hasOwnProperty(boneName)) continue;
			var boneIndex = skeletonData.findBoneIndex(boneName);
			if (boneIndex == -1) throw "Bone not found: " + boneName;
			var boneMap = bones[boneName];

			for (var timelineName in boneMap) {
				if (!boneMap.hasOwnProperty(timelineName)) continue;
				var values = boneMap[timelineName];
				if (timelineName == "rotate") {
					var timeline = new spine.RotateTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap["angle"]);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);

				} else if (timelineName == "translate" || timelineName == "scale") {
					var timeline;
					var timelineScale = 1;
					if (timelineName == "scale")
						timeline = new spine.ScaleTimeline(values.length);
					else {
						timeline = new spine.TranslateTimeline(values.length);
						timelineScale = this.scale;
					}
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var x = (valueMap["x"] || 0) * timelineScale;
						var y = (valueMap["y"] || 0) * timelineScale;
						timeline.setFrame(frameIndex, valueMap["time"], x, y);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 3 - 3]);

				} else if (timelineName == "flipX" || timelineName == "flipY") {
					var x = timelineName == "flipX";
					var timeline = x ? new spine.FlipXTimeline(values.length) : new spine.FlipYTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var field = x ? "x" : "y";
					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap[field] || false);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);
				} else
					throw "Invalid timeline type for a bone: " + timelineName + " (" + boneName + ")";
			}
		}

		var ikMap = map["ik"];
		for (var ikConstraintName in ikMap) {
			if (!ikMap.hasOwnProperty(ikConstraintName)) continue;
			var ikConstraint = skeletonData.findIkConstraint(ikConstraintName);
			var values = ikMap[ikConstraintName];
			var timeline = new spine.IkConstraintTimeline(values.length);
			timeline.ikConstraintIndex = skeletonData.ikConstraints.indexOf(ikConstraint);
			var frameIndex = 0;
			for (var i = 0, n = values.length; i < n; i++) {
				var valueMap = values[i];
				var mix = valueMap.hasOwnProperty("mix") ? valueMap["mix"] : 1;
				var bendDirection = (!valueMap.hasOwnProperty("bendPositive") || valueMap["bendPositive"]) ? 1 : -1;
				timeline.setFrame(frameIndex, valueMap["time"], mix, bendDirection);
				this.readCurve(timeline, frameIndex, valueMap);
				frameIndex++;
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.frameCount * 3 - 3]);
		}

		var ffd = map["ffd"];
		for (var skinName in ffd) {
			var skin = skeletonData.findSkin(skinName);
			var slotMap = ffd[skinName];
			for (slotName in slotMap) {
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var meshMap = slotMap[slotName];
				for (var meshName in meshMap) {
					var values = meshMap[meshName];
					var timeline = new spine.FfdTimeline(values.length);
					var attachment = skin.getAttachment(slotIndex, meshName);
					if (!attachment) throw "FFD attachment not found: " + meshName;
					timeline.slotIndex = slotIndex;
					timeline.attachment = attachment;
					
					var isMesh = attachment.type == spine.AttachmentType.mesh;
					var vertexCount;
					if (isMesh)
						vertexCount = attachment.vertices.length;
					else
						vertexCount = attachment.weights.length / 3 * 2;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var vertices;
						if (!valueMap["vertices"]) {
							if (isMesh)
								vertices = attachment.vertices;
							else {
								vertices = [];
								vertices.length = vertexCount;
							}
						} else {
							var verticesValue = valueMap["vertices"];
							var vertices = [];
							vertices.length = vertexCount;
							var start = valueMap["offset"] || 0;
							var nn = verticesValue.length;
							if (this.scale == 1) {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii];
							} else {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii] * this.scale;
							}
							if (isMesh) {
								var meshVertices = attachment.vertices;
								for (var ii = 0, nn = vertices.length; ii < nn; ii++)
									vertices[ii] += meshVertices[ii];
							}
						}
						
						timeline.setFrame(frameIndex, valueMap["time"], vertices);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines[timelines.length] = timeline;
					duration = Math.max(duration, timeline.frames[timeline.frameCount - 1]);
				}
			}
		}

		var drawOrderValues = map["drawOrder"];
		if (!drawOrderValues) drawOrderValues = map["draworder"];
		if (drawOrderValues) {
			var timeline = new spine.DrawOrderTimeline(drawOrderValues.length);
			var slotCount = skeletonData.slots.length;
			var frameIndex = 0;
			for (var i = 0, n = drawOrderValues.length; i < n; i++) {
				var drawOrderMap = drawOrderValues[i];
				var drawOrder = null;
				if (drawOrderMap["offsets"]) {
					drawOrder = [];
					drawOrder.length = slotCount;
					for (var ii = slotCount - 1; ii >= 0; ii--)
						drawOrder[ii] = -1;
					var offsets = drawOrderMap["offsets"];
					var unchanged = [];
					unchanged.length = slotCount - offsets.length;
					var originalIndex = 0, unchangedIndex = 0;
					for (var ii = 0, nn = offsets.length; ii < nn; ii++) {
						var offsetMap = offsets[ii];
						var slotIndex = skeletonData.findSlotIndex(offsetMap["slot"]);
						if (slotIndex == -1) throw "Slot not found: " + offsetMap["slot"];
						// Collect unchanged items.
						while (originalIndex != slotIndex)
							unchanged[unchangedIndex++] = originalIndex++;
						// Set changed items.
						drawOrder[originalIndex + offsetMap["offset"]] = originalIndex++;
					}
					// Collect remaining unchanged items.
					while (originalIndex < slotCount)
						unchanged[unchangedIndex++] = originalIndex++;
					// Fill in unchanged items.
					for (var ii = slotCount - 1; ii >= 0; ii--)
						if (drawOrder[ii] == -1) drawOrder[ii] = unchanged[--unchangedIndex];
				}
				timeline.setFrame(frameIndex++, drawOrderMap["time"], drawOrder);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		var events = map["events"];
		if (events) {
			var timeline = new spine.EventTimeline(events.length);
			var frameIndex = 0;
			for (var i = 0, n = events.length; i < n; i++) {
				var eventMap = events[i];
				var eventData = skeletonData.findEvent(eventMap["name"]);
				if (!eventData) throw "Event not found: " + eventMap["name"];
				var event = new spine.Event(eventData);
				event.intValue = eventMap.hasOwnProperty("int") ? eventMap["int"] : eventData.intValue;
				event.floatValue = eventMap.hasOwnProperty("float") ? eventMap["float"] : eventData.floatValue;
				event.stringValue = eventMap.hasOwnProperty("string") ? eventMap["string"] : eventData.stringValue;
				timeline.setFrame(frameIndex++, eventMap["time"], event);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		skeletonData.animations.push(new spine.Animation(name, timelines, duration));
	},
	readCurve: function (timeline, frameIndex, valueMap) {
		var curve = valueMap["curve"];
		if (!curve) 
			timeline.curves.setLinear(frameIndex);
		else if (curve == "stepped")
			timeline.curves.setStepped(frameIndex);
		else if (curve instanceof Array)
			timeline.curves.setCurve(frameIndex, curve[0], curve[1], curve[2], curve[3]);
	},
	toColor: function (hexString, colorIndex) {
		if (hexString.length != 8) throw "Color hexidecimal length must be 8, recieved: " + hexString;
		return parseInt(hexString.substring(colorIndex * 2, (colorIndex * 2) + 2), 16) / 255;
	},
	getFloatArray: function (map, name, scale) {
		var list = map[name];
		var values = new spine.Float32Array(list.length);
		var i = 0, n = list.length;
		if (scale == 1) {
			for (; i < n; i++)
				values[i] = list[i];
		} else {
			for (; i < n; i++)
				values[i] = list[i] * scale;
		}
		return values;
	},
	getIntArray: function (map, name) {
		var list = map[name];
		var values = new spine.Uint16Array(list.length);
		for (var i = 0, n = list.length; i < n; i++)
			values[i] = list[i] | 0;
		return values;
	}
};

spine.Atlas = function (atlasText, textureLoader) {
	this.textureLoader = textureLoader;
	this.pages = [];
	this.regions = [];

	var reader = new spine.AtlasReader(atlasText);
	var tuple = [];
	tuple.length = 4;
	var page = null;
	while (true) {
		var line = reader.readLine();
		if (line === null) break;
		line = reader.trim(line);
		if (!line.length)
			page = null;
		else if (!page) {
			page = new spine.AtlasPage();
			page.name = line;

			if (reader.readTuple(tuple) == 2) { // size is only optional for an atlas packed with an old TexturePacker.
				page.width = parseInt(tuple[0]);
				page.height = parseInt(tuple[1]);
				reader.readTuple(tuple);
			}
			page.format = spine.Atlas.Format[tuple[0]];

			reader.readTuple(tuple);
			page.minFilter = spine.Atlas.TextureFilter[tuple[0]];
			page.magFilter = spine.Atlas.TextureFilter[tuple[1]];

			var direction = reader.readValue();
			page.uWrap = spine.Atlas.TextureWrap.clampToEdge;
			page.vWrap = spine.Atlas.TextureWrap.clampToEdge;
			if (direction == "x")
				page.uWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "y")
				page.vWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "xy")
				page.uWrap = page.vWrap = spine.Atlas.TextureWrap.repeat;

			textureLoader.load(page, line, this);

			this.pages.push(page);

		} else {
			var region = new spine.AtlasRegion();
			region.name = line;
			region.page = page;

			region.rotate = reader.readValue() == "true";

			reader.readTuple(tuple);
			var x = parseInt(tuple[0]);
			var y = parseInt(tuple[1]);

			reader.readTuple(tuple);
			var width = parseInt(tuple[0]);
			var height = parseInt(tuple[1]);

			region.u = x / page.width;
			region.v = y / page.height;
			if (region.rotate) {
				region.u2 = (x + height) / page.width;
				region.v2 = (y + width) / page.height;
			} else {
				region.u2 = (x + width) / page.width;
				region.v2 = (y + height) / page.height;
			}
			region.x = x;
			region.y = y;
			region.width = Math.abs(width);
			region.height = Math.abs(height);

			if (reader.readTuple(tuple) == 4) { // split is optional
				region.splits = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

				if (reader.readTuple(tuple) == 4) { // pad is optional, but only present with splits
					region.pads = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

					reader.readTuple(tuple);
				}
			}

			region.originalWidth = parseInt(tuple[0]);
			region.originalHeight = parseInt(tuple[1]);

			reader.readTuple(tuple);
			region.offsetX = parseInt(tuple[0]);
			region.offsetY = parseInt(tuple[1]);

			region.index = parseInt(reader.readValue());

			this.regions.push(region);
		}
	}
};
spine.Atlas.prototype = {
	findRegion: function (name) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++)
			if (regions[i].name == name) return regions[i];
		return null;
	},
	dispose: function () {
		var pages = this.pages;
		for (var i = 0, n = pages.length; i < n; i++)
			this.textureLoader.unload(pages[i].rendererObject);
	},
	updateUVs: function (page) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++) {
			var region = regions[i];
			if (region.page != page) continue;
			region.u = region.x / page.width;
			region.v = region.y / page.height;
			if (region.rotate) {
				region.u2 = (region.x + region.height) / page.width;
				region.v2 = (region.y + region.width) / page.height;
			} else {
				region.u2 = (region.x + region.width) / page.width;
				region.v2 = (region.y + region.height) / page.height;
			}
		}
	}
};

spine.Atlas.Format = {
	alpha: 0,
	intensity: 1,
	luminanceAlpha: 2,
	rgb565: 3,
	rgba4444: 4,
	rgb888: 5,
	rgba8888: 6
};

spine.Atlas.TextureFilter = {
	nearest: 0,
	linear: 1,
	mipMap: 2,
	mipMapNearestNearest: 3,
	mipMapLinearNearest: 4,
	mipMapNearestLinear: 5,
	mipMapLinearLinear: 6
};

spine.Atlas.TextureWrap = {
	mirroredRepeat: 0,
	clampToEdge: 1,
	repeat: 2
};

spine.AtlasPage = function () {};
spine.AtlasPage.prototype = {
	name: null,
	format: null,
	minFilter: null,
	magFilter: null,
	uWrap: null,
	vWrap: null,
	rendererObject: null,
	width: 0,
	height: 0
};

spine.AtlasRegion = function () {};
spine.AtlasRegion.prototype = {
	page: null,
	name: null,
	x: 0, y: 0,
	width: 0, height: 0,
	u: 0, v: 0, u2: 0, v2: 0,
	offsetX: 0, offsetY: 0,
	originalWidth: 0, originalHeight: 0,
	index: 0,
	rotate: false,
	splits: null,
	pads: null
};

spine.AtlasReader = function (text) {
	this.lines = text.split(/\r\n|\r|\n/);
};
spine.AtlasReader.prototype = {
	index: 0,
	trim: function (value) {
		return value.replace(/^\s+|\s+$/g, "");
	},
	readLine: function () {
		if (this.index >= this.lines.length) return null;
		return this.lines[this.index++];
	},
	readValue: function () {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		return this.trim(line.substring(colon + 1));
	},
	/** Returns the number of tuple values read (1, 2 or 4). */
	readTuple: function (tuple) {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		var i = 0, lastMatch = colon + 1;
		for (; i < 3; i++) {
			var comma = line.indexOf(",", lastMatch);
			if (comma == -1) break;
			tuple[i] = this.trim(line.substr(lastMatch, comma - lastMatch));
			lastMatch = comma + 1;
		}
		tuple[i] = this.trim(line.substring(lastMatch));
		return i + 1;
	}
};

spine.AtlasAttachmentLoader = function (atlas) {
	this.atlas = atlas;
};
spine.AtlasAttachmentLoader.prototype = {
	newRegionAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (region attachment: " + name + ")";
		var attachment = new spine.RegionAttachment(name);
		attachment.rendererObject = region;
		attachment.setUVs(region.u, region.v, region.u2, region.v2, region.rotate);
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (mesh attachment: " + name + ")";
		var attachment = new spine.MeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newSkinnedMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (skinned mesh attachment: " + name + ")";
		var attachment = new spine.SkinnedMeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newBoundingBoxAttachment: function (skin, name) {
		return new spine.BoundingBoxAttachment(name);
	}
};

spine.SkeletonBounds = function () {
	this.polygonPool = [];
	this.polygons = [];
	this.boundingBoxes = [];
};
spine.SkeletonBounds.prototype = {
	minX: 0, minY: 0, maxX: 0, maxY: 0,
	update: function (skeleton, updateAabb) {
		var slots = skeleton.slots;
		var slotCount = slots.length;
		var x = skeleton.x, y = skeleton.y;
		var boundingBoxes = this.boundingBoxes;
		var polygonPool = this.polygonPool;
		var polygons = this.polygons;

		boundingBoxes.length = 0;
		for (var i = 0, n = polygons.length; i < n; i++)
			polygonPool.push(polygons[i]);
		polygons.length = 0;

		for (var i = 0; i < slotCount; i++) {
			var slot = slots[i];
			var boundingBox = slot.attachment;
			if (boundingBox.type != spine.AttachmentType.boundingbox) continue;
			boundingBoxes.push(boundingBox);

			var poolCount = polygonPool.length, polygon;
			if (poolCount > 0) {
				polygon = polygonPool[poolCount - 1];
				polygonPool.splice(poolCount - 1, 1);
			} else
				polygon = [];
			polygons.push(polygon);

			polygon.length = boundingBox.vertices.length;
			boundingBox.computeWorldVertices(x, y, slot.bone, polygon);
		}

		if (updateAabb) this.aabbCompute();
	},
	aabbCompute: function () {
		var polygons = this.polygons;
		var minX = Number.MAX_VALUE, minY = Number.MAX_VALUE, maxX = Number.MIN_VALUE, maxY = Number.MIN_VALUE;
		for (var i = 0, n = polygons.length; i < n; i++) {
			var vertices = polygons[i];
			for (var ii = 0, nn = vertices.length; ii < nn; ii += 2) {
				var x = vertices[ii];
				var y = vertices[ii + 1];
				minX = Math.min(minX, x);
				minY = Math.min(minY, y);
				maxX = Math.max(maxX, x);
				maxY = Math.max(maxY, y);
			}
		}
		this.minX = minX;
		this.minY = minY;
		this.maxX = maxX;
		this.maxY = maxY;
	},
	/** Returns true if the axis aligned bounding box contains the point. */
	aabbContainsPoint: function (x, y) {
		return x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY;
	},
	/** Returns true if the axis aligned bounding box intersects the line segment. */
	aabbIntersectsSegment: function (x1, y1, x2, y2) {
		var minX = this.minX, minY = this.minY, maxX = this.maxX, maxY = this.maxY;
		if ((x1 <= minX && x2 <= minX) || (y1 <= minY && y2 <= minY) || (x1 >= maxX && x2 >= maxX) || (y1 >= maxY && y2 >= maxY))
			return false;
		var m = (y2 - y1) / (x2 - x1);
		var y = m * (minX - x1) + y1;
		if (y > minY && y < maxY) return true;
		y = m * (maxX - x1) + y1;
		if (y > minY && y < maxY) return true;
		var x = (minY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		x = (maxY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		return false;
	},
	/** Returns true if the axis aligned bounding box intersects the axis aligned bounding box of the specified bounds. */
	aabbIntersectsSkeleton: function (bounds) {
		return this.minX < bounds.maxX && this.maxX > bounds.minX && this.minY < bounds.maxY && this.maxY > bounds.minY;
	},
	/** Returns the first bounding box attachment that contains the point, or null. When doing many checks, it is usually more
	 * efficient to only call this method if {@link #aabbContainsPoint(float, float)} returns true. */
	containsPoint: function (x, y) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (this.polygonContainsPoint(polygons[i], x, y)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns the first bounding box attachment that contains the line segment, or null. When doing many checks, it is usually
	 * more efficient to only call this method if {@link #aabbIntersectsSegment(float, float, float, float)} returns true. */
	intersectsSegment: function (x1, y1, x2, y2) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (polygons[i].intersectsSegment(x1, y1, x2, y2)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns true if the polygon contains the point. */
	polygonContainsPoint: function (polygon, x, y) {
		var nn = polygon.length;
		var prevIndex = nn - 2;
		var inside = false;
		for (var ii = 0; ii < nn; ii += 2) {
			var vertexY = polygon[ii + 1];
			var prevY = polygon[prevIndex + 1];
			if ((vertexY < y && prevY >= y) || (prevY < y && vertexY >= y)) {
				var vertexX = polygon[ii];
				if (vertexX + (y - vertexY) / (prevY - vertexY) * (polygon[prevIndex] - vertexX) < x) inside = !inside;
			}
			prevIndex = ii;
		}
		return inside;
	},
	/** Returns true if the polygon contains the line segment. */
	polygonIntersectsSegment: function (polygon, x1, y1, x2, y2) {
		var nn = polygon.length;
		var width12 = x1 - x2, height12 = y1 - y2;
		var det1 = x1 * y2 - y1 * x2;
		var x3 = polygon[nn - 2], y3 = polygon[nn - 1];
		for (var ii = 0; ii < nn; ii += 2) {
			var x4 = polygon[ii], y4 = polygon[ii + 1];
			var det2 = x3 * y4 - y3 * x4;
			var width34 = x3 - x4, height34 = y3 - y4;
			var det3 = width12 * height34 - height12 * width34;
			var x = (det1 * width34 - width12 * det2) / det3;
			if (((x >= x3 && x <= x4) || (x >= x4 && x <= x3)) && ((x >= x1 && x <= x2) || (x >= x2 && x <= x1))) {
				var y = (det1 * height34 - height12 * det2) / det3;
				if (((y >= y3 && y <= y4) || (y >= y4 && y <= y3)) && ((y >= y1 && y <= y2) || (y >= y2 && y <= y1))) return true;
			}
			x3 = x4;
			y3 = y4;
		}
		return false;
	},
	getPolygon: function (attachment) {
		var index = this.boundingBoxes.indexOf(attachment);
		return index == -1 ? null : this.polygons[index];
	},
	getWidth: function () {
		return this.maxX - this.minX;
	},
	getHeight: function () {
		return this.maxY - this.minY;
	}
};
var e,aa=document.getElementById("canvasBackground");function ba(a,b){var c=a.userAgent.match(b);return c&&1<c.length&&c[1]||""}
var ca=new function(){this.userAgent=void 0;void 0===this.userAgent&&(this.userAgent=void 0!==navigator?navigator.userAgent:"");var a=ba(this,/(ipod|iphone|ipad)/i).toLowerCase(),b=!/like android/i.test(this.userAgent)&&/android/i.test(this.userAgent),c=ba(this,/version\/(\d+(\.\d+)?)/i),d=/tablet/i.test(this.userAgent),g=!d&&/[^-]mobi/i.test(this.userAgent);this.U={};this.Ae={};this.yh={};/opera|opr/i.test(this.userAgent)?(this.name="Opera",this.U.opera=!0,this.U.version=c||ba(this,/(?:opera|opr)[\s\/](\d+(\.\d+)?)/i)):
/windows phone/i.test(this.userAgent)?(this.name="Windows Phone",this.Ae.pX=!0,this.U.ez=!0,this.U.version=ba(this,/iemobile\/(\d+(\.\d+)?)/i)):/msie|trident/i.test(this.userAgent)?(this.name="Internet Explorer",this.U.ez=!0,this.U.version=ba(this,/(?:msie |rv:)(\d+(\.\d+)?)/i)):/chrome|crios|crmo/i.test(this.userAgent)?(this.name="Chrome",this.U.chrome=!0,this.U.version=ba(this,/(?:chrome|crios|crmo)\/(\d+(\.\d+)?)/i)):a?(this.name="iphone"==a?"iPhone":"ipad"==a?"iPad":"iPod",c&&(this.U.version=
c)):/sailfish/i.test(this.userAgent)?(this.name="Sailfish",this.U.P_=!0,this.U.version=ba(this,/sailfish\s?browser\/(\d+(\.\d+)?)/i)):/seamonkey\//i.test(this.userAgent)?(this.name="SeaMonkey",this.U.U_=!0,this.U.version=ba(this,/seamonkey\/(\d+(\.\d+)?)/i)):/firefox|iceweasel/i.test(this.userAgent)?(this.name="Firefox",this.U.cF=!0,this.U.version=ba(this,/(?:firefox|iceweasel)[ \/](\d+(\.\d+)?)/i),/\((mobile|tablet);[^\)]*rv:[\d\.]+\)/i.test(this.userAgent)&&(this.Ae.TY=!0)):/silk/i.test(this.userAgent)?
(this.name="Amazon Silk",this.U.BI=!0,this.U.version=ba(this,/silk\/(\d+(\.\d+)?)/i)):b?(this.name="Android",this.U.vB=!0,this.U.version=c):/phantom/i.test(this.userAgent)?(this.name="PhantomJS",this.U.p_=!0,this.U.version=ba(this,/phantomjs\/(\d+(\.\d+)?)/i)):/blackberry|\bbb\d+/i.test(this.userAgent)||/rim\stablet/i.test(this.userAgent)?(this.name="BlackBerry",this.U.zD=!0,this.U.version=c||ba(this,/blackberry[\d]+\/(\d+(\.\d+)?)/i)):/(web|hpw)os/i.test(this.userAgent)?(this.name="WebOS",this.U.gK=
!0,this.U.version=c||ba(this,/w(?:eb)?osbrowser\/(\d+(\.\d+)?)/i),/touchpad\//i.test(this.userAgent)&&(this.yh.FW=!0)):/bada/i.test(this.userAgent)?(this.name="Bada",this.U.rD=!0,this.U.version=ba(this,/dolfin\/(\d+(\.\d+)?)/i)):/tizen/i.test(this.userAgent)?(this.name="Tizen",this.U.xW=!0,this.U.version=ba(this,/(?:tizen\s?)?browser\/(\d+(\.\d+)?)/i)||c):/safari/i.test(this.userAgent)&&(this.name="Safari",this.U.aI=!0,this.U.version=c);/(apple)?webkit/i.test(this.userAgent)?(this.name=this.name||
"Webkit",this.U.u0=!0,!this.U.version&&c&&(this.U.version=c)):!this.opera&&/gecko\//i.test(this.userAgent)&&(this.name=this.name||"Gecko",this.U.$Y=!0,this.U.version=this.U.version||ba(this,/gecko\/(\d+(\.\d+)?)/i));b||this.BI?this.Ae.kY=!0:a&&(this.Ae.Kt=!0);c="";a?(c=ba(this,/os (\d+([_\s]\d+)*) like mac os x/i),c=c.replace(/[_\s]/g,".")):b?c=ba(this,/android[ \/-](\d+(\.\d+)*)/i):this.pX?c=ba(this,/windows phone (?:os)?\s?(\d+(\.\d+)*)/i):this.gK?c=ba(this,/(?:web|hpw)os\/(\d+(\.\d+)*)/i):this.zD?
c=ba(this,/rim\stablet\sos\s(\d+(\.\d+)*)/i):this.rD?c=ba(this,/bada\/(\d+(\.\d+)*)/i):this.xW&&(c=ba(this,/tizen[\/\s](\d+(\.\d+)*)/i));c&&(this.Ae.version=c);c=c.split(".")[0];if(d||"ipad"==a||b&&(3==c||4==c&&!g)||this.BI)this.yh.AJ=!0;else if(g||"iphone"==a||"ipod"==a||b||this.zD||this.gK||this.rD)this.yh.ju=!0;this.dy={Io:!1,ep:!1,x:!1};this.ez&&10<=this.U.version||this.chrome&&20<=this.U.version||this.cF&&20<=this.U.version||this.aI&&6<=this.U.version||this.opera&&10<=this.U.version||this.Kt&&
this.Ae.version&&6<=this.Ae.version.split(".")[0]?this.dy.Io=!0:this.ez&&10>this.U.version||this.chrome&&20>this.U.version||this.cF&&20>this.U.version||this.aI&&6>this.U.version||this.opera&&10>this.U.version||this.Kt&&this.Ae.version&&6>this.Ae.version.split(".")[0]?this.dy.ep=!0:this.dy.x=!0;try{this.U.Sr=this.U.version?parseFloat(this.U.version.match(/\d+(\.\d+)?/)[0],10):0}catch(k){this.U.Sr=0}try{this.Ae.Sr=this.Ae.version?parseFloat(this.Ae.version.match(/\d+(\.\d+)?/)[0],10):0}catch(l){this.Ae.Sr=
0}};function da(a,b){this.x=a;this.y=b}e=da.prototype;e.length=function(){return Math.sqrt(this.x*this.x+this.y*this.y)};e.bP=function(a){var b=this.x-a.x;a=this.y-a.y;return Math.sqrt(b*b+a*a)};e.direction=function(){return 180*Math.atan2(-this.y,this.x)/Math.PI};e.Zc=function(){return new da(this.x,this.y)};e.add=function(a){return new da(this.x+a.x,this.y+a.y)};e.scale=function(a){return new da(a*this.x,a*this.y)};
e.rotate=function(a){var b=Math.sin(a*Math.PI/180);a=Math.cos(a*Math.PI/180);return new da(a*this.x+b*this.y,-b*this.x+a*this.y)};function ea(a,b){return a.x*b.x+a.y*b.y}e.normalize=function(){var a=Math.sqrt(this.x*this.x+this.y*this.y);return 0===a?new da(0,0):new da(this.x/a,this.y/a)};
e.ix=function(a,b,c){var d=Math.min(8,this.length()/4),g;g=this.normalize().scale(2*d);g=new da(this.x-g.x,this.y-g.y);var k=g.add((new da(this.y,-this.x)).normalize().scale(d)),d=g.add((new da(this.y,-this.x)).normalize().scale(-d)),l=f.context;l.strokeStyle=c;l.beginPath();l.moveTo(a,b);l.lineTo(a+g.x,b+g.y);l.lineTo(a+k.x,b+k.y);l.lineTo(a+this.x,b+this.y);l.lineTo(a+d.x,b+d.y);l.lineTo(a+g.x,b+g.y);l.stroke()};
function fa(a){this.mq=4294967296;this.Io=1664525;this.ep=1013904223;this.state=void 0===a?Math.floor(Math.random()*(this.mq-1)):a}fa.prototype.Zc=function(){var a=new fa;a.mq=this.mq;a.Io=this.Io;a.ep=this.ep;a.state=this.state;return a};fa.prototype.random=function(a){var b=1;void 0!==a&&(b=a);this.state=(this.Io*this.state+this.ep)%this.mq;return this.state/this.mq*b};function ga(a,b){var c=ha,d=b-a,g=1;void 0!==d&&(g=d);c=Math.floor(c.random(g+1));return a+c}var ha=new fa;
function ia(){this.pL="";this.Jv=[];this.Go=[];this.om=[];this.to=[];this.Bg=[];ka(this,"start");ka(this,"load");ka(this,"game")}function ka(a,b){a.Bg[b]||(a.Go[b]=0,a.om[b]=0,a.to[b]=0,a.Bg[b]=[],a.Jv[b]=!1)}e=ia.prototype;e.loaded=function(a){return this.Bg[a]?this.om[a]:0};e.complete=function(a){return this.Bg[a]?this.om[a]+this.to[a]===this.Go[a]:!0};e.vn=function(a){return this.Bg[a]?100*(this.om[a]+this.to[a])/this.Go[a]:100};
e.Yg=function(a){this.om[a]+=1;this.complete(a)&&la("Load Complete",{TG:a})};e.Uj=function(a){this.to[a]+=1;la("Load Failed",{TG:a})};function ma(a,b,c){var d=na;d.Bg[b]||ka(d,b);d.Bg[b].push(a);d.Go[b]+=c}e.Si=function(a){var b;if(!this.Jv[a])if(this.Jv[a]=!0,this.Bg[a]&&0!==this.Bg[a].length)for(b=0;b<this.Bg[a].length;b+=1)this.Bg[a][b].Si(a,this.pL);else la("Load Complete",{TG:a})};var na=new ia;function oa(a){this.context=this.canvas=void 0;this.height=this.width=0;a&&pa(this,a)}
function pa(a,b){a.canvas=b;a.context=b.getContext("2d");a.width=b.width;a.height=b.height}oa.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height);this.context.beginPath();this.context.moveTo(0,0);this.context.lineTo(-1,-1);this.context.closePath();this.context.stroke()};oa.prototype.clearColor=function(a){var b=this.context.fillStyle;this.context.fillStyle=a;this.context.fillRect(0,0,this.width,this.height);this.context.fillStyle=b};
function qa(a,b,c,d,g,k){var l=f;l.context.save();!1===k?(l.context.fillStyle=g,l.context.fillRect(a,b,c,d)):!0===k?(l.context.strokeStyle=g,l.context.strokeRect(a,b,c,d)):(void 0!==g&&(l.context.fillStyle=g,l.context.fillRect(a,b,c,d)),void 0!==k&&(l.context.strokeStyle=k,l.context.strokeRect(a,b,c,d)));l.context.restore()}
function ra(a,b,c,d,g,k,l){a.context.save();void 0===k&&(k=8);d<2*k&&(k=Math.floor(d/2));g<2*k&&(k=Math.floor(g/2));a.context.beginPath();a.context.moveTo(b+k,c);a.context.arcTo(b+d,c,b+d,c+g,k);a.context.arcTo(b+d,c+g,b,c+g,k);a.context.arcTo(b,c+g,b,c,k);a.context.arcTo(b,c,b+d,c,k);a.context.closePath();"black"===!1?(a.context.fillStyle=l,a.context.fill()):("black"===!0?a.context.strokeStyle=l:(void 0!==l&&(a.context.fillStyle=l,a.context.fill()),a.context.strokeStyle="black"),a.context.stroke());
a.context.restore()}function sa(a,b,c,d){var g;a.context.save();a.context.beginPath();a.context.moveTo(b[0],c[0]);for(g=1;g<b.length;g+=1)a.context.lineTo(b[g],c[g]);a.context.closePath();void 0!==d&&(a.context.fillStyle=d,a.context.fill());a.context.restore()}
oa.prototype.dg=function(a,b,c,d,g,k,l){this.context.save();this.context.font=g;!1===k?(this.context.fillStyle=d,this.context.fillText(a,b,c)):!0===k?(this.context.strokeStyle=d,this.context.strokeText(a,b,c)):(void 0!==d&&(this.context.fillStyle=d,this.context.fillText(a,b,c)),void 0!==k&&(l&&(this.context.lineWidth=l),this.context.strokeStyle=k,this.context.strokeText(a,b,c)));this.context.restore()};oa.prototype.Lr=function(a,b){this.context.font=b;return this.context.measureText(a).width};
var f=new oa(aa);function ta(a,b,c){this.name=a;this.N=b;this.aS=c;this.Vf=[];this.Fx=[];ma(this,this.aS,this.N)}ta.prototype.Si=function(a,b){function c(){na.Uj(a)}function d(){na.Yg(a)}var g,k;for(g=0;g<this.Vf.length;g+=1)k=this.Fx[g],0!==k.toLowerCase().indexOf("http:")&&0!==k.toLowerCase().indexOf("https:")&&(k=b+k),this.Vf[g].src=k,this.Vf[g].addEventListener("load",d,!1),this.Vf[g].addEventListener("error",c,!1)};
ta.prototype.complete=function(){var a;for(a=0;a<this.Vf.length;a+=1)if(!this.Vf[a].complete||0===this.Vf[a].width)return!1;return!0};function ua(a,b,c){0<=b&&b<a.N&&(a.Vf[b]=new Image,a.Fx[b]=c)}ta.prototype.b=function(a,b){0<=a&&a<this.N&&(this.Vf[a]=b,this.Fx[a]="")};ta.prototype.nb=function(a,b,c,d,g,k,l,m,p){this.Vf[a]&&this.Vf[a].complete&&(void 0===m&&(m=d),void 0===p&&(p=g),0>=d||0>=g||0!==Math.round(m)&&0!==Math.round(p)&&f.context.drawImage(this.Vf[a],b,c,d,g,k,l,m,p))};
function h(a,b,c,d,g,k,l,m,p,w){this.name=a;this.aj=b;this.N=c;this.width=d;this.height=g;this.Da=k;this.Ea=l;this.vj=m;this.uj=p;this.yH=w;this.Ui=[];this.Wi=[];this.Yi=[];this.bi=[];this.ai=[];this.Xi=[];this.Zi=[]}e=h.prototype;e.b=function(a,b,c,d,g,k,l,m){0<=a&&a<this.N&&(this.Ui[a]=b,this.Wi[a]=c,this.Yi[a]=d,this.bi[a]=g,this.ai[a]=k,this.Xi[a]=l,this.Zi[a]=m)};
function va(a,b,c,d){var g;g=new ta(a+"_Texture",1,a);ua(g,0,b);b=new h(a,g,1,c,d,0,0,c,d,1);b.b(0,0,0,0,c,d,0,0);na.Si(a);return b}e.complete=function(){return this.aj.complete()};e.B=function(a,b,c){a=(Math.round(a)%this.N+this.N)%this.N;this.aj.nb(this.Ui[a],this.Wi[a],this.Yi[a],this.bi[a],this.ai[a],b-this.Da+this.Xi[a],c-this.Ea+this.Zi[a])};
e.Tk=function(a,b,c,d){var g=f.context,k=g.globalAlpha;g.globalAlpha=d;a=(Math.round(a)%this.N+this.N)%this.N;this.aj.nb(this.Ui[a],this.Wi[a],this.Yi[a],this.bi[a],this.ai[a],b-this.Da+this.Xi[a],c-this.Ea+this.Zi[a]);g.globalAlpha=k};
e.ib=function(a,b,c,d,g,k,l){var m=f.context;1E-4>Math.abs(d)||1E-4>Math.abs(g)||(a=(Math.round(a)%this.N+this.N)%this.N,m.save(),m.translate(b,c),m.rotate(-k*Math.PI/180),m.scale(d,g),m.globalAlpha=l,this.aj.nb(this.Ui[a],this.Wi[a],this.Yi[a],this.bi[a],this.ai[a],this.Xi[a]-this.Da,this.Zi[a]-this.Ea),m.restore())};
e.Og=function(a,b,c,d,g,k){var l=f.context,m=l.globalAlpha;0!==this.width&&0!==this.height&&(a=(Math.round(a)%this.N+this.N)%this.N,l.globalAlpha=k,d/=this.width,g/=this.height,this.aj.nb(this.Ui[a],this.Wi[a],this.Yi[a],this.bi[a],this.ai[a],b+d*this.Xi[a],c+g*this.Zi[a],d*this.bi[a],g*this.ai[a]),l.globalAlpha=m)};
e.Mc=function(a,b,c,d,g,k,l,m,p,w){var z,v,C,x,t,A,B,ja,xa,Xa,Rb,Ib,Sb,Tb,Jb,Ld;0!==this.width&&0!==this.height&&(void 0===l&&(l=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.width/3)),void 0===p&&(p=Math.floor(this.height/3)),void 0===w&&(w=Math.floor(this.height/3)),d<l+m&&(l=Math.round(l*d/(l+m)),m=d-l),g<p+w&&(p=Math.round(p*g/(p+w)),w=g-p),xa=this.width,z=l,v=this.width-l-m,C=m,x=z+v,Xa=this.height,t=p,A=this.height-p-w,B=w,ja=t+A,Rb=l,l=d-l-m,Ib=b+Rb,Sb=b+Rb+l,Tb=p,p=g-p-w,Jb=c+Tb,
Ld=c+Tb+p,d===this.width&&g===this.height?this.Tk(a,b+this.Da,c+this.Ea,k):g===this.height?(this.ne(a,z,0,v,Xa,Ib,c,l,g,k),this.nb(a,0,0,z,Xa,b,c,k),this.nb(a,x,0,C,Xa,Sb,c,k)):d===this.width?(this.ne(a,0,t,xa,A,b,Jb,d,p,k),this.nb(a,0,0,xa,t,b,c,k),this.nb(a,0,ja,xa,B,b,Ld,k)):(this.ne(a,z,t,v,A,Ib,Jb,l,p,k),this.ne(a,z,0,v,t,Ib,c,l,Tb,k),this.ne(a,0,t,z,A,b,Jb,Rb,p,k),this.ne(a,x,t,C,A,Sb,Jb,m,p,k),this.ne(a,z,ja,v,B,Ib,Ld,l,w,k),this.nb(a,0,0,z,t,b,c,k),this.nb(a,0,ja,z,B,b,Ld,k),this.nb(a,x,0,
C,t,Sb,c,k),this.nb(a,x,ja,C,B,Sb,Ld,k)))};
e.Uk=function(a,b,c,d,g,k,l,m){var p=f.context,w=p.globalAlpha,z,v,C,x,t,A,B,ja,xa;if(0!==this.width&&0!==this.height){a=(Math.round(a)%this.N+this.N)%this.N;p.globalAlpha=m;b=Math.round(b-this.Da)%this.width;0<b&&(b-=this.width);c=Math.round(c-this.Ea)%this.height;0<c&&(c-=this.height);m=Math.ceil((k-b)/this.width);z=Math.ceil((l-c)/this.height);b+=d+this.Xi[a];c+=g+this.Zi[a];for(ja=0;ja<m;ja+=1)for(xa=0;xa<z;xa+=1)x=this.Wi[a],t=this.Yi[a],A=this.bi[a],B=this.ai[a],v=b+ja*this.width,C=c+xa*this.height,
v<d&&(x+=d-v,A-=d-v,v=d),v+A>=d+k&&(A=d+k-v),C<g&&(t+=g-C,B-=g-C,C=g),C+B>=g+l&&(B=g+l-C),0<A&&0<B&&this.aj.nb(this.Ui[a],x,t,A,B,v,C);p.globalAlpha=w}};e.jx=function(a,b,c,d,g,k){this.Uk(a,0,0,b,c,d,g,k)};
e.nb=function(a,b,c,d,g,k,l,m){var p=f.context,w=p.globalAlpha,z,v,C,x;a=(Math.round(a)%this.N+this.N)%this.N;z=this.Xi[a];v=this.Zi[a];C=this.bi[a];x=this.ai[a];b-=z;c-=v;0>=b+d||0>=c+g||b>=C||c>=x||(0>b&&(d+=b,k-=b,b=0),0>c&&(g+=c,l-=c,c=0),b+d>C&&(d=C-b),c+g>x&&(g=x-c),p.globalAlpha=m,this.aj.nb(this.Ui[a],this.Wi[a]+b,this.Yi[a]+c,d,g,k,l),p.globalAlpha=w)};
e.ne=function(a,b,c,d,g,k,l,m,p,w){var z=f.context,v=z.globalAlpha,C,x,t,A,B,ja;a=(Math.round(a)%this.N+this.N)%this.N;C=m/d;x=p/g;t=this.Xi[a];A=this.Zi[a];B=this.bi[a];ja=this.ai[a];b-=t;c-=A;0>=b+d||0>=c+g||b>=B||c>=ja||(0>b&&(d+=b,m+=C*b,k-=C*b,b=0),0>c&&(g+=c,p+=x*c,l-=x*c,c=0),b+d>B&&(m-=C*(d-B+b),d=B-b),c+g>ja&&(p-=x*(g-ja+c),g=ja-c),z.globalAlpha=w,this.aj.nb(this.Ui[a],this.Wi[a]+b,this.Yi[a]+c,d,g,k,l,m,p),z.globalAlpha=v)};
function wa(a,b,c){var d,g,k;for(d=0;d<a.N;d+=1)g=b+d%a.yH*a.width,k=c+a.height*Math.floor(d/a.yH),a.aj.nb(a.Ui[d],a.Wi[d],a.Yi[d],a.bi[d],a.ai[d],g-a.Da+a.Xi[d],k-a.Ea+a.Zi[d])}function ya(a,b,c,d,g,k){var l=f.context;1E-4>Math.abs(d)||1E-4>Math.abs(g)||(l.save(),l.translate(b,c),l.rotate(-0*Math.PI/180),l.scale(d,g),l.globalAlpha=k,wa(a,0,0),l.restore())}
function za(a,b){this.canvas=document.createElement("canvas");this.context=this.canvas.getContext("2d");this.width=a;this.height=b;this.Ea=this.Da=0;this.canvas.width=a;this.canvas.height=b;this.clear();this.qu=void 0}e=za.prototype;e.Zc=function(){var a=new za(this.width,this.height);a.Da=this.Da;a.Ea=this.Ea;Aa(a);this.B(0,0);Ba(a);return a};function Aa(a){a.qu=f.canvas;pa(f,a.canvas)}function Ba(a){f.canvas===a.canvas&&void 0!==a.qu&&(pa(f,a.qu),a.qu=void 0)}
e.clear=function(){this.context.clearRect(0,0,this.canvas.width,this.canvas.height)};e.clearColor=function(a){this.context.fillStyle=a;this.context.fillRect(0,0,this.canvas.width,this.canvas.height)};e.B=function(a,b){f.context.drawImage(this.canvas,a-this.Da,b-this.Ea)};e.Tk=function(a,b,c){var d=f.context,g=d.globalAlpha;d.globalAlpha=c;f.context.drawImage(this.canvas,a-this.Da,b-this.Ea);d.globalAlpha=g};
e.ib=function(a,b,c,d,g,k){var l=f.context;1E-4>Math.abs(c)||1E-4>Math.abs(d)||(l.save(),l.translate(a,b),l.rotate(-g*Math.PI/180),l.scale(c,d),l.globalAlpha=k,f.context.drawImage(this.canvas,-this.Da,-this.Ea),l.restore())};e.Og=function(a,b,c,d,g){var k=f.context,l=k.globalAlpha;0!==this.width&&0!==this.height&&0!==Math.round(c)&&0!==Math.round(d)&&(k.globalAlpha=g,f.context.drawImage(this.canvas,a,b,c,d),k.globalAlpha=l)};
e.Mc=function(a,b,c,d,g,k,l,m,p){var w,z,v,C,x,t,A,B,ja,xa,Xa,Rb,Ib,Sb,Tb,Jb;0!==this.width&&0!==this.height&&(void 0===k&&(k=Math.floor(this.width/3)),void 0===l&&(l=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.height/3)),void 0===p&&(p=Math.floor(this.height/3)),c<k+l&&(k=Math.round(k*c/(k+l)),l=c-k),d<m+p&&(m=Math.round(m*d/(m+p)),p=d-m),ja=this.width,w=k,z=this.width-k-l,v=l,C=w+z,xa=this.height,x=m,t=this.height-m-p,A=p,B=x+t,Xa=k,k=c-k-l,Rb=a+Xa,Ib=a+Xa+k,Sb=m,m=d-m-p,Tb=b+Sb,Jb=
b+Sb+m,c===this.width&&d===this.height?this.Tk(a+this.Da,b+this.Ea,g):d===this.height?(this.ne(w,0,z,xa,Rb,b,k,d,g),this.nb(0,0,w,xa,a,b,g),this.nb(C,0,v,xa,Ib,b,g)):c===this.width?(this.ne(0,x,ja,t,a,Tb,c,m,g),this.nb(0,0,ja,x,a,b,g),this.nb(0,B,ja,A,a,Jb,g)):(this.ne(w,x,z,t,Rb,Tb,k,m,g),this.ne(w,0,z,x,Rb,b,k,Sb,g),this.ne(0,x,w,t,a,Tb,Xa,m,g),this.ne(C,x,v,t,Ib,Tb,l,m,g),this.ne(w,B,z,A,Rb,Jb,k,p,g),this.nb(0,0,w,x,a,b,g),this.nb(0,B,w,A,a,Jb,g),this.nb(C,0,v,x,Ib,b,g),this.nb(C,B,v,A,Ib,Jb,g)))};
e.Uk=function(a,b,c,d,g,k,l){var m=f.context,p=m.globalAlpha,w,z,v,C,x,t,A,B,ja;if(0!==this.width&&0!==this.height){m.globalAlpha=l;a=Math.round(a-this.Da)%this.width;0<a&&(a-=this.width);b=Math.round(b-this.Ea)%this.height;0<b&&(b-=this.height);l=Math.ceil((g-a)/this.width);w=Math.ceil((k-b)/this.height);a+=c;b+=d;for(B=0;B<l;B+=1)for(ja=0;ja<w;ja+=1)x=C=0,t=this.width,A=this.height,z=a+B*this.width,v=b+ja*this.height,z<c&&(C+=c-z,t-=c-z,z=c),z+t>=c+g&&(t=c+g-z),v<d&&(x+=d-v,A-=d-v,v=d),v+A>=d+k&&
(A=d+k-v),0<t&&0<A&&f.context.drawImage(this.canvas,C,x,t,A,z,v,t,A);m.globalAlpha=p}};e.jx=function(a,b,c,d,g){this.Uk(0,0,a,b,c,d,g)};e.nb=function(a,b,c,d,g,k,l){var m=f.context,p=m.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),m.globalAlpha=l,f.context.drawImage(this.canvas,a,b,c,d,g,k,c,d),m.globalAlpha=p)};
e.ne=function(a,b,c,d,g,k,l,m,p){var w=f.context,z=w.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),0!==Math.round(l)&&0!==Math.round(m)&&(w.globalAlpha=p,f.context.drawImage(this.canvas,a,b,c,d,g,k,l,m),w.globalAlpha=z))};
function Ca(a,b,c,d){this.l=a;this.qX=b;this.GW=c;this.fs=[{text:"MiHhX!@v&Qq",width:-1,font:"sans-serif"},{text:"MiHhX!@v&Qq",width:-1,font:"serif"},{text:"AaMm#@!Xx67",width:-1,font:"sans-serif"},{text:"AaMm#@!Xx67",width:-1,font:"serif"}];this.WI=!1;ma(this,d,1)}function Da(a,b,c){f.context.save();f.context.font="250pt "+a+", "+b;a=f.context.measureText(c).width;f.context.restore();return a}
function Ea(a){var b,c,d;for(b=0;b<a.fs.length;b+=1)if(c=a.fs[b],d=Da(a.l,c.font,c.text),c.width!==d){na.Yg(a.YR);document.body.removeChild(a.ij);a.WI=!0;return}window.setTimeout(function(){Ea(a)},33)}
Ca.prototype.Si=function(a,b){var c="@font-face {font-family: "+this.l+";src: url('"+b+this.qX+"') format('woff'), url('"+b+this.GW+"') format('truetype');}",d=document.createElement("style");d.id=this.l+"_fontface";d.type="text/css";d.styleSheet?d.styleSheet.cssText=c:d.appendChild(document.createTextNode(c));document.getElementsByTagName("head")[0].appendChild(d);this.ij=document.createElement("span");this.ij.style.position="absolute";this.ij.style.left="-9999px";this.ij.style.top="-9999px";this.ij.style.visibility=
"hidden";this.ij.style.fontSize="250pt";this.ij.id=this.l+"_loader";document.body.appendChild(this.ij);for(c=0;c<this.fs.length;c+=1)d=this.fs[c],d.width=Da(d.font,d.font,d.text);this.YR=a;Ea(this)};Ca.prototype.complete=function(){return this.WI};
function Fa(a,b){this.l=a;this.Jp=b;this.fontWeight=this.fontStyle="";this.Pm="normal";this.fontSize=12;this.fill=!0;this.jb=1;this.Te=0;this.fillColor="black";this.Qg={c:void 0,ra:0,nA:!0,oA:!0};this.kc={Tr:!0,N:3,Us:["red","white","blue"],size:.6,offset:0};this.fillStyle=void 0;this.stroke=!1;this.rb=1;this.Wl=0;this.strokeColor="black";this.strokeStyle=void 0;this.ug=1;this.Ti=!1;this.Vl="miter";this.oc={D:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1};this.align="left";this.ua="top";
this.Ri=this.Xj=0}e=Fa.prototype;
e.Zc=function(){var a=new Fa(this.l,this.Jp);a.fontStyle=this.fontStyle;a.fontWeight=this.fontWeight;a.Pm=this.Pm;a.fontSize=this.fontSize;a.fill=this.fill;a.jb=this.jb;a.Te=this.Te;a.fillColor=this.fillColor;a.Qg={c:this.Qg.c,nA:this.Qg.nA,oA:this.Qg.oA};a.kc={Tr:this.kc.Tr,N:this.kc.N,Us:this.kc.Us.slice(0),size:this.kc.size,offset:this.kc.offset};a.fillStyle=this.fillStyle;a.stroke=this.stroke;a.rb=this.rb;a.Wl=this.Wl;a.strokeColor=this.strokeColor;a.strokeStyle=this.strokeStyle;a.ug=this.ug;
a.Ti=this.Ti;a.Vl=this.Vl;a.oc={D:this.oc.D,color:this.oc.color,offsetX:this.oc.offsetX,offsetY:this.oc.offsetY,blur:this.oc.blur};a.align=this.align;a.ua=this.ua;a.Xj=this.Xj;a.Ri=this.Ri;return a};
e.f=function(a){void 0!==a.l&&(this.l=a.l);void 0!==a.Jp&&(this.Jp=a.Jp);void 0!==a.fontStyle&&(this.fontStyle=a.fontStyle);void 0!==a.fontWeight&&(this.fontWeight=a.fontWeight);void 0!==a.Pm&&(this.Pm=a.Pm);void 0!==a.fontSize&&(this.fontSize=a.fontSize);void 0!==a.fill&&(this.fill=a.fill);void 0!==a.jb&&(this.jb=a.jb);void 0!==a.fillColor&&(this.Te=0,this.fillColor=a.fillColor);void 0!==a.Qg&&(this.Te=1,this.Qg=a.Qg);void 0!==a.kc&&(this.Te=2,this.kc=a.kc);void 0!==a.fillStyle&&(this.Te=3,this.fillStyle=
a.fillStyle);void 0!==a.stroke&&(this.stroke=a.stroke);void 0!==a.rb&&(this.rb=a.rb);void 0!==a.strokeColor&&(this.Wl=0,this.strokeColor=a.strokeColor);void 0!==a.strokeStyle&&(this.Wl=3,this.strokeStyle=a.strokeStyle);void 0!==a.ug&&(this.ug=a.ug);void 0!==a.Ti&&(this.Ti=a.Ti);void 0!==a.Vl&&(this.Vl=a.Vl);void 0!==a.oc&&(this.oc=a.oc);void 0!==a.align&&(this.align=a.align);void 0!==a.ua&&(this.ua=a.ua);void 0!==a.Xj&&(this.Xj=a.Xj);void 0!==a.Ri&&(this.Ri=a.Ri)};
function Ga(a,b){a.fontSize=void 0===b?12:b}e.setFillColor=function(a){this.Te=0;this.fillColor=void 0===a?"black":a};function Ha(a,b){a.stroke=void 0===b?!1:b}e.setStrokeColor=function(a){this.Wl=0;this.strokeColor=void 0===a?"black":a};function Ia(a,b){a.ug=void 0===b?1:b}function Ja(a,b){a.Ti=void 0===b?!1:b}function Ka(a,b){a.Vl=void 0===b?"miter":b}function La(a,b,c,d,g){void 0===b?a.oc.D=!0:a.oc={D:!0,color:b,offsetX:c,offsetY:d,blur:g}}function Ma(a,b){a.align=void 0===b?"left":b}
function Na(a,b){a.ua=void 0===b?"top":b}function Oa(a,b){a.Xj=void 0===b?0:b}function Pa(a,b){a.Ri=void 0===b?0:b}function Qa(a){return a.fontStyle+" "+a.fontWeight+" "+a.fontSize+"px "+a.l+", "+a.Jp}function Ra(a){var b=0,c;for(c=0;c<a.length;c+=1)b=Math.max(b,a[c].width);return b}function Sa(a,b){return a.fontSize*b.length+a.Ri*(b.length-1)}
function Ta(a,b,c){var d,g,k,l,m,p,w=[],z=f.context;z.font=Qa(a);switch(a.Pm){case "upper":b=b.toUpperCase();break;case "lower":b=b.toLowerCase()}if(void 0===c){p=b.split("\n");for(a=0;a<p.length;a+=1)w.push({text:p[a],width:z.measureText(p[a]).width});return w}p=b.split("\n");k=z.measureText(" ").width;for(a=0;a<p.length;a+=1){g=p[a].split(" ");d=g[0];m=z.measureText(g[0]).width;for(b=1;b<g.length;b+=1)l=z.measureText(g[b]).width,m+k+l<c?(d+=" "+g[b],m+=k+l):(w.push({text:d,width:m}),d=g[b],m=l);
w.push({text:d,width:m})}return w}e.Lr=function(a,b){var c;f.context.save();c=Ra(Ta(this,a,b));f.context.restore();return c};e.vg=function(a,b){var c;f.context.save();c=Sa(this,Ta(this,a,b));f.context.restore();return c};function Ua(a,b,c,d,g,k){var l=a.fontSize;a.fontSize=b;b=k?Ta(a,c,d):Ta(a,c);d=Ra(b)<=d&&Sa(a,b)<=g;a.fontSize=l;return d}
function Va(a,b,c,d,g){var k=0,l=32;void 0===g&&(g=!1);for(f.context.save();Ua(a,k+l,b,c,d,g);)k+=l;for(;2<=l;)l/=2,Ua(a,k+l,b,c,d,g)&&(k+=l);f.context.restore();return Math.max(4,k)}function Wa(a,b,c,d,g){var k=Math.max(.01,a.kc.size),l=a.kc.offset;a.kc.Tr?(l=g/2+l*g,k=.5*k*g,b=f.context.createLinearGradient(b,c+l-k,b,c+l+k)):(l=d/2+l*d,k=.5*k*d,b=f.context.createLinearGradient(b+l-k,c,b+l+k,c));c=1/(a.kc.N-1);for(d=0;d<a.kc.N;d+=1)b.addColorStop(d*c,a.kc.Us[d]);return b}
function Ya(a,b,c,d,g,k,l){var m,p;!a.fill&&a.oc.D?(b.shadowColor=a.oc.color,b.shadowOffsetX=a.oc.offsetX,b.shadowOffsetY=a.oc.offsetY,b.shadowBlur=a.oc.blur):(b.shadowColor=void 0,b.shadowOffsetX=0,b.shadowOffsetY=0,b.shadowBlur=0);b.globalAlpha=l*a.rb;switch(a.Wl){case 0:b.strokeStyle=a.strokeColor;break;case 3:b.strokeStyle=a.strokeStyle}b.lineWidth=a.ug;b.lineJoin=a.Vl;for(l=0;l<c.length;l+=1){m=0;switch(a.align){case "right":m=k-c[l].width;break;case "center":m=(k-c[l].width)/2}p=a.fontSize*
(l+1)+a.Ri*l;b.strokeText(c[l].text,d+m,g+p)}}
e.ro=function(a,b,c,d,g,k){b=Ta(this,b,k);k=Ra(b);var l=Sa(this,b);a.textAlign="left";a.textBaseline="bottom";switch(this.align){case "right":c+=-k;break;case "center":c+=-k/2}switch(this.ua){case "base":case "bottom":d+=-l+Math.round(this.Xj*this.fontSize);break;case "middle":d+=-l/2+Math.round(this.Xj*this.fontSize/2)}a.font=Qa(this);this.stroke&&this.Ti&&Ya(this,a,b,c,d,k,g);if(this.fill){var m=c,p=d,w,z;this.oc.D?(a.shadowColor=this.oc.color,a.shadowOffsetX=this.oc.offsetX,a.shadowOffsetY=this.oc.offsetY,
a.shadowBlur=this.oc.blur):(a.shadowColor=void 0,a.shadowOffsetX=0,a.shadowOffsetY=0,a.shadowBlur=0);a.globalAlpha=g*this.jb;switch(this.Te){case 0:a.fillStyle=this.fillColor;break;case 1:l=this.Qg.c;z=new za(l.width,l.height);var v=this.Qg.nA,C=this.Qg.oA;v&&C?w="repeat":v&&!C?w="repeat-x":!v&&C?w="repeat-y":v||C||(w="no-repeat");Aa(z);l.B(this.Qg.ra,0,0);Ba(z);w=f.context.createPattern(z.canvas,w);a.fillStyle=w;break;case 2:a.fillStyle=Wa(this,m,p,k,l);break;case 3:a.fillStyle=this.fillStyle;break;
default:a.fillStyle=this.fillColor}for(w=0;w<b.length;w+=1){l=0;switch(this.align){case "right":l=k-b[w].width;break;case "center":l=(k-b[w].width)/2}z=this.fontSize*(w+1)+this.Ri*w;2===this.Te&&this.kc.Tr&&(a.fillStyle=Wa(this,m,p+z-this.fontSize,k,this.fontSize));a.fillText(b[w].text,m+l,p+z)}}this.stroke&&!this.Ti&&Ya(this,a,b,c,d,k,g)};e.B=function(a,b,c,d){var g=f.context;this.fill&&1===this.Te?this.ib(a,b,c,1,1,0,1,d):(g.save(),this.ro(g,a,b,c,1,d),g.restore())};
e.Tk=function(a,b,c,d,g){var k=f.context;this.fill&&1===this.Te?this.ib(a,b,c,1,1,0,d,g):(k.save(),this.ro(k,a,b,c,d,g),k.restore())};e.ib=function(a,b,c,d,g,k,l,m){var p=f.context;p.save();p.translate(b,c);p.rotate(-k*Math.PI/180);p.scale(d,g);try{this.ro(p,a,0,0,l,m)}catch(w){}p.restore()};
function Za(){this.wS=10;this.Kv=-1;this.qL="stop_lowest_prio";this.kD=this.kd=this.ld=!1;var a,b=this,c="undefined"!==typeof AudioContext?AudioContext:"undefined"!==typeof webkitAudioContext?webkitAudioContext:void 0;if(c)this.ld=!0;else if("undefined"!==typeof Audio)try{"undefined"!==typeof(new Audio).canPlayType&&(this.kd=!0)}catch(d){}this.kD=this.ld||this.kd;this.kd&&ca.U.vB&&(this.Kv=1);if(this.kD)try{a=new Audio,this.kC={ogg:!!a.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,""),
mp3:!!a.canPlayType("audio/mpeg;").replace(/^no$/,""),opus:!!a.canPlayType('audio/ogg; codecs="opus"').replace(/^no$/,""),wav:!!a.canPlayType('audio/wav; codecs="1"').replace(/^no$/,""),m4a:!!(a.canPlayType("audio/x-m4a;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),mp4:!!(a.canPlayType("audio/x-mp4;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),weba:!!a.canPlayType('audio/webm; codecs="vorbis"').replace(/^no$/,"")}}catch(g){this.kC={ogg:!1,mp3:!0,opus:!1,wav:!1,m4a:!1,mp4:!1,weba:!1}}this.Ke=
[];this.Bk={};this.Jc={};this.Eg={};this.hi=[];this.qf=0;this.ld?(this.Ya=new c,this.lC="function"===typeof this.Ya.createGain?function(){return b.Ya.createGain()}:"function"===typeof this.Ya.createGainNode?function(){return b.Ya.createGainNode()}:function(){},this.zk={},this.hs=this.lC(),void 0===this.hs?(this.kd=!0,this.uo=Za.prototype.Iv):(this.hs.connect(this.Ya.destination),this.zk.master=this.hs,this.uo=Za.prototype.oL)):this.uo=this.kd?Za.prototype.Iv:function(){}}e=Za.prototype;
e.Dv=function(a){var b,c,d,g,k;for(b=0;b<this.Ke.length;b+=1)if((c=this.Ke[b])&&0===c.yx)if(c.paused)c.rC&&(c.Mv+=a,c.Mv>=c.rC&&this.Oi(c.id));else if(c.Ov+=a,c.km&&c.Ov>=c.RI)c.km=!1,$a(this,c,c.ji);else if(c.Qh&&this.kd&&ab(this,c.id)>=c.duration)if(c.Vj)try{c.X.pause(),c.X.currentTime=c.ji/1E3,4===c.X.readyState?c.X.play():(d=function(){var a=c;return{ready:function(){a.X.play();a.X.removeEventListener("canplaythrough",d.ready,!1)}}}(),c.X.addEventListener("canplaythrough",d.ready,!1))}catch(l){}else c.X.pause(),
bb(c);for(b=this.hi.length-1;0<=b;b-=1)g=this.hi[b],this.Ym(g.id)||0!==g.yx||(g.La+=a,g.La>=g.duration?(cb(n,g.id,g.Kr),void 0!==this.Eg[g.id]&&(this.Eg[g.id]=g.Kr),g.Qb&&g.Qb(),this.hi.splice(b,1)):(k=g.o(g.La,g.start,g.Kr-g.start,g.duration),cb(n,g.id,k),void 0!==this.Eg[g.id]&&(this.Eg[g.id]=k)))};function db(a,b){a.Bk[b.jf.Zh.name]?a.Bk[b.jf.Zh.name].length<a.wS&&a.Bk[b.jf.Zh.name].push(b.X):a.Bk[b.jf.Zh.name]=[b.X]}
function eb(a,b){var c,d,g;g=[];for(c=0;c<a.Ke.length;c+=1)(d=a.Ke[c])&&0<=d.gb.indexOf(b)&&g.push(d);return g}function fb(a,b){if(0<a.Kv&&a.qf>=a.Kv)switch(a.qL){case "cancel_new":return!1;case "stop_lowest_prio":var c,d,g;for(c=0;c<a.Ke.length;c+=1)(d=a.Ke[c])&&d.Qh&&!d.paused&&(void 0===g||g.Fu<d.Fu)&&(g=d);if(g.Fu>b.Do){a.stop(g.id);break}return!1}return!0}
function gb(a,b){var c,d=1;for(c=0;c<b.gb.length;c+=1)void 0!==n.Jc[b.gb[c]]&&(d*=n.Jc[b.gb[c]]);c=a.lC();c.gain.value=d;c.connect(a.hs);a.zk[b.id]=c;b.X.connect(c)}function hb(a,b){b.X.disconnect(0);a.zk[b.id]&&(a.zk[b.id].disconnect(0),delete a.zk[b.id])}function ib(a,b){var c;if(b.Zh&&b.Zh.Xc){if(a.ld)return c=a.Ya.createBufferSource(),c.buffer=b.Zh.Xc,c.loopStart=b.startOffset/1E3,c.loopEnd=(b.startOffset+b.duration)/1E3,c;if(a.kd)return c=b.Zh.Xc.cloneNode(!0),c.volume=0,c}}
function jb(a,b){var c,d;if(a.ld)(c=ib(a,b))&&(d=new kb(b,c));else if(a.kd){c=a.Bk[b.Zh.name];if(!c)return;0<c.length?d=new kb(b,c.pop()):(c=ib(a,b))&&(d=new kb(b,c))}if(d){a.ld&&gb(a,d);for(c=0;c<a.Ke.length;c+=1)if(void 0===a.Ke[c])return a.Ke[c]=d;a.Ke.push(d)}return d}function lb(a){var b=n,c,d;for(c=0;c<a.length;c+=1)if(d=a[c].split(".").pop(),b.kC[d])return a[c];return!1}
e.Iv=function(a,b,c){function d(){var b;a.loaded=!0;na.Yg(c);a.duration=Math.ceil(1E3*a.Xc.duration);a.Xc.removeEventListener("canplaythrough",d,!1);a.Xc.removeEventListener("error",g,!1);b=a.Xc.cloneNode(!0);n.Bk[a.name].push(b)}function g(){na.Uj(c)}(b=lb(b))?(a.Xc=new Audio,a.Xc.src=b,a.Xc.autoplay=!1,a.Xc.s_="auto",a.Xc.addEventListener("canplaythrough",d,!1),a.Xc.addEventListener("error",g,!1),a.Xc.load()):g()};
e.oL=function(a,b,c){var d=lb(b),g=new XMLHttpRequest;g.open("GET",d,!0);g.responseType="arraybuffer";g.onload=function(){n.Ya.decodeAudioData(g.response,function(b){b&&(a.Xc=b,a.duration=1E3*b.duration,a.loaded=!0,na.Yg(c))},function(){na.Uj(c)})};g.onerror=function(){"undefined"!==typeof Audio&&(n.ld=!1,n.kd=!0,n.uo=Za.prototype.Iv,n.uo(a,b,c))};try{g.send()}catch(k){}};
e.play=function(a,b,c,d){if(a instanceof mb){if(fb(this,a)){a=jb(this,a);if(!a)return-1;a.RI=b||0;a.km=0<b;a.fg=c||0;a.zi=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};a.km||$a(this,a,a.ji);return a.id}return-1}};
function $a(a,b,c){var d;"number"!==typeof c&&(c=0);nb(a,b.id);0<b.fg&&(d=ob(a,b.id),cb(a,b.id,0),a.Ij(b.id,d,b.fg,b.zi),b.fg=0,b.zi=void 0);if(a.ld){d=c-b.ji;b.xL=1E3*a.Ya.currentTime-d;b.X.onended=function(){bb(b)};try{b.X.start?b.X.start(0,c/1E3,(b.duration-d)/1E3):b.X.noteGrainOn&&b.X.noteGrainOn(0,c/1E3,(b.duration-d)/1E3),b.ph=!0,b.Qh=!0,a.qf+=1,b.X.loop=b.Vj}catch(g){}}else if(a.kd){if(4!==b.X.readyState){var k=function(){return{ready:function(){b.X.currentTime=c/1E3;b.X.play();b.ph=!0;b.X.removeEventListener("canplaythrough",
k.ready,!1)}}}();b.X.addEventListener("canplaythrough",k.ready,!1)}else b.X.currentTime=c/1E3,b.X.play(),b.ph=!0;b.Qh=!0;a.qf+=1}}
e.Oi=function(a,b,c,d){var g,k,l,m,p=eb(this,a);for(g=0;g<p.length;g+=1)if(k=p[g],(k.paused||!k.Qh)&&!d||!k.paused&&d){if(!d){for(g=this.hi.length-1;0<=g;g-=1)if(a=this.hi[g],a.id===k.id){m=a;b=0;c=void 0;break}k.paused=!1;k.fg=b||0;k.zi=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};k.so&&(void 0===b&&(k.fg=k.so.duration),void 0===c&&(k.zi=k.so.o),l=k.so.gain,k.so=void 0)}this.ld&&(a=ib(this,k.jf))&&(k.X=a,gb(this,k));void 0!==l&&cb(n,k.id,l);$a(this,k,k.ji+(k.is||0));void 0!==m&&
(cb(n,k.id,m.o(m.La,m.start,m.Kr-m.start,m.duration)),n.Ij(k.id,m.Kr,m.duration-m.La,m.o,m.Qb))}};
e.pause=function(a,b,c,d,g){var k,l,m=eb(this,a);for(a=0;a<m.length;a+=1)if(k=m[a],!k.paused)if(k.fg=c||0,0<k.fg)k.zi=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},k.so={gain:pb(k.id),duration:k.fg,o:k.zi},n.Ij(k.id,0,k.fg,k.zi,function(){n.pause(k.id,b)});else if(l=ab(this,k.id),k.is=l,g||(k.paused=!0,k.Mv=0,k.rC=b,this.qf-=1),this.ld){k.X.onended=function(){};if(k.Qh&&k.ph){try{k.X.stop?k.X.stop(0):k.X.noteOff&&k.X.noteOff(0)}catch(p){}k.ph=!1}hb(this,k)}else this.kd&&k.X.pause()};
function bb(a){var b=n;b.Jc[a.id]&&delete b.Jc[a.id];a.paused||(b.qf-=1);b.ld?(a.ph=!1,a.Qh=!1,hb(b,a)):b.kd&&db(b,a);b.Ke[b.Ke.indexOf(a)]=void 0}
e.stop=function(a,b,c){var d,g=eb(this,a);for(a=0;a<g.length;a+=1)if(d=g[a],d.fg=b||0,0<d.fg)d.zi=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},n.Ij(d.id,0,d.fg,d.zi,function(){n.stop(d.id)});else{this.Jc[d.id]&&delete this.Jc[d.id];d.Qh&&!d.paused&&(this.qf-=1);if(this.ld){if(d.Qh&&!d.paused&&!d.km){if(d.ph){try{d.X.stop?d.X.stop(0):d.X.noteOff&&d.X.noteOff(0)}catch(k){}d.ph=!1}hb(this,d)}}else this.kd&&(d.km||d.X.pause(),db(this,d));this.Ke[this.Ke.indexOf(d)]=void 0;d.Qh=!1}};
e.Ij=function(a,b,c,d,g){var k;for(k=0;k<this.hi.length;k+=1)if(this.hi[k].id===a){this.hi.splice(k,1);break}this.hi.push({id:a,Kr:b,o:d||function(a,b,c,d){return a==d?b+c:c*(-Math.pow(2,-10*a/d)+1)+b},duration:c,La:0,start:ob(this,a),Qb:g,yx:0})};function qb(a){var b=n,c;void 0===b.Eg[a]&&(c=void 0!==b.Jc[a]?b.Jc[a]:1,cb(b,a,0),b.Eg[a]=c)}function rb(a){var b=n;void 0!==b.Eg[a]&&(cb(b,a,b.Eg[a]),delete b.Eg[a])}
e.position=function(a,b){var c,d,g,k,l=eb(this,a);if(!isNaN(b)&&0<=b)for(c=0;c<l.length;c++)if(d=l[c],b%=d.duration,this.ld)if(d.paused)d.is=b;else{d.X.onended=function(){};if(d.ph){try{d.X.stop?d.X.stop(0):d.X.noteOff&&d.X.noteOff(0)}catch(m){}d.ph=!1}hb(this,d);this.qf-=1;if(g=ib(this,d.jf))d.X=g,gb(this,d),$a(this,d,d.ji+b)}else this.kd&&(4===d.X.readyState?d.X.currentTime=(d.ji+b)/1E3:(k=function(){var a=d,c=b;return{CF:function(){a.X.currentTime=(a.ji+c)/1E3;a.X.removeEventListener("canplaythrough",
k.CF,!1)}}}(),d.X.addEventListener("canplaythrough",k.CF,!1)))};e.lk=function(a,b){var c,d=eb(this,a);for(c=0;c<d.length;c+=1)d[c].Vj=b,this.ld&&(d[c].X.loop=b)};function ob(a,b){return void 0!==a.Jc[b]?a.Jc[b]:1}function pb(a){var b=n,c=1,d=eb(b,a)[0];if(d)for(a=0;a<d.gb.length;a+=1)void 0!==b.Jc[d.gb[a]]&&(c*=b.Jc[d.gb[a]]);return Math.round(100*c)/100}
function cb(a,b,c){var d,g,k=1,l=eb(a,b);a.Jc[b]=c;a.Eg[b]&&delete a.Eg[b];for(c=0;c<l.length;c+=1)if(d=l[c],0<=d.gb.indexOf(b)){for(g=0;g<d.gb.length;g+=1)void 0!==a.Jc[d.gb[g]]&&(k*=a.Jc[d.gb[g]]);k=Math.round(100*k)/100;a.ld?a.zk[d.id].gain.value=k:a.kd&&(d.X.volume=k)}}function nb(a,b){var c,d,g,k=1,l=eb(a,b);for(c=0;c<l.length;c+=1){d=l[c];for(g=0;g<d.gb.length;g+=1)void 0!==a.Jc[d.gb[g]]&&(k*=a.Jc[d.gb[g]]);k=Math.round(100*k)/100;a.ld?a.zk[d.id].gain.value=k:a.kd&&(d.X.volume=k)}}
e.zt=function(a){var b,c,d,g=eb(this,a),k=[];for(a=0;a<g.length;a+=1)for(b=g[a],c=0;c<b.gb.length;c+=1)d=b.gb[c],0>k.indexOf(d)&&k.push(d);return k};e.Ym=function(a){if(a=eb(this,a)[0])return a.paused};e.C=function(a){return eb(this,a)[0]?!0:!1};function ab(a,b){var c=eb(a,b)[0];if(c){if(a.ld)return c.paused?c.is:(1E3*n.Ya.currentTime-c.xL)%c.duration;if(n.kd)return Math.ceil(1E3*c.X.currentTime-c.ji)}}var n=new Za;
function sb(a,b,c,d){this.name=a;this.XS=b;this.jT=c;this.Ff=d;this.loaded=!1;this.Xc=null;ma(this,this.Ff,1)}sb.prototype.Si=function(a,b){var c,d;c=this.XS;0!==c.toLowerCase().indexOf("http:")&&0!==c.toLowerCase().indexOf("https:")&&(c=b+c);d=this.jT;0!==d.toLowerCase().indexOf("http:")&&0!==d.toLowerCase().indexOf("https:")&&(d=b+d);n.Bk[this.name]=[];n.uo(this,[d,c],a)};sb.prototype.complete=function(){return this.loaded};
function mb(a,b,c,d,g,k,l){this.name=a;this.Zh=b;this.startOffset=c;this.duration=d;cb(n,this.name,void 0!==g?g:1);this.Do=void 0!==k?k:10;this.gb=[];l&&(this.gb=this.gb.concat(l));0>this.gb.indexOf(this.name)&&this.gb.push(this.name)}mb.prototype.complete=function(){return this.Zh.complete()};mb.prototype.Fu=function(a){void 0!==a&&(this.Do=a);return this.Do};mb.prototype.zt=function(){return this.gb.slice(0)};
function kb(a,b){this.jf=a;this.ji=this.jf.startOffset;this.X=b;this.duration=this.jf.duration;this.Ev()}kb.prototype.Ev=function(){this.id=Math.round(Date.now()*Math.random())+"";this.gb=["master",this.id].concat(this.jf.gb);this.Fu=void 0!==this.jf.Do?this.jf.Do:10;this.paused=this.Qh=this.Vj=!1;this.Ov=this.yx=0;this.ph=this.km=!1;this.RI=this.is=0;var a,b=1;for(a=0;a<this.gb.length;a+=1)void 0!==n.Jc[this.gb[a]]&&(b*=n.Jc[this.gb[a]]);!n.ld&&n.kd&&(this.X.volume=b)};
function tb(a,b){this.name=a;this.fileName=b;this.info=void 0}function ub(a){a&&(this.k=a);this.clear();this.Ao=this.pm=this.Cg=this.zo=this.yo=this.Co=this.vo=this.Bo=this.ii=this.xo=this.wo=0;vb(this,this);wb(this,this);xb(this,this);this.jC=[];this.oo=[];this.Eo=[];this.oa=0;this.sC=!1;this.Ef=this.startTime=Date.now();this.Tl=this.hg=0;this.AS=200;this.Rr=0;this.Ff="";window.cs(window.eC)}e=ub.prototype;e.clear=function(){this.V=[];this.ks=!1;this.ge=[];this.Cv=!1};
function vb(a,b){window.addEventListener("click",function(a){var d,g,k;if(void 0!==b.k&&!(0<b.oa)&&(d=b.k,g=d.getBoundingClientRect(),k=d.width/g.width*(a.clientX-g.left),d=d.height/g.height*(a.clientY-g.top),a.preventDefault(),b.jm.x=k,b.jm.y=d,b.qo.push({x:b.jm.x,y:b.jm.y}),0<b.zo))for(a=b.V.length-1;0<=a&&!((k=b.V[a])&&k.D&&0>=k.oa&&k.fy&&(k=k.fy(b.jm.x,b.jm.y),!0===k));a-=1);},!1);yb(a)}function yb(a){a.jm={x:0,y:0};a.qo=[]}
function wb(a,b){window.addEventListener("mousedown",function(a){0<b.oa||(a.preventDefault(),window.focus(),b.qC>=Date.now()-1E3||(zb(b,0,a.clientX,a.clientY),Ab(b,0)))},!1);window.addEventListener("mouseup",function(a){0<b.oa||(a.preventDefault(),b.gs>=Date.now()-1E3||(zb(b,0,a.clientX,a.clientY),Bb(b,0)))},!1);window.addEventListener("mousemove",function(a){0<b.oa||(a.preventDefault(),zb(b,0,a.clientX,a.clientY))},!1);window.addEventListener("touchstart",function(a){var d=a.changedTouches;b.qC=
Date.now();if(!(0<b.oa))for(a.preventDefault(),window.focus(),a=0;a<d.length;a+=1)zb(b,d[a].identifier,d[a].clientX,d[a].clientY),Ab(b,d[a].identifier)},!1);window.addEventListener("touchend",function(a){var d=a.changedTouches;b.gs=Date.now();if(!(0<b.oa))for(a.preventDefault(),a=0;a<d.length;a+=1)zb(b,d[a].identifier,d[a].clientX,d[a].clientY),Bb(b,d[a].identifier)},!1);window.addEventListener("touchmove",function(a){var d=a.changedTouches;if(!(0<b.oa))for(a.preventDefault(),a=0;a<d.length;a+=1)zb(b,
d[a].identifier,d[a].clientX,d[a].clientY)},!1);window.addEventListener("touchleave",function(a){var d=a.changedTouches;b.gs=Date.now();if(!(0<b.oa))for(a.preventDefault(),a=0;a<d.length;a+=1)zb(b,d[a].identifier,d[a].clientX,d[a].clientY),Bb(b,d[a].identifier)},!1);window.addEventListener("touchcancel",function(a){var d=a.changedTouches;b.gs=Date.now();if(!(0<b.oa))for(a.preventDefault(),a=0;a<d.length;a+=1)zb(b,d[a].identifier,d[a].clientX,d[a].clientY),Bb(b,d[a].identifier)},!1);window.addEventListener("mousewheel",
function(a){Cb(b,a)},!1);window.addEventListener("DOMMouseScroll",function(a){Cb(b,a)},!1);Db(a);a.qC=0;a.gs=0}function Db(a){var b;a.Gb=[];for(b=0;16>b;b+=1)a.Gb[b]={id:-1,Se:!1,x:0,y:0};a.Dk=[]}function Eb(a,b){var c=-1,d;for(d=0;16>d;d+=1)if(a.Gb[d].id===b){c=d;break}if(-1===c)for(d=0;16>d;d+=1)if(!a.Gb[d].Se){c=d;a.Gb[d].id=b;break}return c}
function zb(a,b,c,d){var g,k;void 0!==a.k&&(b=Eb(a,b),-1!==b&&(g=a.k,k=g.getBoundingClientRect(),a.Gb[b].x=g.width/k.width*(c-k.left),a.Gb[b].y=g.height/k.height*(d-k.top)))}function Ab(a,b){var c=Eb(a,b),d,g;if(-1!==c&&!a.Gb[c].Se&&(a.Dk.push({ha:c,x:a.Gb[c].x,y:a.Gb[c].y,Se:!0}),a.Gb[c].Se=!0,0<a.Cg))for(d=a.V.length-1;0<=d&&!((g=a.V[d])&&g.D&&0>=g.oa&&g.el&&(g=g.el(c,a.Gb[c].x,a.Gb[c].y),!0===g));d-=1);}
function Bb(a,b){var c=Eb(a,b),d,g;if(-1!==c&&a.Gb[c].Se&&(a.Dk.push({ha:c,x:a.Gb[c].x,y:a.Gb[c].y,Se:!1}),a.Gb[c].Se=!1,0<a.Cg))for(d=a.V.length-1;0<=d&&!((g=a.V[d])&&g.D&&0>=g.oa&&g.Dh&&(g=g.Dh(c,a.Gb[c].x,a.Gb[c].y),!0===g));d-=1);}
function Cb(a,b){var c;if(!(0<a.oa)){b.preventDefault();window.focus();c=Math.max(-1,Math.min(1,b.wheelDelta||-b.detail));var d,g;a.Dk.push({ha:0,x:a.Gb[0].x,y:a.Gb[0].y,wheelDelta:c});if(0<a.Cg)for(d=a.V.length-1;0<=d&&!((g=a.V[d])&&g.D&&0>=g.oa&&g.iy&&(g=g.iy(c,a.Gb[0].x,a.Gb[0].y),!0===g));d-=1);}}e.hd=function(a){return this.Gb[a].x};e.Uc=function(a){return this.Gb[a].y};
function xb(a,b){window.addEventListener("keydown",function(a){if(!(0<b.oa)){-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault();a=a.keyCode;var d,g;if(!b.nm[a]&&(b.mm.push({key:a,Se:!0}),b.nm[a]=!0,0<b.pm))for(d=0;d<b.V.length&&!((g=b.V[d])&&g.D&&0>=g.oa&&g.gy&&(g=g.gy(a),!0===g));d+=1);}},!1);window.addEventListener("keyup",function(a){if(!(0<b.oa)){-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault();a=a.keyCode;var d,g;if(b.nm[a]&&(b.mm.push({key:a,Se:!1}),b.nm[a]=!1,0<b.pm))for(d=
0;d<b.V.length&&!((g=b.V[d])&&g.D&&0>=g.oa&&g.hy&&(g=g.hy(a),!0===g));d+=1);}},!1);Fb(a)}function Fb(a){var b;a.nm=[];for(b=0;256>b;b+=1)a.nm[b]=!1;a.mm=[]}function la(a,b){var c,d=q,g,k;void 0===c&&(c=null);d.Eo.push({id:a,yM:b,bo:c});if(0<d.Ao)for(g=0;g<d.V.length&&(!((k=d.V[g])&&k.D&&0>=k.oa&&k.jy)||null!==c&&c!==k||(k=k.jy(a,b),!0!==k));g+=1);}
function Gb(a,b){var c=a.ge[b];c.visible&&(void 0!==c.canvas&&c.canvas!==f.canvas&&pa(f,c.canvas),!1!==f.canvas.LE||!0===c.JP)&&(0===c.pC&&(0>=c.oa&&(c.ra+=c.vM*a.Tl/1E3),1===c.uv&&1===c.vv&&0===c.Oa?1===c.alpha?c.c.B(c.ra,c.x,c.y):c.c.Tk(c.ra,c.x,c.y,c.alpha):c.c.ib(c.ra,c.x,c.y,c.uv,c.vv,c.Oa,c.alpha)),1===c.pC&&(1===c.uv&&1===c.vv&&0===c.Oa?1===c.alpha?c.font.B(c.text,c.x,c.y):c.font.Tk(c.text,c.x,c.y,c.alpha):c.font.ib(c.text,c.x,c.y,c.uv,c.vv,c.Oa,c.alpha)))}
function Hb(a,b){var c=a.V[b];if(c.visible&&(void 0!==c.canvas&&c.canvas!==f.canvas&&pa(f,c.canvas),(!1!==f.canvas.LE||!0===c.JP)&&c.Ha))return c.Ha()}function Kb(a){for(var b=0,c=0;b<a.V.length||c<a.ge.length;)if(c===a.ge.length){if(!0===Hb(a,b))break;b+=1}else if(b===a.V.length)Gb(a,c),c+=1;else if(a.ge[c].W>a.V[b].W||a.ge[c].W===a.V[b].W&&a.ge[c].depth>a.V[b].depth)Gb(a,c),c+=1;else{if(!0===Hb(a,b))break;b+=1}}e.pause=function(a){this.oa+=1;void 0===a&&(a=!1);this.sC=a};
e.Oi=function(){0!==this.oa&&(this.Ef=Date.now(),this.oa-=1)};e.Ym=function(){return 0<this.oa};window.Av=0;window.zv=0;window.fC=0;window.fL=0;window.gC=0;window.hL=60;window.iL=0;window.gL=!1;
window.eC=function(){window.Av=Date.now();window.fL=window.Av-window.zv;var a=q,b;if(0<a.oa)a.sC&&(Lb(a),Kb(a));else{b=Date.now();"number"!==typeof b&&(b=a.Ef);a.Tl=Math.min(a.AS,b-a.Ef);a.hg+=a.Tl;a.Rr+=1;""===a.Ff&&(a.Ff="start",na.Si(a.Ff));"start"===a.Ff&&na.complete(a.Ff)&&(a.Ff="load",na.Si(a.Ff));"load"===a.Ff&&na.complete(a.Ff)&&(a.Ff="game",na.Si(a.Ff));"undefined"!==typeof n&&n.Dv(a.Tl);var c,d;if(0<a.wo)for(c=0;c<a.V.length&&!((d=a.V[c])&&d.wa&&d.D&&0>=d.oa&&!0===d.wa(a.Tl));c+=1);var g,
k;if(0!==a.qo.length){if(0<a.xo)for(d=a.V.length-1;0<=d;d-=1)if((g=a.V[d])&&g.D&&0>=g.oa&&g.ey)for(c=0;c<a.qo.length;c+=1)k=a.qo[c],!0!==k.ig&&(k.ig=g.ey(k.x,k.y));a.qo=[]}if(0!==a.Dk.length){if(0<a.ii)for(d=a.V.length-1;0<=d;d-=1)if((g=a.V[d])&&g.D&&0>=g.oa&&(g.Sa||g.qb||g.Ug))for(c=0;c<a.Dk.length;c+=1)k=a.Dk[c],!0!==k.ig&&(void 0!==k.wheelDelta&&g.Ug?k.ig=g.Ug(k.wheelDelta,k.x,k.y):k.Se&&g.Sa?k.ig=g.Sa(k.ha,k.x,k.y):void 0!==k.Se&&!k.Se&&g.qb&&(k.ig=g.qb(k.ha,k.x,k.y)));a.Dk=[]}if(0!==a.mm.length){if(0<
a.Bo)for(d=0;d<a.V.length;d+=1)if((g=a.V[d])&&g.D&&0>=g.oa&&(g.pb||g.Jb))for(c=0;c<a.mm.length;c+=1)k=a.mm[c],!0!==k.ig&&(k.Se&&g.pb?k.ig=g.pb(k.key):!k.Se&&g.Jb&&(k.ig=g.Jb(k.key)));a.mm=[]}c=a.Tl;for(d=a.oo.length=0;d<a.jC.length;d+=1)g=a.jC[d],void 0!==g.id&&0===g.paused&&(0<g.Zn||0<g.pA)&&(g.Zn-=c,0>=g.Zn&&(a.oo.push({id:g.id,bo:g.bo}),0<g.pA?(g.pA-=1,g.Zn+=g.time):g.Zn=0));if(0<a.vo&&0<a.oo.length)for(c=0;c<a.V.length;c+=1)if((d=a.V[c])&&d.Sb&&d.D)for(g=0;g<a.oo.length;g+=1)k=a.oo[g],!0===k.ig||
null!==k.bo&&k.bo!==d||(k.ig=d.Sb(k.id));if(0<a.Co&&0<a.Eo.length)for(c=0;c<a.V.length;c+=1)if((g=a.V[c])&&g.xb&&g.D&&0>=g.oa)for(d=0;d<a.Eo.length;d+=1)k=a.Eo[d],!0===k.ig||null!==k.bo&&k.bo!==g||(k.ig=g.xb(k.id,k.yM));a.Eo.length=0;if(0<a.yo)for(c=0;c<a.V.length&&!((d=a.V[c])&&d.Ga&&d.D&&0>=d.oa&&!0===d.Ga(a.Tl));c+=1);Lb(a);Kb(a);a.Ef=b}window.zv=Date.now();window.fC=window.zv-window.Av;window.gC=Math.max(window.iL,1E3/window.hL-window.fC);window.cs(window.eC)};
window.cs=function(a){window.setTimeout(a,window.gC)};window.gL||(window.cs=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||window.cs);
function Lb(a){function b(a,b){return a.W===b.W?b.depth-a.depth:a.W>b.W?-1:1}var c,d;for(c=d=0;c<a.V.length;c+=1)a.V[c]&&(a.V[c].hC&&(a.V[c].hC=!1,a.V[c].D=!0),a.V[d]=a.V[c],d+=1);a.V.length=d;a.ks&&a.V.sort(b);a.ks=!1;for(c=d=0;c<a.ge.length;c+=1)a.ge[c]&&(a.ge[d]=a.ge[c],d+=1);a.ge.length=d;a.Cv&&a.ge.sort(b);a.Cv=!1}
function Mb(a){var b=q;void 0===a.group&&(a.group=0);void 0===a.visible&&(a.visible=!0);void 0===a.D&&(a.D=!0);void 0===a.depth&&(a.depth=0);void 0===a.W&&(a.W=0);void 0===a.oa&&(a.oa=0);void 0===a.Ck&&(a.Ck=[]);a.hC=!1;b.V.push(a);b.ks=!0;a.wa&&(b.wo+=1);a.ey&&(b.xo+=1);if(a.Sa||a.qb)b.ii+=1;a.Ug&&(b.ii+=1);if(a.pb||a.Jb)b.Bo+=1;a.Sb&&(b.vo+=1);a.xb&&(b.Co+=1);a.Ga&&(b.yo+=1);a.fy&&(b.zo+=1);if(a.el||a.Dh)b.Cg+=1;a.iy&&(b.Cg+=1);if(a.gy||a.hy)b.pm+=1;a.jy&&(b.Ao+=1);a.Za&&a.Za()}
function Nb(a,b){var c=q;a.depth!==b&&(c.ks=!0);a.depth=b}function Ob(a,b){var c;b=[].concat(b);void 0===a.Ck&&(a.Ck=[]);for(c=b.length-1;0<=c;c-=1)0>a.Ck.indexOf(b[c])&&a.Ck.push(b[c])}function Pb(a,b){var c=[],d,g;if(void 0===b||"all"===b||"master"===b)for(d=0;d<a.V.length;d+=1)g=a.V[d],void 0!==g&&c.push(g);else if("function"===typeof b)for(d=0;d<a.V.length;d+=1)g=a.V[d],void 0!==g&&b(g)&&c.push(g);else for(d=0;d<a.V.length;d+=1)g=a.V[d],void 0!==g&&0<=g.Ck.indexOf(b)&&c.push(g);return c}
function Qb(a){a.oa+=1}function Ub(a){var b=Pb(q,a);for(a=0;a<b.length;a+=1)Qb(b[a])}function Vb(a){a.oa=Math.max(0,a.oa-1)}function Wb(a){var b=Pb(q,a);for(a=0;a<b.length;a+=1)Vb(b[a])}
function Xb(a,b){var c=a.V.indexOf(b);if(!(0>c)){a.V[c].Qa&&a.V[c].Qa();var d=a.V[c];d.wa&&(a.wo-=1);d.ey&&(a.xo-=1);if(d.Sa||d.qb)a.ii-=1;d.Ug&&(a.ii-=1);if(d.pb||d.Jb)a.Bo-=1;d.Sb&&(a.vo-=1);d.xb&&(a.Co-=1);d.Ga&&(a.yo-=1);d.fy&&(a.zo-=1);if(d.el||d.Dh)a.Cg-=1;d.iy&&(a.Cg-=1);if(d.gy||d.hy)a.pm-=1;d.jy&&(a.Ao-=1);a.V[c]=void 0}}function Yb(a){var b=q,c=Pb(b,a);for(a=0;a<c.length;a+=1)Xb(b,c[a])}
ub.prototype.b=function(a,b,c,d,g,k,l){void 0===l&&(l=0);this.ge.push({pC:0,c:a,ra:b,vM:c,visible:!0,x:d,y:g,uv:1,vv:1,Oa:0,alpha:1,depth:k,W:l,oa:0,Ck:[]});this.Cv=!0;return this.ge[this.ge.length-1]};var q=new ub(aa);new fa;function Zb(a,b){return b}function $b(a,b,c,d){return b+a/d*c}function ac(a,b,c,d,g){void 0===g&&(g=3);return b+c*Math.pow(a/d,g)}function bc(a,b,c,d){return b+c*ac(d-a,1,-1,d,3)}function cc(a,b,c,d){return b+c*(a<d/2?ac(a,0,.5,d/2,2):ac(d-a,1,-.5,d/2,2))}
function dc(a,b,c,d){return ac(a,b,c,d,3)}function ec(a,b,c,d){return bc(a,b,c,d)}function fc(a,b,c,d){return b+c*(a<d/2?ac(a,0,.5,d/2,3):ac(d-a,1,-.5,d/2,3))}function gc(a,b,c,d,g,k){a=d-a;var l=k;void 0===g&&(g=3);void 0===l&&(l=8);k=Math.sin(2*(1-a/d)*Math.PI*g+Math.PI/2);g=l;void 0===g&&(g=8);l=Math.pow(2,-g);k*=0+(Math.pow(2,g*a/d-g)-l)/(1-l)*1;return b+c*(1+-1*k)}function hc(a,b,c,d,g){void 0===g&&(g=1.70158);return b+c*((1+g)*Math.pow(a/d,3)-g*Math.pow(a/d,2))}
function ic(a,b,c,d,g){return b+c*hc(d-a,1,-1,d,g)}
function jc(a,b,c){var d,g=0,k=1,l=[0],m=[0];for(void 0===b&&(b=[]);b.length<a.length;)b.push(!1);for(void 0===c&&(c=[]);c.length<a.length;)c.push(1/a.length);for(d=0;d<a.length;d+=1)g+=c[d];for(d=0;d<a.length;d+=1)c[d]/=g;for(d=0;d<a.length;d+=1)m.push(m[d]+c[d]),g=a[d]===Zb?0:b[d]?-1:1,l.push(l[d]+g),k=Math.max(k,l[d+1]);return function(d,g,z,v,C,x,t){var A,B;A=a.length-1;for(B=0;B<a.length;B+=1)if(d/v<=m[B+1]){A=B;break}d=a[A](d/v-m[A],0,1,c[A],C,x,t);b[A]&&(d=-d);return g+(l[A]+d)*z/k}}
function kc(a,b,c){this.currentTime=this.paused=0;this.speed=1;this.Vj=!1;this.target=a;this.duration=0;this.dj=[];this.Wa=[];if(void 0!==b&&(a=b,void 0!==a))for(a=[].concat(a),b=0;b<a.length;b+=1)lc(this,a[b].kind,a[b].target,a[b].Up,a[b].oj,a[b].keys);void 0!==c&&this.gY(c)}function lc(a,b,c,d,g,k){a.dj.push({kind:b,target:c,Up:d,oj:g,keys:[],Vj:!1,HU:"none",xT:!0,ER:void 0});b=a.dj[a.dj.length-1];void 0!==k&&mc(a,b,k);return b}
function nc(a){var b;for(b=a.duration=0;b<a.dj.length;b+=1){var c=a.dj[b],d=void 0,d=c.keys.length;a.duration=Math.max(a.duration,0===d?0:c.keys[d-1].time)}b=a.Wa.length;a.duration=Math.max(a.duration,0===b?0:a.Wa[b-1].time)}function mc(a,b,c){var d;if(void 0!==c)for(c=[].concat(c),d=0;d<c.length;d+=1){var g=a,k=b,l=c[d].o;void 0===l&&(l=$b);k.keys.push({time:c[d].time,value:c[d].value,o:l,oj:c[d].oj});oc(k);nc(g)}}function oc(a){a.keys.sort(function(a,c){return a.time-c.time})}
function pc(a,b,c,d,g){a.Wa.push({target:b,time:c,Qb:d,oj:g});qc(a);nc(a)}function rc(a){var b,c=0,d;void 0===c&&(c=-99999999);void 0===b&&(b=99999999);for(d=a.Wa.length-1;0<=d;d-=1)a.Wa[d].time>=c&&a.Wa[d].time<=b&&a.Wa.splice(d);nc(a)}function qc(a){a.Wa.sort(function(a,c){return a.time-c.time})}e=kc.prototype;e.pause=function(){this.paused+=1};e.Oi=function(){this.paused-=1};e.Ym=function(){return 0<this.paused};e.lk=function(a){this.Vj=a};
function sc(a,b){a.Vj?(b%=a.duration,0>b&&(b+=a.duration)):b=Math.max(0,Math.min(a.duration,b));return b}
e.setTime=function(a,b){var c;this.currentTime=sc(this,a);if(!b)for(c=0;c<this.dj.length;c+=1){var d=this.dj[c],g=void 0,k=void 0;if(0!==d.keys.length){var g=d,k=this.currentTime,l=void 0,m=l=void 0,m=l=void 0,l=g.keys.length;if(0===l)g=0;else{g.Vj&&(k%=g.keys[l-1].time,0>k&&(k+=g.keys[l-1].time));if(k<=g.keys[0].time)l=g.keys[0].value;else if(k>=g.keys[l-1].time)l=g.keys[l-1].value;else{for(m=0;g.keys[m].time<k;)m+=1;l=g.keys[m-1];m=g.keys[m];l=l.o(k-l.time,l.value,m.value-l.value,m.time-l.time)}switch(g.HU){case "round":l=
Math.round(l);break;case "floor":l=Math.floor(l);break;case "ceil":l=Math.ceil(l)}g=l}if(g!==d.ER||!d.xT)if(k=void 0===d.target?this.target:d.target,void 0!==k||"function"===d.kind)switch(d.kind){case "image":k.c=g;break;case "subImage":k.ra=g;break;case "alpha":k.alpha=g;break;case "xScale":k.mb=g;break;case "yScale":k.Fb=g;break;case "scale":k.scale=g;break;case "angle":k.Oa=g;break;case "x":k.x=g;break;case "y":k.y=g;break;case "speed":k.speed=g;break;case "function":void 0===k?d.Up(g,d.oj):d.Up.call(k,
g,d.oj)}}}};
e.Vb=function(a){var b;if(!(0<this.paused)){a=sc(this,this.currentTime+this.speed*a);b=this.currentTime;var c,d=[];if(0<this.speed)if(a>=b)for(c=0;c<this.Wa.length;c+=1)this.Wa[c].time>b&&this.Wa[c].time<=a&&d.push(this.Wa[c]);else{for(c=0;c<this.Wa.length;c+=1)this.Wa[c].time>b&&d.push(this.Wa[c]);for(c=0;c<this.Wa.length;c+=1)this.Wa[c].time<=a&&d.push(this.Wa[c])}else if(a<=b)for(c=this.Wa.length-1;0<=c;c-=1)this.Wa[c].time<b&&this.Wa[c].time>=a&&d.push(this.Wa[c]);else{for(c=this.Wa.length-1;0<=
c;c-=1)this.Wa[c].time<b&&d.push(this.Wa[c]);for(c=this.Wa.length-1;0<=c;c-=1)this.Wa[c].time>=a&&d.push(this.Wa[c])}for(b=0;b<d.length;b+=1){this.setTime(d[b].time);c=d[b];var g=void 0,g=void 0===c.target?this.target:c.target;if(void 0===g?c.Qb(c.oj):c.Qb.call(g,c.oj)){this.currentTime=d[b].time-1E-7*Math.d0(this.speed);return}}this.setTime(a)}};
function tc(a,b){this.RC=a;var c=b;void 0===c&&(c=window);this.VG=c;this.state=this.SA=this.rr=null;this.lm=0;this.speed=1;this.es=[];uc(this,this.RC);this.Lv=null}e=tc.prototype;e.Zc=function(){return new tc(this.RC,this.VG)};e.Rc=function(a,b){this.state&&this.state.setAnimationByName(0,a,b)};function vc(a,b){a.Lv=b}
e.Gv=function(){var a=this;this.state&&(this.state.onEvent=function(b,c){var d;for(d=0;d<a.es.length;d+=1)a.es[d].event===c.data.name&&a.es[d].Qb&&a.es[d].Qb()},this.state.onComplete=function(){a.Lv&&a.Lv()})};e.pause=function(){this.lm+=1};e.Oi=function(){this.lm-=1};e.Ym=function(){return 0<this.lm};e.Vb=function(a){0<this.lm||(this.state.update(a/1E3*this.speed),this.state.apply(this.rr),this.rr.updateWorldTransform())};e.B=function(a,b){this.ib(a,b,void 0,void 0,void 0,void 0)};
e.Tk=function(a,b,c){this.ib(a,b,void 0,void 0,void 0,c)};
e.ib=function(a,b,c,d,g,k){var l=f.context,m=this.rr.drawOrder,p,w;void 0===a&&(a=0);void 0===b&&(b=0);void 0===k&&(k=1);void 0===c&&(c=1);void 0===d&&(d=1);void 0===g&&(g=0);void 0===k&&(k=1);l.save();l.translate(a,b);l.scale(c,d);l.rotate(g);for(a=0;a<m.length;a+=1)b=m[a],p=b.attachment,p instanceof spine.RegionAttachment&&(c=b.bone,d=c.worldX+p.x*c.m00+p.y*c.m01,g=c.worldY+p.x*c.m10+p.y*c.m11,w=-(c.worldRotation+p.rotation)*Math.PI/180,p=this.VG[p.name],l.save(),l.translate(wc*d/100,wc*g/100),
l.globalAlpha=k*b.a,l.scale(c.worldScaleX,c.worldScaleY),l.rotate(w),p.B(0,-p.width/2,-p.height/2),l.restore());l.restore()};
function uc(a,b){a.SA=(new spine.SkeletonJson({newRegionAttachment:function(a,b){var g=new spine.RegionAttachment(b);g.rendererObject=void 0;return g},newBoundingBoxAttachment:function(a,b){return new spine.BoundingBoxAttachment(b)}})).readSkeletonData(JSON.parse(b));spine.Bone.yDown=!0;a.rr=new spine.Skeleton(a.SA);a.rr.updateWorldTransform();a.$h=new spine.AnimationStateData(a.SA);a.state=new spine.AnimationState(a.$h);a.Gv()}
function xc(a){this.eS=a;this.bF=this.DG=void 0;this.aN=[];this.NT=[];this.Fk=[];this.options="Group Image Button Label PlaceHolder Animation ImageNineSlice".split(" ")}xc.prototype.Wm=function(){this.DG=JSON.parse(this.eS);this.bF=new yc({x:r.O/2,y:r.M/2});zc(this,this.DG,this.bF)};
function zc(a,b,c){for(var d=0;d<b.children.length;d++)for(var g=0;g<a.options.length;g++)if(b.children[d].type===a.options[g]){var k=a,l=b.children[d],m=c;switch(b.children[d].type){case "Group":var p=new s({Em:l.name,x:Ac(l.x),y:Ac(l.y)});k.Fk.push(p);0<l.children.length&&zc(k,l,p);m.d(p);break;case "Image":p=new u({Em:l.name,x:Ac(l.x),y:Ac(l.y),width:y(Number(l.width)),height:y(Number(l.height)),c:window[l.image.replace(".png","").replace(".jpg","")]});k.Fk.push(p);0<l.children.length&&zc(k,l,
p);m.d(p);break;case "Button":p=new D({Em:l.name,x:Ac(l.x),y:Ac(l.y),width:y(Number(l.width)),height:y(Number(l.height)),c:window[l.image.replace(".png","").replace(".jpg","")]});k.aN.push(p);k.Fk.push(p);0<l.children.length&&zc(k,l,p);m.d(p);break;case "Label":p=l.text;l.unityUseLocalizationFile&&(p=E(p));var w=Number(l.fontSize);isNaN(w)&&(w=12);p=new F({Em:l.name,x:Ac(l.x),y:Ac(l.y),width:y(Number(l.width)),height:y(Number(l.height)),font:{l:l.fontName,fontSize:w,align:l.hAlignment,ua:"middle"},
text:p});k.Fk.push(p);0<l.children.length&&zc(k,l,p);m.d(p);break;case "PlaceHolder":p=new s({Em:l.name,x:Ac(l.x),y:Ac(l.y)});k.NT.push(p);k.Fk.push(p);0<l.children.length&&zc(k,l,p);m.d(p);break;case "Animation":p=window[l.fileName.replace(".json","")];w=-1;isNaN(Number(l.delay))||(w=Number(l.delay));p=new Bc({Em:l.name,x:Ac(l.x),y:Ac(l.y),wr:p,No:l.animationQueue[0],repeat:l.loop,play:l.autoPlay,L:w});k.Fk.push(p);0<l.children.length&&zc(k,l,p);m.d(p);break;case "ImageNineSlice":p=new u({Em:l.name,
x:Ac(l.x),y:Ac(l.y),width:y(Number(l.width)),height:y(Number(l.height)),c:window[l.image.replace(".png","").replace(".jpg","")],tb:!0}),k.Fk.push(p),0<l.children.length&&zc(k,l,p),m.d(p)}}}function Ac(a){a=-1*y(Number(a));-0===a&&(a=0);return a}
var Cc=function(){function a(a,c,d,g,k,l){this.orientation=c;this.FT=d;this.QW=g;this.EV=k;this.Lw=l;this.$L=a.adChannel;this.dQ=a.gameCode;this.eQ=a.gameName;this.Wp=a.gameVersion;this.cQ=a.gameCategory;this.SO=a.developerId;this.bQ=a.gameAnalyticsId;this.dW=a.tabIcon;var m=setInterval(function(){this.ready()&&(this.XU(),clearInterval(m))}.bind(this),100)}a.prototype.ready=function(){return window.Booster.ready&&window.Booster.Ad};a.prototype.XU=function(){new Booster.Init({orientation:this.orientation,
splash:!0,minimalUI:!0,rotationOnHide:function(){window.setTimeout(function(){G.Mf()},400)},rotationOnShow:function(){G.ck()}});adSense=new Booster.Ad({type:"adsense",size:"300x250",channelID:this.$L});community=new Booster.Community({position:1,gameCode:this.dQ,tabIcon:this.dW});analytics=new Booster.Analytics({gameName:this.eQ,gameId:this.Wp,gameCategory:this.cQ,developer:this.SO,gameAnalyticsId:this.bQ});moregames=new Booster.Moregames;try{freemium=new Booster.Freemium}catch(a){}var c=this;Booster.onSplashFinishedEvent=
function(){c.EV.call(c.Lw)};Booster.onOpenTab=function(){c.FT.call(c.Lw)};Booster.onCloseTab=function(){c.QW.call(c.Lw)}};return a}(),H={};window.winLineCollection=H;var I={};window.anticipationImages=I;var J={};window.coinSpin=J;var K={};window.scatterCollection=K;var L={};window.symbolsAnimCollection=L;var Dc={};window.leafs=Dc;window.adBorder=new tb("adBorder","adBorder.png");window.adBorderMob=new tb("adBorderMob","adBorderMob.png");window.AppIcon76x76=new tb("AppIcon76x76","AppIcon76x76.png");
window.AppIcon60x60=new tb("AppIcon60x60","AppIcon60x60.png");var M=new ta("FrameworkTexture",1,"frameworkImages");window.FrameworkTexture=M;ua(M,0,"media/FrameworkTexture0.png");var Ec=new ta("FlowStartTexture",1,"startImages");window.FlowStartTexture=Ec;ua(Ec,0,"media/FlowStartTexture0.png");var Fc=new ta("FlowTexture",1,"images");window.FlowTexture=Fc;ua(Fc,0,"media/FlowTexture0.png");var Gc=new ta("UITexture",1,"images");window.UITexture=Gc;ua(Gc,0,"media/UITexture0.png");
var Hc=new ta("fx1",1,"load");window.fx1=Hc;ua(Hc,0,"media/fx10.png");var Ic=new ta("fx2",1,"load");window.fx2=Ic;ua(Ic,0,"media/fx20.png");var Jc=new ta("fx3",1,"load");window.fx3=Jc;ua(Jc,0,"media/fx30.png");var N=new ta("slot",1,"load");window.slot=N;ua(N,0,"media/slot0.png");var Kc=new ta("tutorial",1,"load");window.tutorial=Kc;ua(Kc,0,"media/tutorial0.png");var Lc=new ta("payLines",1,"load");window.payLines=Lc;ua(Lc,0,"media/payLines0.png");var Mc=new ta("gallery",2,"load");window.gallery=Mc;
ua(Mc,0,"media/gallery0.png");ua(Mc,1,"media/gallery1.png");var Nc=new ta("assets",1,"load");window.assets=Nc;ua(Nc,0,"media/assets0.png");var Oc=new ta("bg",1,"load");window.bg=Oc;ua(Oc,0,"media/bg0.png");var O=new ta("texture",1,"load");window.texture=O;ua(O,0,"media/texture0.png");var wc=50,Pc=new h("s_tgf_transparent",M,1,32,32,0,0,32,32,1);window.s_tgf_transparent=Pc;Pc.b(0,0,1021,5,1,1,0,0);var Qc=new h("s_tgf_throbber",M,12,39,39,0,0,468,39,12);window.s_tgf_throbber=Qc;
Qc.b(0,0,853,49,38,39,1,0);Qc.b(1,0,613,41,38,39,1,0);Qc.b(2,0,533,41,38,39,1,0);Qc.b(3,0,453,41,38,39,1,0);Qc.b(4,0,813,49,38,39,1,0);Qc.b(5,0,493,41,38,39,1,0);Qc.b(6,0,653,41,38,39,1,0);Qc.b(7,0,733,41,38,39,1,0);Qc.b(8,0,309,49,38,39,1,0);Qc.b(9,0,693,41,38,39,1,0);Qc.b(10,0,573,41,38,39,1,0);Qc.b(11,0,773,41,38,39,1,0);var Rc=new h("s_tgf_frame",M,1,60,60,0,0,60,60,1);window.s_tgf_frame=Rc;Rc.b(0,0,205,1,60,60,0,0);var P=new h("s_tgf_button",M,2,45,45,0,0,90,45,2);window.s_tgf_button=P;
P.b(0,0,877,1,45,45,0,0);P.b(1,0,829,1,45,45,0,0);var Sc=new h("s_tgf_tutorial_close",M,1,33,33,0,0,33,33,1);window.s_tgf_tutorial_close=Sc;Sc.b(0,0,933,49,33,33,0,0);var Tc=new h("s_tgf_tutorial_next",M,1,33,33,0,0,33,33,1);window.s_tgf_tutorial_next=Tc;Tc.b(0,0,269,53,33,33,0,0);var Uc=new h("s_tgf_tutorial_previous",M,1,33,33,0,0,33,33,1);window.s_tgf_tutorial_previous=Uc;Uc.b(0,0,969,49,33,33,0,0);var Vc=new h("s_tgf_slider_back",M,2,32,8,0,0,32,16,1);window.s_tgf_slider_back=Vc;
Vc.b(0,0,65,61,28,6,2,1);Vc.b(1,0,33,61,28,6,2,1);var Wc=new h("s_tgf_slider_slider",M,1,8,24,0,0,8,24,1);window.s_tgf_slider_slider=Wc;Wc.b(0,0,349,49,8,22,0,1);var Xc=new h("s_tgf_icon_difficulty_easy",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_difficulty_easy=Xc;Xc.b(0,0,361,41,43,43,1,1);var Yc=new h("s_tgf_icon_difficulty_hard",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_difficulty_hard=Yc;Yc.b(0,0,973,1,43,43,1,1);var Zc=new h("s_tgf_icon_difficulty_medium",M,1,44,44,0,0,44,44,1);
window.s_tgf_icon_difficulty_medium=Zc;Zc.b(0,0,925,1,43,43,1,1);var $c=new h("s_tgf_icon_music_off",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_music_off=$c;$c.b(0,0,129,61,27,21,8,12);var ad=new h("s_tgf_icon_music_on",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_music_on=ad;ad.b(0,0,113,85,20,21,11,12);var bd=new h("s_tgf_icon_sound_off",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_sound_off=bd;bd.b(0,0,97,61,27,16,10,14);var cd=new h("s_tgf_icon_sound_on",M,1,44,44,0,0,44,44,1);
window.s_tgf_icon_sound_on=cd;cd.b(0,0,33,69,25,16,10,14);var dd=new h("s_tgf_icon_options",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_options=dd;dd.b(0,0,1,61,29,29,8,8);var ed=new h("s_tgf_icon_play",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_play=ed;ed.b(0,0,1005,49,16,22,16,12);var fd=new h("s_tgf_icon_pause",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_pause=fd;fd.b(0,0,89,81,19,22,13,12);var gd=new h("s_tgf_icon_retry",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_retry=gd;gd.b(0,0,161,61,25,23,11,11);
var hd=new h("s_tgf_icon_undo",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_undo=hd;hd.b(0,0,217,65,25,16,10,15);var id=new h("s_tgf_icon_exit",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_exit=id;id.b(0,0,189,65,25,24,7,11);var jd=new h("s_tgf_icon_quit",M,1,44,44,0,0,44,44,1);window.s_tgf_icon_quit=jd;jd.b(0,0,245,65,21,22,12,12);var kd=new h("s_tgf_icon_play_large",M,1,54,54,0,0,54,54,1);window.s_tgf_icon_play_large=kd;kd.b(0,0,269,1,38,50,10,2);
var ld=new h("s_tgf_icon_retry_large",M,1,54,54,0,0,54,54,1);window.s_tgf_icon_retry_large=ld;ld.b(0,0,309,1,49,45,5,5);var md=new h("s_tgf_notification_warning",M,1,64,64,0,0,64,64,1);window.s_tgf_notification_warning=md;md.b(0,0,137,1,64,58,0,4);var nd=new h("s_tgf_notification_message",M,1,64,64,0,0,64,64,1);window.s_tgf_notification_message=nd;nd.b(0,0,1,1,64,58,0,4);var od=new h("s_tgf_notification_error",M,1,64,64,0,0,64,64,1);window.s_tgf_notification_error=od;od.b(0,0,69,1,64,58,0,4);
var pd=new h("s_tgf_console_play",M,1,24,24,12,12,24,24,1);window.s_tgf_console_play=pd;pd.b(0,0,349,73,9,13,9,6);var qd=new h("s_tgf_console_pause",M,1,24,24,12,12,24,24,1);window.s_tgf_console_pause=qd;qd.b(0,0,453,85,11,13,7,6);var rd=new h("s_tgf_console_restart",M,1,24,24,12,12,24,24,1);window.s_tgf_console_restart=rd;rd.b(0,0,137,85,14,13,6,6);var sd=new h("s_tgf_console_step",M,1,24,24,12,12,24,24,1);window.s_tgf_console_step=sd;sd.b(0,0,1005,73,14,9,5,8);
var td=new h("s_tgf_console_position",M,1,24,24,12,12,24,24,1);window.s_tgf_console_position=td;td.b(0,0,437,69,13,18,6,3);var ud=new h("s_tgf_console_close",M,1,24,24,12,12,24,24,1);window.s_tgf_console_close=ud;ud.b(0,0,217,85,12,13,6,6);var vd=new h("s_tgf_flag_us",M,1,24,24,0,0,24,24,1);window.s_tgf_flag_us=vd;vd.b(0,0,409,69,24,18,0,3);var wd=new h("s_tgf_flag_gb",M,1,24,24,0,0,24,24,1);window.s_tgf_flag_gb=wd;wd.b(0,0,893,77,24,18,0,3);var xd=new h("s_tgf_flag_nl",M,1,24,24,0,0,24,24,1);
window.s_tgf_flag_nl=xd;xd.b(0,0,61,69,24,18,0,3);var yd=new h("s_tgf_flag_tr",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_tr=yd;yd.b(0,0,465,1,48,36,0,6);var zd=new h("s_tgf_flag_de",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_de=zd;zd.b(0,0,777,1,48,36,0,6);var Ad=new h("s_tgf_flag_fr",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_fr=Ad;Ad.b(0,0,621,1,48,36,0,6);var Bd=new h("s_tgf_flag_br",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_br=Bd;Bd.b(0,0,725,1,48,36,0,6);
var Cd=new h("s_tgf_flag_es",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_es=Cd;Cd.b(0,0,361,1,48,36,0,6);var Dd=new h("s_tgf_flag_ru",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_ru=Dd;Dd.b(0,0,517,1,48,36,0,6);var Ed=new h("s_tgf_flag_ar",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_ar=Ed;Ed.b(0,0,673,1,48,36,0,6);var Fd=new h("s_tgf_flag_kr",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_kr=Fd;Fd.b(0,0,569,1,48,36,0,6);var Gd=new h("s_tgf_flag_unknown",M,1,24,24,0,0,24,24,1);window.s_tgf_flag_unknown=Gd;
Gd.b(0,0,1021,1,1,1,0,0);var Hd=new h("s_tgf_flag_jp",M,1,48,48,0,0,48,48,1);window.s_tgf_flag_jp=Hd;Hd.b(0,0,413,1,48,36,0,6);var Id=new h("s_sfx_star",O,8,150,150,0,0,1200,150,8);window.s_sfx_star=Id;Id.b(0,0,1,577,67,65,43,45);Id.b(1,0,505,409,125,122,10,14);Id.b(2,0,1,313,128,127,9,10);Id.b(3,0,769,289,133,131,6,8);Id.b(4,0,505,265,131,137,7,5);Id.b(5,0,641,289,125,135,10,6);Id.b(6,0,905,289,107,131,19,8);Id.b(7,0,377,265,121,149,12,1);var Jd=new h("s_star01_empty",O,1,85,85,0,0,85,85,1);
window.s_star01_empty=Jd;Jd.b(0,0,937,177,82,84,1,1);var Kd=new h("s_star01_fill",O,1,85,85,0,0,85,85,1);window.s_star01_fill=Kd;Kd.b(0,0,369,529,72,75,7,8);var Md=new h("s_star02_empty",O,1,85,85,0,0,85,85,1);window.s_star02_empty=Md;Md.b(0,0,937,89,84,81,1,1);var Nd=new h("s_star02_fill",O,1,85,85,0,0,85,85,1);window.s_star02_fill=Nd;Nd.b(0,0,449,537,74,71,6,8);var Od=new h("s_star03_empty",O,1,85,85,0,0,85,85,1);window.s_star03_empty=Od;Od.b(0,0,937,1,81,84,3,1);
var Pd=new h("s_star03_fill",O,1,85,85,0,0,85,85,1);window.s_star03_fill=Pd;Pd.b(0,0,633,529,72,74,7,8);var Qd=new h("s_tgf_buttonSelect",O,2,45,45,0,0,90,45,2);window.s_tgf_buttonSelect=Qd;Qd.b(0,0,297,633,45,45,0,0);Qd.b(1,0,465,617,45,45,0,0);var Rd=new h("s_logo_tinglygames",O,1,120,120,0,0,120,120,1);window.s_logo_tinglygames=Rd;Rd.b(0,0,265,417,120,84,0,18);var Sd=new h("s_level2_0",O,1,42,44,0,0,42,44,1);window.s_level2_0=Sd;Sd.b(0,0,513,641,42,44,0,0);
var Td=new h("s_level2_1",O,1,42,44,0,0,42,44,1);window.s_level2_1=Td;Td.b(0,0,49,649,42,44,0,0);var Ud=new h("s_level2_2",O,1,42,44,0,0,42,44,1);window.s_level2_2=Ud;Ud.b(0,0,1,649,42,44,0,0);var Vd=new h("s_level2_3",O,1,42,44,0,0,42,44,1);window.s_level2_3=Vd;Vd.b(0,0,97,649,42,44,0,0);var Wd=new h("s_level2_lock",O,1,42,44,0,0,42,44,1);window.s_level2_lock=Wd;Wd.b(0,0,697,649,42,44,0,0);var Xd=new h("blackAdFrame",O,1,64,64,0,0,64,64,1);window.blackAdFrame=Xd;Xd.b(0,0,153,585,64,64,0,0);
var Yd=new h("s_logo_tinglygames_large",Fc,1,120,120,0,0,120,120,1);window.s_logo_tinglygames_large=Yd;Yd.b(0,0,1,1,120,84,0,18);var Zd=new h("s_logo_tinglygames_background",Ec,1,100,100,0,0,100,100,1);window.s_logo_tinglygames_background=Zd;Zd.b(0,0,1,1,100,100,0,0);var $d=new h("s_dialog_load_frame",Ec,1,60,60,0,0,60,60,1);window.s_dialog_load_frame=$d;$d.b(0,0,265,1,60,60,0,0);var ae=new h("s_dialog_load_bar_back",Ec,1,19,10,0,0,19,10,1);window.s_dialog_load_bar_back=ae;
ae.b(0,0,329,1,19,10,0,0);var be=new h("s_dialog_load_bar_fill",Ec,1,15,6,0,0,15,6,1);window.s_dialog_load_bar_fill=be;be.b(0,0,353,1,15,6,0,0);var ce=new h("s_dialog_load_btn_load",Ec,2,77,76,0,0,77,152,1);window.s_dialog_load_btn_load=ce;ce.b(0,0,105,1,77,76,0,0);ce.b(1,0,185,1,77,76,0,0);var de=new h("s_logo_tinglygames_small",O,1,151,54,75,27,151,54,1);window.s_logo_tinglygames_small=de;de.b(0,0,121,489,79,54,37,0);var ee=new h("s_btn_big_start",O,2,77,76,38,38,154,76,2);
window.s_btn_big_start=ee;ee.b(0,0,753,521,77,76,0,0);ee.b(1,0,1,497,77,76,0,0);var fe=new h("s_btn_bigtext",O,2,77,76,38,38,154,76,2);window.s_btn_bigtext=fe;fe.b(0,0,913,521,77,76,0,0);fe.b(1,0,833,521,77,76,0,0);var ge=new h("s_btn_small_exit",O,2,50,46,25,23,100,46,2);window.s_btn_small_exit=ge;ge.b(0,0,297,585,50,46,0,0);ge.b(1,0,713,601,50,46,0,0);var he=new h("s_btn_small_options",O,2,50,46,25,23,100,46,2);window.s_btn_small_options=he;he.b(0,0,769,601,50,46,0,0);he.b(1,0,881,601,50,46,0,0);
var ie=new h("s_btn_small_pause",O,2,50,46,25,23,100,46,2);window.s_btn_small_pause=ie;ie.b(0,0,353,609,50,46,0,0);ie.b(1,0,585,609,50,46,0,0);var je=new h("s_btn_small_undo",O,2,50,46,25,23,100,46,2);window.s_btn_small_undo=je;je.b(0,0,937,601,50,46,0,0);je.b(1,0,825,601,50,46,0,0);var ke=new h("s_btn_standard",O,2,48,46,0,0,96,46,2);window.s_btn_standard=ke;ke.b(0,0,409,617,48,46,0,0);ke.b(1,0,641,609,48,46,0,0);var le=new h("s_btn_toggle",O,2,81,46,40,23,162,46,2);window.s_btn_toggle=le;
le.b(0,0,265,361,81,46,0,0);le.b(1,0,265,313,81,46,0,0);var me=new h("s_buttons_bigtext",O,2,69,52,0,26,138,52,2);window.s_buttons_bigtext=me;me.b(0,0,529,537,69,52,0,0);me.b(1,0,81,545,69,52,0,0);var ne=new h("s_icon_toggle_fxoff",O,2,114,46,56,23,228,46,2);window.s_icon_toggle_fxoff=ne;ne.b(0,0,873,473,114,46,0,0);ne.b(1,0,769,425,114,46,0,0);var oe=new h("s_icon_toggle_fxon",O,2,114,46,56,23,228,46,2);window.s_icon_toggle_fxon=oe;oe.b(0,0,889,425,114,46,0,0);oe.b(1,0,137,441,114,46,0,0);
var pe=new h("s_icon_toggle_music_off",O,1,34,34,16,16,34,34,1);window.s_icon_toggle_music_off=pe;pe.b(0,0,937,265,27,21,4,7);var qe=new h("s_icon_toggle_music_on",O,1,34,34,16,16,34,34,1);window.s_icon_toggle_music_on=qe;qe.b(0,0,1001,265,20,21,7,7);var re=new h("s_icon_toggle_musicoff",O,2,114,46,56,23,228,46,2);window.s_icon_toggle_musicoff=re;re.b(0,0,1,449,114,46,0,0);re.b(1,0,633,481,114,46,0,0);var se=new h("s_icon_toggle_musicon",O,2,114,46,0,0,228,46,2);window.s_icon_toggle_musicon=se;
se.b(0,0,633,433,114,46,0,0);se.b(1,0,753,473,114,46,0,0);var te=new h("s_icon_toggle_sfx_off",O,1,34,34,16,16,34,34,1);window.s_icon_toggle_sfx_off=te;te.b(0,0,641,265,28,16,3,9);var ue=new h("s_icon_toggle_sfx_on",O,1,34,34,16,16,34,34,1);window.s_icon_toggle_sfx_on=ue;ue.b(0,0,969,265,26,16,3,9);var ve=new h("s_buttons_bigtext_play",O,1,33,33,16,16,33,33,1);window.s_buttons_bigtext_play=ve;ve.b(0,0,993,473,26,33,4,0);var we=new h("s_btn_small_retry",O,2,50,46,25,23,100,46,2);
window.s_btn_small_retry=we;we.b(0,0,529,593,50,46,0,0);we.b(1,0,73,601,50,46,0,0);var xe=new h("s_btn_big_restart",O,2,77,76,0,0,154,76,2);window.s_btn_big_restart=xe;xe.b(0,0,209,505,77,76,0,0);xe.b(1,0,289,505,77,76,0,0);var ye=new h("s_profilepicture_default",O,1,64,64,0,0,64,64,1);window.s_profilepicture_default=ye;ye.b(0,0,225,585,64,64,0,0);var ze=new h("s_overlay_worldmap_levelselect",O,1,576,320,0,0,576,320,1);window.s_overlay_worldmap_levelselect=ze;ze.b(0,0,1,1,374,304,56,2);
var Ae=new h("s_tutorialButton_previous",O,1,33,33,0,0,33,33,1);window.s_tutorialButton_previous=Ae;Ae.b(0,0,153,545,33,33,0,0);var Be=new h("s_tutorialButton_next",O,1,33,33,0,0,33,33,1);window.s_tutorialButton_next=Be;Be.b(0,0,81,497,33,33,0,0);var Ce=new h("s_tutorialButton_exit",O,1,33,33,0,0,33,33,1);window.s_tutorialButton_exit=Ce;Ce.b(0,0,713,529,33,33,0,0);var De=new h("s_button_drop_icon_coin",O,1,14,17,0,0,14,17,1);window.s_button_drop_icon_coin=De;De.b(0,0,353,313,14,17,0,0);
var Ee=new h("s_about",O,1,262,281,0,0,262,281,1);window.s_about=Ee;Ee.b(0,0,673,1,262,281,0,0);var Fe=new h("s_ui_background",Gc,1,70,290,0,0,70,290,1);window.s_ui_background=Fe;Fe.b(0,0,1,1,70,289,0,1);var Ge=new h("s_ui_progress_round_background",Gc,1,60,95,30,30,60,95,1);window.s_ui_progress_round_background=Ge;Ge.b(0,0,73,1,60,95,0,0);var He=new h("s_ui_progress_round_foreground",Gc,1,60,59,30,30,60,59,1);window.s_ui_progress_round_foreground=He;He.b(0,0,137,1,60,59,0,0);
var Ie=new h("s_ui_star_empty",Gc,1,12,12,6,6,12,12,1);window.s_ui_star_empty=Ie;Ie.b(0,0,217,1,12,12,0,0);var Je=new h("s_ui_star_filled",Gc,1,12,12,6,6,12,12,1);window.s_ui_star_filled=Je;Je.b(0,0,201,1,12,12,0,0);var Ke=new h("symbolScatter",N,1,122,176,0,12,122,176,1);window.symbolScatter=Ke;Ke.b(0,0,889,1433,122,176,0,0);var Le=new h("symbol8",N,1,121,145,0,0,121,145,1);window.symbol8=Le;Le.b(0,0,1273,1513,121,145,0,0);var Me=new h("symbol9",N,1,121,145,0,0,121,145,1);window.symbol9=Me;
Me.b(0,0,1401,1513,121,145,0,0);var Ne=new h("symbol10",N,1,121,145,0,0,121,145,1);window.symbol10=Ne;Ne.b(0,0,353,1569,121,145,0,0);H.iK=new h("winBox_01",Ic,1,177,211,0,0,177,211,1);H.winBox_01=H.iK;H.iK.b(0,0,761,889,175,209,1,1);H.jK=new h("winBox_03",Ic,1,197,232,0,0,197,232,1);H.winBox_03=H.jK;H.jK.b(0,0,1,889,196,230,1,1);H.kK=new h("winBox_05",Ic,1,211,243,0,0,211,243,1);H.winBox_05=H.kK;H.kK.b(0,0,1329,881,210,242,1,1);H.lK=new h("winBox_07",Ic,1,224,254,0,0,224,254,1);H.winBox_07=H.lK;
H.lK.b(0,0,529,881,223,253,1,1);H.mK=new h("winBox_09",Ic,1,239,266,0,0,239,266,1);H.winBox_09=H.mK;H.mK.b(0,0,1,617,238,265,1,1);H.nK=new h("winBox_11",Ic,1,255,282,0,0,255,282,1);H.winBox_11=H.nK;H.nK.b(0,0,833,601,254,281,1,1);H.oK=new h("winBox_13",Ic,1,262,291,0,0,262,291,1);H.winBox_13=H.oK;H.oK.b(0,0,1393,305,261,289,1,1);H.pK=new h("winBox_15",Ic,1,265,300,0,0,265,300,1);H.winBox_15=H.pK;H.pK.b(0,0,1393,1,264,299,1,1);H.qK=new h("winBox_17",Ic,1,267,302,0,0,267,302,1);H.winBox_17=H.qK;
H.qK.b(0,0,1121,1,266,300,1,2);H.rK=new h("winBox_19",Ic,1,265,294,0,0,265,294,1);H.winBox_19=H.rK;H.rK.b(0,0,1665,297,264,291,1,2);H.sK=new h("winBox_21",Ic,1,264,286,0,0,264,286,1);H.winBox_21=H.sK;H.sK.b(0,0,281,321,263,285,1,1);H.tK=new h("winBox_23",Ic,1,262,282,0,0,262,282,1);H.winBox_23=H.tK;H.tK.b(0,0,1657,593,261,281,1,1);H.uK=new h("winBox_25",Ic,1,256,277,0,0,256,277,1);H.winBox_25=H.uK;H.uK.b(0,0,1353,601,254,275,1,1);H.vK=new h("winBox_27",Ic,1,249,272,0,0,249,272,1);H.winBox_27=H.vK;
H.vK.b(0,0,273,609,247,271,1,1);H.wK=new h("winBox_29",Ic,1,258,277,0,0,258,277,1);H.winBox_29=H.wK;H.wK.b(0,0,1089,601,256,276,1,1);H.xK=new h("winBox_31",Ic,1,264,283,0,0,264,283,1);H.winBox_31=H.xK;H.xK.b(0,0,1,329,263,282,1,1);H.yK=new h("winBox_33",Ic,1,268,291,0,0,268,291,1);H.winBox_33=H.yK;H.yK.b(0,0,1121,305,267,290,1,1);H.zK=new h("winBox_35",Ic,1,275,304,0,0,275,304,1);H.winBox_35=H.zK;H.zK.b(0,0,841,1,274,303,1,1);H.AK=new h("winBox_37",Ic,1,276,315,0,0,276,315,1);H.winBox_37=H.AK;
H.AK.b(0,0,281,1,275,314,1,1);H.BK=new h("winBox_39",Ic,1,276,322,0,0,276,322,1);H.winBox_39=H.BK;H.BK.b(0,0,1,1,276,320,0,2);H.CK=new h("winBox_41",Ic,1,276,312,0,0,276,312,1);H.winBox_41=H.CK;H.CK.b(0,0,561,1,275,309,1,2);H.DK=new h("winBox_43",Ic,1,272,296,0,0,272,296,1);H.winBox_43=H.DK;H.DK.b(0,0,1665,1,271,294,1,1);H.EK=new h("winBox_45",Ic,1,269,291,0,0,269,291,1);H.winBox_45=H.EK;H.EK.b(0,0,561,313,268,289,1,1);H.FK=new h("winBox_47",Ic,1,263,287,0,0,263,287,1);H.winBox_47=H.FK;
H.FK.b(0,0,833,313,262,286,1,1);H.GK=new h("winBox_49",Ic,1,248,267,0,0,248,267,1);H.winBox_49=H.GK;H.GK.b(0,0,529,609,246,266,1,1);H.HK=new h("winBox_51",Ic,1,239,248,0,0,239,248,1);H.winBox_51=H.HK;H.HK.b(0,0,1089,881,238,246,1,1);H.IK=new h("winBox_53",Ic,1,233,241,0,0,233,241,1);H.winBox_53=H.IK;H.IK.b(0,0,1545,881,232,240,1,1);H.JK=new h("winBox_55",Ic,1,239,231,0,0,239,231,1);H.winBox_55=H.JK;H.JK.b(0,0,1785,881,238,230,1,1);H.KK=new h("winBox_57",Ic,1,229,217,0,0,229,217,1);H.winBox_57=H.KK;
H.KK.b(0,0,201,889,228,216,1,1);var Pe=new h("btnSpin",N,2,192,88,0,0,384,88,2);window.btnSpin=Pe;Pe.b(0,0,1113,1321,192,88,0,0);Pe.b(1,0,689,1409,192,88,0,0);var Qe=new h("btnSpinDown",N,2,192,88,0,0,384,88,2);window.btnSpinDown=Qe;Qe.b(0,0,1113,1417,192,88,0,0);Qe.b(1,0,1513,1417,192,88,0,0);var Re=new h("iconCredit",N,1,38,39,0,0,38,39,1);window.iconCredit=Re;Re.b(0,0,401,673,38,39,0,0);var Se=new h("iconHelp",N,1,17,32,0,0,17,32,1);window.iconHelp=Se;Se.b(0,0,2025,465,17,32,0,0);
var Te=new h("iconMenu",N,1,35,24,0,0,35,24,1);window.iconMenu=Te;Te.b(0,0,1377,713,35,24,0,0);var Ue=new h("iconMin",N,1,27,6,0,0,27,6,1);window.iconMin=Ue;Ue.b(0,0,1465,529,27,6,0,0);var Ve=new h("iconPlus",N,1,27,28,0,0,27,28,1);window.iconPlus=Ve;Ve.b(0,0,2017,801,27,28,0,0);var We=new h("UiBottom",N,1,485,94,0,0,485,94,1);window.UiBottom=We;We.b(0,0,977,489,485,94,0,0);var Xe=new h("UiTop",N,1,493,66,0,0,493,66,1);window.UiTop=Xe;Xe.b(0,0,1529,465,493,66,0,0);
var Ye=new h("btnMinus",N,2,67,47,0,0,134,47,2);window.btnMinus=Ye;Ye.b(0,0,529,1817,67,47,0,0);Ye.b(1,0,457,1817,67,47,0,0);var Ze=new h("btnPlus",N,2,68,47,0,0,136,47,2);window.btnPlus=Ze;Ze.b(0,0,617,993,68,47,0,0);Ze.b(1,0,193,1425,68,47,0,0);var $e=new h("btnMenu",N,2,68,52,0,0,136,52,2);window.btnMenu=$e;$e.b(0,0,265,1225,68,52,0,0);$e.b(1,0,1969,1345,68,52,0,0);var af=new h("btnGallery",N,2,67,52,0,0,134,52,2);window.btnGallery=af;af.b(0,0,609,1809,67,52,0,0);af.b(1,0,681,1809,67,52,0,0);
var bf=new h("btnSmallOrange",N,2,157,61,0,0,314,61,2);window.btnSmallOrange=bf;bf.b(0,0,1777,857,155,60,1,0);bf.b(1,0,761,905,155,60,1,0);var Q=new h("btnBigGreen",N,2,344,61,0,0,688,61,2);window.btnBigGreen=Q;Q.b(0,0,1,985,342,60,1,0);Q.b(1,0,1377,921,342,60,1,0);var cf=new h("btnSmallGreen",N,2,157,61,0,0,314,61,2);window.btnSmallGreen=cf;cf.b(0,0,889,1225,155,60,1,0);cf.b(1,0,353,1505,155,60,1,0);var df=new h("spinCounter",N,1,462,122,0,0,462,122,1);window.spinCounter=df;
df.b(0,0,1465,537,462,122,0,0);var ef=new h("spinCounterBlue",N,1,462,122,0,0,462,122,1);window.spinCounterBlue=ef;ef.b(0,0,977,585,462,122,0,0);var ff=new h("winnerHeader",N,1,233,49,0,0,233,49,1);window.winnerHeader=ff;ff.b(0,0,1777,801,233,49,0,0);var gf=new h("headerSetting",N,1,265,50,0,0,265,50,1);window.headerSetting=gf;gf.b(0,0,1777,745,265,50,0,0);var hf=new h("spinAuto",N,1,200,108,0,0,200,108,1);window.spinAuto=hf;hf.b(0,0,1369,1305,200,108,0,0);
var jf=new h("spinWin",N,1,200,108,0,0,200,108,1);window.spinWin=jf;jf.b(0,0,697,1297,200,108,0,0);var kf=new h("spinLock",N,1,200,108,0,0,200,108,1);window.spinLock=kf;kf.b(0,0,905,1321,200,108,0,0);var lf=new h("btnSpinLock",N,2,192,88,0,0,384,88,2);window.btnSpinLock=lf;lf.b(0,0,1713,1417,192,88,0,0);lf.b(1,0,1313,1417,192,88,0,0);var mf=new h("btnBigOrange",N,2,344,61,0,0,688,61,2);window.btnBigOrange=mf;mf.b(0,0,745,985,342,60,1,0);mf.b(1,0,401,929,342,60,1,0);
var nf=new h("notEnoughCoins",N,1,396,37,0,0,396,37,1);window.notEnoughCoins=nf;nf.b(0,0,1,593,396,37,0,0);var of=new h("iconMusic",N,1,32,34,0,0,32,34,1);window.iconMusic=of;of.b(0,0,401,721,32,34,0,0);var pf=new h("iconSound",N,1,43,31,0,0,43,31,1);window.iconSound=pf;pf.b(0,0,921,945,43,31,0,0);var qf=new h("iconMusicOff",N,1,52,34,0,0,52,34,1);window.iconMusicOff=qf;qf.b(0,0,1465,489,52,34,0,0);var rf=new h("iconSoundOff",N,1,46,31,0,0,46,31,1);window.iconSoundOff=rf;
rf.b(0,0,921,905,46,31,0,0);var sf=new h("btnSpinFree",N,2,192,88,0,0,384,88,2);window.btnSpinFree=sf;sf.b(0,0,1,1329,192,88,0,0);sf.b(1,0,489,1409,192,88,0,0);var tf=new h("spinFree",N,1,200,108,0,0,200,108,1);window.spinFree=tf;tf.b(0,0,489,1297,200,108,0,0);var uf=new h("xpBarEmpty",N,1,460,36,0,0,460,36,1);window.xpBarEmpty=uf;uf.b(0,0,1441,705,460,36,0,0);var vf=new h("xpBarFill",N,1,15,26,0,12,15,26,1);window.xpBarFill=vf;vf.b(0,0,2025,505,15,26,0,0);
var wf=new h("popupGoal",N,1,142,94,0,0,142,94,1);window.popupGoal=wf;wf.b(0,0,1361,1665,142,94,0,0);I.TC=new h("anticipationbox_00",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_00=I.TC;I.TC.b(0,0,1281,553,249,544,0,4);I.UC=new h("anticipationbox_02",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_02=I.UC;I.UC.b(0,0,1025,553,249,544,0,4);I.VC=new h("anticipationbox_04",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_04=I.VC;I.VC.b(0,0,769,553,250,545,0,3);
I.WC=new h("anticipationbox_06",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_06=I.WC;I.WC.b(0,0,257,553,250,545,0,3);I.XC=new h("anticipationbox_08",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_08=I.XC;I.XC.b(0,0,513,553,250,545,0,3);I.YC=new h("anticipationbox_10",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_10=I.YC;I.YC.b(0,0,1793,1,250,545,0,3);I.ZC=new h("anticipationbox_12",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_12=I.ZC;I.ZC.b(0,0,1537,1,250,545,0,3);
I.$C=new h("anticipationbox_14",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_14=I.$C;I.$C.b(0,0,1281,1,250,545,0,3);I.aD=new h("anticipationbox_16",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_16=I.aD;I.aD.b(0,0,257,1,250,545,0,3);I.bD=new h("anticipationbox_18",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_18=I.bD;I.bD.b(0,0,513,1,250,545,0,3);I.cD=new h("anticipationbox_20",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_20=I.cD;I.cD.b(0,0,769,1,250,545,0,3);
I.dD=new h("anticipationbox_22",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_22=I.dD;I.dD.b(0,0,1025,1,250,545,0,3);I.eD=new h("anticipationbox_24",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_24=I.eD;I.eD.b(0,0,1,1,250,545,0,3);I.fD=new h("anticipationbox_26",Hc,1,250,550,125,275,250,550,1);I.anticipationbox_26=I.fD;I.fD.b(0,0,1,553,250,545,0,3);var xf=new h("collectParticles_00",N,1,300,300,0,0,300,300,1);window.collectParticles_00=xf;xf.b(0,0,961,1817,64,63,124,121);
var yf=new h("collectParticles_01",N,1,300,300,0,0,300,300,1);window.collectParticles_01=yf;yf.b(0,0,1577,1305,116,104,97,100);var zf=new h("collectParticles_02",N,1,300,300,0,0,300,300,1);window.collectParticles_02=zf;zf.b(0,0,193,1489,158,138,75,83);var Af=new h("collectParticles_03",N,1,300,300,0,0,300,300,1);window.collectParticles_03=Af;Af.b(0,0,889,1049,193,170,58,70);var Bf=new h("collectParticles_04",N,1,300,300,0,0,300,300,1);window.collectParticles_04=Bf;Bf.b(0,0,265,1281,222,199,43,58);
var Cf=new h("collectParticles_05",N,1,300,300,0,0,300,300,1);window.collectParticles_05=Cf;Cf.b(0,0,1713,1185,247,223,31,49);var Df=new h("collectParticles_06",N,1,300,300,0,0,300,300,1);window.collectParticles_06=Df;Df.b(0,0,617,1049,269,243,20,41);var Ef=new h("collectParticles_07",N,1,300,300,0,0,300,300,1);window.collectParticles_07=Ef;Ef.b(0,0,1761,921,286,259,11,34);var Ff=new h("collectParticles_08",N,1,300,300,0,0,300,300,1);window.collectParticles_08=Ff;Ff.b(0,0,1425,1033,279,265,10,28);
var Gf=new h("collectParticles_09",N,1,300,300,0,0,300,300,1);window.collectParticles_09=Gf;Gf.b(0,0,1,1049,259,276,21,22);var Hf=new h("collectParticles_10",N,1,300,300,0,0,300,300,1);window.collectParticles_10=Hf;Hf.b(0,0,345,993,266,283,18,15);var If=new h("collectParticles_11",N,1,300,300,0,0,300,300,1);window.collectParticles_11=If;If.b(0,0,1089,1041,272,278,15,11);var Jf=new h("collectGlow",N,1,129,129,0,0,129,129,1);window.collectGlow=Jf;Jf.b(0,0,1505,1665,129,129,0,0);
var Kf=new h("maskBet",N,1,144,75,0,0,144,75,1);window.maskBet=Kf;Kf.b(0,0,1209,1665,144,75,0,0);var Lf=new h("maskCoins",N,1,330,45,0,0,330,45,1);window.maskCoins=Lf;Lf.b(0,0,1425,985,330,44,0,1);var Mf=new h("maskCollectables",N,1,354,112,0,0,354,112,1);window.maskCollectables=Mf;Mf.b(0,0,401,809,354,112,0,0);var Nf=new h("maskCollection",N,1,67,52,0,0,67,52,1);window.maskCollection=Nf;Nf.b(0,0,889,1817,67,52,0,0);var Of=new h("maskScatter",N,1,122,176,0,0,122,176,1);window.maskScatter=Of;
Of.b(0,0,1913,1417,122,176,0,0);var Pf=new h("maskSpin",N,1,204,94,0,0,204,94,1);window.maskSpin=Pf;Pf.b(0,0,761,809,204,94,0,0);var Qf=new h("maskSymbol",N,1,123,145,0,0,123,145,1);window.maskSymbol=Qf;Qf.b(0,0,1785,1513,123,145,0,0);var Rf=new h("maskWheel",N,1,125,125,62,62,125,125,1);window.maskWheel=Rf;Rf.b(0,0,1753,1665,125,125,0,0);var Sf=new h("darkOverlay",O,1,125,125,0,0,125,125,1);window.darkOverlay=Sf;Sf.b(0,0,137,313,125,125,0,0);var Tf=new h("maskCollect",N,1,154,154,154,0,154,154,1);
window.maskCollect=Tf;Tf.b(0,0,513,1505,154,154,0,0);var Uf=new h("maskProgressBar",N,1,460,36,0,0,460,36,1);window.maskProgressBar=Uf;Uf.b(0,0,1441,665,460,36,0,0);J.$D=new h("coin_back",N,1,73,73,0,0,73,73,1);J.coin_back=J.$D;J.$D.b(0,0,1673,1801,73,73,0,0);J.aE=new h("coin_back_2",N,1,57,57,0,0,57,57,1);J.coin_back_2=J.aE;J.aE.b(0,0,825,1505,57,57,0,0);J.dE=new h("coin_front",N,1,73,73,0,0,73,73,1);J.coin_front=J.dE;J.dE.b(0,0,1969,1185,73,73,0,0);
J.eE=new h("coin_front_2",N,1,57,57,0,0,57,57,1);J.coin_front_2=J.eE;J.eE.b(0,0,609,1665,57,57,0,0);J.hE=new h("coin_rotate",N,1,55,73,0,0,55,73,1);J.coin_rotate=J.hE;J.hE.b(0,0,201,1329,55,73,0,0);J.jE=new h("coin_side",N,1,15,73,0,0,15,73,1);J.coin_side=J.jE;J.jE.b(0,0,401,593,15,73,0,0);J.bE=new h("coin_back_2_l",N,1,57,57,0,0,57,57,1);J.coin_back_2_l=J.bE;J.bE.b(0,0,609,1729,57,57,0,0);J.cE=new h("coin_back_l",N,1,73,73,0,0,73,73,1);J.coin_back_l=J.cE;J.cE.b(0,0,177,1785,73,73,0,0);
J.fE=new h("coin_front_2_l",N,1,57,57,0,0,57,57,1);J.coin_front_2_l=J.fE;J.fE.b(0,0,1985,1753,57,57,0,0);J.gE=new h("coin_front_l",N,1,73,73,0,0,73,73,1);J.coin_front_l=J.gE;J.gE.b(0,0,1593,1801,73,73,0,0);J.iE=new h("coin_rotate_l",N,1,55,73,0,0,55,73,1);J.coin_rotate_l=J.iE;J.iE.b(0,0,1969,1265,55,73,0,0);J.kE=new h("coin_side_l",N,1,15,73,0,0,15,73,1);J.coin_side_l=J.kE;J.kE.b(0,0,1441,585,15,73,0,0);K.vF=new h("glow_state1",Jc,1,259,261,0,0,259,261,1);K.glow_state1=K.vF;
K.vF.b(0,0,1769,1097,259,255,0,1);K.wF=new h("glow_state2",Jc,1,259,261,0,0,259,261,1);K.glow_state2=K.wF;K.wF.b(0,0,1505,1097,259,260,0,1);K.xF=new h("glow_state3",Jc,1,259,261,0,0,259,261,1);K.glow_state3=K.xF;K.xF.b(0,0,1241,977,259,261,0,0);K.bI=new h("scatterBreak_00",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_00=K.bI;K.bI.b(0,0,513,1201,240,251,7,38);K.cI=new h("scatterBreak_01",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_01=K.cI;K.cI.b(0,0,993,913,243,280,4,11);
K.dI=new h("scatterBreak_02",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_02=K.dI;K.dI.b(0,0,1,969,244,277,3,14);K.eI=new h("scatterBreak_03",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_03=K.eI;K.eI.b(0,0,1,681,246,283,3,9);K.fI=new h("scatterBreak_04",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_04=K.fI;K.fI.b(0,0,249,865,244,282,3,10);K.gI=new h("scatterBreak_05",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_05=K.gI;K.gI.b(0,0,497,865,244,282,3,9);K.hI=new h("scatterBreak_06",Jc,1,250,300,0,0,250,300,1);
K.scatterBreak_06=K.hI;K.hI.b(0,0,745,913,244,282,3,9);K.iI=new h("scatterBreak_07",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_07=K.iI;K.iI.b(0,0,1313,689,244,282,3,9);K.jI=new h("scatterBreak_08",Jc,1,250,300,0,0,250,300,1);K.scatterBreak_08=K.jI;K.jI.b(0,0,1561,809,244,282,3,9);K.vJ=new h("symbolScatter",Jc,1,122,176,0,0,122,176,1);K.symbolScatter=K.vJ;K.vJ.b(0,0,1881,1,122,176,0,0);K.sJ=new h("symbol8",Jc,1,121,145,0,0,121,145,1);K.symbol8=K.sJ;K.sJ.b(0,0,1881,185,121,145,0,0);
K.tJ=new h("symbol9",Jc,1,121,145,0,0,121,145,1);K.symbol9=K.tJ;K.tJ.b(0,0,721,561,121,145,0,0);K.XI=new h("symbol10",Jc,1,121,145,0,0,121,145,1);K.symbol10=K.XI;K.XI.b(0,0,1881,337,121,145,0,0);var Vf=new h("wheel1",Mc,1,413,413,0,0,413,413,1);window.wheel1=Vf;Vf.b(0,0,1633,329,413,413,0,0);var Wf=new h("maskWheel1",Mc,1,204,204,101,101,204,204,1);window.maskWheel1=Wf;Wf.b(0,0,465,1841,204,204,0,0);var Xf=new h("maskWheel2",Mc,1,204,204,101,101,204,204,1);window.maskWheel2=Xf;
Xf.b(0,0,257,1841,204,204,0,0);var Yf=new h("maskWheel3",Mc,1,179,157,89,78,179,157,1);window.maskWheel3=Yf;Yf.b(0,0,1601,1889,179,157,0,0);var Zf=new h("framingTop",Mc,1,551,320,0,0,551,320,1);window.framingTop=Zf;Zf.b(0,0,1089,1,549,320,2,0);var $f=new h("framingTop2",Mc,1,551,320,0,0,551,320,1);window.framingTop2=$f;$f.b(0,0,537,1,550,320,0,0);var ag=new h("plantsTopRight",Mc,1,403,234,0,0,403,234,1);window.plantsTopRight=ag;ag.b(0,0,1641,1,403,234,0,0);
var cg=new h("plantsTop",Mc,1,540,237,0,0,540,237,1);window.plantsTop=cg;cg.b(0,0,1089,737,540,231,0,0);var dg=new h("plantsTopLeft",Mc,1,403,238,0,0,403,238,1);window.plantsTopLeft=dg;dg.b(0,0,1633,745,403,238,0,0);var eg=new h("btnWheelSpin",Mc,2,124,126,0,0,248,126,2);window.btnWheelSpin=eg;eg.b(0,0,1785,1889,124,126,0,0);eg.b(1,0,1913,1905,124,126,0,0);var fg=new h("pointer",Mc,1,92,64,58,44,92,64,1);window.pointer=fg;fg.b(0,0,769,1953,92,64,0,0);
var gg=new h("pointer2",Mc,1,92,64,37,29,92,64,1);window.pointer2=gg;gg.b(0,0,865,1953,83,61,0,0);var hg=new h("wheelPlantsLeftBottom",Mc,1,369,246,0,0,369,246,1);window.wheelPlantsLeftBottom=hg;hg.b(0,0,1633,1233,369,246,0,0);var ig=new h("wheelPlantsRightBottom",Mc,1,366,229,0,0,366,229,1);window.wheelPlantsRightBottom=ig;ig.b(0,0,1633,1481,365,229,1,0);var jg=new h("artefact1Small",Mc,1,124,109,0,0,124,109,1);window.artefact1Small=jg;jg.b(0,1,529,1,124,109,0,0);
var kg=new h("artefact2Small",Mc,1,103,131,0,0,103,131,1);window.artefact2Small=kg;kg.b(0,0,985,1553,102,131,1,0);var lg=new h("artefact3Small",Mc,1,124,73,0,0,124,73,1);window.artefact3Small=lg;lg.b(0,0,1841,241,121,70,0,2);var mg=new h("artefact4Small",Mc,1,99,94,0,0,99,94,1);window.artefact4Small=mg;mg.b(0,0,985,1689,99,94,0,0);var ng=new h("artefact5Small",Mc,1,93,72,0,0,93,72,1);window.artefact5Small=ng;ng.b(0,0,673,1953,93,72,0,0);var og=new h("wheelGold",Mc,1,527,610,263,304,527,610,1);
window.wheelGold=og;og.b(0,0,1,1,527,610,0,0);var pg=new h("btnWheelSpinEmpty",Mc,1,124,126,0,0,124,126,1);window.btnWheelSpinEmpty=pg;pg.b(0,1,401,1,124,126,0,0);var qg=new h("iconNext",Kc,1,28,24,0,0,28,24,1);window.iconNext=qg;qg.b(0,0,2009,1,28,24,0,0);var rg=new h("iconPrev",Kc,1,28,24,0,0,28,24,1);window.iconPrev=rg;rg.b(0,0,1977,1,28,24,0,0);var sg=new h("btnMiniGreen",Kc,2,89,60,0,0,178,60,2);window.btnMiniGreen=sg;sg.b(0,0,1785,1,89,60,0,0);sg.b(1,0,1881,1,89,60,0,0);
var tg=new h("howToPlayHeader",Kc,1,354,44,0,0,354,44,1);window.howToPlayHeader=tg;tg.b(0,0,977,593,354,44,0,0);var ug=new h("popupBig",Kc,1,476,791,0,0,476,791,1);window.popupBig=ug;ug.b(0,0,1,1,476,791,0,0);var vg=new h("paytableInfo1",Kc,1,488,620,0,0,488,620,1);window.paytableInfo1=vg;vg.b(0,0,1345,577,482,519,0,0);var wg=new h("paytableInfo2",Kc,1,421,587,0,0,421,587,1);window.paytableInfo2=wg;wg.b(0,0,921,1,421,587,0,0);var xg=new h("paytableInfo3",Kc,1,488,566,0,0,488,566,1);
window.paytableInfo3=xg;xg.b(0,0,481,609,488,466,0,35);var yg=new h("paytableInfo4",Kc,1,446,598,0,0,446,598,1);window.paytableInfo4=yg;yg.b(0,0,1345,1,432,571,7,27);var zg=new h("paytableWinlines",Kc,1,436,602,0,0,436,602,1);window.paytableWinlines=zg;zg.b(0,0,481,1,436,602,0,0);var Ag=new h("beams1",Jc,1,448,450,0,0,448,450,1);window.beams1=Ag;Ag.b(0,0,457,105,446,447,1,1);var Bg=new h("beams2",Jc,1,450,455,0,0,450,455,1);window.beams2=Bg;Bg.b(0,0,1,105,449,451,1,1);
var Cg=new h("beams3",Jc,1,457,462,0,0,457,462,1);window.beams3=Cg;Cg.b(0,0,961,1,456,461,1,1);var Dg=new h("beams4",Jc,1,452,462,0,0,452,462,1);window.beams4=Dg;Dg.b(0,0,1425,1,450,460,1,1);var Eg=new h("beams5",Jc,1,403,447,0,0,403,447,1);window.beams5=Eg;Eg.b(0,0,905,465,403,445,0,1);var Fg=new h("big",Jc,1,283,147,0,0,283,147,1);window.big=Fg;Fg.b(0,0,1649,657,283,147,0,0);var Gg=new h("glow",Jc,1,339,302,0,0,339,302,1);window.glow=Gg;Gg.b(0,0,377,561,339,302,0,0);
var Hg=new h("txtFortune",Jc,1,441,91,0,0,441,91,1);window.txtFortune=Hg;Hg.b(0,0,1313,465,441,91,0,0);var Ig=new h("txtFree",Jc,1,330,120,0,0,330,120,1);window.txtFree=Ig;Ig.b(0,0,1313,561,330,120,0,0);var Jg=new h("txtOf",Jc,1,122,76,0,0,122,76,1);window.txtOf=Jg;Jg.b(0,0,249,681,122,76,0,0);var Kg=new h("txtSpins",Jc,1,371,118,0,0,371,118,1);window.txtSpins=Kg;Kg.b(0,0,1,561,371,118,0,0);var Lg=new h("txtWheel",Jc,1,323,90,0,0,323,90,1);window.txtWheel=Lg;Lg.b(0,0,1649,561,323,90,0,0);
var Mg=new h("txtWin",Jc,1,258,118,0,0,258,118,1);window.txtWin=Mg;Mg.b(0,0,249,1153,255,117,1,1);var Ng=new h("congratulations",Jc,1,468,98,0,0,468,98,1);window.congratulations=Ng;Ng.b(0,0,489,1,468,98,0,0);var Og=new h("lvlUp",Jc,1,485,98,0,0,485,98,1);window.lvlUp=Og;Og.b(0,0,1,1,485,98,0,0);L.YI=new h("symbol1Jewel",N,1,110,110,0,0,110,110,1);L.symbol1Jewel=L.YI;L.YI.b(0,0,1881,1753,97,106,8,4);L.ZI=new h("symbol2Jewel",N,1,108,106,0,0,108,106,1);L.symbol2Jewel=L.ZI;
L.ZI.b(0,0,1209,1745,106,105,1,1);L.$I=new h("symbol3Jewel",N,1,99,99,0,0,99,99,1);L.symbol3Jewel=L.$I;L.$I.b(0,0,1409,1761,91,93,4,6);L.aJ=new h("symbol4Bg",N,1,121,145,0,0,121,145,1);L.symbol4Bg=L.aJ;L.aJ.b(0,0,1913,1601,121,145,0,0);L.bJ=new h("symbol4BgBlue",N,1,121,145,0,0,121,145,1);L.symbol4BgBlue=L.bJ;L.bJ.b(0,0,1529,1513,121,145,0,0);L.cJ=new h("symbol4Body",N,1,107,127,0,0,107,127,1);L.symbol4Body=L.cJ;L.cJ.b(0,0,1641,1665,105,127,1,0);L.dJ=new h("symbol4Head",N,1,25,16,0,0,25,16,1);
L.symbol4Head=L.dJ;L.dJ.b(0,0,1721,921,25,15,0,1);L.eJ=new h("symbol5Bg",N,1,121,145,0,0,121,145,1);L.symbol5Bg=L.eJ;L.eJ.b(0,0,1657,1513,121,145,0,0);L.fJ=new h("symbol5BgBlue",N,1,121,145,0,0,121,145,1);L.symbol5BgBlue=L.fJ;L.fJ.b(0,0,825,1617,121,145,0,0);L.gJ=new h("symbol5Body",N,1,95,123,0,0,95,123,1);L.symbol5Body=L.gJ;L.gJ.b(0,0,257,1633,94,123,1,0);L.hJ=new h("symbol5Head",N,1,88,68,0,0,88,68,1);L.symbol5Head=L.hJ;L.hJ.b(0,0,1017,1433,88,68,0,0);
L.iJ=new h("symbol6Bg",N,1,121,145,0,0,121,145,1);L.symbol6Bg=L.iJ;L.iJ.b(0,0,953,1665,121,145,0,0);L.jJ=new h("symbol6Body",N,1,107,145,0,0,107,145,1);L.symbol6Body=L.jJ;L.jJ.b(0,0,1929,537,107,145,0,0);L.kJ=new h("symbol6Border",N,1,121,145,0,0,121,145,1);L.symbol6Border=L.kJ;L.kJ.b(0,0,481,1665,121,145,0,0);L.lJ=new h("symbol7Bg",N,1,120,144,0,0,120,144,1);L.symbol7Bg=L.lJ;L.lJ.b(0,0,1081,1665,120,144,0,0);L.mJ=new h("symbol7Body",N,1,98,48,0,0,98,48,1);L.symbol7Body=L.mJ;
L.mJ.b(0,0,1937,857,91,47,7,1);L.nJ=new h("symbol7Border",N,1,122,146,0,0,122,146,1);L.symbol7Border=L.nJ;L.nJ.b(0,0,1017,1513,122,146,0,0);L.oJ=new h("symbol7Eye",N,1,31,22,0,0,31,22,1);L.symbol7Eye=L.oJ;L.oJ.b(0,0,2017,833,26,20,1,2);L.pJ=new h("symbol7Hair",N,1,42,89,0,0,42,89,1);L.symbol7Hair=L.pJ;L.pJ.b(0,0,1713,1033,41,88,1,1);L.qJ=new h("symbol7Head",N,1,99,112,0,0,99,112,1);L.symbol7Head=L.qJ;L.qJ.b(0,0,353,1721,99,111,0,1);L.rJ=new h("symbol7Neck",N,1,40,47,0,0,40,47,1);L.symbol7Neck=L.rJ;
L.rJ.b(0,0,689,993,39,46,1,1);L.ed=new h("symbolEmpty",N,1,122,146,0,0,122,146,1);L.symbolEmpty=L.ed;L.ed.b(0,0,1145,1513,122,146,0,0);L.uJ=new h("symbolEmptyBlue",N,1,121,145,0,0,121,145,1);L.symbolEmptyBlue=L.uJ;L.uJ.b(0,0,129,1633,121,145,0,0);L.wJ=new h("symbolWildBg",N,1,121,145,0,0,121,145,1);L.symbolWildBg=L.wJ;L.wJ.b(0,0,673,1657,121,145,0,0);L.xJ=new h("symbolWildBgBlue",N,1,121,145,0,0,121,145,1);L.symbolWildBgBlue=L.xJ;L.xJ.b(0,0,1,1617,121,145,0,0);
L.yJ=new h("symbolWildTxt",N,1,121,50,0,0,121,50,1);L.symbolWildTxt=L.yJ;L.yJ.b(0,0,1905,689,120,49,1,1);Dc.mG=new h("leaf_1",Mc,1,356,240,0,0,356,240,1);Dc.leaf_1=Dc.mG;Dc.mG.b(0,0,1,1553,355,235,1,3);Dc.nG=new h("leaf_2",Mc,1,396,252,0,0,396,252,1);Dc.leaf_2=Dc.nG;Dc.nG.b(0,0,1633,985,386,246,6,6);Dc.oG=new h("leaf_3",Mc,1,340,286,0,0,340,286,1);Dc.leaf_3=Dc.oG;Dc.oG.b(0,0,361,1553,340,282,0,1);var Pg=new h("border",N,1,540,486,0,0,540,486,1);window.border=Pg;Pg.b(0,0,441,1,539,486,0,0);
var Qg=new h("borderBlue",N,1,536,485,0,0,536,485,1);window.borderBlue=Qg;Qg.b(0,0,985,1,536,485,0,0);var Sg=new h("collect1",N,1,92,100,0,0,92,100,1);window.collect1=Sg;Sg.b(0,0,1321,1761,84,94,4,4);var Tg=new h("collect2",N,1,92,100,0,0,92,100,1);window.collect2=Tg;Tg.b(0,0,1,1769,82,91,5,7);var Ug=new h("collect3",N,1,92,100,0,0,92,100,1);window.collect3=Ug;Ug.b(0,0,1753,1793,84,85,5,13);var Vg=new h("collect1Gold",N,1,92,100,0,0,92,100,1);window.collect1Gold=Vg;Vg.b(0,0,257,1761,84,94,4,4);
var Wg=new h("collect2Gold",N,1,92,100,0,0,92,100,1);window.collect2Gold=Wg;Wg.b(0,0,801,1769,82,90,5,8);var Xg=new h("collect3Gold",N,1,92,100,0,0,92,100,1);window.collect3Gold=Xg;Xg.b(0,0,89,1785,83,85,5,13);var Yg=new h("reelBg",N,1,508,457,0,0,508,457,1);window.reelBg=Yg;Yg.b(0,0,1529,1,508,457,0,0);var Zg=new h("s_background_map",Oc,4,270,405,0,0,540,810,2);window.s_background_map=Zg;Zg.b(0,0,545,1225,270,405,0,0);Zg.b(1,0,1713,409,270,405,0,0);Zg.b(2,0,1713,1,270,405,0,0);
Zg.b(3,0,1633,817,270,405,0,0);var $g=new h("s_payline5",Lc,1,526,359,0,0,526,359,1);window.s_payline5=$g;$g.b(0,0,1073,385,523,331,2,0);var ah=new h("s_payline10",Lc,1,532,395,0,0,532,395,1);window.s_payline10=ah;ah.b(0,0,1073,1,527,378,5,0);var bh=new h("s_payline25",Lc,1,532,425,0,0,532,425,1);window.s_payline25=bh;bh.b(0,0,1,1,531,423,1,1);var ch=new h("s_payline50",Lc,1,532,415,0,0,532,415,1);window.s_payline50=ch;ch.b(0,0,537,1,531,412,1,3);
var dh=new h("popupSmall",N,1,437,584,0,0,437,584,1);window.popupSmall=dh;dh.b(0,0,1,1,437,584,0,0);var eh=new h("infoBoxSmallPopup",N,1,333,50,0,0,333,50,1);window.infoBoxSmallPopup=eh;eh.b(0,0,1089,985,333,50,0,0);var fh=new h("bigCoin",N,1,187,186,0,0,187,186,1);window.bigCoin=fh;fh.b(0,0,1,1425,185,184,1,1);var gh=new h("s_winline",N,1,4,9,0,4,4,9,1);window.s_winline=gh;gh.b(0,0,2041,1,4,9,0,0);var hh=new h("tutPanel",N,1,532,316,0,0,532,316,1);window.tutPanel=hh;hh.b(0,0,441,489,532,316,0,0);
var ih=new h("popupBoxA",N,1,395,125,0,0,395,125,1);window.popupBoxA=ih;ih.b(0,0,1,633,395,125,0,0);var jh=new h("popupBoxB",N,1,395,170,0,0,395,170,1);window.popupBoxB=jh;jh.b(0,0,1377,745,395,170,0,0);var kh=new h("popupBoxC",N,1,395,218,0,0,395,218,1);window.popupBoxC=kh;kh.b(0,0,1,761,395,218,0,0);var lh=new h("popupBoxD",N,1,395,263,0,0,395,263,1);window.popupBoxD=lh;lh.b(0,0,977,713,395,263,0,0);var mh=new h("tutArrow",N,1,76,84,0,0,76,84,1);window.tutArrow=mh;mh.b(0,0,265,1137,76,84,0,0);
var nh=new h("tutArrowUp",N,1,76,84,0,0,76,84,1);window.tutArrowUp=nh;nh.b(0,0,265,1049,76,84,0,0);var oh=new h("s_part_star",N,1,148,148,0,0,148,148,1);window.s_part_star=oh;oh.b(0,0,673,1505,148,148,0,0);var ph=new h("s_shine",N,1,81,81,80,0,81,81,1);window.s_shine=ph;ph.b(0,0,1505,1801,81,81,0,0);var qh=new h("newIcon",N,1,31,34,15,16,31,34,1);window.newIcon=qh;qh.b(0,0,401,761,31,34,0,0);var rh=new h("txtBalloon",O,1,108,108,0,0,108,108,1);window.txtBalloon=rh;rh.b(0,0,393,417,108,108,0,0);
var sh=new h("s_tag",Mc,1,199,82,0,0,199,82,1);window.s_tag=sh;sh.b(0,0,1641,241,198,78,0,0);var th=new h("artefact1",Mc,1,253,222,0,0,253,222,1);window.artefact1=th;th.b(0,0,705,1729,253,222,0,0);var uh=new h("artefact1_empty",Mc,1,253,222,0,0,253,222,1);window.artefact1_empty=uh;uh.b(0,0,1,1793,248,209,0,0);var vh=new h("artefact2",Mc,1,278,172,0,0,278,172,1);window.artefact2=vh;vh.b(0,0,705,1553,278,172,0,0);var wh=new h("artefact2_empty",Mc,1,278,172,0,0,278,172,1);window.artefact2_empty=wh;
wh.b(0,0,1633,1713,278,172,0,0);var xh=new h("artefact3",Mc,1,242,153,0,0,242,153,1);window.artefact3=xh;xh.b(0,0,1209,1793,242,153,0,0);var yh=new h("artefact3_empty",Mc,1,247,159,0,0,247,159,1);window.artefact3_empty=yh;yh.b(0,0,961,1793,243,157,3,0);var zh=new h("artefact4",Mc,1,194,199,0,0,194,199,1);window.artefact4=zh;zh.b(0,1,1,1,194,199,0,0);var Bh=new h("artefact4_empty",Mc,1,194,199,0,0,194,199,1);window.artefact4_empty=Bh;Bh.b(0,1,201,1,194,199,0,0);
var Ch=new h("artefact5",Mc,1,138,194,0,0,138,194,1);window.artefact5=Ch;Ch.b(0,0,1457,1793,138,193,0,1);var Dh=new h("artefact5_empty",Mc,1,138,194,0,0,138,194,1);window.artefact5_empty=Dh;Dh.b(0,0,1913,1713,134,188,2,0);var Eh=new h("artefactCount",Mc,1,48,49,0,0,48,49,1);window.artefactCount=Eh;Eh.b(0,0,1969,241,48,49,0,0);var Fh=new h("galleryCoin",Mc,1,38,39,0,0,38,39,1);window.galleryCoin=Fh;Fh.b(0,0,497,617,38,39,0,0);var Gh=new h("UiBottomGallery",Mc,1,494,82,0,0,494,82,1);
window.UiBottomGallery=Gh;Gh.b(0,0,1,617,494,82,0,0);var Hh=new h("s_logo",Oc,1,621,483,0,0,621,483,1);window.s_logo=Hh;Hh.b(0,0,1,1,621,483,0,0);var Ih=new h("s_tutorial",O,1,289,261,0,0,289,261,1);window.s_tutorial=Ih;Ih.b(0,0,377,1,289,261,0,0);var Jh=new h("s_overlay_settings",Nc,1,434,560,0,0,434,560,1);window.s_overlay_settings=Jh;Jh.b(0,0,953,1,434,560,0,0);var Kh=new h("s_overlay_options",Nc,1,434,560,0,0,434,560,1);window.s_overlay_options=Kh;Kh.b(0,0,1393,1,434,560,0,0);
var Lh=new h("btnHuge",Nc,1,306,51,0,0,306,51,1);window.btnHuge=Lh;Lh.b(0,0,953,569,306,51,0,0);var Mh=new h("btnBig",Nc,1,120,41,0,0,120,41,1);window.btnBig=Mh;Mh.b(0,0,1833,1,120,41,0,0);var Nh=new h("popUp",Nc,1,475,778,0,0,475,778,1);window.popUp=Nh;Nh.b(0,0,1,1,475,778,0,0);var Oh=new h("popUpFill",Nc,1,467,727,0,0,467,727,1);window.popUpFill=Oh;Oh.b(0,0,481,1,467,727,0,0);var Ph=new h("s_tgf_progressbar_fill",M,1,36,23,0,0,36,23,1);window.s_tgf_progressbar_fill=Ph;Ph.b(0,0,893,49,36,23,0,0);
var Qh=new h("s_tgf_progressbar_back",M,1,42,26,0,0,42,26,1);window.s_tgf_progressbar_back=Qh;Qh.b(0,0,409,41,42,26,0,0);var Rh=new h("s_background",Oc,4,540,405,0,0,1080,810,2);window.s_background=Rh;Rh.b(0,0,1089,817,540,405,0,0);Rh.b(1,0,545,817,540,405,0,0);Rh.b(2,0,1,489,540,405,0,0);Rh.b(3,0,1169,1,540,405,0,0);var Sh=new h("s_background_free",Oc,4,540,405,0,0,1080,810,2);window.s_background_free=Sh;Sh.b(0,0,625,409,540,405,0,0);Sh.b(1,0,1169,409,540,405,0,0);Sh.b(2,0,625,1,540,405,0,0);
Sh.b(3,0,1,897,540,405,0,0);var Th=new h("bgWheel",Mc,4,540,405,0,0,1080,810,2);window.bgWheel=Th;Th.b(0,0,1,737,540,405,0,0);Th.b(1,0,537,329,540,405,0,0);Th.b(2,0,1081,329,540,405,0,0);Th.b(3,0,1,1145,540,405,0,0);var Uh=new h("bgGallery",Mc,4,540,405,0,0,1080,810,2);window.bgGallery=Uh;Uh.b(0,0,545,1145,540,405,0,0);Uh.b(1,0,1089,977,540,405,0,0);Uh.b(2,0,1089,1385,540,405,0,0);Uh.b(3,0,545,737,540,405,0,0);var Vh=new Ca("ff_tgf_normal","fonts/ff_tgf_normal.woff","fonts/ff_tgf_normal.ttf","frameworkFonts");
window.ff_tgf_normalLoader=Vh;var Wh=new Ca("ff_tgf_bold","fonts/ff_tgf_bold.woff","fonts/ff_tgf_bold.ttf","frameworkFonts");window.ff_tgf_boldLoader=Wh;var Xh=new Fa("ff_tgf_bold","Arial");window.f_tgf_title=Xh;Ga(Xh,24);Xh.fill=!0;Xh.setFillColor("Black");Xh.jb=1;Ha(Xh,!1);Xh.setStrokeColor("Black");Ia(Xh,1);Ka(Xh,"miter");Xh.rb=1;Ja(Xh,!1);Ma(Xh,"center");Na(Xh,"middle");Oa(Xh,0);Pa(Xh,0);var R=new Fa("ff_tgf_normal","Arial");window.f_tgf_text=R;Ga(R,16);R.fill=!0;R.setFillColor("Black");
R.jb=1;Ha(R,!1);R.setStrokeColor("Black");Ia(R,1);Ka(R,"miter");R.rb=1;Ja(R,!1);Ma(R,"center");Na(R,"middle");Oa(R,0);Pa(R,0);var S=new Fa("ff_tgf_normal","Arial");window.f_tgf_button=S;Ga(S,20);S.fill=!0;S.setFillColor("#01198A");S.jb=1;Ha(S,!1);S.setStrokeColor("Black");Ia(S,1);Ka(S,"miter");S.rb=1;Ja(S,!1);La(S,"rgba(120,253,255,1.00)",0,1,0);Ma(S,"center");Na(S,"middle");Oa(S,.14);Pa(S,0);var Yh=new Ca("f_default","fonts/f_default.woff","fonts/f_default.ttf","fonts");window.f_defaultLoader=Yh;
var Zh=new Fa("f_default","Arial");window.f_default=Zh;Ga(Zh,12);Zh.fill=!0;Zh.setFillColor("Black");Zh.jb=1;Ha(Zh,!1);Zh.setStrokeColor("Black");Ia(Zh,1);Ka(Zh,"miter");Zh.rb=1;Ja(Zh,!1);Ma(Zh,"left");Na(Zh,"top");Oa(Zh,0);Pa(Zh,0);var $h=new Ca("MyriadProSemibold_WOF","fonts/MyriadProSemibold_WOF.woff","fonts/MyriadProSemibold_WOF.ttf","fonts");window.MyriadProSemibold_WOFLoader=$h;var ai=new Fa("MyriadProSemibold_WOF","Arial");window.MyriadProSemibold_WOF=ai;Ga(ai,28);ai.fill=!0;ai.setFillColor("White");
ai.jb=1;Ha(ai,!0);ai.setStrokeColor("#d94200");Ia(ai,4);Ka(ai,"round");ai.rb=1;Ja(ai,!0);Ma(ai,"center");Na(ai,"middle");Oa(ai,0);Pa(ai,0);var bi=new Ca("MyriadProSemibold_gallery","fonts/MyriadProSemibold_gallery.woff","fonts/MyriadProSemibold_gallery.ttf","fonts");window.MyriadProSemibold_galleryLoader=bi;var ci=new Fa("MyriadProSemibold_gallery","Arial");window.MyriadProSemibold_gallery=ci;Ga(ci,27);ci.fill=!0;ci.setFillColor("White");ci.jb=1;Ha(ci,!1);ci.setStrokeColor("Black");Ia(ci,1);
Ka(ci,"miter");ci.rb=1;Ja(ci,!1);Ma(ci,"center");Na(ci,"middle");Oa(ci,0);Pa(ci,0);var di=new Ca("MyriadProSemibold_copy1","fonts/MyriadProSemibold_copy1.woff","fonts/MyriadProSemibold_copy1.ttf","fonts");window.MyriadProSemibold_copy1Loader=di;var ei=new Fa("MyriadProSemibold_copy1","Arial");window.MyriadProSemibold_copy1=ei;Ga(ei,50);ei.fill=!0;ei.Te=2;ei.kc.Tr=!0;ei.kc.N=3;ei.kc.Us=["#FF8040","Yellow","#FF8040"].slice(0);ei.kc.size=.22;ei.kc.offset=.01;ei.jb=1;Ha(ei,!0);ei.Wl=3;
ei.strokeStyle="[yellow";Ia(ei,1);Ka(ei,"round");ei.rb=1;Ja(ei,!1);La(ei,"rgba(128,128,0,1.00)",0,2,1);Ma(ei,"left");Na(ei,"middle");Oa(ei,0);Pa(ei,0);var fi=new Ca("f_butterfly","fonts/f_butterfly.woff","fonts/f_butterfly.ttf","fonts");window.f_butterflyLoader=fi;var gi=new Fa("f_butterfly","Arial");window.f_butterfly=gi;Ga(gi,21);gi.fill=!0;gi.setFillColor("Black");gi.jb=1;Ha(gi,!0);gi.setStrokeColor("Lime");Ia(gi,2);Ka(gi,"round");gi.rb=1;Ja(gi,!0);La(gi,"rgba(128,128,128,1.00)",4,4,10);
Ma(gi,"center");Na(gi,"middle");Oa(gi,0);Pa(gi,3);var hi=new Ca("soupofjustice","fonts/soupofjustice.woff","fonts/soupofjustice.ttf","fonts");window.soupofjusticeLoader=hi;var ii=new Fa("soupofjustice","Arial");window.soupofjustice=ii;Ga(ii,6);ii.fill=!0;ii.setFillColor("Black");ii.jb=1;Ha(ii,!1);ii.setStrokeColor("Black");Ia(ii,1);Ka(ii,"miter");ii.rb=1;Ja(ii,!1);Ma(ii,"left");Na(ii,"top");Oa(ii,0);Pa(ii,0);var ji=new Ca("BigWinFont","fonts/BigWinFont.woff","fonts/BigWinFont.ttf","fonts");
window.BigWinFontLoader=ji;var ki=new Fa("BigWinFont","Arial");window.BigWinFont=ki;Ga(ki,110);ki.fill=!0;ki.setFillColor("#00dfff");ki.jb=1;Ha(ki,!0);ki.setStrokeColor("#094dc5");Ia(ki,5);Ka(ki,"round");ki.rb=1;Ja(ki,!0);Ma(ki,"center");Na(ki,"middle");Oa(ki,0);Pa(ki,0);var li=new Ca("MyriadProBold","fonts/MyriadProBold.woff","fonts/MyriadProBold.ttf","fonts");window.MyriadProBoldLoader=li;var T=new Fa("MyriadProBold","Arial");window.MyriadProBold=T;Ga(T,6);T.fill=!0;T.setFillColor("Black");
T.jb=1;Ha(T,!1);T.setStrokeColor("Black");Ia(T,1);Ka(T,"miter");T.rb=1;Ja(T,!1);Ma(T,"left");Na(T,"middle");Oa(T,0);Pa(T,0);var mi=new Ca("MyriadProBold_goodluck","fonts/MyriadProBold_goodluck.woff","fonts/MyriadProBold_goodluck.ttf","fonts");window.MyriadProBold_goodluckLoader=mi;var ni=new Fa("MyriadProBold_goodluck","Arial");window.MyriadProBold_goodluck=ni;Ga(ni,31);ni.fill=!0;ni.setFillColor("White");ni.jb=1;Ha(ni,!0);ni.setStrokeColor("#8000FF");Ia(ni,4);Ka(ni,"round");ni.rb=1;Ja(ni,!0);
Ma(ni,"center");Na(ni,"middle");Oa(ni,0);Pa(ni,0);var oi=new Ca("MyriadProBold_freespins","fonts/MyriadProBold_freespins.woff","fonts/MyriadProBold_freespins.ttf","fonts");window.MyriadProBold_freespinsLoader=oi;var pi=new Fa("MyriadProBold_freespins","Arial");window.MyriadProBold_freespins=pi;Ga(pi,31);pi.fill=!0;pi.setFillColor("White");pi.jb=1;Ha(pi,!0);pi.setStrokeColor("Blue");Ia(pi,4);Ka(pi,"round");pi.rb=1;Ja(pi,!0);Ma(pi,"center");Na(pi,"middle");Oa(pi,0);Pa(pi,0);
var qi=new Ca("MyriadProBold_spin","fonts/MyriadProBold_spin.woff","fonts/MyriadProBold_spin.ttf","fonts");window.MyriadProBold_spinLoader=qi;var ri=new Fa("MyriadProBold_spin","Arial");window.MyriadProBold_spin=ri;Ga(ri,39);ri.fill=!0;ri.setFillColor("White");ri.jb=1;Ha(ri,!0);ri.setStrokeColor("#006600");Ia(ri,4);Ka(ri,"round");ri.rb=1;Ja(ri,!0);Ma(ri,"center");Na(ri,"middle");Oa(ri,0);Pa(ri,0);
var si=new Ca("MyriadProBold_buttons","fonts/MyriadProBold_buttons.woff","fonts/MyriadProBold_buttons.ttf","fonts");window.MyriadProBold_buttonsLoader=si;var ti=new Fa("MyriadProBold_buttons","Arial");window.MyriadProBold_buttons=ti;Ga(ti,24);ti.fill=!0;ti.setFillColor("White");ti.jb=1;Ha(ti,!0);ti.setStrokeColor("#006600");Ia(ti,4);Ka(ti,"round");ti.rb=1;Ja(ti,!0);Ma(ti,"center");Na(ti,"middle");Oa(ti,0);Pa(ti,0);
var ui=new Ca("MyriadProSemibold_buttons_orange","fonts/MyriadProSemibold_buttons_orange.woff","fonts/MyriadProSemibold_buttons_orange.ttf","fonts");window.MyriadProSemibold_buttons_orangeLoader=ui;var vi=new Fa("MyriadProSemibold_buttons_orange","Arial");window.MyriadProSemibold_buttons_orange=vi;Ga(vi,24);vi.fill=!0;vi.setFillColor("White");vi.jb=1;Ha(vi,!0);vi.setStrokeColor("#d94200");Ia(vi,4);Ka(vi,"round");vi.rb=1;Ja(vi,!0);Ma(vi,"center");Na(vi,"middle");Oa(vi,0);Pa(vi,0);
var wi=new Ca("MyriadProBold_spinout","fonts/MyriadProBold_spinout.woff","fonts/MyriadProBold_spinout.ttf","fonts");window.MyriadProBold_spinoutLoader=wi;var xi=new Fa("MyriadProBold_spinout","Arial");window.MyriadProBold_spinout=xi;Ga(xi,39);xi.fill=!0;xi.setFillColor("White");xi.jb=1;Ha(xi,!0);xi.setStrokeColor("#C40000");Ia(xi,4);Ka(xi,"round");xi.rb=1;Ja(xi,!0);Ma(xi,"center");Na(xi,"middle");Oa(xi,0);Pa(xi,0);
var yi=new Ca("MyriadProBoldCond","fonts/MyriadProBoldCond.woff","fonts/MyriadProBoldCond.ttf","fonts");window.MyriadProBoldCondLoader=yi;var zi=new Fa("MyriadProBoldCond","Arial");window.MyriadProBoldCond=zi;Ga(zi,6);zi.fill=!0;zi.setFillColor("Black");zi.jb=1;Ha(zi,!1);zi.setStrokeColor("Black");Ia(zi,1);Ka(zi,"miter");zi.rb=1;Ja(zi,!1);Ma(zi,"left");Na(zi,"top");Oa(zi,0);Pa(zi,0);var Ai=new Fa("MyriadProBold","Arial");window.f_coin=Ai;Ga(Ai,31);Ai.fill=!0;Ai.setFillColor("Black");Ai.jb=1;
Ha(Ai,!1);Ai.setStrokeColor("Black");Ia(Ai,1);Ka(Ai,"miter");Ai.rb=1;Ja(Ai,!1);Ma(Ai,"left");Na(Ai,"middle");Oa(Ai,0);Pa(Ai,0);var Bi=new Ca("MyriadProSemibold","fonts/MyriadProSemibold.woff","fonts/MyriadProSemibold.ttf","fonts");window.MyriadProSemiboldLoader=Bi;var Ci=new Fa("MyriadProSemibold","Arial");window.MyriadProSemibold=Ci;Ga(Ci,12);Ci.fill=!0;Ci.setFillColor("Black");Ci.jb=1;Ha(Ci,!1);Ci.setStrokeColor("Black");Ia(Ci,1);Ka(Ci,"miter");Ci.rb=1;Ja(Ci,!1);Ma(Ci,"center");Na(Ci,"middle");
Oa(Ci,0);Pa(Ci,0);
var Di=new tc('{"skeleton":{"hash":"V2Ne2dGWxNgYZcC44LYURJP5R+s","spine":"3.1.06","width":353,"height":422,"images":"./images/"},"bones":[{"name":"root"}],"slots":[{"name":"winBox_01","bone":"root","attachment":"winBox_01"}],"skins":{"default":{"winBox_01":{"winBox_01":{"x":4.97,"y":4.57,"width":353,"height":422},"winBox_03":{"x":10.47,"y":5.07,"width":394,"height":463},"winBox_05":{"x":12.97,"y":3.57,"width":421,"height":486},"winBox_07":{"x":17.47,"y":4.07,"width":448,"height":507},"winBox_09":{"x":15.47,"y":-4.92,"width":478,"height":531},"winBox_11":{"x":21.47,"y":-0.92,"width":510,"height":563},"winBox_13":{"x":14.47,"y":-7.42,"width":524,"height":582},"winBox_15":{"x":11.47,"y":-14.42,"width":530,"height":600},"winBox_17":{"x":9.47,"y":-16.92,"width":534,"height":603},"winBox_19":{"x":11.47,"y":-15.92,"width":530,"height":587},"winBox_21":{"x":12.97,"y":-16.42,"width":527,"height":572},"winBox_23":{"x":14.47,"y":-15.92,"width":524,"height":563},"winBox_25":{"x":11.97,"y":-16.42,"width":511,"height":554},"winBox_27":{"x":8.97,"y":-15.92,"width":497,"height":543},"winBox_29":{"x":11.97,"y":-16.42,"width":515,"height":554},"winBox_31":{"x":12.97,"y":-16.42,"width":527,"height":566},"winBox_33":{"x":8.97,"y":-15.42,"width":535,"height":582},"winBox_35":{"x":1.97,"y":-17.42,"width":549,"height":608},"winBox_37":{"x":0.47,"y":-17.42,"width":552,"height":630},"winBox_39":{"x":0.47,"y":-10.92,"width":552,"height":643},"winBox_41":{"x":0.47,"y":-18.42,"width":552,"height":624},"winBox_43":{"x":4.97,"y":-16.92,"width":543,"height":591},"winBox_45":{"x":6.47,"y":-16.42,"width":538,"height":582},"winBox_47":{"x":2.97,"y":-15.92,"width":525,"height":573},"winBox_49":{"x":4.97,"y":-14.92,"width":495,"height":533},"winBox_51":{"x":8.97,"y":-13.92,"width":477,"height":495},"winBox_53":{"x":1.47,"y":-20.92,"width":466,"height":481},"winBox_55":{"x":2.47,"y":-16.42,"width":478,"height":462},"winBox_57":{"x":-0.02,"y":0.07,"width":457,"height":433}}}},"animations":{"animation":{"slots":{"winBox_01":{"attachment":[{"time":0,"name":"winBox_01"},{"time":0.0666,"name":"winBox_03"},{"time":0.1333,"name":"winBox_05"},{"time":0.2,"name":"winBox_07"},{"time":0.2666,"name":"winBox_09"},{"time":0.3333,"name":"winBox_11"},{"time":0.4,"name":"winBox_13"},{"time":0.4666,"name":"winBox_15"},{"time":0.5333,"name":"winBox_17"},{"time":0.6,"name":"winBox_19"},{"time":0.6666,"name":"winBox_21"},{"time":0.7333,"name":"winBox_23"},{"time":0.8,"name":"winBox_25"},{"time":0.8666,"name":"winBox_27"},{"time":0.9333,"name":"winBox_29"},{"time":1,"name":"winBox_31"},{"time":1.0666,"name":"winBox_33"},{"time":1.1333,"name":"winBox_35"},{"time":1.2,"name":"winBox_37"},{"time":1.2666,"name":"winBox_39"},{"time":1.3333,"name":"winBox_41"},{"time":1.4,"name":"winBox_43"},{"time":1.4666,"name":"winBox_45"},{"time":1.5333,"name":"winBox_47"},{"time":1.6,"name":"winBox_49"},{"time":1.6666,"name":"winBox_51"},{"time":1.7333,"name":"winBox_53"},{"time":1.8,"name":"winBox_55"},{"time":1.8666,"name":"winBox_57"},{"time":1.9333,"name":null}]}}}}}\n',H);
window.winline=Di;
var Ei=new tc('{"skeleton":{"hash":"5/YdogMQUxnNNwhzU+tYq6D+eck","spine":"3.1.06","width":500,"height":1100,"images":"./images/"},"bones":[{"name":"root"}],"slots":[{"name":"anticipationbox_01","bone":"root","attachment":"anticipationbox_26"}],"skins":{"default":{"anticipationbox_01":{"anticipationbox_00":{"width":500,"height":1100},"anticipationbox_02":{"width":500,"height":1100},"anticipationbox_04":{"width":500,"height":1100},"anticipationbox_06":{"width":500,"height":1100},"anticipationbox_08":{"width":500,"height":1100},"anticipationbox_10":{"width":500,"height":1100},"anticipationbox_12":{"width":500,"height":1100},"anticipationbox_14":{"width":500,"height":1100},"anticipationbox_16":{"width":500,"height":1100},"anticipationbox_18":{"width":500,"height":1100},"anticipationbox_20":{"width":500,"height":1100},"anticipationbox_22":{"width":500,"height":1100},"anticipationbox_24":{"width":500,"height":1100},"anticipationbox_26":{"width":500,"height":1100}}}},"animations":{"animation":{},"animation2":{"slots":{"anticipationbox_01":{"attachment":[{"time":0,"name":"anticipationbox_00"},{"time":0.0666,"name":"anticipationbox_02"},{"time":0.1333,"name":"anticipationbox_04"},{"time":0.2,"name":"anticipationbox_06"},{"time":0.2666,"name":"anticipationbox_08"},{"time":0.3333,"name":"anticipationbox_10"},{"time":0.4,"name":"anticipationbox_12"},{"time":0.4666,"name":"anticipationbox_14"},{"time":0.5333,"name":"anticipationbox_16"},{"time":0.6,"name":"anticipationbox_18"},{"time":0.6666,"name":"anticipationbox_20"},{"time":0.7333,"name":"anticipationbox_22"},{"time":0.8,"name":"anticipationbox_24"},{"time":0.8666,"name":"anticipationbox_26"},{"time":0.9333,"name":"anticipationbox_00"}]}}}}}\n',I);
window.anticipationAnimation=Ei;var Fi=new tc('{"skeleton":{"hash":"ldUaxPSQO5Fj5doiZbkxhi/Ud7o","spine":"3.1.06","width":1080,"height":1365,"images":"./images/"},"bones":[{"name":"root"},{"name":"artefacts","parent":"root"},{"name":"beams","parent":"root"}],"slots":[{"name":"beams","bone":"beams","attachment":"beams"},{"name":"artefactImg","bone":"artefacts","attachment":"artefact1"}],"skins":{"default":{"artefactImg":{"artefact1":{"width":523,"height":484},"artefact2":{"width":544,"height":361},"artefact3":{"width":514,"height":385},"artefact4":{"width":404,"height":418},"artefact5":{"width":362,"height":429}},"beams":{"beams":{"width":1080,"height":1365}}}},"animations":{"winArtefact1":{"slots":{"artefactImg":{"color":[{"time":1.3333,"color":"ffffffff"},{"time":1.4,"color":"ffffff00"}]}},"bones":{"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1,"y":1,"curve":"stepped"},{"time":0.9333,"x":1,"y":1},{"time":1.1666,"x":0,"y":0}]},"artefacts":{"translate":[{"time":1.1333,"x":0,"y":0},{"time":1.4,"x":270,"y":740}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.1333,"x":1,"y":1},{"time":1.4,"x":0.3,"y":0.3}]}}},"winArtefact2":{"slots":{"artefactImg":{"attachment":[{"time":0,"name":"artefact2"}],"color":[{"time":1.3333,"color":"ffffffff"},{"time":1.4,"color":"ffffff00"}]}},"bones":{"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1,"y":1,"curve":"stepped"},{"time":0.9333,"x":1,"y":1},{"time":1.1666,"x":0,"y":0}]},"artefacts":{"translate":[{"time":1.1333,"x":0,"y":0},{"time":1.4,"x":270,"y":740}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.1333,"x":1,"y":1},{"time":1.4,"x":0.3,"y":0.3}]}}},"winArtefact3":{"slots":{"artefactImg":{"attachment":[{"time":0,"name":"artefact3"}],"color":[{"time":1.3333,"color":"ffffffff"},{"time":1.4,"color":"ffffff00"}]}},"bones":{"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1,"y":1,"curve":"stepped"},{"time":0.9333,"x":1,"y":1},{"time":1.1666,"x":0,"y":0}]},"artefacts":{"translate":[{"time":1.1333,"x":0,"y":0},{"time":1.4,"x":270,"y":740}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.1333,"x":1,"y":1},{"time":1.4,"x":0.3,"y":0.3}]}}},"winArtefact4":{"slots":{"artefactImg":{"attachment":[{"time":0,"name":"artefact4"}],"color":[{"time":1.3333,"color":"ffffffff"},{"time":1.4,"color":"ffffff00"}]}},"bones":{"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1,"y":1,"curve":"stepped"},{"time":0.9333,"x":1,"y":1},{"time":1.1666,"x":0,"y":0}]},"artefacts":{"translate":[{"time":1.1333,"x":0,"y":0},{"time":1.4,"x":270,"y":740}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.1333,"x":1,"y":1},{"time":1.4,"x":0.3,"y":0.3}]}}},"winArtefact5":{"slots":{"artefactImg":{"attachment":[{"time":0,"name":"artefact5"}],"color":[{"time":1.3333,"color":"ffffffff"},{"time":1.4,"color":"ffffff00"}]}},"bones":{"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1,"y":1,"curve":"stepped"},{"time":0.9333,"x":1,"y":1},{"time":1.1666,"x":0,"y":0}]},"artefacts":{"translate":[{"time":1.1333,"x":0,"y":0},{"time":1.4,"x":270,"y":740}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.1333,"x":1,"y":1},{"time":1.4,"x":0.3,"y":0.3}]}}}}}\n');
window.artifactWinAnimation=Fi;var Gi=new tc('{"skeleton":{"hash":"65jbd3wvLqr9bxPWMWMGaJwBemg","spine":"3.2.01","width":600,"height":600,"images":"./images/"},"bones":[{"name":"root"},{"name":"collectable","parent":"root"},{"name":"glow","parent":"root"}],"slots":[{"name":"glow","bone":"glow","attachment":"collectGlow"},{"name":"particles","bone":"root","attachment":"collectParticles_00"},{"name":"collectable","bone":"collectable","attachment":"collect1"}],"skins":{"default":{"collectable":{"collect1":{"width":184,"height":199},"collect2":{"width":184,"height":199},"collect3":{"width":184,"height":199},"collect1Gold":{"width":184,"height":199},"collect2Gold":{"width":184,"height":199},"collect3Gold":{"width":184,"height":199}},"glow":{"collectGlow":{"y":-2.6,"width":258,"height":258}},"particles":{"collectParticles_00":{"width":600,"height":600},"collectParticles_01":{"width":600,"height":600},"collectParticles_02":{"width":600,"height":600},"collectParticles_03":{"width":600,"height":600},"collectParticles_04":{"x":8.5,"width":600,"height":600},"collectParticles_05":{"width":600,"height":600},"collectParticles_06":{"width":600,"height":600},"collectParticles_07":{"width":600,"height":600},"collectParticles_08":{"width":600,"height":600},"collectParticles_09":{"width":600,"height":600},"collectParticles_10":{"width":600,"height":600},"collectParticles_11":{"width":600,"height":600}}}},"animations":{"animCollect1":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect1"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}},"animCollect2":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect2"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}},"animCollect3":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect3"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}},"animCollect1Complete":{"slots":{"collectable":{"attachment":[{"time":0,"name":"collect1Gold"}]},"glow":{"color":[{"time":0,"color":"ffffffff"},{"time":0.5,"color":"ffffffae"},{"time":1,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collectGlow"}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.5,"x":1.152,"y":1.152},{"time":1,"x":1,"y":1}]},"glow":{"scale":[{"time":0,"x":0.95,"y":0.95},{"time":0.5,"x":1.266,"y":1.266},{"time":1,"x":0.95,"y":0.95}]}}},"animCollect1Gold":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect1Gold"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}},"animCollect2Complete":{"slots":{"collectable":{"attachment":[{"time":0,"name":"collect2Gold"}]},"glow":{"color":[{"time":0,"color":"ffffffff"},{"time":0.5,"color":"ffffffae"},{"time":1,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collectGlow"}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.5,"x":1.152,"y":1.152},{"time":1,"x":1,"y":1}]},"glow":{"scale":[{"time":0,"x":0.95,"y":0.95},{"time":0.5,"x":1.266,"y":1.266},{"time":1,"x":0.95,"y":0.95}]}}},"animCollect2Gold":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect2Gold"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}},"animCollect3Complete":{"slots":{"collectable":{"attachment":[{"time":0,"name":"collect3Gold"}]},"glow":{"color":[{"time":0,"color":"ffffffff"},{"time":0.5,"color":"ffffffae"},{"time":1,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collectGlow"}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.5,"x":1.152,"y":1.152},{"time":1,"x":1,"y":1}]},"glow":{"scale":[{"time":0,"x":0.95,"y":0.95},{"time":0.5,"x":1.266,"y":1.266},{"time":1,"x":0.95,"y":0.95}]}}},"animCollect3Gold":{"slots":{"collectable":{"color":[{"time":0.0666,"color":"ffffffff"},{"time":0.1,"color":"777a74ff","curve":"stepped"},{"time":0.1666,"color":"777a74ff"},{"time":0.2,"color":"ffffffff"}],"attachment":[{"time":0,"name":"collect3Gold"}]},"glow":{"attachment":[{"time":0,"name":null}]},"particles":{"attachment":[{"time":0.0666,"name":"collectParticles_00"},{"time":0.1,"name":"collectParticles_01"},{"time":0.1333,"name":"collectParticles_02"},{"time":0.1666,"name":"collectParticles_03"},{"time":0.2,"name":"collectParticles_04"},{"time":0.2333,"name":"collectParticles_05"},{"time":0.2666,"name":"collectParticles_06"},{"time":0.3,"name":"collectParticles_07"},{"time":0.3333,"name":"collectParticles_08"},{"time":0.3666,"name":"collectParticles_09"},{"time":0.4,"name":"collectParticles_10"},{"time":0.4333,"name":"collectParticles_11"},{"time":0.4666,"name":null}]}},"bones":{"collectable":{"scale":[{"time":0,"x":1,"y":1},{"time":0.0333,"x":0.9,"y":1},{"time":0.0666,"x":0.5,"y":1},{"time":0.1,"x":-0.5,"y":1},{"time":0.1333,"x":-0.9,"y":1},{"time":0.1666,"x":0.1,"y":1},{"time":0.2,"x":0.8,"y":1},{"time":0.2333,"x":1,"y":1}]}}}}}\n');
window.collectableAnimation=Gi;var Hi=new tc('{\n  "skeleton": {\n    "hash": "EiJZ7xqS+0zCxyTeBmZ4Ypsn2Uc",\n    "spine": "3.2.01",\n    "width": 969,\n    "height": 952.41,\n    "images": "./images/"\n  },\n  "bones": [\n    {\n      "name": "root"\n    },\n    {\n      "name": "artefact",\n      "parent": "root"\n    },\n    {\n      "name": "beams1",\n      "parent": "root"\n    },\n    {\n      "name": "beams2",\n      "parent": "root"\n    },\n    {\n      "name": "beams3",\n      "parent": "root"\n    },\n    {\n      "name": "beams4",\n      "parent": "root"\n    },\n    {\n      "name": "beams5",\n      "parent": "root"\n    },\n    {\n      "name": "big",\n      "parent": "root"\n    },\n    {\n      "name": "congratulations",\n      "parent": "root",\n      "y": 405.91\n    },\n    {\n      "name": "glow",\n      "parent": "root"\n    },\n    {\n      "name": "lvlUp",\n      "parent": "root"\n    },\n    {\n      "name": "txtFortune",\n      "parent": "root"\n    },\n    {\n      "name": "txtFree",\n      "parent": "root"\n    },\n    {\n      "name": "txtOf",\n      "parent": "root"\n    },\n    {\n      "name": "txtSpins",\n      "parent": "root"\n    },\n    {\n      "name": "txtWheel",\n      "parent": "root"\n    },\n    {\n      "name": "win",\n      "parent": "root"\n    }\n  ],\n  "slots": [\n    {\n      "name": "beams1",\n      "bone": "beams1",\n      "attachment": "beams1"\n    },\n    {\n      "name": "beams2",\n      "bone": "beams2",\n      "attachment": "beams2"\n    },\n    {\n      "name": "beams3",\n      "bone": "beams3",\n      "attachment": "beams3"\n    },\n    {\n      "name": "beams4",\n      "bone": "beams4",\n      "attachment": "beams4"\n    },\n    {\n      "name": "beams5",\n      "bone": "beams5",\n      "attachment": "beams5"\n    },\n    {\n      "name": "congratulations",\n      "bone": "congratulations",\n      "attachment": "congratulations"\n    },\n    {\n      "name": "txtFree",\n      "bone": "txtFree",\n      "attachment": "txtFree"\n    },\n    {\n      "name": "txtSpins",\n      "bone": "txtSpins",\n      "attachment": "txtSpins"\n    },\n    {\n      "name": "txtWheel",\n      "bone": "txtWheel",\n      "attachment": "txtWheel"\n    },\n    {\n      "name": "txtOf",\n      "bone": "txtOf",\n      "attachment": "txtOf"\n    },\n    {\n      "name": "txtFortune",\n      "bone": "txtFortune",\n      "attachment": "txtFortune"\n    },\n    {\n      "name": "artefact",\n      "bone": "artefact",\n      "attachment": "artefact5"\n    },\n    {\n      "name": "glow",\n      "bone": "glow",\n      "attachment": "glow"\n    },\n    {\n      "name": "big",\n      "bone": "big",\n      "attachment": "big"\n    },\n    {\n      "name": "win",\n      "bone": "win",\n      "attachment": "txtWin"\n    },\n    {\n      "name": "lvlUp",\n      "bone": "lvlUp",\n      "attachment": "lvlUp"\n    }\n  ],\n  "skins": {\n    "default": {\n      "artefact": {\n        "artefact1": {\n          "width": 506,\n          "height": 443\n        },\n        "artefact2": {\n          "width": 555,\n          "height": 343\n        },\n        "artefact3": {\n          "width": 493,\n          "height": 317\n        },\n        "artefact4": {\n          "width": 388,\n          "height": 397\n        },\n        "artefact5": {\n          "width": 276,\n          "height": 388\n        }\n      },\n      "beams1": {\n        "beams1": {\n          "x": 10,\n          "y": 10,\n          "width": 895,\n          "height": 899\n        }\n      },\n      "beams2": {\n        "beams2": {\n          "x": 10.5,\n          "y": 15,\n          "width": 900,\n          "height": 909\n        }\n      },\n      "beams3": {\n        "beams3": {\n          "x": 18.5,\n          "y": 16,\n          "width": 914,\n          "height": 923\n        }\n      },\n      "beams4": {\n        "beams4": {\n          "x": 14.5,\n          "y": 13.5,\n          "width": 904,\n          "height": 924\n        }\n      },\n      "beams5": {\n        "beams5": {\n          "x": 9,\n          "y": 7,\n          "width": 805,\n          "height": 893\n        }\n      },\n      "big": {\n        "big": {\n          "x": 17.85,\n          "y": 103.52,\n          "width": 566,\n          "height": 294\n        }\n      },\n      "congratulations": {\n        "congratulations": {\n          "width": 936,\n          "height": 196\n        }\n      },\n      "glow": {\n        "glow": {\n          "x": 17.74,\n          "y": 5.78,\n          "width": 678,\n          "height": 603\n        }\n      },\n      "lvlUp": {\n        "lvlUp": {\n          "width": 969,\n          "height": 195\n        }\n      },\n      "txtFortune": {\n        "txtFortune": {\n          "y": -145.41,\n          "width": 881,\n          "height": 182\n        }\n      },\n      "txtFree": {\n        "txtFree": {\n          "y": 111.39,\n          "width": 659,\n          "height": 240\n        }\n      },\n      "txtOf": {\n        "txtOf": {\n          "width": 243,\n          "height": 152\n        }\n      },\n      "txtSpins": {\n        "txtSpins": {\n          "x": 3.96,\n          "y": -102.24,\n          "width": 742,\n          "height": 236\n        }\n      },\n      "txtWheel": {\n        "txtWheel": {\n          "y": 141.97,\n          "width": 645,\n          "height": 180\n        }\n      },\n      "win": {\n        "txtWin": {\n          "x": 22.5,\n          "y": -120.92,\n          "width": 516,\n          "height": 236\n        }\n      }\n    }\n  },\n  "animations": {\n    "artefactWin1": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": "artefact1"\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.7,\n              "angle": 240\n            },\n            {\n              "time": 1.2666,\n              "angle": 120\n            },\n            {\n              "time": 1.8,\n              "angle": 0\n            },\n            {\n              "time": 2.0666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.4666,\n              "angle": 240\n            },\n            {\n              "time": 0.8,\n              "angle": 120\n            },\n            {\n              "time": 1.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.4666,\n              "angle": 240\n            },\n            {\n              "time": 1.8,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "artefact": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 0.3,\n              "x": 0.9,\n              "y": 0.9\n            },\n            {\n              "time": 0.4333,\n              "x": 1,\n              "y": 1,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 1.9666,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "artefactWin2": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": "artefact2"\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.7,\n              "angle": 240\n            },\n            {\n              "time": 1.2666,\n              "angle": 120\n            },\n            {\n              "time": 1.8,\n              "angle": 0\n            },\n            {\n              "time": 2.0666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.4666,\n              "angle": 240\n            },\n            {\n              "time": 0.8,\n              "angle": 120\n            },\n            {\n              "time": 1.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.4666,\n              "angle": 240\n            },\n            {\n              "time": 1.8,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "artefact": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 0.3,\n              "x": 0.9,\n              "y": 0.9\n            },\n            {\n              "time": 0.4333,\n              "x": 1,\n              "y": 1,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 1.9666,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "artefactWin3": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": "artefact3"\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.7,\n              "angle": 240\n            },\n            {\n              "time": 1.2666,\n              "angle": 120\n            },\n            {\n              "time": 1.8,\n              "angle": 0\n            },\n            {\n              "time": 2.0666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.4666,\n              "angle": 240\n            },\n            {\n              "time": 0.8,\n              "angle": 120\n            },\n            {\n              "time": 1.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.4666,\n              "angle": 240\n            },\n            {\n              "time": 1.8,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "artefact": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 0.3,\n              "x": 0.9,\n              "y": 0.9\n            },\n            {\n              "time": 0.4333,\n              "x": 1,\n              "y": 1,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 1.9666,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "artefactWin4": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": "artefact4"\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.7,\n              "angle": 240\n            },\n            {\n              "time": 1.2666,\n              "angle": 120\n            },\n            {\n              "time": 1.8,\n              "angle": 0\n            },\n            {\n              "time": 2.0666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.4666,\n              "angle": 240\n            },\n            {\n              "time": 0.8,\n              "angle": 120\n            },\n            {\n              "time": 1.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.4666,\n              "angle": 240\n            },\n            {\n              "time": 1.8,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "artefact": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 0.3,\n              "x": 0.9,\n              "y": 0.9\n            },\n            {\n              "time": 0.4333,\n              "x": 1,\n              "y": 1,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 1.9666,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "artefactWin5": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": "artefact5"\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.1333,\n              "color": "ffffffb5"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.1333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.7,\n              "angle": 240\n            },\n            {\n              "time": 1.2666,\n              "angle": 120\n            },\n            {\n              "time": 1.8,\n              "angle": 0\n            },\n            {\n              "time": 2.0666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.4666,\n              "angle": 240\n            },\n            {\n              "time": 0.8,\n              "angle": 120\n            },\n            {\n              "time": 1.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.4666,\n              "angle": 240\n            },\n            {\n              "time": 1.8,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.0666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.1333,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.1333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.4333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.5666,\n              "x": 1.3,\n              "y": 1.3,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 1.9666,\n              "x": 1.5,\n              "y": 1.5\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "artefact": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 0.3,\n              "x": 0.9,\n              "y": 0.9\n            },\n            {\n              "time": 0.4333,\n              "x": 1,\n              "y": 1,\n              "curve": "stepped"\n            },\n            {\n              "time": 1.8333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 1.9666,\n              "x": 1.2,\n              "y": 1.2\n            },\n            {\n              "time": 2.0666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "beams": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.1,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.2,\n              "angle": 0\n            },\n            {\n              "time": 2.7666,\n              "angle": 240\n            },\n            {\n              "time": 3.3333,\n              "angle": 120\n            },\n            {\n              "time": 3.8666,\n              "angle": 0\n            },\n            {\n              "time": 4.3666,\n              "angle": 240\n            },\n            {\n              "time": 4.9,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 0.8666,\n              "angle": 240\n            },\n            {\n              "time": 1.2,\n              "angle": 120\n            },\n            {\n              "time": 1.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.8666,\n              "angle": 240\n            },\n            {\n              "time": 2.2,\n              "angle": 120\n            },\n            {\n              "time": 2.5333,\n              "angle": 0\n            },\n            {\n              "time": 2.8666,\n              "angle": 240\n            },\n            {\n              "time": 3.2,\n              "angle": 120\n            },\n            {\n              "time": 3.5333,\n              "angle": 0\n            },\n            {\n              "time": 3.8666,\n              "angle": 240\n            },\n            {\n              "time": 4.2,\n              "angle": 120\n            },\n            {\n              "time": 4.5333,\n              "angle": 0\n            },\n            {\n              "time": 4.9,\n              "angle": 240\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.3,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            },\n            {\n              "time": 2.8666,\n              "angle": 0\n            },\n            {\n              "time": 3.6333,\n              "angle": 240\n            },\n            {\n              "time": 4.4,\n              "angle": 120\n            },\n            {\n              "time": 4.9,\n              "angle": 44.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.5333,\n              "angle": 240\n            },\n            {\n              "time": 2.5333,\n              "angle": 120\n            },\n            {\n              "time": 3.5333,\n              "angle": 0\n            },\n            {\n              "time": 4.5333,\n              "angle": 240\n            },\n            {\n              "time": 4.9,\n              "angle": -164\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "glow": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "win": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 1\n            }\n          ]\n        },\n        "root": {\n          "scale": [\n            {\n              "time": 4.6666,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 4.8,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 4.9,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "bigWin": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "color": [\n            {\n              "time": 0.7666,\n              "color": "ffffffff"\n            },\n            {\n              "time": 1.7666,\n              "color": "ffffff81"\n            },\n            {\n              "time": 2.7666,\n              "color": "ffffffff"\n            },\n            {\n              "time": 3.7666,\n              "color": "ffffff81"\n            },\n            {\n              "time": 4.7666,\n              "color": "ffffffff"\n            },\n            {\n              "time": 4.9,\n              "color": "ffffffee"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.7666,\n              "name": "glow"\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.3333,\n              "name": "txtWin"\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.1,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.2,\n              "angle": 0\n            },\n            {\n              "time": 2.7666,\n              "angle": 240\n            },\n            {\n              "time": 3.3333,\n              "angle": 120\n            },\n            {\n              "time": 3.8666,\n              "angle": 0\n            },\n            {\n              "time": 4.4333,\n              "angle": 240\n            },\n            {\n              "time": 4.9,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 0.8666,\n              "angle": 240\n            },\n            {\n              "time": 1.2,\n              "angle": 120\n            },\n            {\n              "time": 1.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.8666,\n              "angle": 240\n            },\n            {\n              "time": 2.2,\n              "angle": 120\n            },\n            {\n              "time": 2.5333,\n              "angle": 0\n            },\n            {\n              "time": 2.8666,\n              "angle": 240\n            },\n            {\n              "time": 3.2,\n              "angle": 120\n            },\n            {\n              "time": 3.5333,\n              "angle": 0\n            },\n            {\n              "time": 3.8666,\n              "angle": 240\n            },\n            {\n              "time": 4.2,\n              "angle": 120\n            },\n            {\n              "time": 4.5333,\n              "angle": 0\n            },\n            {\n              "time": 4.9,\n              "angle": 240\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.3,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            },\n            {\n              "time": 2.8666,\n              "angle": 0\n            },\n            {\n              "time": 3.6333,\n              "angle": 240\n            },\n            {\n              "time": 4.4,\n              "angle": 120\n            },\n            {\n              "time": 4.9,\n              "angle": 44.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.5333,\n              "angle": 240\n            },\n            {\n              "time": 2.5333,\n              "angle": 120\n            },\n            {\n              "time": 3.5333,\n              "angle": 0\n            },\n            {\n              "time": 4.5333,\n              "angle": 240\n            },\n            {\n              "time": 4.9,\n              "angle": -164\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "glow": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.7666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "win": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 1\n            },\n            {\n              "time": 0.3333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.5333,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.6666,\n              "x": 0.8,\n              "y": 0.8\n            },\n            {\n              "time": 0.7666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.2,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.3333,\n              "x": 0.8,\n              "y": 0.8\n            },\n            {\n              "time": 0.4333,\n              "x": 1.15,\n              "y": 1.15\n            },\n            {\n              "time": 0.5,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "root": {\n          "scale": [\n            {\n              "time": 4.6666,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 4.8,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 4.9,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    },\n    "freeSpins": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0.2,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.5666,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5666,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.5666,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5666,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.5666,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5666,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.5666,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5666,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.5666,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5666,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffff"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": "congratulations"\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00",\n              "curve": "stepped"\n            },\n            {\n              "time": 0.2,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.3333,\n              "color": "ffffffff"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0.2,\n              "name": "txtFree"\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "color": [\n            {\n              "time": 0.4333,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.5666,\n              "color": "ffffffff"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.4333,\n              "name": "txtSpins"\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.5666,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8666,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 1,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.5666,\n              "angle": 0\n            },\n            {\n              "time": 1.1333,\n              "angle": 240\n            },\n            {\n              "time": 1.7,\n              "angle": 120\n            },\n            {\n              "time": 2.2333,\n              "angle": 0\n            },\n            {\n              "time": 2.5,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5666,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8666,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 1,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.5666,\n              "angle": 0\n            },\n            {\n              "time": 0.9,\n              "angle": 240\n            },\n            {\n              "time": 1.2333,\n              "angle": 120\n            },\n            {\n              "time": 1.5666,\n              "angle": 0\n            },\n            {\n              "time": 1.9,\n              "angle": 240\n            },\n            {\n              "time": 2.2333,\n              "angle": 120\n            },\n            {\n              "time": 2.5,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5666,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8666,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 1,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.5666,\n              "angle": 0\n            },\n            {\n              "time": 1.3333,\n              "angle": 240\n            },\n            {\n              "time": 2.1,\n              "angle": 120\n            },\n            {\n              "time": 2.5,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5666,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8666,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 1,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.5666,\n              "angle": 0\n            },\n            {\n              "time": 1.5666,\n              "angle": 240\n            },\n            {\n              "time": 2.5,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5666,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8666,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 1,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "txtFree": {\n          "scale": [\n            {\n              "time": 0.2,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.3666,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.5,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.5666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "txtSpins": {\n          "scale": [\n            {\n              "time": 0.4333,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.6,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.7333,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.8,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "root": {\n          "scale": [\n            {\n              "time": 2.0666,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 2.2,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 2.3,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "congratulations": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 2,\n              "y": 2\n            },\n            {\n              "time": 0.1666,\n              "x": 0.8,\n              "y": 0.8\n            },\n            {\n              "time": 0.3,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.3666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        }\n      }\n    },\n    "lvlUp": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffff"\n            }\n          ]\n        },\n        "txtFortune": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.1,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.2,\n              "angle": 0\n            },\n            {\n              "time": 2.4666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 0.8666,\n              "angle": 240\n            },\n            {\n              "time": 1.2,\n              "angle": 120\n            },\n            {\n              "time": 1.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.8666,\n              "angle": 240\n            },\n            {\n              "time": 2.2,\n              "angle": 120\n            },\n            {\n              "time": 2.4666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.3,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            },\n            {\n              "time": 2.4666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.5333,\n              "angle": 240\n            },\n            {\n              "time": 2.4666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "root": {\n          "scale": [\n            {\n              "time": 2.2333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 2.3666,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 2.4666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "lvlUp": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.1666,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.3,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.3666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        }\n      }\n    },\n    "wheelOfFortune": {\n      "slots": {\n        "artefact": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "beams1": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams1"\n            }\n          ]\n        },\n        "beams2": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams2"\n            }\n          ]\n        },\n        "beams3": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams3"\n            }\n          ]\n        },\n        "beams4": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams4"\n            }\n          ]\n        },\n        "beams5": {\n          "color": [\n            {\n              "time": 0.5333,\n              "color": "ffffffc7"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.5333,\n              "name": "beams5"\n            }\n          ]\n        },\n        "big": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "congratulations": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "glow": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "lvlUp": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtFortune": {\n          "color": [\n            {\n              "time": 0.4666,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.6,\n              "color": "ffffffff"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.4666,\n              "name": "txtFortune"\n            }\n          ]\n        },\n        "txtFree": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtOf": {\n          "color": [\n            {\n              "time": 0.2333,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.3666,\n              "color": "ffffffff"\n            }\n          ],\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            },\n            {\n              "time": 0.2333,\n              "name": "txtOf"\n            }\n          ]\n        },\n        "txtSpins": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        },\n        "txtWheel": {\n          "color": [\n            {\n              "time": 0,\n              "color": "ffffff00"\n            },\n            {\n              "time": 0.1333,\n              "color": "ffffffff"\n            }\n          ]\n        },\n        "win": {\n          "attachment": [\n            {\n              "time": 0,\n              "name": null\n            }\n          ]\n        }\n      },\n      "bones": {\n        "beams1": {\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams2": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.1,\n              "angle": 240\n            },\n            {\n              "time": 1.6666,\n              "angle": 120\n            },\n            {\n              "time": 2.2,\n              "angle": 0\n            },\n            {\n              "time": 2.4666,\n              "angle": -56.47\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams3": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 0.8666,\n              "angle": 240\n            },\n            {\n              "time": 1.2,\n              "angle": 120\n            },\n            {\n              "time": 1.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.8666,\n              "angle": 240\n            },\n            {\n              "time": 2.2,\n              "angle": 120\n            },\n            {\n              "time": 2.4666,\n              "angle": 23.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams4": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.3,\n              "angle": 240\n            },\n            {\n              "time": 2.0666,\n              "angle": 120\n            },\n            {\n              "time": 2.4666,\n              "angle": 59.99\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "beams5": {\n          "rotate": [\n            {\n              "time": 0.5333,\n              "angle": 0\n            },\n            {\n              "time": 1.5333,\n              "angle": 240\n            },\n            {\n              "time": 2.4666,\n              "angle": 120\n            }\n          ],\n          "scale": [\n            {\n              "time": 0.5333,\n              "x": 0,\n              "y": 0\n            },\n            {\n              "time": 0.8333,\n              "x": 1.6,\n              "y": 1.6\n            },\n            {\n              "time": 0.9666,\n              "x": 1.3,\n              "y": 1.3\n            }\n          ]\n        },\n        "big": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        },\n        "txtFortune": {\n          "scale": [\n            {\n              "time": 0.4666,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.6333,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.7666,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.8333,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "txtOf": {\n          "scale": [\n            {\n              "time": 0.2333,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.4,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.4666,\n              "x": 1.024,\n              "y": 1.024\n            },\n            {\n              "time": 0.5333,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.6,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "txtWheel": {\n          "scale": [\n            {\n              "time": 0,\n              "x": 3,\n              "y": 3\n            },\n            {\n              "time": 0.1666,\n              "x": 0.7,\n              "y": 0.7\n            },\n            {\n              "time": 0.3,\n              "x": 1.35,\n              "y": 1.35\n            },\n            {\n              "time": 0.3666,\n              "x": 1,\n              "y": 1\n            }\n          ]\n        },\n        "root": {\n          "scale": [\n            {\n              "time": 2.2333,\n              "x": 1,\n              "y": 1\n            },\n            {\n              "time": 2.3666,\n              "x": 1.3,\n              "y": 1.3\n            },\n            {\n              "time": 2.4666,\n              "x": 0,\n              "y": 0\n            }\n          ]\n        }\n      }\n    }\n  }\n}\n');
window.textOverlay=Hi;var Ii=new tc('{"skeleton":{"hash":"43QQOpQ6M5PmhRz4smhUO4mpoCM","spine":"3.1.03","width":1076,"height":1366,"images":"./images/"},"bones":[{"name":"root"},{"name":"beams","parent":"root"},{"name":"txtMegaWin","parent":"root"}],"slots":[{"name":"beams","bone":"beams","attachment":"beams"},{"name":"coinsAnim","bone":"txtMegaWin","attachment":"coinsAnim"},{"name":"txtMegaWin","bone":"txtMegaWin","attachment":"txtMegaWin"}],"skins":{"default":{"beams":{"beams":{"width":1076,"height":1366}},"coinsAnim":{"coinsAnim":{"width":1043,"height":1009}},"txtMegaWin":{"txtMegaWin":{"width":841,"height":514}}}},"animations":{"megaWin":{"bones":{"txtMegaWin":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1.2,"y":1.2},{"time":0.3333,"x":0.9,"y":0.9},{"time":0.4666,"x":1,"y":1,"curve":"stepped"},{"time":0.9,"x":1,"y":1},{"time":1.1,"x":0,"y":0}]},"beams":{"rotate":[{"time":0,"angle":0},{"time":1.1666,"angle":260}],"scale":[{"time":0,"x":0,"y":0},{"time":0.2333,"x":1.3,"y":1.3,"curve":"stepped"},{"time":0.9666,"x":1.3,"y":1.3},{"time":1.1666,"x":0,"y":0}]}}}}}\n');
window.winOverlay=Ii;
var Ji=new tc('{"skeleton":{"hash":"P5Pm3W/1mUrs8PFuFRipSwdXcc0","spine":"3.2.01","width":145.2,"height":145,"images":"./images/"},"bones":[{"name":"root"},{"name":"back","parent":"root","length":70.86},{"name":"back_L","parent":"root","length":70.86},{"name":"coin_back_2","parent":"back","length":54.8},{"name":"coin_back_3","parent":"back_L","length":54.8},{"name":"front","parent":"root","length":70.86},{"name":"coin_front_2","parent":"front","length":54.8},{"name":"front_L","parent":"root","length":70.86},{"name":"coin_front_3","parent":"front_L","length":54.8},{"name":"rotate","parent":"root","length":50.4,"x":-17.7},{"name":"rotate2","parent":"root","length":50.4,"x":-17.7},{"name":"rotate2_L","parent":"root","length":50.4,"x":-17.7},{"name":"rotate_L","parent":"root","length":50.4,"x":-17.7},{"name":"side","parent":"root","length":13.32},{"name":"side_L","parent":"root","length":13.32}],"slots":[{"name":"coin_side","bone":"side","attachment":"coin_side"},{"name":"coin_side2","bone":"side_L","attachment":"coin_side_l"},{"name":"coin_rotate","bone":"rotate","attachment":"coin_rotate"},{"name":"coin_rotate3","bone":"rotate_L","attachment":"coin_rotate_l"},{"name":"coin_rotate2","bone":"rotate2","attachment":"coin_rotate"},{"name":"coin_rotate4","bone":"rotate2_L","attachment":"coin_rotate_l"},{"name":"coin_front","bone":"front","attachment":"coin_front"},{"name":"coin_front2","bone":"front_L","attachment":"coin_front_l"},{"name":"coin_front_2","bone":"coin_front_2","attachment":"coin_front_2"},{"name":"coin_front_3","bone":"coin_front_3","attachment":"coin_front_2_l"},{"name":"coin_back","bone":"back","attachment":"coin_back"},{"name":"coin_back2","bone":"back_L","attachment":"coin_back_l"},{"name":"coin_back_2","bone":"coin_back_2","attachment":"coin_back_2"},{"name":"coin_back_3","bone":"coin_back_3","attachment":"coin_back_2_l"}],"skins":{"default":{"coin_back":{"coin_back":{"width":145,"height":145}},"coin_back2":{"coin_back_l":{"width":145,"height":145}},"coin_back_2":{"coin_back_2":{"width":114,"height":114}},"coin_back_3":{"coin_back_2_l":{"width":114,"height":114}},"coin_front":{"coin_front":{"width":145,"height":145}},"coin_front2":{"coin_front_l":{"width":145,"height":145}},"coin_front_2":{"coin_front_2":{"width":114,"height":114}},"coin_front_3":{"coin_front_2_l":{"width":114,"height":114}},"coin_rotate":{"coin_rotate":{"width":110,"height":145}},"coin_rotate2":{"coin_rotate":{"width":110,"height":145}},"coin_rotate3":{"coin_rotate_l":{"width":110,"height":145}},"coin_rotate4":{"coin_rotate_l":{"width":110,"height":145}},"coin_side":{"coin_side":{"width":29,"height":145}},"coin_side2":{"coin_side_l":{"width":29,"height":145}}}},"animations":{"coinspin1":{"slots":{"coin_back":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back"},{"time":0.6,"name":"coin_back"},{"time":0.6333,"name":null}]},"coin_back2":{"attachment":[{"time":0,"name":null}]},"coin_back_2":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back_2"},{"time":0.6,"name":"coin_back_2"},{"time":0.6333,"name":null}]},"coin_back_3":{"attachment":[{"time":0,"name":null}]},"coin_front":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0.2,"name":"coin_front"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front"}]},"coin_front2":{"attachment":[{"time":0,"name":null}]},"coin_front_2":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0.2,"name":"coin_front_2"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front_2"}]},"coin_front_3":{"attachment":[{"time":0,"name":null}]},"coin_rotate":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0,"name":"coin_rotate"},{"time":0.2,"name":null},{"time":0.4,"name":"coin_rotate"},{"time":0.6,"name":null}]},"coin_rotate2":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}],"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_rotate"},{"time":0.4,"name":null},{"time":0.6,"name":"coin_rotate"},{"time":0.8,"name":null}]},"coin_rotate3":{"attachment":[{"time":0,"name":null}]},"coin_rotate4":{"attachment":[{"time":0,"name":null}]},"coin_side":{"color":[{"time":0.6,"color":"ffffffff"},{"time":0.8,"color":"ffffff00"}]},"coin_side2":{"attachment":[{"time":0,"name":null}]}},"bones":{"front":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":13.46,"y":0},{"time":0.6,"x":-13.56,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.2,"x":0.01,"y":1,"curve":"stepped"},{"time":0.6,"x":0.01,"y":1},{"time":0.8,"x":1,"y":1}]},"back":{"translate":[{"time":0.2,"x":-13.56,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":13.46,"y":0}],"scale":[{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":4.87,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":4.87,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.55,"y":1},{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.55,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate2":{"translate":[{"time":0.2,"x":30.29,"y":0,"curve":"stepped"},{"time":0.6,"x":30.29,"y":0}],"scale":[{"time":0.2,"x":-0.01,"y":1},{"time":0.3,"x":-0.6,"y":1},{"time":0.4,"x":-1,"y":1},{"time":0.6,"x":-0.01,"y":1},{"time":0.7,"x":-0.65,"y":1},{"time":0.8,"x":-1,"y":1}]},"side":{"scale":[{"time":0,"x":0.01,"y":1},{"time":0.2,"x":1,"y":1},{"time":0.4,"x":0.01,"y":1},{"time":0.6,"x":1,"y":1},{"time":0.8,"x":0.01,"y":1}]},"coin_back_2":{"translate":[{"time":0.2,"x":0,"y":0},{"time":0.3,"x":-2.57,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.5,"x":2.57,"y":0},{"time":0.6,"x":0,"y":0}],"scale":[{"time":0.2,"x":1,"y":1},{"time":0.3,"x":0.871,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.871,"y":1},{"time":0.6,"x":1,"y":1}]},"coin_front_2":{"translate":[{"time":0,"x":0,"y":0},{"time":0.1,"x":2.81,"y":0},{"time":0.7,"x":-2.51,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.902,"y":1.007},{"time":0.1666,"x":0.722,"y":1.021,"curve":"stepped"},{"time":0.6333,"x":0.722,"y":1.021},{"time":0.7,"x":0.902,"y":1.007},{"time":0.8,"x":1,"y":1}]},"root":{"rotate":[{"time":0,"angle":0},{"time":0.2666,"angle":56.95},{"time":0.5333,"angle":-168.2},{"time":0.8,"angle":0}],"scale":[{"time":0,"x":0.2,"y":0.2},{"time":0.8,"x":1,"y":1}]}}},"coinspin2":{"slots":{"coin_back":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back"},{"time":0.6,"name":"coin_back"},{"time":0.6333,"name":null}]},"coin_back2":{"attachment":[{"time":0,"name":null}]},"coin_back_2":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back_2"},{"time":0.6,"name":"coin_back_2"},{"time":0.6333,"name":null}]},"coin_back_3":{"attachment":[{"time":0,"name":null}]},"coin_front":{"attachment":[{"time":0.2,"name":"coin_front"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front"}]},"coin_front2":{"attachment":[{"time":0,"name":null}]},"coin_front_2":{"attachment":[{"time":0.2,"name":"coin_front_2"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front_2"}]},"coin_front_3":{"attachment":[{"time":0,"name":null}]},"coin_rotate":{"attachment":[{"time":0,"name":"coin_rotate"},{"time":0.2,"name":null},{"time":0.4,"name":"coin_rotate"},{"time":0.6,"name":null}]},"coin_rotate2":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_rotate"},{"time":0.4,"name":null},{"time":0.6,"name":"coin_rotate"},{"time":0.8,"name":null}]},"coin_rotate3":{"attachment":[{"time":0,"name":null}]},"coin_rotate4":{"attachment":[{"time":0,"name":null}]},"coin_side2":{"attachment":[{"time":0,"name":null}]}},"bones":{"front":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":13.46,"y":0},{"time":0.6,"x":-13.56,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.2,"x":0.01,"y":1,"curve":"stepped"},{"time":0.6,"x":0.01,"y":1},{"time":0.8,"x":1,"y":1}]},"back":{"translate":[{"time":0.2,"x":-13.56,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":13.46,"y":0}],"scale":[{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":4.87,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":4.87,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.55,"y":1},{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.55,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate2":{"translate":[{"time":0.2,"x":30.29,"y":0,"curve":"stepped"},{"time":0.6,"x":30.29,"y":0}],"scale":[{"time":0.2,"x":-0.01,"y":1},{"time":0.3,"x":-0.6,"y":1},{"time":0.4,"x":-1,"y":1},{"time":0.6,"x":-0.01,"y":1},{"time":0.7,"x":-0.65,"y":1},{"time":0.8,"x":-1,"y":1}]},"side":{"scale":[{"time":0,"x":0.01,"y":1},{"time":0.2,"x":1,"y":1},{"time":0.4,"x":0.01,"y":1},{"time":0.6,"x":1,"y":1},{"time":0.8,"x":0.01,"y":1}]},"coin_back_2":{"translate":[{"time":0.2,"x":0,"y":0},{"time":0.3,"x":-2.57,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.5,"x":2.57,"y":0},{"time":0.6,"x":0,"y":0}],"scale":[{"time":0.2,"x":1,"y":1},{"time":0.3,"x":0.871,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.871,"y":1},{"time":0.6,"x":1,"y":1}]},"coin_front_2":{"translate":[{"time":0,"x":0,"y":0},{"time":0.1,"x":2.81,"y":0},{"time":0.7,"x":-2.51,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.902,"y":1.007},{"time":0.1666,"x":0.722,"y":1.021,"curve":"stepped"},{"time":0.6333,"x":0.722,"y":1.021},{"time":0.7,"x":0.902,"y":1.007},{"time":0.8,"x":1,"y":1}]},"root":{"rotate":[{"time":0,"angle":0}],"scale":[{"time":0,"x":1,"y":1}]}}},"coinspin3":{"slots":{"coin_back":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back"},{"time":0.6,"name":"coin_back"},{"time":0.6333,"name":null}]},"coin_back2":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back_l"},{"time":0.6,"name":"coin_back_l"},{"time":0.6333,"name":null}]},"coin_back_2":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back_2"},{"time":0.6,"name":"coin_back_2"},{"time":0.6333,"name":null}]},"coin_back_3":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_back_2_l"},{"time":0.6,"name":"coin_back_2_l"},{"time":0.6333,"name":null}]},"coin_front":{"attachment":[{"time":0.2,"name":"coin_front"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front"}]},"coin_front2":{"attachment":[{"time":0,"name":"coin_front_l"},{"time":0.2333,"name":null},{"time":0.5666,"name":null},{"time":0.6,"name":"coin_front_l"}]},"coin_front_2":{"attachment":[{"time":0.2,"name":"coin_front_2"},{"time":0.2333,"name":null},{"time":0.6,"name":"coin_front_2"}]},"coin_front_3":{"attachment":[{"time":0,"name":"coin_front_2_l"},{"time":0.2333,"name":null},{"time":0.5666,"name":null},{"time":0.6,"name":"coin_front_2_l"}]},"coin_rotate":{"attachment":[{"time":0,"name":"coin_rotate"},{"time":0.2,"name":null},{"time":0.4,"name":"coin_rotate"},{"time":0.6,"name":null}]},"coin_rotate2":{"attachment":[{"time":0,"name":null},{"time":0.2,"name":"coin_rotate"},{"time":0.4,"name":null},{"time":0.6,"name":"coin_rotate"},{"time":0.8,"name":null}]},"coin_rotate3":{"attachment":[{"time":0,"name":"coin_rotate_l"},{"time":0.2,"name":null},{"time":0.3666,"name":null},{"time":0.4,"name":"coin_rotate_l"},{"time":0.5666,"name":"coin_rotate_l"},{"time":0.6,"name":null}]},"coin_rotate4":{"attachment":[{"time":0,"name":null},{"time":0.1666,"name":null},{"time":0.2,"name":"coin_rotate_l"},{"time":0.3666,"name":"coin_rotate_l"},{"time":0.4,"name":null},{"time":0.5666,"name":null},{"time":0.6,"name":"coin_rotate_l"},{"time":0.7666,"name":"coin_rotate_l"},{"time":0.8,"name":null}]}},"bones":{"front":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":13.46,"y":0},{"time":0.6,"x":-13.56,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.2,"x":0.01,"y":1,"curve":"stepped"},{"time":0.6,"x":0.01,"y":1},{"time":0.8,"x":1,"y":1}]},"back":{"translate":[{"time":0.2,"x":-13.56,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":13.46,"y":0}],"scale":[{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":4.87,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":4.87,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.55,"y":1},{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.55,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate2":{"translate":[{"time":0.2,"x":30.29,"y":0,"curve":"stepped"},{"time":0.6,"x":30.29,"y":0}],"scale":[{"time":0.2,"x":-0.01,"y":1},{"time":0.3,"x":-0.6,"y":1},{"time":0.4,"x":-1,"y":1},{"time":0.6,"x":-0.01,"y":1},{"time":0.7,"x":-0.65,"y":1},{"time":0.8,"x":-1,"y":1}]},"side":{"scale":[{"time":0,"x":0.01,"y":1},{"time":0.2,"x":1,"y":1},{"time":0.4,"x":0.01,"y":1},{"time":0.6,"x":1,"y":1},{"time":0.8,"x":0.01,"y":1}]},"coin_back_2":{"translate":[{"time":0.2,"x":0,"y":0},{"time":0.3,"x":-2.57,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.5,"x":2.57,"y":0},{"time":0.6,"x":0,"y":0}],"scale":[{"time":0.2,"x":1,"y":1},{"time":0.3,"x":0.871,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.871,"y":1},{"time":0.6,"x":1,"y":1}]},"coin_front_2":{"translate":[{"time":0,"x":0,"y":0},{"time":0.1,"x":2.81,"y":0},{"time":0.7,"x":-2.51,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.902,"y":1.007},{"time":0.1666,"x":0.722,"y":1.021,"curve":"stepped"},{"time":0.6333,"x":0.722,"y":1.021},{"time":0.7,"x":0.902,"y":1.007},{"time":0.8,"x":1,"y":1}]},"root":{"rotate":[{"time":0,"angle":0}],"scale":[{"time":0,"x":1,"y":1}]},"back_L":{"translate":[{"time":0.2,"x":-13.56,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":13.46,"y":0}],"scale":[{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.6,"x":0.01,"y":1}]},"front_L":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":13.46,"y":0},{"time":0.6,"x":-13.56,"y":0},{"time":0.8,"x":0,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.2,"x":0.01,"y":1,"curve":"stepped"},{"time":0.6,"x":0.01,"y":1},{"time":0.8,"x":1,"y":1}]},"rotate_L":{"translate":[{"time":0,"x":0,"y":0},{"time":0.2,"x":4.87,"y":0},{"time":0.4,"x":0,"y":0},{"time":0.6,"x":4.87,"y":0}],"scale":[{"time":0,"x":1,"y":1},{"time":0.1,"x":0.55,"y":1},{"time":0.2,"x":0.01,"y":1},{"time":0.4,"x":1,"y":1},{"time":0.5,"x":0.55,"y":1},{"time":0.6,"x":0.01,"y":1}]},"rotate2_L":{"translate":[{"time":0.2,"x":30.29,"y":0,"curve":"stepped"},{"time":0.6,"x":30.29,"y":0}],"scale":[{"time":0.2,"x":-0.01,"y":1},{"time":0.3,"x":-0.6,"y":1},{"time":0.4,"x":-1,"y":1},{"time":0.6,"x":-0.01,"y":1},{"time":0.7,"x":-0.65,"y":1},{"time":0.8,"x":-1,"y":1}]},"side_L":{"scale":[{"time":0,"x":0.01,"y":1},{"time":0.2,"x":1,"y":1},{"time":0.4,"x":0.01,"y":1},{"time":0.6,"x":1,"y":1},{"time":0.8,"x":0.01,"y":1}]}}}}}\n',J);
window.coinAnimation=Ji;
var Ki=new tc('{\n"skeleton": { "hash": "gVSjcV2pUn97SxCl8bVkXK+EZYQ", "spine": "3.2.01", "width": 518, "height": 600, "images": "./images/" },\n"bones": [\n\t{ "name": "root" },\n\t{ "name": "scatterRoot", "parent": "root" },\n\t{ "name": "glow_state1", "parent": "scatterRoot" },\n\t{ "name": "glow_state2", "parent": "scatterRoot" },\n\t{ "name": "glow_state3", "parent": "scatterRoot" },\n\t{ "name": "scatterBreak", "parent": "scatterRoot" },\n\t{ "name": "symbolScatter", "parent": "scatterRoot" }\n],\n"slots": [\n\t{ "name": "collectables", "bone": "root", "attachment": "symbol10" },\n\t{ "name": "symbolScatter", "bone": "symbolScatter", "attachment": "symbolScatter" },\n\t{ "name": "scatterBreak", "bone": "scatterBreak", "attachment": "scatterBreak_00" },\n\t{ "name": "glow_state1", "bone": "glow_state1", "attachment": "glow_state1" },\n\t{ "name": "glow_state2", "bone": "glow_state2", "attachment": "glow_state2" },\n\t{ "name": "glow_state3", "bone": "glow_state3", "attachment": "glow_state3" }\n],\n"skins": {\n\t"default": {\n\t\t"collectables": {\n\t\t\t"symbol8": { "y": 18.64, "width": 242, "height": 290 },\n\t\t\t"symbol9": { "y": 18.64, "width": 242, "height": 290 },\n\t\t\t"symbol10": { "y": 18.5, "width": 242, "height": 290 }\n\t\t},\n\t\t"glow_state1": {\n\t\t\t"glow_state1": { "x": 6, "y": -18, "width": 518, "height": 522 }\n\t\t},\n\t\t"glow_state2": {\n\t\t\t"glow_state2": { "x": 6, "y": -18, "width": 518, "height": 522 }\n\t\t},\n\t\t"glow_state3": {\n\t\t\t"glow_state3": { "x": 6, "y": -18, "width": 518, "height": 522 }\n\t\t},\n\t\t"scatterBreak": {\n\t\t\t"scatterBreak_00": { "x": 1, "y": 11.13, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_01": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_02": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_03": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_04": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_05": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_06": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_07": { "x": 6, "width": 500, "height": 600 },\n\t\t\t"scatterBreak_08": { "x": 6, "width": 500, "height": 600 }\n\t\t},\n\t\t"symbolScatter": {\n\t\t\t"symbolScatter": { "x": 0.5, "y": 12, "width": 243, "height": 352 }\n\t\t}\n\t}\n},\n"animations": {\n\t"ScatterState1Play": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffffcc" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"glow_state1": {\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState1Start": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffff00" },\n\t\t\t\t\t{ "time": 0.2666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState2Play": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffffd3" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffff80" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"glow_state1": {\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState2Start": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffff00" },\n\t\t\t\t\t{ "time": 0.2666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState3PlayFlower": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol10" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.1333, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0.8, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1, "color": "ffffff00" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffffcc" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.9333, "color": "ffffffbe" },\n\t\t\t\t\t{ "time": 1.0666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1.3333, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.3666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 1, "name": "scatterBreak_00" },\n\t\t\t\t\t{ "time": 1.0333, "name": "scatterBreak_01" },\n\t\t\t\t\t{ "time": 1.0666, "name": "scatterBreak_02" },\n\t\t\t\t\t{ "time": 1.1, "name": "scatterBreak_03" },\n\t\t\t\t\t{ "time": 1.1333, "name": "scatterBreak_04" },\n\t\t\t\t\t{ "time": 1.1666, "name": "scatterBreak_05" },\n\t\t\t\t\t{ "time": 1.2, "name": "scatterBreak_06" },\n\t\t\t\t\t{ "time": 1.2666, "name": "scatterBreak_07" },\n\t\t\t\t\t{ "time": 1.3333, "name": "scatterBreak_08" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolScatter": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 1, "name": "symbolScatter" },\n\t\t\t\t\t{ "time": 1.0333, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"glow_state3": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1.0666, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState3PlayFrog": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol9" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.1333, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0.8, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1, "color": "ffffff00" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffffcc" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.9333, "color": "ffffffbe" },\n\t\t\t\t\t{ "time": 1.0666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1.3333, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.3666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 1, "name": "scatterBreak_00" },\n\t\t\t\t\t{ "time": 1.0333, "name": "scatterBreak_01" },\n\t\t\t\t\t{ "time": 1.0666, "name": "scatterBreak_02" },\n\t\t\t\t\t{ "time": 1.1, "name": "scatterBreak_03" },\n\t\t\t\t\t{ "time": 1.1333, "name": "scatterBreak_04" },\n\t\t\t\t\t{ "time": 1.1666, "name": "scatterBreak_05" },\n\t\t\t\t\t{ "time": 1.2, "name": "scatterBreak_06" },\n\t\t\t\t\t{ "time": 1.2666, "name": "scatterBreak_07" },\n\t\t\t\t\t{ "time": 1.3333, "name": "scatterBreak_08" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolScatter": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 1, "name": "symbolScatter" },\n\t\t\t\t\t{ "time": 1.0333, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"glow_state3": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1.0666, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState3PlayTucan": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol8" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.1333, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0.8, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1, "color": "ffffff00" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.3333, "color": "ffffffcc" },\n\t\t\t\t\t{ "time": 0.6666, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.9333, "color": "ffffffbe" },\n\t\t\t\t\t{ "time": 1.0666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "glow_state3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1.3333, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.3666, "color": "ffffff00" }\n\t\t\t\t],\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 1, "name": "scatterBreak_00" },\n\t\t\t\t\t{ "time": 1.0333, "name": "scatterBreak_01" },\n\t\t\t\t\t{ "time": 1.0666, "name": "scatterBreak_02" },\n\t\t\t\t\t{ "time": 1.1, "name": "scatterBreak_03" },\n\t\t\t\t\t{ "time": 1.1333, "name": "scatterBreak_04" },\n\t\t\t\t\t{ "time": 1.1666, "name": "scatterBreak_05" },\n\t\t\t\t\t{ "time": 1.2, "name": "scatterBreak_06" },\n\t\t\t\t\t{ "time": 1.2666, "name": "scatterBreak_07" },\n\t\t\t\t\t{ "time": 1.3333, "name": "scatterBreak_08" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolScatter": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 1, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 1.0333, "color": "ffffff00" }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"glow_state3": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1.0666, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.3333, "x": 1.03, "y": 1.03 },\n\t\t\t\t\t{ "time": 0.6666, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 1, "x": 1.5, "y": 1.5 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 1, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"ScatterState3Start": {\n\t\t"slots": {\n\t\t\t"collectables": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state2": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffffff" },\n\t\t\t\t\t{ "time": 0.2666, "color": "ffffff99" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"glow_state3": {\n\t\t\t\t"color": [\n\t\t\t\t\t{ "time": 0, "color": "ffffff00" },\n\t\t\t\t\t{ "time": 0.2666, "color": "ffffffff" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"scatterBreak": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t}\n}\n}\n',K);
window.scatterAnimation=Ki;
var Li=new tc('{\n"skeleton": { "hash": "BhdxuEcsdIKQskrxdOdzikQf37I", "spine": "3.2.01", "width": 244, "height": 292, "images": "./images/" },\n"bones": [\n\t{ "name": "root" },\n\t{ "name": "symbol1", "parent": "root" },\n\t{ "name": "symbol2", "parent": "root" },\n\t{ "name": "symbol3", "parent": "root" },\n\t{ "name": "symbol4", "parent": "root" },\n\t{ "name": "symbol5", "parent": "root" },\n\t{ "name": "symbol6", "parent": "root" },\n\t{ "name": "symbol7", "parent": "root" },\n\t{ "name": "symbol1Jewel", "parent": "symbol1" },\n\t{ "name": "symbol2Jewel", "parent": "symbol2" },\n\t{ "name": "symbol3Jewel", "parent": "symbol3", "x": 4.16, "y": -1.91 },\n\t{ "name": "symbol4Body", "parent": "symbol4", "length": 201.25, "rotation": 89.68, "x": -6.18, "y": -85.93 },\n\t{ "name": "symbol4Head", "parent": "symbol4", "x": -17.95, "y": 113.14 },\n\t{ "name": "symbol5Body", "parent": "symbol5", "length": 98.23, "rotation": 88.69, "x": -15.11, "y": -67.7 },\n\t{ "name": "symbol5Head", "parent": "symbol5" },\n\t{ "name": "symbol6Body", "parent": "symbol6", "length": 268.88, "rotation": 92.69, "x": -2.09, "y": -140.98 },\n\t{ "name": "symbol6Border", "parent": "symbol6" },\n\t{ "name": "symbol7Bg", "parent": "symbol7" },\n\t{ "name": "symbol7Body", "parent": "root", "x": 0.59, "y": -2.71 },\n\t{ "name": "symbol7Border", "parent": "symbol7" },\n\t{ "name": "symbol7Neck", "parent": "symbol7Body", "x": 68.25, "y": -58.48 },\n\t{ "name": "symbol7Head", "parent": "symbol7Neck", "x": -15.95, "y": 29.79 },\n\t{ "name": "symbol7Eye", "parent": "symbol7Head", "x": -53.73, "y": 64.37 },\n\t{ "name": "symbol7Hair", "parent": "symbol7Head", "x": -108.52, "y": 59.97 },\n\t{ "name": "symbolWild", "parent": "root" },\n\t{ "name": "symbolWildTxt", "parent": "symbolWild" }\n],\n"slots": [\n\t{ "name": "symbol7Bg", "bone": "symbol7Bg", "attachment": "symbol7Bg" },\n\t{ "name": "symbol7Body", "bone": "symbol7Body", "attachment": "symbol7Body" },\n\t{ "name": "symbol7Neck", "bone": "symbol7Neck", "attachment": "symbol7Neck" },\n\t{ "name": "symbol7Hair", "bone": "symbol7Hair", "attachment": "symbol7Hair" },\n\t{ "name": "symbol7Head", "bone": "symbol7Head", "attachment": "symbol7Head" },\n\t{ "name": "symbol7Eye", "bone": "symbol7Eye", "attachment": "symbol7Eye" },\n\t{ "name": "symbol7Border", "bone": "symbol7Border", "attachment": "symbol7Border" },\n\t{ "name": "symbolEmpty1", "bone": "symbol1", "attachment": "symbolEmptyBlue" },\n\t{ "name": "symbolEmpty2", "bone": "symbol2", "attachment": "symbolEmpty" },\n\t{ "name": "symbolEmpty3", "bone": "symbol3", "attachment": "symbolEmpty" },\n\t{ "name": "symbol1Jewel", "bone": "symbol1Jewel", "attachment": "symbol1Jewel" },\n\t{ "name": "symbol2Jewel", "bone": "symbol2Jewel", "attachment": "symbol2Jewel" },\n\t{ "name": "symbol3Jewel", "bone": "symbol3Jewel", "attachment": "symbol3Jewel" },\n\t{ "name": "symbol4Bg", "bone": "symbol4", "attachment": "symbol4Bg" },\n\t{ "name": "symbol4Body", "bone": "symbol4Body", "attachment": "symbol4Body" },\n\t{ "name": "symbol4Head", "bone": "symbol4Head", "attachment": "symbol4Head" },\n\t{ "name": "symbol5Bg", "bone": "symbol5", "attachment": "symbol5Bg" },\n\t{ "name": "symbol5Body", "bone": "symbol5Body", "attachment": "symbol5Body" },\n\t{ "name": "symbol5Head", "bone": "symbol5Head", "attachment": "symbol5Head" },\n\t{ "name": "symbol6Bg", "bone": "symbol6", "attachment": "symbol6Bg" },\n\t{ "name": "symbol6Body", "bone": "symbol6Body", "attachment": "symbol6Body" },\n\t{ "name": "symbol6Border", "bone": "symbol6Border", "attachment": "symbol6Border" },\n\t{ "name": "symbolWildBg", "bone": "symbolWild", "attachment": "symbolWildBg" },\n\t{ "name": "symbolWildTxt", "bone": "symbolWildTxt", "attachment": "symbolWildTxt" }\n],\n"skins": {\n\t"default": {\n\t\t"symbol1Jewel": {\n\t\t\t"symbol1Jewel": { "x": 0.96, "y": 6.71, "width": 220, "height": 220 }\n\t\t},\n\t\t"symbol2Jewel": {\n\t\t\t"symbol2Jewel": { "x": 4.8, "y": -7.67, "width": 215, "height": 211 }\n\t\t},\n\t\t"symbol3Jewel": {\n\t\t\t"symbol3Jewel": { "width": 198, "height": 198 }\n\t\t},\n\t\t"symbol4Bg": {\n\t\t\t"symbol4Bg": { "width": 242, "height": 290 },\n\t\t\t"symbol4BgBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbol4Body": {\n\t\t\t"symbol4Body": { "x": 84.72, "y": 4.55, "scaleX": 0.98, "scaleY": 0.98, "rotation": -89.68, "width": 213, "height": 254 }\n\t\t},\n\t\t"symbol4Head": {\n\t\t\t"symbol4Head": { "x": -17.59, "y": -4.91, "width": 50, "height": 32 }\n\t\t},\n\t\t"symbol5Bg": {\n\t\t\t"symbol5Bg": { "width": 242, "height": 290 },\n\t\t\t"symbol5BgBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbol5Body": {\n\t\t\t"symbol5Body": { "x": 82.87, "y": -6.11, "scaleX": 0.9, "scaleY": 0.9, "rotation": -88.69, "width": 189, "height": 245 }\n\t\t},\n\t\t"symbol5Head": {\n\t\t\t"symbol5Head": { "x": 12.79, "y": 55.35, "scaleX": 0.897, "scaleY": 0.897, "width": 175, "height": 136 }\n\t\t},\n\t\t"symbol6Bg": {\n\t\t\t"symbol6Bg": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbol6Body": {\n\t\t\t"symbol6Body": { "x": 140.07, "y": -22.77, "rotation": -92.69, "width": 214, "height": 290 }\n\t\t},\n\t\t"symbol6Border": {\n\t\t\t"symbol6Border": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbol7Bg": {\n\t\t\t"symbol7Bg": { "x": 0.5, "y": 0.5, "width": 239, "height": 287 }\n\t\t},\n\t\t"symbol7Body": {\n\t\t\t"symbol7Body": { "x": 23.9, "y": -95.28, "width": 195, "height": 96 }\n\t\t},\n\t\t"symbol7Border": {\n\t\t\t"symbol7Border": { "width": 244, "height": 292 }\n\t\t},\n\t\t"symbol7Eye": {\n\t\t\t"symbol7Eye": { "x": 3.5, "y": 2.5, "width": 61, "height": 43 }\n\t\t},\n\t\t"symbol7Hair": {\n\t\t\t"symbol7Hair": { "x": 11.63, "y": -37.55, "width": 84, "height": 178 }\n\t\t},\n\t\t"symbol7Head": {\n\t\t\t"symbol7Head": { "x": -46.89, "y": 60.91, "width": 198, "height": 223 }\n\t\t},\n\t\t"symbol7Neck": {\n\t\t\t"symbol7Neck": { "x": -20.35, "y": 5.2, "width": 79, "height": 94 }\n\t\t},\n\t\t"symbolEmpty1": {\n\t\t\t"symbolEmpty": { "width": 244, "height": 292 },\n\t\t\t"symbolEmptyBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbolEmpty2": {\n\t\t\t"symbolEmpty": { "width": 244, "height": 292 },\n\t\t\t"symbolEmptyBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbolEmpty3": {\n\t\t\t"symbolEmpty": { "width": 244, "height": 292 },\n\t\t\t"symbolEmptyBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbolWildBg": {\n\t\t\t"symbolWildBg": { "width": 242, "height": 290 },\n\t\t\t"symbolWildBgBlue": { "width": 242, "height": 290 }\n\t\t},\n\t\t"symbolWildTxt": {\n\t\t\t"symbolWildTxt": { "width": 242, "height": 100 }\n\t\t}\n\t}\n},\n"animations": {\n\t"symbol1": {\n\t\t"slots": {\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol2": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol3": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol5": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol6": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Border" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"symbol6Body": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.5333, "angle": -4.95 },\n\t\t\t\t\t{ "time": 1.0666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 10.29 },\n\t\t\t\t\t{ "time": 1.0666, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1.023, "y": 1.023 },\n\t\t\t\t\t{ "time": 0.5333, "x": 0.924, "y": 0.924 },\n\t\t\t\t\t{ "time": 1.0666, "x": 1.02, "y": 1.02 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol7": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"symbol7Body": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.5333, "angle": -9.36 },\n\t\t\t\t\t{ "time": 1.0666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": -6.02, "y": 3.01 },\n\t\t\t\t\t{ "time": 1.0666, "x": 0, "y": 0 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.5333, "x": 0.9, "y": 0.9 },\n\t\t\t\t\t{ "time": 1.0666, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol1Blue": {\n\t\t"slots": {\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol1BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol1Still": {\n\t\t"slots": {\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol2Blue": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol2Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol2BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol2Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol2Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol2Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol3Blue": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol3Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol3BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol3Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmptyBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol3Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol3Jewel" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolEmpty" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4Blue": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4BgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4BgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol5Blue": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5BgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol5BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5BgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol5Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol5Head" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol6Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Bg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Body" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol6Border" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol7Still": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbolWild": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildBg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildTxt" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbolWildBlue": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildBgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildTxt" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbolWildBlueStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildBgBlue" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildTxt" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbolWildStill": {\n\t\t"slots": {\n\t\t\t"symbol1Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol2Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol3Jewel": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol5Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol6Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Body": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Border": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Eye": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Hair": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Head": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol7Neck": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolEmpty3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildBg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildBg" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbolWildTxt": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbolWildTxt" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t}\n}\n}\n',L);
window.SymbolAnimation=Li;
var Mi=new tc('{\n"skeleton": { "hash": "DLjT7jcYT4jIEClAXTrHMfwZX/g", "spine": "3.2.01", "width": 1820.44, "height": 2430.89, "images": "./images/" },\n"bones": [\n\t{ "name": "root" },\n\t{ "name": "landscape_left", "parent": "root" },\n\t{ "name": "landscape_right", "parent": "root" },\n\t{ "name": "portrait", "parent": "root" },\n\t{ "name": "leafDark", "parent": "portrait", "x": -475.07, "y": 710.15, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark2", "parent": "portrait", "x": -611.23, "y": -661.89, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark3", "parent": "portrait", "x": -639.17, "y": 118.53, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark4", "parent": "portrait", "x": -346.02, "y": -134.37, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark5", "parent": "portrait", "x": 496.05, "y": 224.87, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark6", "parent": "portrait", "x": 582.27, "y": 609.99, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark7", "parent": "portrait", "x": 611.03, "y": -815.51, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark8", "parent": "landscape_left", "x": -475.07, "y": 710.15, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark9", "parent": "landscape_left", "x": -611.23, "y": -661.89, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark10", "parent": "landscape_left", "x": -639.17, "y": 118.53, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark11", "parent": "landscape_left", "x": -346.02, "y": -134.37, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark16", "parent": "landscape_right", "x": 496.05, "y": 224.87, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark17", "parent": "landscape_right", "x": 582.27, "y": 609.99, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafDark18", "parent": "landscape_right", "x": 611.03, "y": -815.51, "scaleX": 1.07, "scaleY": 1.07 },\n\t{ "name": "leafLight", "parent": "portrait", "x": -382.05, "y": 467.96 },\n\t{ "name": "leafLight2", "parent": "portrait", "x": -640.71, "y": -149.94 },\n\t{ "name": "leafLight3", "parent": "portrait", "x": -718.31, "y": -776.48 },\n\t{ "name": "leafLight4", "parent": "portrait", "x": 287.58, "y": -264.9 },\n\t{ "name": "leafLight5", "parent": "portrait", "x": 600.85, "y": 307.01 },\n\t{ "name": "leafLight6", "parent": "portrait", "x": 427.81, "y": 829.75 },\n\t{ "name": "leafLight7", "parent": "portrait", "x": 446.25, "y": -996.19 },\n\t{ "name": "leafLight8", "parent": "landscape_left", "x": -382.05, "y": 467.96 },\n\t{ "name": "leafLight9", "parent": "landscape_left", "x": -640.71, "y": -149.94 },\n\t{ "name": "leafLight10", "parent": "landscape_left", "x": -718.31, "y": -776.48 },\n\t{ "name": "leafLight14", "parent": "landscape_right", "x": 287.58, "y": -264.9 },\n\t{ "name": "leafLight15", "parent": "landscape_right", "x": 600.85, "y": 307.01 },\n\t{ "name": "leafLight16", "parent": "landscape_right", "x": 427.81, "y": 829.75 },\n\t{ "name": "leafLight17", "parent": "landscape_right", "x": 446.25, "y": -996.19 },\n\t{ "name": "leafMedium", "parent": "portrait", "x": -612.39, "y": -116.73 },\n\t{ "name": "leafMedium2", "parent": "portrait", "x": -690.66, "y": 492.05 },\n\t{ "name": "leafMedium3", "parent": "portrait", "x": -444.25, "y": -876.27 },\n\t{ "name": "leafMedium4", "parent": "portrait", "x": 469.48, "y": 406.8 },\n\t{ "name": "leafMedium5", "parent": "portrait", "x": 355.87, "y": 955.89 },\n\t{ "name": "leafMedium6", "parent": "portrait", "x": 722.14, "y": -209.07 },\n\t{ "name": "leafMedium7", "parent": "landscape_left", "x": -612.39, "y": -116.73 },\n\t{ "name": "leafMedium8", "parent": "landscape_left", "x": -690.66, "y": 492.05 },\n\t{ "name": "leafMedium9", "parent": "landscape_left", "x": -444.25, "y": -876.27 },\n\t{ "name": "leafMedium13", "parent": "landscape_right", "x": 469.48, "y": 406.8 },\n\t{ "name": "leafMedium14", "parent": "landscape_right", "x": 355.87, "y": 955.89 },\n\t{ "name": "leafMedium15", "parent": "landscape_right", "x": 722.14, "y": -209.07 }\n],\n"slots": [\n\t{ "name": "6", "bone": "leafDark4", "attachment": "leaf_3" },\n\t{ "name": "26", "bone": "leafDark11", "attachment": "leaf_3" },\n\t{ "name": "3", "bone": "leafDark", "attachment": "leaf_3" },\n\t{ "name": "21", "bone": "leafDark8", "attachment": "leaf_3" },\n\t{ "name": "4", "bone": "leafDark2", "attachment": "leaf_3" },\n\t{ "name": "24", "bone": "leafDark9", "attachment": "leaf_3" },\n\t{ "name": "5", "bone": "leafDark3", "attachment": "leaf_3" },\n\t{ "name": "25", "bone": "leafDark10", "attachment": "leaf_3" },\n\t{ "name": "7", "bone": "leafDark5", "attachment": "leaf_3" },\n\t{ "name": "35", "bone": "leafDark16", "attachment": "leaf_3" },\n\t{ "name": "8", "bone": "leafDark6", "attachment": "leaf_3" },\n\t{ "name": "38", "bone": "leafDark17", "attachment": "leaf_3" },\n\t{ "name": "9", "bone": "leafDark7", "attachment": "leaf_3" },\n\t{ "name": "39", "bone": "leafDark18", "attachment": "leaf_3" },\n\t{ "name": "1", "bone": "leafLight", "attachment": "leaf_1" },\n\t{ "name": "22", "bone": "leafLight8", "attachment": "leaf_1" },\n\t{ "name": "18", "bone": "leafMedium4", "attachment": "leaf_2" },\n\t{ "name": "48", "bone": "leafMedium13", "attachment": "leaf_2" },\n\t{ "name": "10", "bone": "leafLight2", "attachment": "leaf_1" },\n\t{ "name": "30", "bone": "leafLight9", "attachment": "leaf_1" },\n\t{ "name": "11", "bone": "leafLight3", "attachment": "leaf_1" },\n\t{ "name": "31", "bone": "leafLight10", "attachment": "leaf_1" },\n\t{ "name": "12", "bone": "leafLight4", "attachment": "leaf_1" },\n\t{ "name": "42", "bone": "leafLight14", "attachment": "leaf_1" },\n\t{ "name": "13", "bone": "leafLight5", "attachment": "leaf_1" },\n\t{ "name": "43", "bone": "leafLight15", "attachment": "leaf_1" },\n\t{ "name": "14", "bone": "leafLight6", "attachment": "leaf_1" },\n\t{ "name": "44", "bone": "leafLight16", "attachment": "leaf_1" },\n\t{ "name": "15", "bone": "leafLight7", "attachment": "leaf_1" },\n\t{ "name": "45", "bone": "leafLight17", "attachment": "leaf_1" },\n\t{ "name": "16", "bone": "leafMedium2", "attachment": "leaf_2" },\n\t{ "name": "36", "bone": "leafMedium8", "attachment": "leaf_2" },\n\t{ "name": "17", "bone": "leafMedium3", "attachment": "leaf_2" },\n\t{ "name": "37", "bone": "leafMedium9", "attachment": "leaf_2" },\n\t{ "name": "20", "bone": "leafMedium6", "attachment": "leaf_2" },\n\t{ "name": "50", "bone": "leafMedium15", "attachment": "leaf_2" },\n\t{ "name": "19", "bone": "leafMedium5", "attachment": "leaf_2" },\n\t{ "name": "49", "bone": "leafMedium14", "attachment": "leaf_2" },\n\t{ "name": "2", "bone": "leafMedium", "attachment": "leaf_2" },\n\t{ "name": "23", "bone": "leafMedium7", "attachment": "leaf_2" }\n],\n"skins": {\n\t"default": {\n\t\t"1": {\n\t\t\t"leaf_1": { "x": 207.78, "y": -86.08, "rotation": -33.31, "width": 711, "height": 479 }\n\t\t},\n\t\t"10": {\n\t\t\t"leaf_1": { "x": 190.53, "y": 138.08, "scaleX": 0.906, "scaleY": 0.906, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"11": {\n\t\t\t"leaf_1": { "x": 190.53, "y": 138.08, "scaleX": 0.906, "scaleY": 0.906, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"12": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"13": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"14": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"15": {\n\t\t\t"leaf_1": { "x": -134.29, "y": 150.2, "scaleX": -1, "rotation": -31.77, "width": 711, "height": 479 }\n\t\t},\n\t\t"16": {\n\t\t\t"leaf_2": { "x": 248.75, "y": 7.7, "scaleX": 0.882, "scaleY": 0.882, "rotation": 18.29, "width": 792, "height": 504 }\n\t\t},\n\t\t"17": {\n\t\t\t"leaf_2": { "x": 277.74, "y": 120.76, "rotation": 40.75, "width": 792, "height": 504 }\n\t\t},\n\t\t"18": {\n\t\t\t"leaf_2": { "x": -217.98, "y": -15.48, "scaleX": -1, "rotation": -15.67, "width": 792, "height": 504 }\n\t\t},\n\t\t"19": {\n\t\t\t"leaf_2": { "x": -229.58, "y": -119.85, "scaleX": -0.9, "scaleY": 0.9, "rotation": 25.47, "width": 792, "height": 504 }\n\t\t},\n\t\t"2": {\n\t\t\t"leaf_2": { "x": 240.05, "y": -32.88, "width": 792, "height": 504 }\n\t\t},\n\t\t"20": {\n\t\t\t"leaf_2": { "x": -265.47, "y": -62.97, "scaleX": -1, "rotation": 15.23, "width": 792, "height": 504 }\n\t\t},\n\t\t"21": {\n\t\t\t"leaf_3": { "x": 201.96, "y": -120.48, "scaleX": 1.108, "scaleY": 1.108, "rotation": -18.28, "width": 680, "height": 572 }\n\t\t},\n\t\t"22": {\n\t\t\t"leaf_1": { "x": 207.78, "y": -86.08, "rotation": -33.31, "width": 711, "height": 479 }\n\t\t},\n\t\t"23": {\n\t\t\t"leaf_2": { "x": 240.05, "y": -32.88, "width": 792, "height": 504 }\n\t\t},\n\t\t"24": {\n\t\t\t"leaf_3": { "x": 246.84, "y": 95.66, "scaleX": 1.133, "scaleY": 1.133, "rotation": 48.65, "width": 680, "height": 572 }\n\t\t},\n\t\t"25": {\n\t\t\t"leaf_3": { "x": 276.68, "y": -18.11, "scaleX": 1.004, "scaleY": 1.004, "rotation": 20.17, "width": 680, "height": 572 }\n\t\t},\n\t\t"26": {\n\t\t\t"leaf_3": { "x": 276.68, "y": -18.11, "scaleX": 1.004, "scaleY": 1.004, "rotation": 20.17, "width": 680, "height": 572 }\n\t\t},\n\t\t"3": {\n\t\t\t"leaf_3": { "x": 201.96, "y": -120.48, "scaleX": 1.108, "scaleY": 1.108, "rotation": -18.28, "width": 680, "height": 572 }\n\t\t},\n\t\t"30": {\n\t\t\t"leaf_1": { "x": 190.53, "y": 138.08, "scaleX": 0.906, "scaleY": 0.906, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"31": {\n\t\t\t"leaf_1": { "x": 190.53, "y": 138.08, "scaleX": 0.906, "scaleY": 0.906, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"35": {\n\t\t\t"leaf_3": { "x": -163.79, "y": -190.02, "scaleX": -1.1, "scaleY": 1.1, "rotation": 18.1, "width": 680, "height": 572 }\n\t\t},\n\t\t"36": {\n\t\t\t"leaf_2": { "x": 248.75, "y": 7.7, "scaleX": 0.882, "scaleY": 0.882, "rotation": 18.29, "width": 792, "height": 504 }\n\t\t},\n\t\t"37": {\n\t\t\t"leaf_2": { "x": 277.74, "y": 120.76, "rotation": 40.75, "width": 792, "height": 504 }\n\t\t},\n\t\t"38": {\n\t\t\t"leaf_3": { "x": -260.49, "y": -20.8, "scaleX": -1, "rotation": -39.25, "width": 680, "height": 572 }\n\t\t},\n\t\t"39": {\n\t\t\t"leaf_3": { "x": -308.83, "y": 113.49, "scaleX": -1.1, "scaleY": 1.1, "rotation": -40.56, "width": 680, "height": 572 }\n\t\t},\n\t\t"4": {\n\t\t\t"leaf_3": { "x": 246.84, "y": 95.66, "scaleX": 1.133, "scaleY": 1.133, "rotation": 48.65, "width": 680, "height": 572 }\n\t\t},\n\t\t"42": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"43": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"44": {\n\t\t\t"leaf_1": { "x": -177.33, "y": -80.34, "scaleX": -1, "rotation": 30.33, "width": 711, "height": 479 }\n\t\t},\n\t\t"45": {\n\t\t\t"leaf_1": { "x": -134.29, "y": 150.2, "scaleX": -1, "rotation": -31.77, "width": 711, "height": 479 }\n\t\t},\n\t\t"48": {\n\t\t\t"leaf_2": { "x": -217.98, "y": -15.48, "scaleX": -1, "rotation": -15.67, "width": 792, "height": 504 }\n\t\t},\n\t\t"49": {\n\t\t\t"leaf_2": { "x": -229.58, "y": -119.85, "scaleX": -0.9, "scaleY": 0.9, "rotation": 25.47, "width": 792, "height": 504 }\n\t\t},\n\t\t"5": {\n\t\t\t"leaf_3": { "x": 276.68, "y": -18.11, "scaleX": 1.004, "scaleY": 1.004, "rotation": 20.17, "width": 680, "height": 572 }\n\t\t},\n\t\t"50": {\n\t\t\t"leaf_2": { "x": -265.47, "y": -62.97, "scaleX": -1, "rotation": 15.23, "width": 792, "height": 504 }\n\t\t},\n\t\t"6": {\n\t\t\t"leaf_3": { "x": 276.68, "y": -18.11, "scaleX": 1.004, "scaleY": 1.004, "rotation": 20.17, "width": 680, "height": 572 }\n\t\t},\n\t\t"7": {\n\t\t\t"leaf_3": { "x": -163.79, "y": -190.02, "scaleX": -1.1, "scaleY": 1.1, "rotation": 18.1, "width": 680, "height": 572 }\n\t\t},\n\t\t"8": {\n\t\t\t"leaf_3": { "x": -260.49, "y": -20.8, "scaleX": -1, "rotation": -39.25, "width": 680, "height": 572 }\n\t\t},\n\t\t"9": {\n\t\t\t"leaf_3": { "x": -308.83, "y": 113.49, "scaleX": -1.1, "scaleY": 1.1, "rotation": -40.56, "width": 680, "height": 572 }\n\t\t}\n\t}\n},\n"animations": {\n\t"leafsClose": {\n\t\t"slots": {\n\t\t\t"1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1333, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"4": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"5": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1333, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"6": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"7": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"8": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"9": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"10": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"11": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"12": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"13": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"14": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"15": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"16": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"17": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"18": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"19": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2333, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"20": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"21": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"22": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"23": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1333, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"24": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"25": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"26": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"30": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"31": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"35": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"36": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"37": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"38": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"39": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_3" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"42": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"43": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"44": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1666, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"45": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.0333, "name": "leaf_1" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"48": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"49": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.2333, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"50": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": null },\n\t\t\t\t\t{ "time": 0.1, "name": "leaf_2" }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"leafLight3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2333, "angle": 38.27 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -10.95 },\n\t\t\t\t\t{ "time": 0.5666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2333, "x": -116.75, "y": 152.98 },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 28.04 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -13.32 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": -265.71, "y": 169.09 },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 60.04 },\n\t\t\t\t\t{ "time": 0.3, "angle": -14.6 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -602.31, "y": 231.65 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -31.64 },\n\t\t\t\t\t{ "time": 0.4, "angle": 12.85 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 454.93, "y": 132.85 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": -31.64 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 12.58 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 495.19, "y": 136.88 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -75.39 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 12.21 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 632.08, "y": 132.85 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 46.66 },\n\t\t\t\t\t{ "time": 0.3, "angle": -19.03 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -676.36, "y": 157.01 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 39.32 },\n\t\t\t\t\t{ "time": 0.3333, "angle": -16.84 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": -422.72, "y": 60.39 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 28.73 },\n\t\t\t\t\t{ "time": 0.3, "angle": -14.86 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -454.93, "y": 72.46 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 38.55 },\n\t\t\t\t\t{ "time": 0.2, "angle": -10.66 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": -499.22, "y": 181.16 },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": -61.39 },\n\t\t\t\t\t{ "time": 0.3, "angle": 14.96 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 446.47, "y": 160.05 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -68.29 },\n\t\t\t\t\t{ "time": 0.4, "angle": 11.15 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 720.25, "y": 151.63 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": -24.49 },\n\t\t\t\t\t{ "time": 0.2666, "angle": 16.87 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 446.47, "y": 164.26 },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -41.75 },\n\t\t\t\t\t{ "time": 0.4, "angle": 11.49 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 318.72, "y": 168.96 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 52.67 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -16.66 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": -537.6, "y": 172.79 },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 36.91 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -20.44 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": -295.67, "y": 138.23 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 29.38 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -12.75 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": -640.13, "y": 297.92 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -58.88 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 12.49 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 446.88, "y": 237.53 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2333, "angle": -34.56 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 11.43 },\n\t\t\t\t\t{ "time": 0.5666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2333, "x": 310, "y": 152.98 },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -54.45 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 16.73 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 450.91, "y": 253.63 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"root": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 4.95 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"landscape_left": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": -567.07, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 38.55 },\n\t\t\t\t\t{ "time": 0.2, "angle": -10.66 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": -499.22, "y": 181.16 },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 28.73 },\n\t\t\t\t\t{ "time": 0.3, "angle": -14.86 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -454.93, "y": 72.46 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark10": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 46.66 },\n\t\t\t\t\t{ "time": 0.3, "angle": -19.03 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -676.36, "y": 157.01 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark11": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 46.66 },\n\t\t\t\t\t{ "time": 0.3, "angle": -19.03 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -676.36, "y": 157.01 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 60.04 },\n\t\t\t\t\t{ "time": 0.3, "angle": -14.6 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": -602.31, "y": 231.65 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 28.04 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -13.32 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": -265.71, "y": 169.09 },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight10": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2333, "angle": 38.27 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -10.95 },\n\t\t\t\t\t{ "time": 0.5666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2333, "x": -116.75, "y": 152.98 },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 52.67 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -16.66 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": -537.6, "y": 172.79 },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 36.91 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -20.44 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": -295.67, "y": 138.23 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 29.38 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -12.75 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": -640.13, "y": 297.92 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"landscape_right": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 502.63, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark16": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -75.39 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 12.21 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 632.08, "y": 132.85 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark17": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": -31.64 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 12.58 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 495.19, "y": 136.88 },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark18": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -31.64 },\n\t\t\t\t\t{ "time": 0.4, "angle": 12.85 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 454.93, "y": 132.85 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight14": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -68.29 },\n\t\t\t\t\t{ "time": 0.4, "angle": 11.15 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 720.25, "y": 151.63 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight15": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": -61.39 },\n\t\t\t\t\t{ "time": 0.3, "angle": 14.96 },\n\t\t\t\t\t{ "time": 0.4, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 446.47, "y": 160.05 },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight16": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": -41.75 },\n\t\t\t\t\t{ "time": 0.4, "angle": 11.49 },\n\t\t\t\t\t{ "time": 0.5, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 318.72, "y": 168.96 },\n\t\t\t\t\t{ "time": 0.4, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight17": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": -24.49 },\n\t\t\t\t\t{ "time": 0.2666, "angle": 16.87 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 446.47, "y": 164.26 },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium13": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -54.45 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 16.73 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 450.91, "y": 253.63 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium14": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2333, "angle": -34.56 },\n\t\t\t\t\t{ "time": 0.4666, "angle": 11.43 },\n\t\t\t\t\t{ "time": 0.5666, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2333, "x": 310, "y": 152.98 },\n\t\t\t\t\t{ "time": 0.4666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.5666, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium15": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": -58.88 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 12.49 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 0 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 446.88, "y": 237.53 },\n\t\t\t\t\t{ "time": 0.3333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.4333, "x": 0, "y": 0 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"leafsOpen": {\n\t\t"slots": {\n\t\t\t"1": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"2": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"3": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5333, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"4": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"5": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"6": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"7": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4666, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"8": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"9": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"10": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"11": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.3666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"12": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"13": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"14": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"15": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"16": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"17": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"18": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.5, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"19": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"20": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"21": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5333, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"22": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"23": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"24": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"25": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"26": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"30": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"31": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.3666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"35": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4666, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.5, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"36": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"37": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"38": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"39": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_3" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"42": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"43": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"44": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.4333, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"45": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.5333, "name": "leaf_1" },\n\t\t\t\t\t{ "time": 0.5666, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"48": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.5, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"49": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.3666, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4, "name": null }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"50": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0.4333, "name": "leaf_2" },\n\t\t\t\t\t{ "time": 0.4666, "name": null }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"leafLight3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1, "angle": -10.95 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 38.27 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3333, "x": -116.75, "y": 152.98 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -13.32 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 28.04 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -265.71, "y": 169.09 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -14.6 },\n\t\t\t\t\t{ "time": 0.5, "angle": 60.04 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -602.31, "y": 231.65 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 12.85 },\n\t\t\t\t\t{ "time": 0.4, "angle": -31.64 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 454.93, "y": 132.85 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": 12.58 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -31.64 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": 495.19, "y": 136.88 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2333, "angle": 12.21 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -75.39 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4666, "x": 632.08, "y": 132.85 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -19.03 },\n\t\t\t\t\t{ "time": 0.5, "angle": 46.66 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -676.36, "y": 157.01 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -16.84 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 39.32 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -422.72, "y": 60.39 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -14.86 },\n\t\t\t\t\t{ "time": 0.5, "angle": 28.73 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -454.93, "y": 72.46 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 0 },\n\t\t\t\t\t{ "time": 0.3, "angle": -10.66 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 38.55 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": -499.22, "y": 181.16 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": 14.96 },\n\t\t\t\t\t{ "time": 0.5, "angle": -61.39 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": 446.47, "y": 160.05 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 11.15 },\n\t\t\t\t\t{ "time": 0.4, "angle": -68.29 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 720.25, "y": 151.63 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 0 },\n\t\t\t\t\t{ "time": 0.3, "angle": 16.87 },\n\t\t\t\t\t{ "time": 0.5333, "angle": -24.49 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": 446.47, "y": 164.26 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 11.49 },\n\t\t\t\t\t{ "time": 0.4, "angle": -41.75 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 318.72, "y": 168.96 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -16.66 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 52.67 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -537.6, "y": 172.79 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium2": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": -20.44 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 36.91 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": -295.67, "y": 138.23 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium3": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": -12.75 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 29.38 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": -640.13, "y": 297.92 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium6": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": 12.49 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -58.88 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": 446.88, "y": 237.53 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium5": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1, "angle": 11.43 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -34.56 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": 310, "y": 152.98 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium4": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2333, "angle": 16.73 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -54.45 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4666, "x": 450.91, "y": 253.63 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"landscape_right": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 502.63, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"landscape_left": {\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": -567.07, "y": 0 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 0 },\n\t\t\t\t\t{ "time": 0.3, "angle": -10.66 },\n\t\t\t\t\t{ "time": 0.5333, "angle": 38.55 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": -499.22, "y": 181.16 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -14.86 },\n\t\t\t\t\t{ "time": 0.5, "angle": 28.73 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -454.93, "y": 72.46 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark10": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -16.84 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 39.32 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -422.72, "y": 60.39 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark11": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -19.03 },\n\t\t\t\t\t{ "time": 0.5, "angle": 46.66 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -676.36, "y": 157.01 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": -14.6 },\n\t\t\t\t\t{ "time": 0.5, "angle": 60.04 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": -602.31, "y": 231.65 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -13.32 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 28.04 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -265.71, "y": 169.09 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight10": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1, "angle": -10.95 },\n\t\t\t\t\t{ "time": 0.3333, "angle": 38.27 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3333, "x": -116.75, "y": 152.98 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium7": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": -16.66 },\n\t\t\t\t\t{ "time": 0.4333, "angle": 52.67 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": -537.6, "y": 172.79 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium8": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": -20.44 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 36.91 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": -295.67, "y": 138.23 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium9": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": -12.75 },\n\t\t\t\t\t{ "time": 0.3666, "angle": 29.38 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": -640.13, "y": 297.92 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark16": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2333, "angle": 12.21 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -75.39 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4666, "x": 632.08, "y": 132.85 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark17": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1333, "angle": 12.58 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -31.64 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": 495.19, "y": 136.88 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafDark18": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 12.85 },\n\t\t\t\t\t{ "time": 0.4, "angle": -31.64 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 454.93, "y": 132.85 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight14": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 11.15 },\n\t\t\t\t\t{ "time": 0.4, "angle": -68.29 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 720.25, "y": 151.63 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight15": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2666, "angle": 14.96 },\n\t\t\t\t\t{ "time": 0.5, "angle": -61.39 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5, "x": 446.47, "y": 160.05 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight16": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.0666, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1666, "angle": 11.49 },\n\t\t\t\t\t{ "time": 0.4, "angle": -41.75 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.0666, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1666, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4, "x": 318.72, "y": 168.96 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafLight17": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.2, "angle": 0 },\n\t\t\t\t\t{ "time": 0.3, "angle": 16.87 },\n\t\t\t\t\t{ "time": 0.5333, "angle": -24.49 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.3, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.5333, "x": 446.47, "y": 164.26 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium13": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1333, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2333, "angle": 16.73 },\n\t\t\t\t\t{ "time": 0.4666, "angle": -54.45 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1333, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2333, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4666, "x": 450.91, "y": 253.63 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium14": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": 0 },\n\t\t\t\t\t{ "time": 0.1, "angle": 11.43 },\n\t\t\t\t\t{ "time": 0.3666, "angle": -34.56 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.3666, "x": 310, "y": 152.98 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"leafMedium15": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0.1, "angle": 0 },\n\t\t\t\t\t{ "time": 0.2, "angle": 12.49 },\n\t\t\t\t\t{ "time": 0.4333, "angle": -58.88 }\n\t\t\t\t],\n\t\t\t\t"translate": [\n\t\t\t\t\t{ "time": 0.1, "x": 0, "y": 0, "curve": "stepped" },\n\t\t\t\t\t{ "time": 0.2, "x": 0, "y": 0 },\n\t\t\t\t\t{ "time": 0.4333, "x": 446.88, "y": 237.53 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t}\n}\n}\n',Dc);
window.doorAnimation=Mi;var Ni=new tc('{"skeleton":{"hash":"EiJZ7xqS+0zCxyTeBmZ4Ypsn2Uc","spine":"3.2.01","width":969,"height":952.41,"images":"./images/"},"bones":[{"name":"root"},{"name":"artefact","parent":"root"},{"name":"beams1","parent":"root"},{"name":"beams2","parent":"root"},{"name":"beams3","parent":"root"},{"name":"beams4","parent":"root"},{"name":"beams5","parent":"root"},{"name":"big","parent":"root"},{"name":"congratulations","parent":"root","y":405.91},{"name":"glow","parent":"root"},{"name":"lvlUp","parent":"root"},{"name":"txtFortune","parent":"root"},{"name":"txtFree","parent":"root"},{"name":"txtOf","parent":"root"},{"name":"txtSpins","parent":"root"},{"name":"txtWheel","parent":"root"},{"name":"win","parent":"root"}],"slots":[{"name":"beams1","bone":"beams1","attachment":"beams1"},{"name":"beams2","bone":"beams2","attachment":"beams2"},{"name":"beams3","bone":"beams3","attachment":"beams3"},{"name":"beams4","bone":"beams4","attachment":"beams4"},{"name":"beams5","bone":"beams5","attachment":"beams5"},{"name":"congratulations","bone":"congratulations","attachment":"congratulations"},{"name":"txtFree","bone":"txtFree","attachment":"txtFree"},{"name":"txtSpins","bone":"txtSpins","attachment":"txtSpins"},{"name":"txtWheel","bone":"txtWheel","attachment":"txtWheel"},{"name":"txtOf","bone":"txtOf","attachment":"txtOf"},{"name":"txtFortune","bone":"txtFortune","attachment":"txtFortune"},{"name":"artefact","bone":"artefact","attachment":"artefact5"},{"name":"glow","bone":"glow","attachment":"glow"},{"name":"big","bone":"big","attachment":"big"},{"name":"win","bone":"win","attachment":"txtWin"},{"name":"lvlUp","bone":"lvlUp","attachment":"lvlUp"}],"skins":{"default":{"artefact":{"artefact1":{"width":506,"height":443},"artefact2":{"width":555,"height":343},"artefact3":{"width":493,"height":317},"artefact4":{"width":388,"height":397},"artefact5":{"width":276,"height":388}},"beams1":{"beams1":{"x":10,"y":10,"width":895,"height":899}},"beams2":{"beams2":{"x":10.5,"y":15,"width":900,"height":909}},"beams3":{"beams3":{"x":18.5,"y":16,"width":914,"height":923}},"beams4":{"beams4":{"x":14.5,"y":13.5,"width":904,"height":924}},"beams5":{"beams5":{"x":9,"y":7,"width":805,"height":893}},"big":{"big":{"x":17.85,"y":103.52,"width":566,"height":294}},"congratulations":{"congratulations":{"width":936,"height":196}},"glow":{"glow":{"x":17.74,"y":5.78,"width":678,"height":603}},"lvlUp":{"lvlUp":{"width":969,"height":195}},"txtFortune":{"txtFortune":{"y":-145.41,"width":881,"height":182}},"txtFree":{"txtFree":{"y":111.39,"width":659,"height":240}},"txtOf":{"txtOf":{"width":243,"height":152}},"txtSpins":{"txtSpins":{"x":3.96,"y":-102.24,"width":742,"height":236}},"txtWheel":{"txtWheel":{"y":141.97,"width":645,"height":180}},"win":{"txtWin":{"x":22.5,"y":-120.92,"width":516,"height":236}}}},"animations":{"artefactWin1":{"slots":{"artefact":{"attachment":[{"time":0,"name":"artefact1"}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams1"}]},"beams2":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams2"}]},"beams3":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams3"}]},"beams4":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams4"}]},"beams5":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams2":{"rotate":[{"time":0.1333,"angle":0},{"time":0.7,"angle":240},{"time":1.2666,"angle":120},{"time":1.8,"angle":0},{"time":2.0666,"angle":-56.47}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams3":{"rotate":[{"time":0.1333,"angle":0},{"time":0.4666,"angle":240},{"time":0.8,"angle":120},{"time":1.1333,"angle":0},{"time":1.4666,"angle":240},{"time":1.8,"angle":120},{"time":2.0666,"angle":23.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams4":{"rotate":[{"time":0.1333,"angle":0},{"time":0.9,"angle":240},{"time":1.6666,"angle":120},{"time":2.0666,"angle":59.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams5":{"rotate":[{"time":0.1333,"angle":0},{"time":1.1333,"angle":240},{"time":2.0666,"angle":120}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"artefact":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.8333,"x":1,"y":1},{"time":1.9666,"x":1.2,"y":1.2},{"time":2.0666,"x":0,"y":0}]}}},"artefactWin2":{"slots":{"artefact":{"attachment":[{"time":0,"name":"artefact2"}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams1"}]},"beams2":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams2"}]},"beams3":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams3"}]},"beams4":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams4"}]},"beams5":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams2":{"rotate":[{"time":0.1333,"angle":0},{"time":0.7,"angle":240},{"time":1.2666,"angle":120},{"time":1.8,"angle":0},{"time":2.0666,"angle":-56.47}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams3":{"rotate":[{"time":0.1333,"angle":0},{"time":0.4666,"angle":240},{"time":0.8,"angle":120},{"time":1.1333,"angle":0},{"time":1.4666,"angle":240},{"time":1.8,"angle":120},{"time":2.0666,"angle":23.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams4":{"rotate":[{"time":0.1333,"angle":0},{"time":0.9,"angle":240},{"time":1.6666,"angle":120},{"time":2.0666,"angle":59.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams5":{"rotate":[{"time":0.1333,"angle":0},{"time":1.1333,"angle":240},{"time":2.0666,"angle":120}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"artefact":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.8333,"x":1,"y":1},{"time":1.9666,"x":1.2,"y":1.2},{"time":2.0666,"x":0,"y":0}]}}},"artefactWin3":{"slots":{"artefact":{"attachment":[{"time":0,"name":"artefact3"}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams1"}]},"beams2":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams2"}]},"beams3":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams3"}]},"beams4":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams4"}]},"beams5":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams2":{"rotate":[{"time":0.1333,"angle":0},{"time":0.7,"angle":240},{"time":1.2666,"angle":120},{"time":1.8,"angle":0},{"time":2.0666,"angle":-56.47}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams3":{"rotate":[{"time":0.1333,"angle":0},{"time":0.4666,"angle":240},{"time":0.8,"angle":120},{"time":1.1333,"angle":0},{"time":1.4666,"angle":240},{"time":1.8,"angle":120},{"time":2.0666,"angle":23.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams4":{"rotate":[{"time":0.1333,"angle":0},{"time":0.9,"angle":240},{"time":1.6666,"angle":120},{"time":2.0666,"angle":59.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams5":{"rotate":[{"time":0.1333,"angle":0},{"time":1.1333,"angle":240},{"time":2.0666,"angle":120}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"artefact":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.8333,"x":1,"y":1},{"time":1.9666,"x":1.2,"y":1.2},{"time":2.0666,"x":0,"y":0}]}}},"artefactWin4":{"slots":{"artefact":{"attachment":[{"time":0,"name":"artefact4"}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams1"}]},"beams2":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams2"}]},"beams3":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams3"}]},"beams4":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams4"}]},"beams5":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams2":{"rotate":[{"time":0.1333,"angle":0},{"time":0.7,"angle":240},{"time":1.2666,"angle":120},{"time":1.8,"angle":0},{"time":2.0666,"angle":-56.47}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams3":{"rotate":[{"time":0.1333,"angle":0},{"time":0.4666,"angle":240},{"time":0.8,"angle":120},{"time":1.1333,"angle":0},{"time":1.4666,"angle":240},{"time":1.8,"angle":120},{"time":2.0666,"angle":23.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams4":{"rotate":[{"time":0.1333,"angle":0},{"time":0.9,"angle":240},{"time":1.6666,"angle":120},{"time":2.0666,"angle":59.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams5":{"rotate":[{"time":0.1333,"angle":0},{"time":1.1333,"angle":240},{"time":2.0666,"angle":120}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"artefact":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.8333,"x":1,"y":1},{"time":1.9666,"x":1.2,"y":1.2},{"time":2.0666,"x":0,"y":0}]}}},"artefactWin5":{"slots":{"artefact":{"attachment":[{"time":0,"name":"artefact5"}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams1"}]},"beams2":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams2"}]},"beams3":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams3"}]},"beams4":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams4"}]},"beams5":{"color":[{"time":0.1333,"color":"ffffffb5"}],"attachment":[{"time":0,"name":null},{"time":0.1333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams2":{"rotate":[{"time":0.1333,"angle":0},{"time":0.7,"angle":240},{"time":1.2666,"angle":120},{"time":1.8,"angle":0},{"time":2.0666,"angle":-56.47}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams3":{"rotate":[{"time":0.1333,"angle":0},{"time":0.4666,"angle":240},{"time":0.8,"angle":120},{"time":1.1333,"angle":0},{"time":1.4666,"angle":240},{"time":1.8,"angle":120},{"time":2.0666,"angle":23.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams4":{"rotate":[{"time":0.1333,"angle":0},{"time":0.9,"angle":240},{"time":1.6666,"angle":120},{"time":2.0666,"angle":59.99}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"beams5":{"rotate":[{"time":0.1333,"angle":0},{"time":1.1333,"angle":240},{"time":2.0666,"angle":120}],"scale":[{"time":0.1333,"x":0,"y":0},{"time":0.4333,"x":1.6,"y":1.6},{"time":0.5666,"x":1.3,"y":1.3,"curve":"stepped"},{"time":1.8333,"x":1.3,"y":1.3},{"time":1.9666,"x":1.5,"y":1.5},{"time":2.0666,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"artefact":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.2,"y":1.2},{"time":0.3,"x":0.9,"y":0.9},{"time":0.4333,"x":1,"y":1,"curve":"stepped"},{"time":1.8333,"x":1,"y":1},{"time":1.9666,"x":1.2,"y":1.2},{"time":2.0666,"x":0,"y":0}]}}},"beams":{"slots":{"artefact":{"attachment":[{"time":0,"name":null}]},"beams1":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams1"}]},"beams2":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams2"}]},"beams3":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams3"}]},"beams4":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams4"}]},"beams5":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams2":{"rotate":[{"time":0.5333,"angle":0},{"time":1.1,"angle":240},{"time":1.6666,"angle":120},{"time":2.2,"angle":0},{"time":2.7666,"angle":240},{"time":3.3333,"angle":120},{"time":3.8666,"angle":0},{"time":4.3666,"angle":240},{"time":4.9,"angle":120}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams3":{"rotate":[{"time":0.5333,"angle":0},{"time":0.8666,"angle":240},{"time":1.2,"angle":120},{"time":1.5333,"angle":0},{"time":1.8666,"angle":240},{"time":2.2,"angle":120},{"time":2.5333,"angle":0},{"time":2.8666,"angle":240},{"time":3.2,"angle":120},{"time":3.5333,"angle":0},{"time":3.8666,"angle":240},{"time":4.2,"angle":120},{"time":4.5333,"angle":0},{"time":4.9,"angle":240}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams4":{"rotate":[{"time":0.5333,"angle":0},{"time":1.3,"angle":240},{"time":2.0666,"angle":120},{"time":2.8666,"angle":0},{"time":3.6333,"angle":240},{"time":4.4,"angle":120},{"time":4.9,"angle":44.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams5":{"rotate":[{"time":0.5333,"angle":0},{"time":1.5333,"angle":240},{"time":2.5333,"angle":120},{"time":3.5333,"angle":0},{"time":4.5333,"angle":240},{"time":4.9,"angle":-164}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"glow":{"scale":[{"time":0,"x":0,"y":0}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"win":{"scale":[{"time":0,"x":0,"y":1}]},"root":{"scale":[{"time":4.6666,"x":1,"y":1},{"time":4.8,"x":1.3,"y":1.3},{"time":4.9,"x":0,"y":0}]}}},"bigWin":{"slots":{"artefact":{"attachment":[{"time":0,"name":null}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams1"}]},"beams2":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams2"}]},"beams3":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams3"}]},"beams4":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams4"}]},"beams5":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams5"}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"color":[{"time":0.7666,"color":"ffffffff"},{"time":1.7666,"color":"ffffff81"},{"time":2.7666,"color":"ffffffff"},{"time":3.7666,"color":"ffffff81"},{"time":4.7666,"color":"ffffffff"},{"time":4.9,"color":"ffffffee"}],"attachment":[{"time":0,"name":null},{"time":0.7666,"name":"glow"}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null},{"time":0.3333,"name":"txtWin"}]}},"bones":{"beams1":{"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams2":{"rotate":[{"time":0.5333,"angle":0},{"time":1.1,"angle":240},{"time":1.6666,"angle":120},{"time":2.2,"angle":0},{"time":2.7666,"angle":240},{"time":3.3333,"angle":120},{"time":3.8666,"angle":0},{"time":4.4333,"angle":240},{"time":4.9,"angle":120}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams3":{"rotate":[{"time":0.5333,"angle":0},{"time":0.8666,"angle":240},{"time":1.2,"angle":120},{"time":1.5333,"angle":0},{"time":1.8666,"angle":240},{"time":2.2,"angle":120},{"time":2.5333,"angle":0},{"time":2.8666,"angle":240},{"time":3.2,"angle":120},{"time":3.5333,"angle":0},{"time":3.8666,"angle":240},{"time":4.2,"angle":120},{"time":4.5333,"angle":0},{"time":4.9,"angle":240}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams4":{"rotate":[{"time":0.5333,"angle":0},{"time":1.3,"angle":240},{"time":2.0666,"angle":120},{"time":2.8666,"angle":0},{"time":3.6333,"angle":240},{"time":4.4,"angle":120},{"time":4.9,"angle":44.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams5":{"rotate":[{"time":0.5333,"angle":0},{"time":1.5333,"angle":240},{"time":2.5333,"angle":120},{"time":3.5333,"angle":0},{"time":4.5333,"angle":240},{"time":4.9,"angle":-164}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"glow":{"scale":[{"time":0,"x":0,"y":0},{"time":0.7666,"x":1,"y":1}]},"win":{"scale":[{"time":0,"x":0,"y":1},{"time":0.3333,"x":0,"y":0},{"time":0.5333,"x":1.35,"y":1.35},{"time":0.6666,"x":0.8,"y":0.8},{"time":0.7666,"x":1,"y":1}]},"big":{"scale":[{"time":0,"x":0,"y":0},{"time":0.2,"x":1.35,"y":1.35},{"time":0.3333,"x":0.8,"y":0.8},{"time":0.4333,"x":1.15,"y":1.15},{"time":0.5,"x":1,"y":1}]},"root":{"scale":[{"time":4.6666,"x":1,"y":1},{"time":4.8,"x":1.3,"y":1.3},{"time":4.9,"x":0,"y":0}]}}},"freeSpins":{"slots":{"artefact":{"attachment":[{"time":0,"name":null}]},"beams1":{"color":[{"time":0.2,"color":"ffffff00"},{"time":0.5666,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5666,"name":"beams1"}]},"beams2":{"color":[{"time":0.5666,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5666,"name":"beams2"}]},"beams3":{"color":[{"time":0.5666,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5666,"name":"beams3"}]},"beams4":{"color":[{"time":0.5666,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5666,"name":"beams4"}]},"beams5":{"color":[{"time":0.5666,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5666,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffff"}],"attachment":[{"time":0,"name":"congratulations"}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"color":[{"time":0,"color":"ffffff00","curve":"stepped"},{"time":0.2,"color":"ffffff00"},{"time":0.3333,"color":"ffffffff"}],"attachment":[{"time":0.2,"name":"txtFree"}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"color":[{"time":0.4333,"color":"ffffff00"},{"time":0.5666,"color":"ffffffff"}],"attachment":[{"time":0,"name":null},{"time":0.4333,"name":"txtSpins"}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.5666,"x":0,"y":0},{"time":0.8666,"x":1.6,"y":1.6},{"time":1,"x":1.3,"y":1.3}]},"beams2":{"rotate":[{"time":0.5666,"angle":0},{"time":1.1333,"angle":240},{"time":1.7,"angle":120},{"time":2.2333,"angle":0},{"time":2.5,"angle":-56.47}],"scale":[{"time":0.5666,"x":0,"y":0},{"time":0.8666,"x":1.6,"y":1.6},{"time":1,"x":1.3,"y":1.3}]},"beams3":{"rotate":[{"time":0.5666,"angle":0},{"time":0.9,"angle":240},{"time":1.2333,"angle":120},{"time":1.5666,"angle":0},{"time":1.9,"angle":240},{"time":2.2333,"angle":120},{"time":2.5,"angle":23.99}],"scale":[{"time":0.5666,"x":0,"y":0},{"time":0.8666,"x":1.6,"y":1.6},{"time":1,"x":1.3,"y":1.3}]},"beams4":{"rotate":[{"time":0.5666,"angle":0},{"time":1.3333,"angle":240},{"time":2.1,"angle":120},{"time":2.5,"angle":59.99}],"scale":[{"time":0.5666,"x":0,"y":0},{"time":0.8666,"x":1.6,"y":1.6},{"time":1,"x":1.3,"y":1.3}]},"beams5":{"rotate":[{"time":0.5666,"angle":0},{"time":1.5666,"angle":240},{"time":2.5,"angle":120}],"scale":[{"time":0.5666,"x":0,"y":0},{"time":0.8666,"x":1.6,"y":1.6},{"time":1,"x":1.3,"y":1.3}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"txtFree":{"scale":[{"time":0.2,"x":3,"y":3},{"time":0.3666,"x":0.7,"y":0.7},{"time":0.5,"x":1.35,"y":1.35},{"time":0.5666,"x":1,"y":1}]},"txtSpins":{"scale":[{"time":0.4333,"x":3,"y":3},{"time":0.6,"x":0.7,"y":0.7},{"time":0.7333,"x":1.35,"y":1.35},{"time":0.8,"x":1,"y":1}]},"root":{"scale":[{"time":2.0666,"x":1,"y":1},{"time":2.2,"x":1.3,"y":1.3},{"time":2.3,"x":0,"y":0}]},"congratulations":{"scale":[{"time":0,"x":2,"y":2},{"time":0.1666,"x":0.8,"y":0.8},{"time":0.3,"x":1.35,"y":1.35},{"time":0.3666,"x":1,"y":1}]}}},"lvlUp":{"slots":{"artefact":{"attachment":[{"time":0,"name":null}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams1"}]},"beams2":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams2"}]},"beams3":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams3"}]},"beams4":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams4"}]},"beams5":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffff"}]},"txtFortune":{"attachment":[{"time":0,"name":null}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"attachment":[{"time":0,"name":null}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"attachment":[{"time":0,"name":null}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams2":{"rotate":[{"time":0.5333,"angle":0},{"time":1.1,"angle":240},{"time":1.6666,"angle":120},{"time":2.2,"angle":0},{"time":2.4666,"angle":-56.47}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams3":{"rotate":[{"time":0.5333,"angle":0},{"time":0.8666,"angle":240},{"time":1.2,"angle":120},{"time":1.5333,"angle":0},{"time":1.8666,"angle":240},{"time":2.2,"angle":120},{"time":2.4666,"angle":23.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams4":{"rotate":[{"time":0.5333,"angle":0},{"time":1.3,"angle":240},{"time":2.0666,"angle":120},{"time":2.4666,"angle":59.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams5":{"rotate":[{"time":0.5333,"angle":0},{"time":1.5333,"angle":240},{"time":2.4666,"angle":120}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"root":{"scale":[{"time":2.2333,"x":1,"y":1},{"time":2.3666,"x":1.3,"y":1.3},{"time":2.4666,"x":0,"y":0}]},"lvlUp":{"scale":[{"time":0,"x":3,"y":3},{"time":0.1666,"x":0.7,"y":0.7},{"time":0.3,"x":1.35,"y":1.35},{"time":0.3666,"x":1,"y":1}]}}},"wheelOfFortune":{"slots":{"artefact":{"attachment":[{"time":0,"name":null}]},"beams1":{"color":[{"time":0,"color":"ffffff00"},{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams1"}]},"beams2":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams2"}]},"beams3":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams3"}]},"beams4":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams4"}]},"beams5":{"color":[{"time":0.5333,"color":"ffffffc7"}],"attachment":[{"time":0,"name":null},{"time":0.5333,"name":"beams5"}]},"big":{"attachment":[{"time":0,"name":null}]},"congratulations":{"attachment":[{"time":0,"name":null}]},"glow":{"attachment":[{"time":0,"name":null}]},"lvlUp":{"attachment":[{"time":0,"name":null}]},"txtFortune":{"color":[{"time":0.4666,"color":"ffffff00"},{"time":0.6,"color":"ffffffff"}],"attachment":[{"time":0,"name":null},{"time":0.4666,"name":"txtFortune"}]},"txtFree":{"attachment":[{"time":0,"name":null}]},"txtOf":{"color":[{"time":0.2333,"color":"ffffff00"},{"time":0.3666,"color":"ffffffff"}],"attachment":[{"time":0,"name":null},{"time":0.2333,"name":"txtOf"}]},"txtSpins":{"attachment":[{"time":0,"name":null}]},"txtWheel":{"color":[{"time":0,"color":"ffffff00"},{"time":0.1333,"color":"ffffffff"}]},"win":{"attachment":[{"time":0,"name":null}]}},"bones":{"beams1":{"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams2":{"rotate":[{"time":0.5333,"angle":0},{"time":1.1,"angle":240},{"time":1.6666,"angle":120},{"time":2.2,"angle":0},{"time":2.4666,"angle":-56.47}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams3":{"rotate":[{"time":0.5333,"angle":0},{"time":0.8666,"angle":240},{"time":1.2,"angle":120},{"time":1.5333,"angle":0},{"time":1.8666,"angle":240},{"time":2.2,"angle":120},{"time":2.4666,"angle":23.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams4":{"rotate":[{"time":0.5333,"angle":0},{"time":1.3,"angle":240},{"time":2.0666,"angle":120},{"time":2.4666,"angle":59.99}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"beams5":{"rotate":[{"time":0.5333,"angle":0},{"time":1.5333,"angle":240},{"time":2.4666,"angle":120}],"scale":[{"time":0.5333,"x":0,"y":0},{"time":0.8333,"x":1.6,"y":1.6},{"time":0.9666,"x":1.3,"y":1.3}]},"big":{"scale":[{"time":0,"x":0,"y":0}]},"txtFortune":{"scale":[{"time":0.4666,"x":3,"y":3},{"time":0.6333,"x":0.7,"y":0.7},{"time":0.7666,"x":1.35,"y":1.35},{"time":0.8333,"x":1,"y":1}]},"txtOf":{"scale":[{"time":0.2333,"x":3,"y":3},{"time":0.4,"x":0.7,"y":0.7},{"time":0.4666,"x":1.024,"y":1.024},{"time":0.5333,"x":1.35,"y":1.35},{"time":0.6,"x":1,"y":1}]},"txtWheel":{"scale":[{"time":0,"x":3,"y":3},{"time":0.1666,"x":0.7,"y":0.7},{"time":0.3,"x":1.35,"y":1.35},{"time":0.3666,"x":1,"y":1}]},"root":{"scale":[{"time":2.2333,"x":1,"y":1},{"time":2.3666,"x":1.3,"y":1.3},{"time":2.4666,"x":0,"y":0}]}}}}}\n');
window.overlaysAnimations=Ni;
var Oi=new tc('{\n"skeleton": {\n\t"hash": "kZPK92fIUsGGmxwsP+iKWbs1Lx4",\n\t"spine": "3.2.01",\n\t"width": 244,\n\t"height": 292,\n\t"images": "/Users/melissadeleeuw/Desktop/snake/images"\n},\n"bones": [\n\t{ "name": "root" },\n\t{ "name": "symbol4Body", "parent": "root", "length": 206.9, "rotation": 89.99, "x": -12.01, "y": -99.7 },\n\t{ "name": "symbol4Head", "parent": "symbol4Body", "rotation": -89.99, "x": 203.88, "y": -3.62 }\n],\n"slots": [\n\t{ "name": "symbol4Bg", "bone": "root", "attachment": "symbol4Bg" },\n\t{ "name": "symbol4Body", "bone": "symbol4Body", "attachment": "symbol4Body" },\n\t{ "name": "symbol4Head", "bone": "symbol4Head", "attachment": "symbol4Head" }\n],\n"skins": {\n\t"default": {\n\t\t"symbol4Bg": {\n\t\t\t"symbol4Bg": { "width": 244, "height": 292 },\n\t\t\t"symbol4BgBlue": { "width": 244, "height": 292 }\n\t\t},\n\t\t"symbol4Body": {\n\t\t\t"symbol4Body": { "x": 89.7, "y": -3.51, "rotation": -89.99, "width": 215, "height": 256 }\n\t\t},\n\t\t"symbol4Head": {\n\t\t\t"symbol4Head": { "x": -20.61, "y": -3.68, "width": 52, "height": 33 }\n\t\t}\n\t}\n},\n"animations": {\n\t"symbol4": {\n\t\t"slots": {\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Bg" }\n\t\t\t\t]\n\t\t\t}\n\t\t},\n\t\t"bones": {\n\t\t\t"symbol4Body": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": -89.99 }\n\t\t\t\t],\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.5, "x": 0.915, "y": 1 },\n\t\t\t\t\t{ "time": 1, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": -11.46 },\n\t\t\t\t\t{ "time": 0.5, "angle": 6.52 },\n\t\t\t\t\t{ "time": 1, "angle": -11.46 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4Blue": {\n\t\t"bones": {\n\t\t\t"symbol4Body": {\n\t\t\t\t"scale": [\n\t\t\t\t\t{ "time": 0, "x": 1, "y": 1 },\n\t\t\t\t\t{ "time": 0.5, "x": 0.915, "y": 1 },\n\t\t\t\t\t{ "time": 1, "x": 1, "y": 1 }\n\t\t\t\t]\n\t\t\t},\n\t\t\t"symbol4Head": {\n\t\t\t\t"rotate": [\n\t\t\t\t\t{ "time": 0, "angle": -11.46 },\n\t\t\t\t\t{ "time": 0.5, "angle": 6.52 },\n\t\t\t\t\t{ "time": 1, "angle": -11.46 }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4BlueStill": {\n\t\t"slots": {\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4BgBlue" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t},\n\t"symbol4Still": {\n\t\t"slots": {\n\t\t\t"symbol4Bg": {\n\t\t\t\t"attachment": [\n\t\t\t\t\t{ "time": 0, "name": "symbol4Bg" }\n\t\t\t\t]\n\t\t\t}\n\t\t}\n\t}\n}\n}\n',L);
window.symbol4Animation=Oi;window.unityTest=new xc('{ \n   "name" : "TestScene", \n   "width" : "2160", \n   "height" : "1920", \n   "children" : [ \n      { \n         "name" : "grp_something", \n         "width" : "810", \n         "height" : "540", \n         "type" : "Group", \n         "x" : "0", \n         "y" : "0", \n         "relativePosition" : "true", \n         "positionPercentX" : "0.5", \n         "positionPercentY" : "0.5", \n         "anchorX" : "0.5", \n         "anchorY" : "0.5", \n         "scaleX" : "1", \n         "scaleY" : "1", \n         "rotation" : "0", \n         "visible" : "true", \n         "showImageInEditor" : "false", \n         "children" : [ \n            { \n               "name" : "imgSlice_GameObject", \n               "width" : "950", \n               "height" : "691", \n               "type" : "ImageNineSlice", \n               "x" : "13", \n               "y" : "17", \n               "relativePosition" : "true", \n               "positionPercentX" : "0.5", \n               "positionPercentY" : "0.5", \n               "anchorX" : "0.5", \n               "anchorY" : "0.5", \n               "scaleX" : "1", \n               "scaleY" : "1", \n               "rotation" : "0", \n               "visible" : "true", \n               "image" : "spinAuto.png", \n               "children" : [ \n               ]\n            }, \n            { \n               "name" : "img_GameObject", \n               "width" : "923", \n               "height" : "243", \n               "type" : "Image", \n               "x" : "0", \n               "y" : "-535", \n               "relativePosition" : "true", \n               "positionPercentX" : "0.5", \n               "positionPercentY" : "0.5", \n               "anchorX" : "0.5", \n               "anchorY" : "0.5", \n               "scaleX" : "1", \n               "scaleY" : "1", \n               "rotation" : "0", \n               "visible" : "true", \n               "image" : "spinCounter.png", \n               "children" : [ \n                  { \n                     "name" : "lbl_GameObject", \n                     "width" : "810", \n                     "height" : "540", \n                     "type" : "Label", \n                     "x" : "0", \n                     "y" : "0", \n                     "relativePosition" : "true", \n                     "positionPercentX" : "0.5", \n                     "positionPercentY" : "0.5", \n                     "anchorX" : "0.5", \n                     "anchorY" : "0.5", \n                     "scaleX" : "1", \n                     "scaleY" : "1", \n                     "rotation" : "0", \n                     "visible" : "true", \n                     "fontName" : "Arial", \n                     "fontSize" : "42", \n                     "text" : "", \n                     "hAlignment" : "center", \n                     "color" : "#FFFFFF", \n                     "unityUseLocalizationFile" : "true", \n                     "children" : [ \n                     ]\n                  }\n               ]\n            }, \n            { \n               "name" : "img_GameObject_2", \n               "width" : "923", \n               "height" : "243", \n               "type" : "Image", \n               "x" : "0", \n               "y" : "563", \n               "relativePosition" : "true", \n               "positionPercentX" : "0.5", \n               "positionPercentY" : "0.5", \n               "anchorX" : "0.5", \n               "anchorY" : "0.5", \n               "scaleX" : "1", \n               "scaleY" : "1", \n               "rotation" : "0", \n               "visible" : "true", \n               "image" : "spinCounter.png", \n               "children" : [ \n                  { \n                     "name" : "btn_GameObject", \n                     "width" : "314", \n                     "height" : "121", \n                     "type" : "Button", \n                     "x" : "0", \n                     "y" : "0", \n                     "relativePosition" : "true", \n                     "positionPercentX" : "0.5", \n                     "positionPercentY" : "0.5", \n                     "anchorX" : "0.5", \n                     "anchorY" : "0.5", \n                     "scaleX" : "1", \n                     "scaleY" : "1", \n                     "rotation" : "0", \n                     "visible" : "true", \n                     "image" : "btnSmallGreen.png", \n                     "highlightedState" : "btnSmallGreen.png", \n                     "pressedState" : "", \n                     "disabledState" : "", \n                     "children" : [ \n                     ]\n                  }\n               ]\n            }, \n            { \n               "name" : "ph_GameObject", \n               "width" : "810", \n               "height" : "540", \n               "type" : "PlaceHolder", \n               "x" : "0", \n               "y" : "0", \n               "relativePosition" : "true", \n               "positionPercentX" : "0.5", \n               "positionPercentY" : "0.5", \n               "anchorX" : "0.5", \n               "anchorY" : "0.5", \n               "scaleX" : "1", \n               "scaleY" : "1", \n               "rotation" : "0", \n               "visible" : "true", \n               "image" : "", \n               "children" : [ \n               ]\n            }, \n            { \n               "name" : "anim_GameObject", \n               "width" : "810", \n               "height" : "540", \n               "type" : "Animation", \n               "x" : "0", \n               "y" : "0", \n               "relativePosition" : "true", \n               "positionPercentX" : "0.5", \n               "positionPercentY" : "0.5", \n               "anchorX" : "0.5", \n               "anchorY" : "0.5", \n               "scaleX" : "1", \n               "scaleY" : "1", \n               "rotation" : "0", \n               "visible" : "true", \n               "image" : "", \n               "fileName" : "winline.json", \n               "animationQueue" : [ \n                  "animation"\n               ], \n               "autoPlay" : "true", \n               "loop" : "true", \n               "timeScale" : "1", \n               "delay" : "0", \n               "children" : [ \n               ]\n            }\n         ]\n      }\n   ]\n}\n');
var Pi=new sb("FrameworkAudio","audio/FrameworkAudio.mp3","audio/FrameworkAudio.ogg","frameworkAudio");window.FrameworkAudio=Pi;var Qi=new sb("audioSprite","audio/audioSprite.mp3","audio/audioSprite.ogg","audio");window.audioSprite=Qi;var Ri=new sb("firstLoad","audio/firstLoad.mp3","audio/firstLoad.ogg","audio");window.firstLoad=Ri;var Si=new mb("a_tgf_silence",Pi,0,471,0,10,["sfx"]);window.a_tgf_silence=Si;var Ti=new mb("a_levelend_star_01",Qi,0,1161,1,10,["game"]);window.a_levelend_star_01=Ti;
var Ui=new mb("a_levelend_star_02",Qi,3E3,1070,1,10,["game"]);window.a_levelend_star_02=Ui;var Vi=new mb("a_levelend_star_03",Qi,6E3,1039,1,10,["game"]);window.a_levelend_star_03=Vi;var Wi=new mb("sfx_anticipationfail",Qi,9E3,1850,1,10,["game"]);window.sfx_anticipationfail=Wi;var Xi=new mb("sfx_artefactreward",Qi,12E3,4403,1,10,["game"]);window.sfx_artefactreward=Xi;var Yi=new mb("sfx_bigwin",Qi,18E3,7106,1,10,["game"]);window.sfx_bigwin=Yi;var Zi=new mb("sfx_coincount",Qi,27E3,178,1,10,["game"]);
window.sfx_coincount=Zi;var $i=new mb("sfx_coinshower",Qi,29E3,2492,1,10,["game"]);window.sfx_coinshower=$i;var aj=new mb("sfx_collectiblecollect",Qi,33E3,2891,1,10,["game"]);window.sfx_collectiblecollect=aj;var bj=new mb("sfx_collectiblecomplete",Qi,37E3,3031,1,10,["game"]);window.sfx_collectiblecomplete=bj;var cj=new mb("sfx_creditwin",Qi,42E3,5619,1,10,["game"]);window.sfx_creditwin=cj;var dj=new mb("sfx_flyingcoin",Qi,49E3,2271,1,10,["game"]);window.sfx_flyingcoin=dj;
var ej=new mb("sfx_imagefloater",Qi,53E3,4202,1,10,["game"]);window.sfx_imagefloater=ej;var fj=new mb("sfx_leavestransition",Qi,59E3,2972,1,10,["game"]);window.sfx_leavestransition=fj;var gj=new mb("sfx_objectivecomplete",Qi,63E3,3411,1,10,["game"]);window.sfx_objectivecomplete=gj;var hj=new mb("sfx_payline",Qi,68E3,1120,1,10,["game"]);window.sfx_payline=hj;var ij=new mb("sfx_popupclose",Qi,71E3,439,1,10,["game"]);window.sfx_popupclose=ij;var jj=new mb("sfx_popupopen",Qi,73E3,558,1,10,["game"]);
window.sfx_popupopen=jj;var kj=new mb("sfx_reelanticipation",Qi,75E3,5899,1,10,["game"]);window.sfx_reelanticipation=kj;var lj=new mb("sfx_reelspin",Qi,82E3,2061,1,10,["game"]);window.sfx_reelspin=lj;var mj=new mb("sfx_reelstop",Qi,86E3,433,1,10,["game"]);window.sfx_reelstop=mj;var nj=new mb("sfx_scatterbreak",Qi,88E3,1797,1,10,["game"]);window.sfx_scatterbreak=nj;var oj=new mb("sfx_scattercollect1",Qi,91E3,2839,1,10,["game"]);window.sfx_scattercollect1=oj;
var pj=new mb("sfx_scattercollect2",Qi,95E3,5014,1,10,["game"]);window.sfx_scattercollect2=pj;var qj=new mb("sfx_scattercollect3",Qi,102E3,3011,1,10,["game"]);window.sfx_scattercollect3=qj;var rj=new mb("sfx_spinbutton",Qi,107E3,2530,1,10,["game"]);window.sfx_spinbutton=rj;var sj=new mb("sfx_spinbuttonfail",Qi,111E3,1341,1,10,["game"]);window.sfx_spinbuttonfail=sj;var tj=new mb("sfx_wheelspin",Qi,114E3,4388,1,10,["sfx"]);window.sfx_wheelspin=tj;
var uj=new mb("sfx_wheelspinbutton",Qi,12E4,2879,1,10,["game"]);window.sfx_wheelspinbutton=uj;var vj=new mb("sfx_wheelstop",Qi,124E3,342,1,10,["game"]);window.sfx_wheelstop=vj;var wj=new mb("sfx_winpop",Qi,126E3,1054,1,10,["game"]);window.sfx_winpop=wj;var xj=new mb("bgm_freespins",Ri,0,30744,1,1,["music"]);window.bgm_freespins=xj;var yj=new mb("bgm_slotmachine",Ri,32E3,62088,1,0,["music"]);window.bgm_slotmachine=yj;var zj=new mb("bgm_wheel",Ri,96E3,10608,1,2,["music"]);window.bgm_wheel=zj;
var Aj=new mb("a_tgf_button_down",Ri,108E3,448,1,0,["game"]);window.a_tgf_button_down=Aj;var Bj=new mb("sfx_generalbutton",Ri,11E4,448,1,0,["game"]);window.sfx_generalbutton=Bj;var Cj="37d007a56d816107ce5b52c10342db37 63584f3a94bbad2d1f63d3ce77ff6171 654876fa2c2a615f1a5410bdb6109cbe b6856a1f17d5a6ec76dc8b837841e476 ec0af3752142da7f2c1bc7947864ead0 03a60a509d53952c91fc9865fbd492ef 8784d238b5a81ab432d0bf303850ed8a 9f5ffc7a10e0bad054458b089947ce2f 0c73b027c77dd2c1ee6cd996c2c83efc 0e26dbc8d26a0880786e55e3e950a320 7e77fcbd9a8ec327db79b6c753a5eef1 5ff97ceeea117a01f512adc7ece5ade7 54f5ededff723ca5c52bc75764ceb738 526ceb1f05b2418711e1eb59058e0b09 ae11a4449bebb3561a078bac793dc74b f51482fb5ecee35fd139f89728a7a616 feecd1420633723d96c9739d50653239".split(" ");
"use strict";
var Dj=new (function(){function a(){window.addEventListener("message",function(a){this.uU(a)}.bind(this),!1)}a.prototype.kL=function(){return ca.yh.ju||ca.yh.AJ||ca.yh.FW?{hF:"adFrameMobile",FC:"adtechMobile",width:320,height:250,PK:publisher.mobileRewardId}:{hF:"adFrame",FC:"adtech",width:640,height:480,PK:publisher.desktopRewardId}};a.prototype.QT=function(a,c){this.yL=a;this.zL=c;var d=this.kL(),g=Math.floor(1E9*Math.random());this.Dg=document.createElement("div");this.Dg.className="adOverlay";
var k=document.createElement("div");k.className="adBg";var l=document.createElement("div");l.className=d.hF;this.Ak=document.createElement("iframe");this.Ak.src="http://media.oadts.com/www/delivery/afv.php?zoneid="+d.PK+"&cb="+g;this.Ak.WY="0";this.Ak.scrolling="no";this.Ak.width=d.width;this.Ak.height=d.height;this.Ak.className=d.FC;this.Dg.appendChild(k);this.Dg.appendChild(l);this.Dg.appendChild(this.Ak);document.body.appendChild(this.Dg)};a.prototype.rE=function(){this.Dg&&(document.body.removeChild(this.Dg),
this.Dg=null);this.yL.call(this.zL,!0)};a.prototype.uU=function(a){if("http://media.oadts.com"===a.origin&&this.Dg)switch(console.log(a),a.data){case "noVideo":case "NoVideo":document.body.removeChild(this.Dg);this.Dg=null;this.rE();break;case "videoEnds":case "videoComplete":this.rE()}};return a}());function Ej(){U.play(jj)}function Fj(){U.play(ij)}function Gj(a){switch(a){case 0:U.play(oj);break;case 1:U.play(pj);break;case 2:U.play(qj);break;case 3:U.play(nj)}}
function Hj(){var a;U.stop("music");a=U.play(yj);U.lk(a,!0)}function Ij(){var a;U.stop("music");a=U.play(xj);U.lk(a,!0)}function y(a,b){var c;if("number"===typeof a)return c=wc*a/100,"round"===b&&(c=Math.round(c)),"floor"===b&&(c=Math.floor(c)),"ceil"===b&&(c=Math.ceil(c)),c;if("[object Array]"===Object.prototype.toString.call(a)){for(c=0;c<a.length;c+=1)a[c]=y(a[c],b);return a}if("object"===typeof a)for(c in a)a.hasOwnProperty(c)&&(a[c]=y(a[c],b));return a}
function Jj(a,b){var c;if("object"===typeof b)for(c in b)if(b.hasOwnProperty(c))if(void 0===b[c]||null===b[c])a[c]=b[c];else if("[object Array]"===Object.prototype.toString.call(b[c]))a[c]=b[c];else if("object"===typeof b[c]&&b[c].constructor===Object){"object"!==typeof a[c]&&(a[c]={});var d=a[c],g=b[c],k=void 0;if("object"===typeof g)for(k in g)if(g.hasOwnProperty(k))if(void 0===g[k]||null===g[k])d[k]=g[k];else if("[object Array]"===Object.prototype.toString.call(g[k]))d[k]=g[k];else if("object"===
typeof g[k]&&g[k].constructor===Object){"object"!==typeof d[k]&&(d[k]={});var l=d[k],m=g[k],p=void 0;if("object"===typeof m)for(p in m)m.hasOwnProperty(p)&&(l[p]=m[p])}else d[k]=g[k]}else a[c]=b[c]}var V=new function(){this.Rm={};this.TE={};this.console={};this.za={};this.AF={};this.Xc={};this.ct={};this.profile={};this.WV={};this.status={};this.qZ={};this.q={};this.la={};this.lf={};this.ia={};this.play={}},Kj,Lj;function Mj(a){Kj=a;Lj=q.hg;for(a=0;a<Kj.Li.length;a+=1)na.Si(Kj.Li[a])}
function Nj(){var a,b=!0;if(q.hg<Lj+1E3*Kj.ah)return!1;for(a=0;a<Kj.required.length;a+=1)if(!na.complete(Kj.required[a]))return!1;for(a=0;a<Kj.Li.length;a+=1)na.complete(Kj.Li[a])||(b=!1);return b||q.hg>=Lj+1E3*Kj.Gf}function Oj(){var a,b=1,c=0;if(Nj())return 100;for(a=0;a<Kj.Li.length;a+=1)c+=na.vn(Kj.Li[a]),b+=1;c/=b;a=1E3*Math.max(Kj.Gf,Kj.ah);return c*Math.min(1,(q.hg-Lj)/a)}function Pj(){n.Oi("master");yb(q);Db(q);Fb(q);q.Oi()}
function Qj(a){var b,c,d,g,k,l;if(!a)return!1;a=[].concat(a);if(0===a.length)return!1;l=void 0!==window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname;for(b=0;b<a.length;b+=1){d=a[b];if(0===l.indexOf("file://")&&d===Rj("file://"))return!0;g=l.split(".");c=g.shift().split("://");c[0]+="://";g=c.concat(g);k=g[g.length-1];for(c=g.length-2;0<=c;c-=1)if(k=g[c]+(0<c?".":"")+k,d===Rj(k))return!0}return!1}
function Sj(a,b){var c;if(void 0===a)return void 0===b;if(null===a)return null===b;if(void 0===b||null===b)return!1;if("[object Array]"===Object.prototype.toString.call(a)){if("[object Array]"!==Object.prototype.toString.call(b)||a.length!==b.length)return!1;for(c=0;c<a.length;c+=1)if(!Sj(a[c],b[c]))return!1;return!0}if("object"===typeof a&&a.constructor===Object){if("object"!==typeof b||b.constructor!==Object)return!1;for(c in a)if(a.hasOwnProperty(c)&&!Sj(a[c],b[c]))return!1;for(c in b)if(b.hasOwnProperty(c)&&
!Sj(a[c],b[c]))return!1;return!0}return b===a}function Tj(a){var b,c;if(void 0!==a){if(null===a)return null;if("[object Array]"===Object.prototype.toString.call(a)){c=[];for(b=0;b<a.length;b+=1)c.push(Tj(a[b]));return c}if("object"===typeof a&&a.constructor===Object){c={};for(b in a)a.hasOwnProperty(b)&&(c[b]=Tj(a[b]));return c}return a}}
function Uj(a,b){var c,d;if(void 0===a||null===a)return Tj(b);if(void 0===b||null===b)return Tj(a);if("[object Array]"===Object.prototype.toString.call(a)){if("[object Array]"!==Object.prototype.toString.call(b))return Tj(b);d=Tj(a);for(c=0;c<b.length;c+=1)d[c]=Tj(b[c]);return d}if("object"===typeof a&&a.constructor===Object){if("object"!==typeof b||b.constructor!==Object)return Tj(b);d=Tj(a);for(c in b)b.hasOwnProperty(c)&&(d[c]=Tj(b[c]));return d}return Tj(b)}
function Vj(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(a){var b=ga(0,15);if("x"===a)return b.toString(16);if("y"===a)return(b%4+8).toString(16)})}
function Wj(a){if(null===a||"undefined"===typeof a)return"";a+="";var b="",c,d,g=0;c=d=0;for(var g=a.length,k=0;k<g;k++){var l=a.charCodeAt(k),m=null;if(128>l)d++;else if(127<l&&2048>l)m=String.fromCharCode(l>>6|192,l&63|128);else if(55296!==(l&63488))m=String.fromCharCode(l>>12|224,l>>6&63|128,l&63|128);else{if(55296!==(l&64512))throw new RangeError("Unmatched trail surrogate at "+k);m=a.charCodeAt(++k);if(56320!==(m&64512))throw new RangeError("Unmatched lead surrogate at "+(k-1));l=((l&1023)<<
10)+(m&1023)+65536;m=String.fromCharCode(l>>18|240,l>>12&63|128,l>>6&63|128,l&63|128)}null!==m&&(d>c&&(b+=a.slice(c,d)),b+=m,c=d=k+1)}d>c&&(b+=a.slice(c,g));return b}
function Rj(a){function b(a){var b="",c="",d;for(d=0;3>=d;d++)c=a>>>8*d&255,c="0"+c.toString(16),b+=c.substr(c.length-2,2);return b}function c(a,b,c,d,g,k,m){a=l(a,l(l(c^(b|~d),g),m));return l(a<<k|a>>>32-k,b)}function d(a,b,c,d,g,k,m){a=l(a,l(l(b^c^d,g),m));return l(a<<k|a>>>32-k,b)}function g(a,b,c,d,g,k,m){a=l(a,l(l(b&d|c&~d,g),m));return l(a<<k|a>>>32-k,b)}function k(a,b,c,d,g,k,m){a=l(a,l(l(b&c|~b&d,g),m));return l(a<<k|a>>>32-k,b)}function l(a,b){var c,d,g,k,l;g=a&2147483648;k=b&2147483648;
c=a&1073741824;d=b&1073741824;l=(a&1073741823)+(b&1073741823);return c&d?l^2147483648^g^k:c|d?l&1073741824?l^3221225472^g^k:l^1073741824^g^k:l^g^k}var m=[],p,w,z,v,C,x,t,A,B;a=Wj(a);m=function(a){var b,c=a.length;b=c+8;for(var d=16*((b-b%64)/64+1),g=Array(d-1),k=0,l=0;l<c;)b=(l-l%4)/4,k=l%4*8,g[b]|=a.charCodeAt(l)<<k,l++;b=(l-l%4)/4;g[b]|=128<<l%4*8;g[d-2]=c<<3;g[d-1]=c>>>29;return g}(a);x=1732584193;t=4023233417;A=2562383102;B=271733878;a=m.length;for(p=0;p<a;p+=16)w=x,z=t,v=A,C=B,x=k(x,t,A,B,m[p+
0],7,3614090360),B=k(B,x,t,A,m[p+1],12,3905402710),A=k(A,B,x,t,m[p+2],17,606105819),t=k(t,A,B,x,m[p+3],22,3250441966),x=k(x,t,A,B,m[p+4],7,4118548399),B=k(B,x,t,A,m[p+5],12,1200080426),A=k(A,B,x,t,m[p+6],17,2821735955),t=k(t,A,B,x,m[p+7],22,4249261313),x=k(x,t,A,B,m[p+8],7,1770035416),B=k(B,x,t,A,m[p+9],12,2336552879),A=k(A,B,x,t,m[p+10],17,4294925233),t=k(t,A,B,x,m[p+11],22,2304563134),x=k(x,t,A,B,m[p+12],7,1804603682),B=k(B,x,t,A,m[p+13],12,4254626195),A=k(A,B,x,t,m[p+14],17,2792965006),t=k(t,A,
B,x,m[p+15],22,1236535329),x=g(x,t,A,B,m[p+1],5,4129170786),B=g(B,x,t,A,m[p+6],9,3225465664),A=g(A,B,x,t,m[p+11],14,643717713),t=g(t,A,B,x,m[p+0],20,3921069994),x=g(x,t,A,B,m[p+5],5,3593408605),B=g(B,x,t,A,m[p+10],9,38016083),A=g(A,B,x,t,m[p+15],14,3634488961),t=g(t,A,B,x,m[p+4],20,3889429448),x=g(x,t,A,B,m[p+9],5,568446438),B=g(B,x,t,A,m[p+14],9,3275163606),A=g(A,B,x,t,m[p+3],14,4107603335),t=g(t,A,B,x,m[p+8],20,1163531501),x=g(x,t,A,B,m[p+13],5,2850285829),B=g(B,x,t,A,m[p+2],9,4243563512),A=g(A,
B,x,t,m[p+7],14,1735328473),t=g(t,A,B,x,m[p+12],20,2368359562),x=d(x,t,A,B,m[p+5],4,4294588738),B=d(B,x,t,A,m[p+8],11,2272392833),A=d(A,B,x,t,m[p+11],16,1839030562),t=d(t,A,B,x,m[p+14],23,4259657740),x=d(x,t,A,B,m[p+1],4,2763975236),B=d(B,x,t,A,m[p+4],11,1272893353),A=d(A,B,x,t,m[p+7],16,4139469664),t=d(t,A,B,x,m[p+10],23,3200236656),x=d(x,t,A,B,m[p+13],4,681279174),B=d(B,x,t,A,m[p+0],11,3936430074),A=d(A,B,x,t,m[p+3],16,3572445317),t=d(t,A,B,x,m[p+6],23,76029189),x=d(x,t,A,B,m[p+9],4,3654602809),
B=d(B,x,t,A,m[p+12],11,3873151461),A=d(A,B,x,t,m[p+15],16,530742520),t=d(t,A,B,x,m[p+2],23,3299628645),x=c(x,t,A,B,m[p+0],6,4096336452),B=c(B,x,t,A,m[p+7],10,1126891415),A=c(A,B,x,t,m[p+14],15,2878612391),t=c(t,A,B,x,m[p+5],21,4237533241),x=c(x,t,A,B,m[p+12],6,1700485571),B=c(B,x,t,A,m[p+3],10,2399980690),A=c(A,B,x,t,m[p+10],15,4293915773),t=c(t,A,B,x,m[p+1],21,2240044497),x=c(x,t,A,B,m[p+8],6,1873313359),B=c(B,x,t,A,m[p+15],10,4264355552),A=c(A,B,x,t,m[p+6],15,2734768916),t=c(t,A,B,x,m[p+13],21,
1309151649),x=c(x,t,A,B,m[p+4],6,4149444226),B=c(B,x,t,A,m[p+11],10,3174756917),A=c(A,B,x,t,m[p+2],15,718787259),t=c(t,A,B,x,m[p+9],21,3951481745),x=l(x,w),t=l(t,z),A=l(A,v),B=l(B,C);return(b(x)+b(t)+b(A)+b(B)).toLowerCase()}V.BQ={dS:"canvas",wE:"game_container",O:y(1152),M:y(640),FO:!0,De:y(850),ng:y(640),Th:y(0),Sh:y(151),IU:"center",JU:"middle",sM:!0,rM:!0,backgroundImage:void 0,backgroundColor:"white",oD:1,FM:!1};function Xj(){this.oC=!1;this.hc=[]}
Xj.prototype.n=function(a){var b=this;this.oC=!0;this.hc=[];this.Na(V.BQ);this.Na(a);this.g=document.getElementById(this.wE);this.g||(this.g=document.createElement("DIV"),this.g.id=this.wE,document.body.appendChild(this.g));this.k=document.getElementById(this.dS);this.k||(this.k=document.createElement("canvas"),this.g.appendChild(this.k));Yj(this,this.k,{xf:0,wf:0});this.hc.push(this.k);this.FO&&(this.sh=Zj(this,void 0,{hp:!0}));window.addEventListener("resize",function(){Xj.prototype.Ho.call(b,!0)},
!0);0<this.oD&&window.setInterval(function(){Xj.prototype.Ho.call(b,b.FM)},1E3*this.oD);this.Ho(!0);void 0!==this.backgroundColor&&ak(this.backgroundColor);void 0!==this.backgroundImage&&(document.body.style.backgroundImage="url("+this.backgroundImage+")");q.k=this.k;pa(f,this.k)};Xj.prototype.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
Xj.prototype.Ho=function(a){var b,c,d,g;if(this.oC&&(a||void 0===this.hj||this.hj!==window.innerWidth||void 0===this.gj||this.gj!==window.innerHeight)){this.hj=window.innerWidth;this.gj=window.innerHeight;d=this.hj/this.gj;b=this.O/this.M;c=this.De/this.ng;a=this.hj;g=this.gj;this.Nb=Math.min(this.hj/this.De,this.gj/this.ng);d<b&&d<c&&(g=Math.floor(this.hj/(this.De/this.M)),this.Nb=this.hj/this.De);d>b&&d>c&&(a=Math.floor(this.O/this.ng*this.gj),this.Nb=this.gj/this.ng);!this.sM&&1<this.Nb&&(a=Math.min(a,
this.O),g=Math.min(g,this.M),this.Nb=1);!this.rM&&1>this.Nb&&(a=Math.max(a,this.O),g=Math.max(g,this.M),this.Nb=1);this.vp=this.up=0;b=this.O-this.hj/this.Nb;c=this.O===this.De?1:b/(this.O-this.De);if(1<=b)switch(this.IU){case "right":this.up=-Math.min(b,this.Sh);break;case "left":this.up=-Math.max(0,b-this.O+this.De+this.Sh);break;default:this.up=-c*this.Sh}b=this.M-this.gj/this.Nb;c=b/(this.M-this.ng);if(1<=b)switch(this.JU){case "bottom":this.vp=-Math.min(b,this.Th);break;case "top":this.vp=-Math.max(0,
b-this.M+this.ng+this.Th);break;default:this.vp=-c*this.Th}g=Math.min(this.gj,g);a=Math.min(this.hj,a);this.g.setAttribute("style","position:fixed; overflow:hidden; z-index: 0; width:"+a+"px; left:50%; margin-left:"+-a/2+"px; height: "+g+"px; top:50%; margin-top:"+-g/2+"px");bk(this);this.vk=-this.up;this.wk=-this.vp;this.em=Math.ceil(a/this.Nb);this.Ur=Math.ceil(g/this.Nb);ck(this)}};
function ck(a){var b,c,d,g,k;if(ca.U.vB&&ca.U.Sr&&4<=ca.U.Sr&&!a.dC){a.dC=!0;n.pause("master");q.pause();g=[];for(c=0;c<a.hc.length;c+=1){d=a.hc[c];b=d.getContext("2d");try{k=b.getImageData(0,0,d.width,d.height),g.push(k)}catch(l){}b.clearRect(0,0,d.width,d.height);d.style.visibility="hidden"}setTimeout(function(){var b;for(b=0;b<a.hc.length;b+=1)a.hc[b].style.visibility="visible"},1);setTimeout(function(){var b,c;for(b=0;b<a.hc.length;b+=1){c=a.hc[b].getContext("2d");try{c.putImageData(g[b],0,0)}catch(d){}}Pj();
this.dC=!1},100)}}function dk(a,b,c){var d,g;void 0!==a.Nb&&(d=a.up+b.wf,g=a.vp+b.xf,b.setAttribute("style","position:absolute; left:"+Math.round(a.Nb*d)+"px; top:"+Math.round(a.Nb*g)+"px; width:"+Math.round(a.Nb*b.uh)+"px; height:"+Math.round(a.Nb*b.th)+"px; z-index: "+(c+1).toString()))}function bk(a){var b;for(b=0;b<a.hc.length;b+=1)dk(a,a.hc[b],b)}
function Yj(a,b,c){var d,g,k;c||(c={});d=void 0!==c.xf?c.xf:0;g=void 0!==c.wf?c.wf:0;k=void 0!==c.uh?c.uh:a.O;a=void 0!==c.th?c.th:a.M;c=void 0!==c.hp?c.hp:!1;b.style.top=d+"px";b.style.left=g+"px";b.style.position="absolute";b.width=k;b.height=a;b.xf=d;b.wf=g;b.uh=k;b.th=a;if(b.hp=c)b.LE=!1}function ek(a,b){var c=document.createElement("canvas");Yj(a,c,b);a.g?a.g.appendChild(c):document.body.appendChild(c);return c}
function fk(a,b){var c;if(!b)return-1;for(c=0;c<a.hc.length;c+=1)if(a.hc[c]===b)return c;return-1}function gk(a){var b=r;a=ek(b,a);b.hc.push(a);dk(b,a,b.hc.length-1);return a}function Zj(a,b,c){b=fk(a,b);0>b&&(b=0);c=ek(a,c);a.hc.splice(b,0,c);bk(a);return c}function hk(a){var b=r,c;a!==b.k&&(c=fk(b,a),0>c||(b.hc.splice(c,1),a===b.sh&&(b.sh=void 0),b.g?b.g.removeChild(a):document.body.removeChild(a),bk(b)))}function ik(){var a=r,b,c=[];for(b=0;b<a.hc.length;b+=1)c.push(a.hc[b]);return c}
function jk(a,b){var c=r.k;return c&&a?c.xf-a.xf+b:b}function ak(a){document.body.style.backgroundColor=a}function kk(a,b,c,d){var g=r;g.Sh=void 0===a?g.Sh:a;g.Th=void 0===b?g.Th:b;g.De=void 0===c?g.De:c;g.ng=void 0===d?g.ng:d;g.Ho(!0)}function lk(a,b,c){a.O=void 0===b?a.O:b;a.M=void 0===c?a.M:c;a.Ho(!0)}var r=new Xj;V.VO={DE:[],kl:[],WH:[],xU:!0,Xm:void 0,UW:!0,SW:"lang",TW:!0,WJ:!0};function mk(){this.be={};this.Xf="en-us";this.Hb=["en-us"]}e=mk.prototype;
e.n=function(a){var b,c;this.Na(V.VO);this.Na(a);this.be={};a=this.DE;var d;a=[].concat(a);for(d=0;d<a.length;d+=1){var g=a[d],k=void 0,l=void 0;if("object"===typeof g)for(k in g)if(g.hasOwnProperty(k))for(l in this.be[k]||(this.be[k]={}),g[k])g[k].hasOwnProperty(l)&&(this.be[k][l]=g[k][l])}this.Hb=[];for(b in this.be)this.be.hasOwnProperty(b)&&this.Hb.push(b);0===this.Hb.length&&this.Hb.push("en-us");0<this.kl.length&&nk(this,this.kl);this.kl.ow&&0<this.kl.ow.length&&nk(this,this.kl.ow);if(this.UW){b=
this.SW;a=[];g=window.location.search.substring(1);d={};if(g)for(g=g.split("&"),l=0;l<g.length;l+=1)k=g[l].split("="),d[k[0]]=k[1];"string"===typeof d[b]&&(a=d[b].toLowerCase().split("+"));b=a;0<b.length&&nk(this,b)}0<this.WH.length&&ok(this,this.WH);if(this.xU){b=[];for(var m in this.be)if(this.be.hasOwnProperty(m)){a:if(a=m,k=g=d=void 0,void 0===a&&(a=this.Xf),a=a.toLowerCase(),d=this.be[a],void 0===d)a=!1;else{for(g in this.be)if(this.be.hasOwnProperty(g))for(k in this.be[g])if(this.be[g].hasOwnProperty(k)&&
void 0===d[k]){a=!1;break a}a=!0}a||b.push(m)}ok(this,b)}0!==this.Hb.length&&this.kk(this.Hb[0]);this.WJ&&(c=pk(qk).language,rk(this,c)||(c=void 0));void 0===c&&this.WJ&&(c=sk.language,rk(this,c)||(c=void 0));void 0===c&&this.Xm&&(c=this.Xm,rk(this,c)||(c=void 0));if(void 0===c&&this.TW){a:{b=navigator.languages||[navigator.language||navigator.userLanguage];for(c=0;c<b.length;c+=1)if("string"===typeof b[c])for(a=b[c].toLowerCase(),m=0;m<this.Hb.length;m+=1)if(0<=this.Hb[m].search(a)){c=this.Hb[m];
break a}c=void 0}rk(this,c)||(c=void 0)}void 0!==c&&this.kk(c)};e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};function nk(a,b){a.Hb=[];var c,d=!0,g,k;void 0===d&&(d=!0);c=[].concat(b);for(g=0;g<c.length;g+=1)k=c[g].toLowerCase(),0<=a.Hb.indexOf(k)||d&&void 0===a.be[k]||a.Hb.push(k);0===a.Hb.length&&a.Hb.push("en-us")}
function ok(a,b){var c,d;b=[].concat(b);for(c=0;c<b.length;c+=1)d=b[c].toLowerCase(),d=a.Hb.indexOf(d),0<=d&&a.Hb.splice(d,1);0===a.Hb.length&&a.Hb.push("en-us")}e.Ei=function(){return this.Hb.slice(0)};function rk(a,b){if(!b)return!1;b=b.toLowerCase();return 0<=a.Hb.indexOf(b)}e.kk=function(a){a&&(a=a.toLowerCase(),this.Xf!==a&&-1!==this.Hb.indexOf(a)&&(this.Xf=a,la("languageSet",a)))};e.zy=function(a,b){var c;void 0===b&&(b=this.Xf);b=b.toLowerCase();c=this.be[b];return void 0===c?!1:void 0!==c[a]};
function E(a,b){var c,d=tk,g,k,l;void 0===c&&(c=d.Xf);c=c.toLowerCase();void 0===b&&(b="< UNDEFINED: "+a+">");c=d.be[c];if(void 0===c)return b;c=c[a];if(void 0===c)return b;if(d=c.match(/#touch\{.*\}\s*\{.*\}/g))for(l=ca.yh.AJ||ca.yh.ju,k=0;k<d.length;k+=1)g=l?d[k].match(/\{[^}]*\}/g)[1]:d[k].match(/\{[^}]*\}/g)[0],g=g.substring(1,g.length-1),c=c.replace(d[k],g);return c}
function uk(a){switch(a){case "nl-nl":return xd;case "en-us":return vd;case "en-gb":return wd;case "de-de":return zd;case "fr-fr":return Ad;case "pt-br":return Bd;case "es-es":return Cd;case "tr-tr":return yd;case "ru-ru":return Dd;case "ar-eg":return Ed;case "ko-kr":return Fd;case "jp-jp":return Hd;default:return Gd}}
function vk(a){switch(a){case "nl-nl":return"Nederlands";case "en-us":return"English (US)";case "en-gb":return"English (GB)";case "de-de":return"Deutsch";case "fr-fr":return"Fran\u00e7ais";case "pt-br":return"Portugu\u00eas do Brasil";case "es-es":return"Espa\u00f1ol";case "tr-tr":return"T\u00fcrk\u00e7e";case "ru-ru":return"\u0420\u0443\u0441\u0441\u043a\u0438\u0439";case "ar-eg":return"\u0627\u0644\u0639\u0631\u0628\u064a\u0629";case "ko-kr":return"\ud55c\uad6d\uc5b4";case "jp-jp":return"\u65e5\u672c\u8a9e";
default:return"<UNKNOWN>"}}var tk=new mk;V.ZV={wU:"none",wx:"hex",OY:!1,version:1,WU:!0,VU:!0,Cs:0,Ds:5};function wk(a){this.name=void 0===a?"storage":a;this.timeStamp=0;this.data={};this.Km=!1}e=wk.prototype;
e.n=function(a,b,c){var d=this;this.Na(V.ZV);this.Na(a);this.In=this.Oy=this.Ls=this.Ks=!1;this.Yg=this.zJ=!0;this.Uj=!1;this.ir=!0;this.Ze=this.Ye=this.wA=!1;if(JSON&&JSON.stringify){this.Oy=void 0!==window.localStorage;switch(this.wU){case "none":this.zq=void 0}this.In=void 0!==this.zq;sk.id&&(this.In=!1);this.In?(this.zJ=this.zq.zJ,this.zq.n(function(){b&&b();d.Ye=!0},function(){c&&c();d.Ze=!0;d.In=!1})):this.Ye=!0;xk(this,this.Cs);yk(this,this.Ds)}else this.Ze=!0};
function xk(a,b){void 0!==a.lD&&window.clearInterval(a.lD);a.Cs=b;0<a.Cs&&(a.lD=window.setInterval(function(){wk.prototype.Ny.call(a)},1E3*a.Cs))}function yk(a,b){void 0!==a.nD&&window.clearInterval(a.nD);a.Ds=b;0<a.Ds&&(a.nD=window.setInterval(function(){wk.prototype.Ku.call(a)},1E3*a.Ds))}e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
function zk(a,b){var c,d,g;g=("000"+a.toString(16)).slice(-4);for(d=0;d<b.length;d+=1)c=b.charCodeAt(d),c+=d*a,c%=65535,g+=("000"+c.toString(16)).slice(-4);return g}function Ak(a){var b;b="TG_"+(a.version+"_");b=sk.id?b+(sk.id+"_"):b+"anonymous_";V.la&&V.la.id&&(b+=V.la.id+"_");a.WU&&V.lf&&V.lf.id&&(b+=V.lf.id+"_");a.VU&&V.ia&&V.ia.id&&(b+=V.ia.id+"_");b+=a.name;switch(a.wx){case "hex":b=zk(12345,b)}return b}
function Bk(a){var b=JSON.stringify({timeStamp:a.timeStamp,data:JSON.stringify(a.data)});switch(a.wx){case "hex":b=zk(ga(1E4,2E4),b)}return b}e.tC=function(a){var b;if(a){switch(this.wx){case "hex":var c,d;b="";var g=a.match(/.{1,4}/g)||[];c=parseInt(g[0],16);for(a=1;a<g.length;a+=1)d=parseInt(g[a],16),d-=(a-1)*c,d=(d%65535+65535)%65535,b+=String.fromCharCode(d);a=b}b=JSON.parse(a);b.timeStamp>=this.timeStamp&&(this.timeStamp=b.timeStamp,this.data=JSON.parse(b.data),this.Km=!1)}};
function W(a,b,c){a.data[b]!==c&&(a.timeStamp=(new Date).getTime(),a.data[b]=c,a.Km=!0)}e.zy=function(a){return void 0!==this.data[a]};e.Ta=function(a,b,c,d,g,k){Sj(this.data[a],b)||(this.timeStamp=(new Date).getTime(),this.data[a]=k?b:Tj(b),this.Km=!0);c&&this.Km&&this.Ku(d,g,!1)};e.ea=function(a,b){return b?this.data[a]:Tj(this.data[a])};
e.Ny=function(a,b,c){var d=this,g;if(this.Ks||this.Ls)b&&b();else{c&&(this.timeStamp=0);b=Ak(this);if(this.Oy)try{g=window.localStorage.getItem(b),this.tC(g)}catch(k){}this.In?(this.Uj=this.Yg=!1,this.Ks=!0,this.zq.Ny(b,function(a){wk.prototype.tC.call(d,a)},function(){d.Ks=!1;this.Yg=!0;a&&a()})):(this.Yg=!0,a&&a())}};
e.Ku=function(a,b,c){var d=this;if(this.Km||c)if(this.Ks||this.Ls)b&&b();else{c=Ak(this);b=Bk(this);if(this.Oy)try{window.localStorage.setItem(c,b)}catch(g){}this.In?(this.wA=this.ir=!1,this.Ls=!0,this.zq.Ku(c,b,function(){d.Ls=!1;this.ir=!0;a&&a()})):(this.ir=!0,a&&a());this.Km=!1}};V.eU={name:"Anonymous",id:void 0,oY:"",nY:void 0,language:void 0};function Ck(){}Ck.prototype.n=function(a){this.Na(V.eU);this.Na(a)};
Ck.prototype.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};var sk=new Ck;V.Cr={KH:{},version:{},global:{Qf:0,Tc:0,lh:0,hq:-1,Ot:-1,Nt:-1,Zg:-1,kn:-1,tq:-1,Qt:-1,Rt:-1,Pt:-1,vq:-1,wq:-1,uq:-1,Wn:0,Fr:0,Er:0,Dr:0},play:{jo:!1,Qf:0,Tc:0,lh:0,Tt:0,Hr:0,Bq:0,Wj:0,Ef:0,Jr:0,ah:0,Gf:0,Ut:0,Ir:0,Cq:0,$g:0,St:0,Gr:0,Aq:0,nl:0},KC:{}};function Dk(){}e=Dk.prototype;
e.n=function(a,b,c,d){var g=this;this.m=new wk("tgfStatus");this.m.n(a);Ek(this,Uj(V.Cr.KH,b.KH));Fk(this,Uj(V.Cr.version,b.version));Gk(this,Uj(V.Cr.global,b.global));Hk(this,Uj(V.Cr.KC,b.KC));this.ST=Uj(V.Cr.play,b.play);this.Ze=this.Ye=!1;this.dq=c;this.cq=d;this.$e=0;this.vy=window.setInterval(function(){Dk.prototype.Ow.call(g)},50)};
e.Ow=function(){0===this.$e&&(this.m.Ye?(Ik(this),this.$e=1):this.m.Ze&&(this.Ze=!0,this.$e=2));1===this.$e&&(this.Yg?(this.Ye=!0,this.$e=2):this.Uj&&(this.Ze=!0,this.$e=2));2===this.$e&&(window.clearInterval(this.vy),this.Ye&&this.dq&&this.dq(),this.Ze&&this.cq&&this.cq())};function Ik(a){a.Yg=!1;a.Uj=!1;a.m.Ny(function(){a.Yg=!0},function(){a.Uj=!0},!0)}function Jk(a){a.ir=!1;a.wA=!1;a.m.Ku(function(){a.ir=!0},function(){a.wA=!0},!1)}
function pk(a){return{language:a.m.data.Pla,yi:a.m.data.Pem,Yk:a.m.data.Peg,Mi:a.m.data.Pmm,vl:a.m.data.Pmg}}function Ek(a,b){void 0!==b.language&&W(a.m,"Pla",b.language);void 0!==b.yi&&W(a.m,"Pem",b.yi);void 0!==b.Yk&&W(a.m,"Peg",b.Yk);void 0!==b.Mi&&W(a.m,"Pmm",b.Mi);void 0!==b.vl&&W(a.m,"Pmg",b.vl)}
function Fk(a,b){void 0!==b.Vp&&W(a.m,"Vgi",b.Vp);void 0!==b.CB&&W(a.m,"Vti",b.CB);void 0!==b.ip&&W(a.m,"Vci",b.ip);void 0!==b.Wp&&W(a.m,"Vgv",b.Wp);void 0!==b.DB&&W(a.m,"Vtv",b.DB);void 0!==b.Pw&&W(a.m,"Vcv",b.Pw)}
function Kk(a){return{Qf:a.m.data.Gtp,Tc:a.m.data.Gtw,lh:a.m.data.Gtl,hq:a.m.data.Gllp,Ot:a.m.data.Gllw,Nt:a.m.data.Glll,Zg:a.m.data.Gmlp,kn:a.m.data.Gmlw,tq:a.m.data.Gmll,Qt:a.m.data.Glmp,Rt:a.m.data.Glmw,Pt:a.m.data.Glml,vq:a.m.data.Gmmp,wq:a.m.data.Gmmw,uq:a.m.data.Gmml,Wn:a.m.data.Gsms,Fr:a.m.data.Gsmt,Er:a.m.data.Gsmr,Dr:a.m.data.Gsmm}}
function Gk(a,b){void 0!==b.Qf&&W(a.m,"Gtp",b.Qf);void 0!==b.Tc&&W(a.m,"Gtw",b.Tc);void 0!==b.lh&&W(a.m,"Gtl",b.lh);void 0!==b.hq&&W(a.m,"Gllp",b.hq);void 0!==b.Ot&&W(a.m,"Gllw",b.Ot);void 0!==b.Nt&&W(a.m,"Glll",b.Nt);void 0!==b.Zg&&W(a.m,"Gmlp",b.Zg);void 0!==b.kn&&W(a.m,"Gmlw",b.kn);void 0!==b.tq&&W(a.m,"Gmll",b.tq);void 0!==b.Qt&&W(a.m,"Glmp",b.Qt);void 0!==b.Rt&&W(a.m,"Glmw",b.Rt);void 0!==b.Pt&&W(a.m,"Glml",b.Pt);void 0!==b.vq&&W(a.m,"Gmmp",b.vq);void 0!==b.wq&&W(a.m,"Gmmw",b.wq);void 0!==b.uq&&
W(a.m,"Gmml",b.uq);void 0!==b.Wn&&W(a.m,"Gsms",b.Wn);void 0!==b.Fr&&W(a.m,"Gsmt",b.Fr);void 0!==b.Er&&W(a.m,"Gsmr",b.Er);void 0!==b.Dr&&W(a.m,"Gsmm",b.Dr)}
function Lk(a,b,c){void 0===b&&(b=0);void 0===c&&(c=0);b="M"+b+"L"+c;return a.m.zy(b+"ex")?{jo:a.m.data[b+"un"],Qf:a.m.data[b+"tp"],Tc:a.m.data[b+"tw"],lh:a.m.data[b+"tl"],Tt:a.m.data[b+"las"],Hr:a.m.data[b+"sus"],Bq:a.m.data[b+"mis"],Wj:a.m.data[b+"mas"],Ef:a.m.data[b+"lat"],Jr:a.m.data[b+"sut"],ah:a.m.data[b+"mit"],Gf:a.m.data[b+"mat"],Ut:a.m.data[b+"lar"],Ir:a.m.data[b+"sur"],Cq:a.m.data[b+"mir"],$g:a.m.data[b+"mar"],St:a.m.data[b+"lam"],Gr:a.m.data[b+"sum"],Aq:a.m.data[b+"mim"],nl:a.m.data[b+
"mam"]}:Tj(a.ST)}
function Mk(a,b,c,d){void 0===b&&(b=0);void 0===c&&(c=0);b="M"+b+"L"+c;W(a.m,b+"ex",!0);void 0!==d.jo&&W(a.m,b+"un",d.jo);void 0!==d.Qf&&W(a.m,b+"tp",d.Qf);void 0!==d.Tc&&W(a.m,b+"tw",d.Tc);void 0!==d.lh&&W(a.m,b+"tl",d.lh);void 0!==d.Tt&&W(a.m,b+"las",d.Tt);void 0!==d.Hr&&W(a.m,b+"sus",d.Hr);void 0!==d.Bq&&W(a.m,b+"mis",d.Bq);void 0!==d.Wj&&W(a.m,b+"mas",d.Wj);void 0!==d.Ef&&W(a.m,b+"lat",d.Ef);void 0!==d.Jr&&W(a.m,b+"sut",d.Jr);void 0!==d.ah&&W(a.m,b+"mit",d.ah);void 0!==d.Gf&&W(a.m,b+"mat",d.Gf);
void 0!==d.Ut&&W(a.m,b+"lar",d.Ut);void 0!==d.Ir&&W(a.m,b+"sur",d.Ir);void 0!==d.Cq&&W(a.m,b+"mir",d.Cq);void 0!==d.$g&&W(a.m,b+"mar",d.$g);void 0!==d.St&&W(a.m,b+"lam",d.St);void 0!==d.Gr&&W(a.m,b+"sum",d.Gr);void 0!==d.Aq&&W(a.m,b+"mim",d.Aq);void 0!==d.nl&&W(a.m,b+"mam",d.nl)}function Hk(a,b){a.m.Ta("Additional",b)}e.kk=function(a){var b=pk(this);void 0!==a&&(b.language=a);Ek(this,b);Jk(this)};function Nk(a,b){var c=qk,d=pk(c);void 0!==a&&(d.yi=a);void 0!==b&&(d.Mi=b);Ek(c,d);Jk(c)}
e.Un=function(a,b){var c={Vp:this.m.data.Vgi,CB:this.m.data.Vti,ip:this.m.data.Vci,Wp:this.m.data.Vgv,DB:this.m.data.Vtv,Pw:this.m.data.Vcv},d=Kk(this),g=Lk(this,a,b);this.ci=void 0===b?0:b;this.di=void 0===a?0:a;V.la&&V.la.id&&(c.Vp=V.la.id);V.lf&&V.lf.id&&(c.CB=V.lf.id);V.ia&&V.ia.id&&(c.ip=V.ia.id);V.la&&V.la.version&&(c.Wp=V.la.version);V.lf&&V.lf.version&&(c.DB=V.lf.version);V.ia&&V.ia.version&&(c.Pw=V.ia.version);d.Qf+=1;d.hq=this.ci;d.Zg=Math.max(d.Zg,this.ci);d.Qt=this.di;d.vq=Math.max(d.vq,
this.di);g.Qf+=1;Fk(this,c);Gk(this,d);Mk(this,a,b,g);Jk(this)};
e.lt=function(a,b,c,d){var g=Kk(this),k=Lk(this,this.di,this.ci);void 0===a&&(a=0);void 0===b&&(b=0);void 0===c&&(c=0);void 0===d&&(d=0);g.Tc+=1;g.Ot=this.ci;g.kn=Math.max(g.kn,this.ci);g.Rt=this.di;g.wq=Math.max(g.wq,this.di);a>k.Wj&&(g.Wn+=a-k.Wj);b>k.Gf&&(g.Fr+=b-k.Gf);c>k.$g&&(g.Er+=c-k.$g);d>k.nl&&(g.Dr+=d-k.nl);k.Tc+=1;k.Tt=a;k.Hr+=a;k.Bq=1===k.Tc?a:Math.min(k.Bq,a);k.Wj=1===k.Tc?a:Math.max(k.Wj,a);k.Ef=b;k.Jr+=b;k.ah=1===k.Tc?b:Math.min(k.ah,b);k.Gf=1===k.Tc?b:Math.max(k.Gf,b);k.Ut=c;k.Ir+=
c;k.Cq=1===k.Tc?c:Math.min(k.Cq,c);k.$g=1===k.Tc?c:Math.max(k.$g,c);k.St=d;k.Gr+=d;k.Aq=1===k.Tc?d:Math.min(k.Aq,d);k.nl=1===k.Tc?d:Math.max(k.nl,d);Gk(this,g);Mk(this,this.di,this.ci,k);Jk(this)};e.kt=function(){var a=Kk(this),b=Lk(this,this.di,this.ci);a.lh+=1;a.Nt=this.ci;a.tq=Math.max(a.tq,this.ci);a.Pt=this.di;a.uq=Math.max(a.uq,this.di);b.lh+=1;Gk(this,a);Mk(this,this.di,this.ci,b);Jk(this)};var qk=new Dk;
V.OC={fk:"gameAnalytics",version:"1",Py:"analyticsUserId",bV:!0,nF:"http://api.gameanalytics.com/1/",Ux:void 0,Vx:void 0};function Ok(){this.fa=this.D=!1}
Ok.prototype.n=function(a){var b;this.Na(V.OC);this.Na(a);this.Le=[];this.yg=sk.yg;if(void 0===this.yg&&void 0!==window.localStorage)try{this.yg=window.localStorage.getItem(this.Py)}catch(c){this.yg=Vj()}if(null===this.yg||void 0===this.yg)this.yg=Vj();if(void 0!==window.localStorage)try{window.localStorage.setItem(this.Py,this.yg)}catch(d){}b=[].concat(this.fk);this.Ki=[];for(a=0;a<b.length;a+=1)switch(b[a]){case "gameAnalytics":this.Ki.push(new Pk(this))}for(a=0;a<this.Ki.length;a+=1)this.Ki[a].n();
this.D=!1;this.fa=!0};Ok.prototype.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};Ok.prototype.uB=function(){var a;if(!this.D&&this.fa){this.D=!0;for(a=0;a<this.Ki.length;a+=1)this.Ki[a].uB(V.la.id,V.lf.id,V.ia.id,this.yg,this.version);for(a=0;a<this.Ki.length;a+=1)this.Ki[a].hk("session",void 0,"start")}};Ok.prototype.hk=function(a,b,c,d){var g;if(this.D&&this.fa)for(g=0;g<this.Ki.length;g+=1)this.Ki[g].hk(a,b,c,d)};
function Qk(a,b,c){var d=Rk,g,k;for(g=0;g<d.Le.length;g+=1)if(!d.Le[g].D){k=d.Le[g];break}void 0===k&&(d.Le.push({}),k=d.Le[d.Le.length-1]);k.paused=0;k.D=!0;k.tag=a;k.name=c;k.FN=b;k.bW=void 0;k.startTime=q.hg;k.IT=0}function Sk(a){var b=Rk,c,d;for(c=0;c<b.Le.length;c+=1)!b.Le[c].D||void 0!==a&&b.Le[c].tag!==a||(d=b.Le[c],0<d.paused&&(d.startTime+=q.hg-d.IT),b.hk(d.FN,d.bW,d.name,q.hg-d.startTime),d.D=!1)}
function Tk(a){var b=Rk,c,d;for(c=0;c<b.Le.length;c+=1)!b.Le[c].D||void 0!==a&&b.Le[c].tag!==a||(d=b.Le[c],d.D=!1)}function Pk(a){this.za=a;this.D=this.fa=!1}Pk.prototype.n=function(){this.pF=this.za.Ux;this.oI=this.za.Vx;this.MM=this.za.nF+this.pF;void 0!==this.pF&&void 0!==this.oI&&JSON&&JSON.stringify&&(this.fa=!0)};
Pk.prototype.uB=function(a,b,c,d,g){!this.D&&this.fa&&(this.D=!0,this.rI=Vj(),this.yg=d,this.version=g,this.D=!0,a={user_id:this.yg,session_id:this.rI,build:this.version,install_publisher:c,install_site:window.location!==window.parent.location?document.referrer:document.location.href},Uk(this,"user",a))};
Pk.prototype.hk=function(a,b,c,d){var g="";this.D&&this.fa&&(void 0!==a&&(g+=a+":"),void 0!==b&&(g+=b+":"),void 0!==c&&(g+=c),0!==g.length&&(":"===g.slice(-1)&&(g=g.slice(0,-1)),a={user_id:this.yg,session_id:this.rI,build:this.version,event_id:g,value:d},Uk(this,"design",a)))};
function Uk(a,b,c){var d;c=JSON.stringify(c);var g=Rj(c+a.oI);a=a.MM+"/"+b;try{d=new XMLHttpRequest,d.open("POST",a,!0),d.setRequestHeader("Content-Type","text/plain"),d.setRequestHeader("Authorization",g),d.send(c)}catch(k){}}var Rk=new Ok;
V.tO={pV:!1,wI:!0,AW:120,Zu:"ABBCCDDA",cW:5,PB:.2,PA:!0,NP:1,width:y(320),height:void 0,left:void 0,top:y(0),hK:void 0,PF:y(320),pG:y(0),RJ:void 0,cX:!1,dX:!1,fX:!1,eX:!1,zV:!0,KP:!0,BU:!0,pi:y(48),Xo:"#CCE6FF",DD:"#EEEEEE",margin:y(6),ny:y(48),oy:"#CCCCCC",JQ:"#999999",py:"#000000",NF:"Arial",OF:y(16,"round"),zB:"Courier New",AB:y(16,"round"),FJ:"#000000",EJ:"#CCE6FF",vg:y(24),textIndent:y(24),BB:"#2E8AE6",fB:y(32),xV:"#DDDDDD",wV:"#AAAAAA"};
function Vk(){this.depth=0;this.W=-99999999;this.visible=!1;this.D=!0;this.fa=!1;this.sk="";this.Xn=0;Mb(this)}e=Vk.prototype;e.n=function(a){this.fa||(this.Na(V.tO),this.Na(a),this.wI||(this.fa=!0,this.info=[],this.yq=[],this.Ic=[],this.mode=0,this.clear(),this.Cu=this.Ci=!1,this.hb=null,this.pV&&this.show(),this.PA&&(this.iG=q.hg,this.lG=q.Rr,this.ot="",this.pt=0),0<this.PB&&(this.Vb=0)))};
e.clear=function(){this.fa&&(this.fa&&this.C(!1)&&(this.yq=[],Wk(this)),this.fa&&this.C(!1)&&(this.info=[],Xk(this)),this.fa&&this.C(!1)&&(this.Ic=[],Yk(this)))};e.C=function(a){return!this.fa||this.wI||!this.hb&&!1!==a?!1:!0};e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
e.show=function(a){var b,c,d;this.fa&&this.C(!1)&&!this.hb&&(void 0===a&&(a=!1),this.sL=r.O,this.rL=r.M,this.wL=r.De,this.tL=r.ng,this.vL=r.Th,this.uL=r.Sh,(this.jL=a)?(a=void 0===this.pG?r.O:this.pG,b=void 0===this.RJ?r.M:this.RJ,c=void 0===this.hK?r.O:this.hK,d=void 0===this.PF?r.M:this.PF):(a=void 0===this.left?r.O:this.left,b=void 0===this.top?r.M:this.top,c=void 0===this.width?r.O:this.width,d=void 0===this.height?r.M:this.height),0>a&&(a=0),0>b&&(b=0),this.hb=gk({wf:a,xf:b,uh:c,th:d,hp:!0}),
lk(r,Math.max(r.O,a+c),Math.max(r.M,b+d)),kk(0,0,r.O,r.M),this.mode=-1,Zk(this))};e.i=function(){this.fa&&this.C()&&(lk(r,this.sL,this.rL),kk(this.uL,this.vL,this.wL,this.tL),hk(this.hb),this.hb=null,this.Ci&&this.BU&&(Qb(this),Wb(),this.Ci=!1))};e.toggle=function(){this.fa&&this.C(!1)&&(this.hb?this.i():this.show())};function Zk(a){var b;a.fa&&a.C()&&2!==a.mode&&(a.mode=2,$k(a),b=Math.floor(a.M/a.vg),a.nk=Math.min(1,b/a.yq.length),a.qg=1-a.nk,al(a),Wk(a))}
function Wk(a){var b=[],c,d,g=a.AB+"px "+a.zB;if(a.fa&&a.C()&&2===a.mode){for(d=0;d<a.yq.length;d+=1)c=a.yq[d],void 0!==c?b.push({text:c.text,color:c.color,kg:0,icon:d===a.yq.length-1?"disk":"",font:g}):b.push({text:"",color:"black",kg:0,icon:"",font:g});bl(a,b)}}
function Xk(a){var b=[],c,d,g,k=a.AB+"px "+a.zB;if(a.fa&&a.C()&&0===a.mode){for(g=0;g<a.info.length;g+=1)c=a.info[g],void 0!==c?(d=c.text,void 0!==c.Up&&(d+=c.Up()),b.push({text:d,color:c.color,kg:0,icon:"",font:k})):b.push({text:"",color:"black",kg:0,icon:"",font:k});bl(a,b)}}
function Yk(a){var b=[],c,d,g,k,l,m=a.AB+"px "+a.zB;if(a.fa&&a.C()&&1===a.mode){for(c=0;c<a.Ic.length;c+=1)d=a.Ic[c],g=d.$G,void 0!==d.Gu&&(g=g[d.Gu]),k=d.name+": ",l="",void 0===g?k+="undefined":null===g?k+="null":"[object Array]"===Object.prototype.toString.call(g)?(k+="Array["+g.length+"]",l=d.Gj?"arrowD":"arrowR"):"object"===typeof g?(k+="Object",l=d.Gj?"arrowD":"arrowR"):k="function"===typeof g?k+"Function":"string"===typeof g?k+('"'+g+'"'):k+g.toString(),b.push({text:k,color:d.color,kg:d.kg,
icon:l,font:m});bl(a,b)}}function cl(a,b,c,d,g,k,l){var m=d,p=!0;void 0!==m&&void 0!==g&&(m=m[g]);void 0!==m||a.fX||(p=!1);null!==m||a.dX||(p=!1);"function"!==typeof m||a.cX||(p=!1);p&&a.Ic.splice(b,0,{name:c,$G:d,Gu:g,color:k,Gj:!1,kg:l});return p}function dl(a,b){if(a.fa&&a.C()&&($k(a),a.$A))switch(a.qg=(b-a.vf)/a.M-a.nk/2,0>a.qg&&(a.qg=0),1<a.qg+a.nk&&(a.qg=1-a.nk),a.mode){case 0:Xk(a);break;case 1:Yk(a);break;case 2:Wk(a)}}
function $k(a){a.fa&&a.C()&&(a.wm=a.margin+1,a.vf=a.margin+a.pi+a.ny+1,a.O=a.hb.width-2*a.margin-2,a.M=a.hb.height-a.vf-a.margin-2)}
function al(a){var b,c,d,g,k,l,m,p;if(a.fa&&a.C()){b=a.margin;c=b+a.pi;d=a.hb.width;g=a.hb.height;k=Math.min(100,Math.round((d-4*b)/3));l=a.ny-b;m=a.OF+"px "+a.NF;pa(f,a.hb);f.clearColor(a.DD);$k(a);for(p=0;3>p;p+=1)ra(f,b+p*(k+b),c,k,l+y(6),y(6),p===a.mode?a.oy:a.JQ);f.dg("Info",b+y(8),c+Math.round(.65*l),a.py,m);f.dg("Watch",b+(k+b)+y(8),c+Math.round(.65*l),a.py,m);f.dg("Messages",b+2*(k+b)+y(8),c+Math.round(.65*l),a.py,m);qa(0,c+l,d,g-c-l,a.oy,"black");d=b+a.mode*(k+b)+1;g=c+l;b=b+a.mode*(k+b)+
k-2;c+=l;l=a.oy;k=f;k.context.save();k.context.beginPath();k.context.moveTo(d,g);k.context.lineTo(b,c);k.context.lineWidth=2;k.context.strokeStyle=l;k.context.stroke();k.context.restore();qa(a.wm-1,a.vf-1,a.O+2,a.M+2,a.EJ,"black");el(a);fl(a)}}
function el(a){var b,c,d,g;a.fa&&a.C()&&(c=b=a.margin,d=a.pi-a.margin,pa(f,a.hb),ra(f,b,c,d,d,y(6),a.Xo),g=a.Ci?pd:qd,g.B(0,b+d/2,c+d/2),b+=d+a.margin,ra(f,b,c,d,d,y(6),a.Xo),sd.B(0,b+d/2,c+d/2),b+=d+a.margin,ra(f,b,c,d,d,y(6),a.Xo),rd.B(0,b+d/2,c+d/2),b+=d+a.margin,ra(f,b,c,d,d,y(6),a.Xo),td.B(0,b+d/2,c+d/2),b+=d+a.margin,ra(f,b,c,d,d,y(6),a.Xo),ud.B(0,b+d/2,c+d/2))}
function fl(a){var b,c,d,g,k;a.fa&&a.C()&&a.PA&&(b=a.hb.width,k=a.OF+"px "+a.NF,c=b-f.Lr(a.ot,k)-y(10),d=Math.round(1.2*a.pi/3),g=Math.round(2.8*a.pi/3),pa(f,a.hb),qa(c,0,b-c,a.pi,a.DD),f.dg(a.ot,c,d,a.FJ,k),f.dg(tk.Xf,c,g,a.FJ,k))}
function bl(a,b){var c,d;if(a.fa&&a.C()){pa(f,a.hb);$k(a);c=Math.floor(a.M/a.vg);a.nk=0===b.length?1:Math.min(1,c/b.length);1<a.qg+a.nk&&(a.qg=1-a.nk);var g,k;a.fa&&a.C()&&(c=a.fB,g=a.wm+a.O-c,d=a.vf+Math.round(a.qg*a.M),k=Math.round(a.nk*a.M),pa(f,a.hb),qa(g,a.vf,c,a.M,a.xV),qa(g+2,d+2,c-4,k-4,a.wV,"black"));f.context.save();f.context.beginPath();f.context.rect(a.wm,a.vf,a.O-a.fB,a.M);f.context.clip();qa(a.wm,a.vf,a.O,a.M,a.EJ);for(c=0;c<b.length;c+=1)if(d=a.vf+c*a.vg-a.qg*b.length*a.vg,!(d<=a.vf-
a.vg||d>=a.vf+a.M)){g=a;var l=a.wm,m=d;d=b[c];var p=k=void 0;if(void 0!==d){f.dg(d.text,l+(d.kg+1)*g.textIndent,m+Math.round(.75*g.vg),d.color,d.font);k=l+(d.kg+.5)*g.textIndent;p=m+g.vg/2;if("disk"===d.icon){var l=f,m=k,w=p,z=y(4),v=g.BB;l.context.save();l.context.beginPath();l.context.arc(m,w,z,0,2*Math.PI,!1);l.context.closePath();void 0!==v&&(l.context.fillStyle=v,l.context.fill());l.context.restore()}"arrowR"===d.icon&&sa(f,[k-y(4),k-y(4),k+y(4)],[p-y(4),p+y(4),p],g.BB);"arrowD"===d.icon&&sa(f,
[k-y(4),k+y(4),k],[p-y(4),p-y(4),p+y(4)],g.BB)}}f.context.restore()}}e.Qa=function(){this.fa&&this.C()&&this.i()};e.wa=function(){this.fa&&this.C()&&this.Cu&&(Ub(),Vb(this),this.Ci=!0,this.Cu=!1,el(this))};
e.Sa=function(a,b,c){var d="X";if(this.fa&&(""===this.Zu||void 0!==this.hb&&null!==this.hb||(b<f.width/3&&c<f.height/3&&(d="A"),b>2*f.width/3&&c<f.height/3&&(d="B"),b<f.width/3&&c>2*f.height/3&&(d="C"),b>2*f.width/3&&c>2*f.height/3&&(d="D"),this.sk+=d,0!==this.Zu.indexOf(this.sk)&&(this.sk="",this.Xn=0),this.sk===this.Zu&&(this.show(),this.sk="",this.Xn=0)),this.C())){var d=this.hb,g=r.k;b=g&&d?g.wf-d.wf+b:b;c=jk(this.hb,c);if(0<=b&&b<this.hb.width&&0<=c&&c<this.hb.height){this.bz=!0;this.UG=a;a=
Math.min(100,Math.round((this.hb.width-4*this.margin)/3));var k;if(this.fa&&this.C())if($k(this),c<this.pi){if(k=Math.floor((b-this.margin/2)/this.pi),this.fa&&this.C())switch(k){case 0:this.Ci=!this.Ci;this.Cu=!1;this.Ci?(Ub(),Vb(this)):(Qb(this),Wb());el(this);break;case 1:this.Ci&&(Qb(this),Wb(),this.Ci=!1);this.Cu=!0;break;case 2:location.reload(this.KP);break;case 3:this.i();this.show(!this.jL);break;case 4:this.i()}}else if(c<this.pi+this.ny)switch(k=Math.floor((b-this.margin/2)/(a+this.margin)),
k){case 0:this.fa&&this.C()&&0!==this.mode&&(this.qg=this.mode=0,al(this),Xk(this));break;case 1:this.fa&&this.C()&&1!==this.mode&&(this.mode=1,this.qg=0,al(this),Yk(this));break;case 2:Zk(this)}else if(c<=this.vf+this.M&&b>=this.wm+this.O-this.fB)this.$A=!0;else if(1===this.mode&&c<=this.vf+this.M&&(a=Math.floor(this.qg*this.Ic.length+(c-this.vf)/this.vg),0<=a&&a<this.Ic.length))if(this.Ic[a].Gj){if(this.fa&&this.C()&&!(0>a||a>=this.Ic.length)&&(k=this.Ic[a],void 0!==k&&k.Gj)){k.Gj=!1;for(b=0;a+
b+1<this.Ic.length&&this.Ic[a+b+1].kg>k.kg;)b+=1;this.Ic.splice(a+1,b);Yk(this)}}else if(g=0,this.fa&&this.C()&&!(0>a||a>=this.Ic.length)&&(d=this.Ic[a],void 0!==d&&!d.Gj)){b=d.$G;void 0!==b&&void 0!==d.Gu&&(b=b[d.Gu]);if("[object Array]"===Object.prototype.toString.call(b))for(d.Gj=!0,k=b.length-1;0<=k;k-=1)cl(this,a+1,k.toString(),b,k.toString(),d.color,d.kg+1)&&(g+=1);else if("object"===typeof b)for(k in d.Gj=!0,b)(b.hasOwnProperty(k)||!this.eX)&&cl(this,a+1,k,b,k,d.color,d.kg+1)&&(g+=1);if(this.zV)for(k=
a+g,a+=1;a<k;a+=1)for(b=a+1;b<=k;b+=1)this.Ic[b].name<this.Ic[a].name&&(d=this.Ic[a],this.Ic[a]=this.Ic[b],this.Ic[b]=d);Yk(this)}dl(this,c);return!0}}};e.qb=function(a){if(this.fa&&this.C()&&this.bz&&this.UG===a)return this.bz=!1,this.fa&&this.C()&&this.$A&&(this.$A=!1),!0};e.pb=function(a){this.fa&&this.C(!1)&&a===this.AW&&this.toggle()};
e.Ga=function(a){if(this.fa&&(""===this.Zu||void 0!==this.hb&&null!==this.hb||(""!==this.sk&&(this.Xn+=a/1E3),this.Xn>this.cW&&(this.Xn=0,this.sk="")),this.C())){if(this.PA&&(this.pt+=a/1E3,this.pt>=this.NP)){a:{var b=Math.round((q.Rr-this.lG)/((q.hg-this.iG)/1E3));if(this.fa){this.iG=q.hg;this.lG=q.Rr;b="fps: "+b;if(b!==this.ot&&(this.ot=b,!this.hb))break a;fl(this)}}this.pt=0}0<this.PB&&(this.Vb+=a/1E3,this.Vb>=this.PB&&(this.fa&&this.C()&&0===this.mode&&Xk(this),this.fa&&this.C()&&1===this.mode&&
Yk(this),this.Vb=0));this.bz&&(a=jk(this.hb,q.Uc(this.UG)),dl(this,a))}};var gl=new Vk;V.rP={Z_:!0,c0:!0,W_:!0,hV:!1,rV:!1,I_:!1,L_:!1,G_:!0,H_:!0,K_:!0,J_:"console",Nk:{width:y(640),height:y(400),Yc:y(200),dK:-280,eK:150,cK:{l:"ff_tgf_normal",fontSize:14,align:"left",ua:"top"}}};function hl(){}
hl.prototype.n=function(a){this.Na(V.rP);this.Na(a);this.dm="F: "+il.id+"_"+il.version;V.la&&(this.dm+=", G: "+V.la.id+"_"+V.la.version);V.lf&&(this.dm+=", T: "+V.lf.id+"_"+V.lf.version);V.ia&&(this.dm+=", C: "+V.ia.id+"_"+V.ia.version)};hl.prototype.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
hl.prototype.show=function(a,b,c,d){var g="",k=new jl(this.Nk);k.f({Fd:a,ef:b,buttons:[{text:"Close"}]});c&&this.hV&&"error"===d&&(g+="Error Id: "+c+"\n");this.rV&&"error"===d&&(""===g&&(g="\n"),g+="Version: "+this.dm);""!==g&&k.e.push(new F({x:void 0!==this.Nk.dK?this.Nk.dK:-k.width/2+k.marginLeft,y:void 0!==this.Nk.eK?this.Nk.eK:k.height/2-k.marginBottom-y(12),font:void 0!==this.Nk.cK?this.Nk.cK:{l:"ff_tgf_normal",fontSize:14,align:"left",ua:"top"},text:g}));switch(d){case "message":k.xa=nd;break;
case "warning":k.xa=md;break;default:k.xa=od}k.Ia=function(a){a.i();Wb()};Ub();k.show()};var kl=new hl;V.AM={zI:Si,ht:["sfx","effect","game"],nu:"music",gt:!0,lu:!0,ft:!0,ku:!0,Mi:!1,yi:!1,vl:1,Yk:1};function ll(){}e=ll.prototype;e.n=function(a){var b=pk(qk);this.Na(V.AM);this.Na(a);ml(this);void 0!==b.Yk&&(this.Yk=b.Yk);void 0!==b.vl&&(this.vl=b.vl);void 0!==b.yi&&(this.yi=b.yi);void 0!==b.Mi&&(this.Mi=b.Mi);nl(this,this.Yk);ol(this,this.vl);this.yi?pl(this):ql(this);this.Mi?rl(this):sl(this)};
e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};function ml(a){void 0!==a.zI&&(a.AI=!1,a.En=function(){a.AI||(a.AI=!0,n.play(a.zI),window.removeEventListener("click",a.En,!1),window.removeEventListener("mousedown",a.En,!1),window.removeEventListener("touchstart",a.En,!1))},window.addEventListener("click",a.En,!1),window.addEventListener("mousedown",a.En,!1),window.addEventListener("touchstart",a.En,!1))}
function pl(a){var b=[].concat(a.ht);if(a.gt&&a.ft)for(a=0;a<b.length;a+=1)qb(b[a])}function rl(a){var b=[].concat(a.nu);if(a.lu&&a.ku)for(a=0;a<b.length;a+=1)qb(b[a])}function ql(a){var b=[].concat(a.ht);if(a.gt&&a.ft)for(a=0;a<b.length;a+=1)rb(b[a])}function sl(a){var b=[].concat(a.nu);if(a.lu&&a.ku)for(a=0;a<b.length;a+=1)rb(b[a])}function nl(a,b){var c,d=[].concat(a.ht);if(a.gt&&a.ft)for(c=0;c<d.length;c+=1)cb(n,d[c],b)}
function ol(a,b){var c,d=[].concat(a.nu);if(a.lu&&a.ku)for(c=0;c<d.length;c+=1)cb(n,d[c],b)}e.play=function(a,b,c,d){var g;a:{g=a.zt();var k=[].concat(this.ht),l;for(l=0;l<k.length;l+=1)if(0<=g.indexOf(k[l])){g=!0;break a}g=!1}if(!(g=g&&this.gt&&this.ft)){a:{g=a.zt();k=[].concat(this.nu);for(l=0;l<k.length;l+=1)if(0<=g.indexOf(k[l])){g=!0;break a}g=!1}g=g&&this.lu&&this.ku}return g?n.play(a,b,c,d):void 0};e.stop=function(a,b,c){void 0!==a&&n.stop(a,b,c)};e.C=function(a){return void 0!==a?n.C(a):!1};
e.pause=function(a,b,c,d){void 0!==a&&n.pause(a,b,c,d)};e.Oi=function(a,b,c){void 0!==a&&n.Oi(a,b,c)};e.Ym=function(a){return void 0!==a?n.Ym(a):!1};e.Ij=function(a,b,c,d,g){void 0!==a&&n.Ij(a,b,c,d,g)};e.lk=function(a,b){void 0!==a&&n.lk(a,b)};var U=new ll;
V.TP={name:"Tingly Games Framework",id:"tgf",version:"3.0.0",load:{Li:"start startImages startAudio startFonts frameworkImages frameworkAudio frameworkFonts".split(" "),required:["start","startImages","frameworkImages"],ah:0,Gf:1},gR:!0,hR:!0,eR:!0,iR:!0,Jt:!0,fR:!0,VF:!0,It:!0,GT:!0,HT:!0,uP:[],vP:[]};function tl(){}e=tl.prototype;
e.n=function(a,b,c){var d=this;this.Na(V.TP);this.Na(a);this.gR&&kl.n(V.TE);this.hR&&r.n(V.AF);this.eR&&gl.n(V.console);this.iR&&sk.n(V.profile);this.Jt&&qk.n(V.WV,V.status);ul(this,this.uP,this.vP);this.Ze=this.Ye=!1;this.dq=b;this.cq=c;this.$e=0;this.vy=window.setInterval(function(){tl.prototype.Ow.call(d)},50)};
e.Ow=function(){0!==this.$e||this.Jt&&!qk.Ye&&!qk.Ze||(this.$e=1,this.fR&&tk.n(V.ct),this.VF&&(Rk.n(V.za),Rk.uB()));1===this.$e&&Nj()&&(this.$e=2,this.It&&U.n(V.Xc),ck(r));2===this.$e&&(this.Ye=!0,this.Ze=!1,this.Jt&&(this.Ye=this.Ye&&qk.Ye),this.Jt&&(this.Ze=this.Ze||qk.Ze),window.clearInterval(this.vy),this.Ye&&this.dq&&this.dq(),this.Ze&&this.cq&&this.cq(),this.Gv())};e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
function ul(a,b,c){var d=[],g=[];void 0===b&&(b=[]);void 0===c&&(c=[]);d=d.concat(a.load.Li);d=d.concat(b);g=g.concat(a.load.required);g=g.concat(c);Mj({Li:d,required:g,ah:a.load.ah,Gf:a.load.Gf})}e.Gv=function(){this.GT&&document.addEventListener("visibilitychange",this.nL,!1);this.HT&&(r.g.onfocus=this.mL,r.g.onblur=this.lL)};e.nL=function(){document.hidden?(n.pause("master"),q.pause()):Pj()};e.mL=function(){};e.lL=function(){};var il=new tl,G={};window.tgfHooks=G;
G.n=function(){G.getClientName||(G.getClientName=G.oQ);G.getClientId||(G.getClientId=G.mQ);G.getClientVersion||(G.getClientVersion=G.rQ);G.getAnalyticsTracking||(G.getAnalyticsTracking=G.kQ);G.getSiteLocks||(G.getSiteLocks=G.uF);G.getTimeLock||(G.getTimeLock=G.xQ);G.getInitialLanguage||(G.getInitialLanguage=G.sQ);G.getAvailableLanguages||(G.getAvailableLanguages=G.Ei);G.getMoreGamesUrl||(G.getMoreGamesUrl=G.yt);G.getMoreGamesFunction||(G.getMoreGamesFunction=G.ay);G.getSplashScreenImage||(G.getSplashScreenImage=
G.wQ);G.getSplashScreenColor||(G.getSplashScreenColor=G.uQ);G.getSplashScreenDuration||(G.getSplashScreenDuration=G.vQ);G.getClientLogo||(G.getClientLogo=G.nQ);G.getClientUrl||(G.getClientUrl=G.qQ);G.getClientFunction||(G.getClientFunction=G.lQ);G.getClientReplace||(G.getClientReplace=G.pQ);G.beforeInitializing||(G.beforeInitializing=G.uD);G.afterInitializing||(G.afterInitializing=G.LC);G.loadingProgress||(G.loadingProgress=G.bS);G.afterLoading||(G.afterLoading=G.oM);G.beforeTitleScreen||(G.beforeTitleScreen=
G.vD);G.beforeLevelScreen||(G.beforeLevelScreen=G.NM);G.beforePlay||(G.beforePlay=G.OM);G.playStart||(G.playStart=G.Rz);G.playWon||(G.playWon=G.EH);G.playLost||(G.playLost=G.BH);G.playStage||(G.playStage=G.VT);G.playEnd||(G.playEnd=G.AH);G.playRestart||(G.playRestart=G.CH);G.stepGame||(G.stepGame=G.XV);G.stepPlay||(G.stepPlay=G.YV);G.gameCompleted||(G.gameCompleted=G.oF);G.DU()};
G.DU=function(){V.ia=V.ia||{};G.getClientName&&(V.ia.name=G.cb("getClientName"));G.getClientId&&(V.ia.id=G.cb("getClientId"));G.getClientVersion&&(V.ia.version=G.cb("getClientVersion"));G.getAnalyticsTracking&&(V.ia.PC=G.cb("getAnalyticsTracking"));G.getInitialLanguage&&(V.ia.Xm=G.cb("getInitialLanguage"));G.getAvailableLanguages&&(V.ia.Hb=G.cb("getAvailableLanguages"));G.getMoreGamesUrl&&(V.ia.PZ=G.cb("getMoreGamesUrl"));G.getMoreGamesFunction&&(V.ia.QZ=G.cb("getMoreGamesFunction"));G.getSplashScreenImage&&
(V.ia.JI=G.cb("getSplashScreenImage"));G.getSplashScreenColor&&(V.ia.HI=G.cb("getSplashScreenColor"));G.getSplashScreenDuration&&(V.ia.II=G.cb("getSplashScreenDuration"));G.getClientLogo&&(V.ia.GZ=G.cb("getClientLogo"));G.getClientUrl&&(V.ia.JZ=G.cb("getClientUrl"));G.getClientFunction&&(V.ia.HZ=G.cb("getClientFunction"));G.getClientReplace&&(V.ia.IZ=G.cb("getClientReplace"))};G.cb=function(a,b,c,d,g){if(G[a])return G[a](b,c,d,g,void 0)};G.vH=function(){n.pause("master")};G.YH=function(){n.Oi("master")};
G.Bu=function(){vl.Bu()};G.Pi=function(){yb(q);Db(q);Fb(q);vl.Pi(!1)};G.xH=function(){wl()};G.ZH=function(){yb(q);Db(q);Fb(q);xl()};G.ck=function(){G.Bu();G.xH();G.vH()};G.Mf=function(){G.Pi();G.ZH();G.YH()};G.pauseFlow||(G.pauseFlow=G.Bu);G.resumeFlow||(G.resumeFlow=G.Pi);G.pauseGame||(G.pauseGame=G.xH);G.resumeGame||(G.resumeGame=G.ZH);G.pauseAudio||(G.pauseAudio=G.vH);G.resumeAudio||(G.resumeAudio=G.YH);G.pauseAll||(G.pauseAll=G.ck);G.resumeAll||(G.resumeAll=G.Mf);
G.DO=function(a,b){var c=b.width,d=b.height,g;g=new ta(a+"_Texture",1,a);g.b(0,b);g=new h(a,g,1,c,d,0,0,c,d,1);g.b(0,0,0,0,c,d,0,0);return g};G.EO=function(a,b,c,d){return va(a,b,c,d)};G.convertImage||(G.convertImage=G.DO);G.convertImageFile||(G.convertImageFile=G.EO);G.Vp=function(){return V.la.id};G.gameId||(G.gameId=G.Vp);G.oQ=function(){return"Unknown"};G.mQ=function(){return"unknown"};G.rQ=function(){return"1.0"};G.kQ=function(){return!0};G.uF=function(){};G.xQ=function(){};G.sQ=function(){};
G.Ei=function(){};G.yt=function(){};G.ay=function(){};G.wQ=function(){};G.uQ=function(){};G.vQ=function(){};G.nQ=function(){};G.qQ=function(){};G.lQ=function(){};G.pQ=function(){};G.uD=function(){};G.LC=function(){};G.bS=function(){};G.oM=function(){};G.vD=function(){};G.NM=function(){};G.OM=function(){};G.Rz=function(){};G.EH=function(){};G.BH=function(){};G.VT=function(){};G.AH=function(){};G.CH=function(){};G.XV=function(){};G.YV=function(){};G.oF=function(){};var yl={};V.J={};
function zl(a,b){function c(){}c.prototype=b.prototype;a.prototype=new c;a.Cb=b.prototype;a.prototype.constructor=a}function Al(a){switch(a){case "nothing":return Bl;case "show":return Cl;case "hide":return Dl;case "fadeIn":return El;case "fadeOut":return Fl;case "move":return Gl;case "scale":return Hl;case "rotate":return Il;case "alpha":return Jl;case "transform":return Kl;case "blink":return Ll;default:return Bl}}function Bl(){}function Cl(a){a.alpha=1}function Dl(a){a.alpha=0}
function El(a,b,c){a.alpha=(void 0===b.o?$b:b.o)(c,0,1,b.duration,b.K)}function Fl(a,b,c){a.alpha=(void 0===b.o?$b:b.o)(c,1,-1,b.duration,b.K)}function Gl(a,b,c){var d=void 0===b.o?$b:b.o,g=void 0===b.K?void 0:b.K,k=void 0===b.aa?0:b.aa,l=void 0===b.Aa?0:b.Aa,m=void 0===b.u?0:b.u,p=void 0===b.G?0:b.G;if(void 0!==b.aa||void 0!==b.Aa)a.x=d(c,k,l-k,b.duration,g);if(void 0!==b.u||void 0!==b.G)a.y=d(c,m,p-m,b.duration,g)}
function Il(a,b,c){var d=void 0===b.sB?0:b.sB;a.Oa=(void 0===b.o?$b:b.o)(c,d,(void 0===b.xx?0:b.xx)-d,b.duration,void 0===b.K?void 0:b.K)}function Hl(a,b,c){var d=void 0===b.qc?1:b.qc;a.mb=(void 0===b.o?$b:b.o)(c,d,(void 0===b.wb?1:b.wb)-d,b.duration,void 0===b.K?void 0:b.K);a.Fb=a.mb}function Jl(a,b,c){var d=void 0===b.Of?1:b.Of;a.alpha=(void 0===b.o?$b:b.o)(c,d,(void 0===b.Dj?1:b.Dj)-d,b.duration,void 0===b.K?void 0:b.K)}
function Kl(a,b,c){var d=void 0===b.o?$b:b.o,g=void 0===b.K?void 0:b.K,k=void 0===b.aa?0:b.aa,l=void 0===b.u?0:b.u,m=void 0===b.G?0:b.G,p=void 0===b.hP?d:b.hP,w=void 0===b.iP?g:b.iP,z=void 0===b.qc?1:b.qc,v=void 0===b.wb?1:b.wb,C=void 0===b.Wk?d:b.Wk,x=void 0===b.Cp?g:b.Cp,t=void 0===b.sB?0:b.sB,A=void 0===b.xx?0:b.xx,B=void 0===b.jP?d:b.jP,ja=void 0===b.kP?g:b.kP,xa=void 0===b.Of?1:b.Of,Xa=void 0===b.Dj?1:b.Dj,d=void 0===b.kx?d:b.kx,g=void 0===b.fP?g:b.fP;a.x=p(c,k,(void 0===b.Aa?0:b.Aa)-k,b.duration,
w);a.y=p(c,l,m-l,b.duration,w);a.mb=C(c,z,v-z,b.duration,x);a.Fb=a.mb;a.Oa=B(c,t,A-t,b.duration,ja);a.alpha=d(c,xa,Xa-xa,b.duration,g)}function Ll(a,b,c){var d=void 0===b.Ij?0:b.Ij;b=1/(2*(void 0===b.frequency?1:b.frequency));var g=c%b;a.alpha=0===Math.floor(c/b)%2?Math.min(1,g/d):1-Math.min(1,g/d)}V.J.Ra={gb:[],x:0,y:0,width:0,height:0,mb:1,Fb:1,Oa:0,alpha:1,S:null,wH:!1,yU:99999999,nP:2,cH:null,yb:null,Kh:null,dh:null};function s(a){this.n();void 0!==a&&this.f(a)}e=s.prototype;
e.n=function(a){this.f(V.J.Ra);this.f(a);this.parent=null;this.kind="component";this.C=this.eb=this.Wg=!1;this.t=[]};e.f=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};e.gf=function(a,b){var c,d,g=this.Oa*Math.PI/180;null!==this.parent?(c=this.parent.gf(a,b),d=this.parent.hf(a,b)):(c=a,d=b);c-=this.x;0!==this.Oa&&(c=c*Math.cos(g)-d*Math.sin(g));0!==this.mb&&1!==this.mb&&(c/=this.mb);return c};
e.hf=function(a,b){var c,d,g=this.Oa*Math.PI/180;null!==this.parent?(c=this.parent.gf(a,b),d=this.parent.hf(a,b)):(c=a,d=b);d-=this.y;0!==this.Oa&&(d=c*Math.sin(g)+d*Math.cos(g));0!==this.Fb&&1!==this.Fb&&(d/=this.Fb);return d};e.pp=function(a,b){var c,d,g=this.Oa*Math.PI/180;c=a*(0===this.mb?1:this.mb);d=b*(0===this.Fb?1:this.Fb);0!==this.Oa&&(c=c*Math.cos(g)-d*Math.sin(g),d=c*Math.sin(g)+d*Math.cos(g));return null!==this.parent?this.parent.pp(c+this.x,d+this.y):c+this.x};
e.qp=function(a,b){var c,d,g=this.Oa*Math.PI/180;c=a*(0===this.mb?1:this.mb);d=b*(0===this.Fb?1:this.Fb);0!==this.Oa&&(c=c*Math.cos(g)-d*Math.sin(g),d=c*Math.sin(g)+d*Math.cos(g));return null!==this.parent?this.parent.qp(c+this.x,d+this.y):d+this.y};e.Vs=function(a,b){return new da(this.pp(a,b),this.qp(a,b))};e.hd=function(a){return this.gf(q.hd(a),q.Uc(a))};e.Uc=function(a){return this.hf(q.hd(a),q.Uc(a))};e.Pc=function(){return void 0===this.width?0:this.width};
e.Oc=function(){return void 0===this.height?0:this.height};e.zt=function(){return this.gb.slice(0)};e.d=function(a){a.parent=this;this.t.push(a)};e.ya=function(){this.t=[]};function X(a,b){var c;a.xh=0;if("[object Array]"===Object.prototype.toString.call(a.S))for(void 0===b&&(b=0),0>b&&(b=0),b>=a.S.length&&(b=a.S.length-1),c=0;c<b;c+=1)a.xh+=Ml(a,a.S[c],!1)}
function Ml(a,b,c){var d,g,k=0;void 0===c&&(c=!0);if(null===b||"[object Array]"===Object.prototype.toString.call(b)&&0===b.length)return 0;if("[object Array]"!==Object.prototype.toString.call(b))return b.duration;for(d=0;d<b.length;d+=1)g=Ml(a,b[d],!c),k=c?k+g:Math.max(k,g);return k}function Nl(a,b){null===a.S||"[object Array]"===Object.prototype.toString.call(a.S)&&0===a.S.length||0>=a.Ep||(0<a.mx?a.mx-=1:a.xh+=b/1E3,a.xh>=a.OE&&(a.yb&&a.yb(a),a.Ep-=1,0>=a.Ep||(a.xh-=a.OE,a.cH&&a.cH(a))))}
function Ol(a,b,c,d,g){var k,l,m;if(null!==b&&("[object Array]"!==Object.prototype.toString.call(b)||0!==b.length))if("[object Array]"!==Object.prototype.toString.call(b))c<b.duration&&g.push({h:b,time:c});else if(d)for(k=l=0;k<b.length;k+=1){m=Ml(a,b[k],!d);if(l+m>c){Ol(a,b[k],c-l,!d,g);break}l+=m}else for(k=0;k<b.length;k+=1)Ol(a,b[k],c,!d,g)}e.br=function(a){void 0===a&&(a=!0);if(!(this.Wg||this.Cz&&this.Cz(this))&&(this.Wg=!0,this.w&&this.w(),a))for(a=0;a<this.t.length;a+=1)this.t[a].br()};
e.gg=function(a){void 0===a&&(a=!0);if(this.Wg&&(!this.vz||!this.vz(this))){this.eb&&this.i();this.Wg=!1;if(a)for(a=0;a<this.t.length;a+=1)this.t[a].gg();this.I&&this.I()}};
e.show=function(a){void 0===a&&(a=!0);if(!this.eb&&(this.Wg||this.br(),!this.xu||!this.xu())&&(this.eb=!0,null===this.S||"[object Array]"===Object.prototype.toString.call(this.S)&&0===this.S.length||(this.OE=Ml(this,this.S,!0),this.xh=0,this.mx=this.nP,this.Ep=this.yU,this.Dp=[]),this.da&&this.da(),a))for(a=0;a<this.t.length;a+=1)this.t[a].show()};
e.i=function(a){void 0===a&&(a=!0);if(this.eb&&(this.C&&this.ga(),!this.Ia||!this.Ia(this))){this.eb=!1;if(a)for(a=0;a<this.t.length;a+=1)this.t[a].i();this.pa&&this.pa()}};e.ka=function(a){void 0===a&&(a=!0);if(!(this.C||this.Iq&&this.Iq(this))&&(this.eb||this.show(),this.C=!0,a))for(this.$f&&this.$f(),a=0;a<this.t.length;a+=1)this.t[a].ka()};e.ga=function(a){void 0===a&&(a=!0);if(this.C&&(!this.sz||!this.sz(this))&&(this.C=!1,a))for(a=0;a<this.t.length;a+=1)this.t[a].ga()};
e.wa=function(a){var b;if(this.C&&this.eb){this.wH&&Nl(this,a);this.nT&&this.nT(this,a);if(this.sd&&this.sd(a))return!0;for(b=0;b<this.t.length;b+=1)if(this.t[b].wa(a))return!0}};e.Sa=function(a,b,c){var d;if(this.C&&this.eb){for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Sa(a,b,c))return!0;d=this.gf(b,c);b=this.hf(b,c);this.ak&&this.ak(this,a,d,b);if(this.me&&this.me(a,d,b))return!0}};
e.qb=function(a,b,c){var d;if(this.C&&this.eb){for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].qb(a,b,c))return!0;d=this.gf(b,c);b=this.hf(b,c);this.vT&&this.vT(this,a,d,b);if(this.Bf&&this.Bf(a,d,b))return!0}};e.Ug=function(a,b,c){var d;if(this.C&&this.eb){for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Ug(a,b,c))return!0;d=this.gf(b,c);b=this.hf(b,c);this.tT&&this.tT(this,a,d,b);if(this.Qk&&this.Qk(a,d,b))return!0}};
e.el=function(a,b,c){var d;if(this.C&&this.eb){for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].el(a,b,c))return!0;d=this.gf(b,c);b=this.hf(b,c);this.pT&&this.pT(this,a,d,b);if(this.zj&&this.zj(a,d,b))return!0}};e.Dh=function(a,b,c){var d;if(this.C&&this.eb){for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Dh(a,b,c))return!0;d=this.gf(b,c);b=this.hf(b,c);this.qT&&this.qT(this,a,d,b);if(this.Aj&&this.Aj(a,d,b))return!0}};
e.pb=function(a){var b;if(this.C&&this.eb){this.rT&&this.rT(this,a);if(this.Bj&&this.Bj(a))return!0;for(b=0;b<this.t.length;b+=1)if(this.t[b].pb(a))return!0}};e.Jb=function(a){var b;if(this.C&&this.eb){this.sT&&this.sT(this,a);if(this.xi&&this.xi(a))return!0;for(b=0;b<this.t.length;b+=1)if(this.t[b].Jb(a))return!0}};e.Sb=function(a){var b;if(this.C&&this.eb)for(this.mT&&this.mT(this,a),b=0;b<this.t.length;b+=1)if(this.t[b].Sb(a))return!0};
e.xb=function(a,b){var c;if(this.C&&this.eb){this.Bl&&this.Bl(this,a,b);if(this.wh&&this.wh(a,b))return!0;for(c=0;c<this.t.length;c+=1)if(this.t[c].xb(a,b))return!0}};e.Ga=function(a){var b;if(this.C&&this.eb){this.oT&&this.oT(this,a);if(this.$c&&this.$c(a))return!0;for(b=0;b<this.t.length;b+=1)if(this.t[b].Ga(a))return!0}};
function Pl(a,b){var c;if(a.eb){a.wH||Nl(a,b);c=[];var d,g,k,l;if(null!==a.S&&!("[object Array]"===Object.prototype.toString.call(a.S)&&0===a.S.length||0>=a.Ep)){Ol(a,a.S,a.xh,!0,c);for(k=0;k<a.Dp.length;k+=1){d=a.Dp[k];l=!1;for(g=0;g<c.length;g+=1)if(c[g].h===d.h){l=!0;break}l||("function"===typeof d.h.h?d.h.h(a,d.h,d.h.duration):Al(d.h.h)(a,d.h,d.h.duration),a.dh&&a.dh(a,d.h))}for(k=0;k<c.length;k+=1){d=c[k];l=!1;for(g=0;g<a.Dp.length;g+=1)if(a.Dp[g].h===d.h){l=!0;break}l||(a.Kh&&a.Kh(a,d.h),"function"===
typeof d.h.h?d.h.h(a,d.h,0):Al(d.h.h)(a,d.h,0))}for(g=0;g<c.length;g+=1)d=c[g],"function"===typeof d.h.h?d.h.h(a,d.h,d.time):Al(d.h.h)(a,d.h,d.time);a.Dp=c}a.wT&&a.wT(a,b);if(a.Cf&&a.Cf(b))return!0;for(c=0;c<a.t.length;c+=1)if(Pl(a.t[c],b))return!0}}
e.Ha=function(){var a;if(this.eb&&!(1E-6>Math.abs(this.mb)||1E-6>Math.abs(this.Fb))){f.context.save();f.context.translate(this.x,this.y);1===this.mb&&1===this.Fb||f.context.scale(this.mb,this.Fb);0!==this.Oa&&f.context.rotate(-this.Oa*Math.PI/180);f.context.globalAlpha*=this.alpha;this.tz&&this.tz(this);if(this.jc&&this.jc())return f.context.restore(),!0;for(a=0;a<this.t.length;a+=1)if(this.t[a].Ha())return f.context.restore(),!0;this.gH&&this.gH(this);if(this.ag&&this.ag())return f.context.restore(),
!0;f.context.restore()}};V.J.xB={e:[]};function Ql(a){this.name="Template";this.n(V.J.xB);void 0!==a&&this.f(a)}zl(Ql,s);e=Ql.prototype;e.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};e.sd=function(){};e.me=function(){};e.Bf=function(){};e.Qk=function(){};e.zj=function(){};e.Aj=function(){};e.Bj=function(){};e.xi=function(){};e.wh=function(){};e.$c=function(){};e.Cf=function(){};e.jc=function(){};
e.ag=function(){};V.J.NU={On:!0,Mu:!0,O:0,M:0,gD:0,hD:0,clip:!0,gV:!1,sV:!1,vc:!0,kI:null,SQ:null,aX:null,ik:600,e:[]};function Rl(a){this.name="ScrollBox";this.n(V.J.NU);void 0!==a&&this.f(a);this.cd=new da(0,0);this.jk=new da(0,0);this.Nn=new da(0,0);this.mC=[];this.scroll=new da(0,0);this.hv=new da(0,0);this.Rs=new da(0,0)}zl(Rl,s);e=Rl.prototype;
e.w=function(){var a;Math.round(this.width/2);Math.round(this.height/2);this.scroll.x=0;this.scroll.y=0;this.cj=new da(0,0);this.gv=new da(0,0);this.speed=new da(0,0);this.sV&&this.Mu&&(this.fc=new Sl,this.fc.f(this.kI),this.fc.f(this.aX),this.fc.x=(this.width-this.fc.Pc())/2,this.fc.y=0,this.fc.height=this.height,this.d(this.fc),this.fc.Pc());this.gV&&this.On&&(this.$b=new Sl({direction:Tl}),this.$b.f(this.kI),this.$b.f(this.SQ),this.$b.x=0,this.$b.y=(this.height-this.$b.Oc())/2,this.$b.width=this.width,
this.d(this.$b),this.$b.Oc());this.fc&&this.$b&&(this.fc.height-=this.$b.Oc(),this.fc.y-=this.$b.Oc()/2,this.$b.width-=this.fc.Pc(),this.$b.x-=this.fc.Pc()/2);this.ha=-1;this.H=new za(this.width-(this.fc?this.fc.Pc():0),this.height-(this.$b?this.$b.Oc():0));this.g=new s({x:this.scroll.x,y:this.scroll.y});this.H.context.translate(Math.round(this.width/2),Math.round(this.height/2));this.d(this.g);this.Rs.x=-Math.round(this.width-this.H.width)/2;this.Rs.y=-Math.round(this.height-this.H.height)/2;if(this.e)for(a=
0;a<this.e.length;a+=1)this.g.d(this.e[a]);this.TI&&(this.Mu?(a=-(Math.max(this.M,this.H.height)-this.H.height),this.scroll.y=this.TI*a):this.On&&(a=-(Math.max(this.O,this.H.width)-this.H.width),this.scroll.x=this.TI*a))};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};function Ul(a){return a.LP?a.LP:-(Math.max(a.O,a.H.width)-a.H.width)}function Vl(a){return a.MP?a.MP:-(Math.max(a.M,a.H.height)-a.H.height)}e.sd=function(){};
e.me=function(a,b,c){var d=Math.round(this.width),g=Math.round(this.height);if(b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&(this.ha=a,b=this.hd(this.ha),c=this.Uc(this.ha),this.cd.x=0,this.cd.y=0,this.cj.x=b,this.cj.y=c,this.hv.x=this.scroll.x,this.hv.y=this.scroll.y,this.vc))return!0};
e.Qk=function(a,b,c){var d=Math.round(this.width),g=Math.round(this.height);b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&(this.Mu?(this.scroll.y+=100*a,a=this.Pp?this.Pp:0,b=Vl(this),this.scroll.y>a&&(this.scroll.y=0),this.scroll.y<b&&(this.scroll.y=b)):this.On&&(this.scroll.x+=100*a,a=this.Op?this.Op:0,b=Ul(this),this.scroll.x>a&&(this.scroll.x=0),this.scroll.x<b&&(this.scroll.x=b)))};e.Bf=function(a){this.ha===a&&(this.ha=-1,Wl(this),Xl(this))};
function Wl(a){var b=a.Op?a.Op:0,c=Ul(a);a.scroll.x>b&&(a.cd.x=a.ik,a.jk.x=a.scroll.x,a.Nn.x=b);a.scroll.x<c&&(a.cd.x=a.ik,a.jk.x=a.scroll.x,a.Nn.x=c)}function Xl(a){var b=a.Pp?a.Pp:0,c=Vl(a);a.scroll.y>b&&(a.cd.y=a.ik,a.jk.y=a.scroll.y,a.Nn.y=b);a.scroll.y<c&&(a.cd.y=a.ik,a.jk.y=a.scroll.y,a.Nn.y=c)}e.Bj=function(){};e.xi=function(){};e.wh=function(){};
e.$c=function(a){var b,c,d,g,k,l=Math.max(this.M,this.H.height),m=Math.max(this.O,this.H.width);g=Ul(this);d=Vl(this);c=this.Op?this.Op:0;k=this.Pp?this.Pp:0;if(-1!==this.ha)this.On&&(b=this.hd(this.ha),this.gv.x=b,b=this.hv.x+this.gv.x-this.cj.x,this.speed.x=(this.speed.x+(b-this.scroll.x)/(a/1E3))/2,this.scroll.x=b,this.scroll.x>c&&(this.scroll.x=c+Math.min(this.H.width/2,bc(b-c,0,this.H.width/2,this.H.width))/2),this.scroll.x<g&&(this.scroll.x=g+Math.max(-this.H.width/2,bc(b-g,0,-this.H.width/
2,-this.H.width))/2)),this.Mu&&(c=this.Uc(this.ha),this.gv.y=c,c=this.hv.y+this.gv.y-this.cj.y,this.speed.y=(this.speed.y+(c-this.scroll.y)/(a/1E3))/2,this.scroll.y=c,this.scroll.y>k&&(this.scroll.y=k+Math.min(this.H.height/2,bc(c-k,0,this.H.height/2,this.H.height))/2),this.scroll.y<d&&(this.scroll.y=d+Math.max(-this.H.height/2,bc(c-d,0,-this.H.height/2,-this.H.height))/2));else{if(0<this.cd.x)this.cd.x-=a,this.cd.x=Math.max(0,this.cd.x),this.scroll.x=ic(this.ik-this.cd.x,this.jk.x,this.Nn.x-this.jk.x,
this.ik),this.speed.x=0;else if(0<Math.abs(this.speed.x))if(this.speed.x*=Math.pow(.99,a),1<Math.abs(this.speed.x)){if(this.scroll.x+=a/1E3*this.speed.x,0<this.scroll.x||this.scroll.x<g)this.speed.x=0,Wl(this)}else this.speed.x=0;if(0<this.cd.y)this.cd.y-=a,this.cd.y=Math.max(0,this.cd.y),this.scroll.y=ic(this.ik-this.cd.y,this.jk.y,this.Nn.y-this.jk.y,this.ik),this.speed.y=0;else if(0<Math.abs(this.speed.y))if(this.speed.y*=Math.pow(.99,a),1<Math.abs(this.speed.y)){if(this.scroll.y+=a/1E3*this.speed.y,
0<this.scroll.y||this.scroll.y<d)this.speed.y=0,Xl(this)}else this.speed.y=0}this.fc&&(this.fc.Jl=l-this.H.height,this.fc.Il=Math.min(-d,Math.max(0,-this.scroll.y)),void 0!==this.fc.fo&&(this.scroll.y=-this.fc.fo));this.$b&&(this.$b.Jl=m-this.H.width,this.$b.Il=Math.min(-g,Math.max(0,-this.scroll.x)),void 0!==this.$b.fo&&(this.scroll.x=-this.$b.fo));this.g.x=this.scroll.x+this.Rs.x;this.g.y=this.scroll.y+this.Rs.y};e.d=function(a){Rl.Cb.d.call(this,a);a!==this.g&&this.mC.push(a)};e.Cf=function(){};
e.jc=function(){var a=Math.round(this.width/2),b=Math.round(this.height/2);Aa(this.H);this.H.context.clearRect(-a,-b,this.H.width,this.H.height);this.g.Ha();Ba(this.H);this.H.B(-this.width/2,-this.height/2);this.vC=this.t;this.t=this.mC};e.ag=function(){this.t=this.vC};V.J.GR={width:y(400),height:y(400),xs:"top",tE:y(90),Fm:y(8),Lo:!0,Mo:!0,e:[]};function Yl(a){this.name="LayoutVertical";this.n(V.J.GR);void 0!==a&&this.f(a)}zl(Yl,s);
Yl.prototype.Fy=function(){var a,b,c,d,g,k;b=[].concat(this.Mo);c=[].concat(this.Lo);d=[].concat(this.tE);for(a=g=0;a<this.e.length;a+=1)k=d[a%d.length],b[a%b.length]&&(this.e[a].width=this.width),c[a%c.length]&&(this.e[a].height=k),g+=k;g+=(this.e.length-1)*this.Fm;b=this.Fm;switch(this.xs){case "top":c=-this.height/2;break;case "middle":c=-g/2;break;case "bottom":c=this.height/2-g;break;case "spread":c=-this.height/2;b+=(this.height-g)/(this.e.length-1);break;default:c=-this.height/2}for(a=0;a<
this.e.length;a+=1)k=d[a%d.length],this.e[a].y=Math.round(c+k/2),c+=k+b};Yl.prototype.w=function(){var a;this.Fy();for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};V.J.FR={width:y(400),height:y(400),xs:"center",kO:y(90),Fm:y(8),Lo:!0,Mo:!0,e:[]};function Zl(a){this.name="LayoutHorizontal";this.n(V.J.FR);void 0!==a&&this.f(a)}zl(Zl,s);
Zl.prototype.Fy=function(){var a,b,c,d,g,k;b=[].concat(this.Mo);c=[].concat(this.Lo);d=[].concat(this.kO);for(a=g=0;a<this.e.length;a+=1)k=d[a%d.length],b[a%b.length]&&(this.e[a].width=k),c[a%c.length]&&(this.e[a].height=this.height),g+=k;g+=(this.e.length-1)*this.Fm;b=this.Fm;switch(this.xs){case "left":c=-this.width/2;break;case "center":c=-g/2;break;case "right":c=this.width/2-g;break;case "spread":c=-this.width/2;b+=(this.width-g)/(this.e.length-1);break;default:c=-this.width/2}for(a=0;a<this.e.length;a+=
1)k=d[a%d.length],this.e[a].x=Math.round(c+k/2),c+=k+b};Zl.prototype.w=function(){var a;this.Fy();for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};V.J.La={jt:!0,interval:1,repeat:99999999,e:[],$j:null};function $l(a){this.name="Timer";this.n(V.J.La);void 0!==a&&this.f(a)}zl($l,s);e=$l.prototype;e.Pc=function(){return y(32)};e.Oc=function(){return y(32)};e.reset=function(){this.Dc=0};e.w=function(){var a;this.reset();for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
e.sd=function(a){var b;this.jt&&(b=Math.floor(this.Dc/this.interval),this.Dc+=a/1E3,a=Math.floor(this.Dc/this.interval),b!==a&&a<=this.repeat&&this.$j&&this.$j(this))};V.J.g={e:[]};function am(a){this.name="Container";this.n(V.J.g);void 0!==a&&this.f(a)}zl(am,s);am.prototype.Pc=function(){return y(32)};am.prototype.Oc=function(){return y(32)};am.prototype.w=function(){var a;for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
V.J.label={text:"",s:"",font:R,align:void 0,ua:void 0,Sd:!0,pc:!1,Ca:y(20),nc:!0,e:[],j:null};function F(a){this.name="Label";this.n(V.J.label);void 0!==a&&this.f(a)}zl(F,s);e=F.prototype;e.Pc=function(){return this.ae.width-2*this.Ca};e.Oc=function(){return this.ae.height-2*this.Ca};e.Xa=function(){this.tp()};e.findText=function(){return""!==this.s?E(this.s,"<"+this.s+">"):void 0===this.text?"<UNDEFINED>":this.text};
e.tp=function(){var a,b,c,d,g,k,l,m,p=this.findText();this.font instanceof Fa?g=this.font:(g=new Fa,g.f(this.font));c=0<this.width?this.width:g.Lr(p);d=0<this.height?this.height:g.vg(p);k=g.align;void 0!==this.align&&Ma(g,this.align);l=g.ua;void 0!==this.ua&&Na(g,this.ua);switch(g.align){case "left":a=this.Ca;break;case "center":a=this.Ca+c/2;break;case "right":a=this.Ca+c}switch(g.ua){case "top":b=this.Ca;break;case "middle":b=this.Ca+d/2;break;case "bottom":b=this.Ca+d}this.nc&&(a=Math.floor(a),
b=Math.floor(b));this.ae=new za(c+2*this.Ca,d+2*this.Ca);Aa(this.ae);c=g.fontSize;this.Sd&&0<this.width&&(m=this.height,0>=m&&(m=d),d=Va(g,p,this.width,m,this.pc),d<c&&Ga(g,d));this.pc&&0<this.width?g.B(p,a,b,this.width):g.B(p,a,b);Ga(g,c);void 0!==this.align&&Ma(g,k);void 0!==this.ua&&Na(g,l);Ba(this.ae)};e.w=function(){var a;this.tp();for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ae=void 0};
e.me=function(a,b,c){var d,g,k;if(null!==this.j){a=-this.ae.width/2;d=-this.ae.height/2;this.nc&&(a=Math.floor(a),d=Math.floor(d));switch(this.font.align){case "left":a=-this.Ca;break;case "right":a=-this.ae.width+this.Ca}switch(this.font.ua){case "top":d=-this.Ca;break;case "bottom":d=-this.ae.height+this.Ca}g=this.ae.width-2*this.Ca;k=this.ae.height-2*this.Ca;b>=a&&b<=a+g&&c>=d&&c<=d+k&&this.j(this)}};e.wh=function(a){"languageSet"===a&&this.tp()};
e.jc=function(){var a=-this.ae.width/2,b=-this.ae.height/2;this.nc&&(a=Math.floor(a),b=Math.floor(b));switch(this.font.align){case "left":a=-this.Ca;break;case "right":a=-this.ae.width+this.Ca}switch(this.font.ua){case "top":b=-this.Ca;break;case "bottom":b=-this.ae.height+this.Ca}this.ae.B(a,b)};V.J.LT={c:Rc,Nd:0,Ar:0,Eh:!0,hr:!0,Ng:!1,tb:!1,Xd:null,nc:!0,bu:!0,e:[],j:null};function u(a){this.name="Picture";this.n(V.J.LT);void 0!==a&&this.f(a)}zl(u,s);e=u.prototype;
e.Pc=function(){return 0<this.width?this.width:this.c?this.Ng?this.c.vj:this.c.width:0};e.Oc=function(){return 0<this.height?this.height:this.c?this.Ng?this.c.uj:this.c.height:0};e.w=function(){var a;for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.da=function(){this.ra=this.Ar;this.he=!0};
e.me=function(a,b,c){var d;this.j&&null!==this.c&&(this.Ng&&this.c instanceof h?(a=0<this.width?this.width:this.c.vj,d=0<this.height?this.height:this.c.uj):(a=0<this.width?this.width:this.c.width,d=0<this.height?this.height:this.c.height),b>=-a/2&&b<=a&&c>=-d/2&&c<=d/2&&this.j(this))};
e.Cf=function(a){null!==this.c&&this.c instanceof h&&this.he&&(this.ra+=this.Nd*a/1E3,0<this.Nd&&this.ra>=this.c.N?(this.Eh?this.ra-=this.c.N:(this.ra=this.c.N-1,this.he=!1),this.Xd&&this.Xd(this)):0>this.Nd&&0>this.ra&&(this.Eh?this.ra+=this.c.N:(this.ra=0,this.he=!1),this.Xd&&this.Xd(this)))};
e.jc=function(){var a,b,c,d,g,k;null!==this.c&&(this.c instanceof za?(b=0<this.width?this.width:this.c.width,c=0<this.height?this.height:this.c.height,d=-b/2,g=-c/2,this.nc&&(d=Math.floor(d),g=Math.floor(g)),this.tb?this.c.Mc(d,g,b,c,f.context.alpha,Math.floor(this.c.width/2)-2,Math.floor(this.c.width/2)-2,Math.floor(this.c.height/2)-2,Math.floor(this.c.height/2)-2):b===this.c.width&&c===this.c.height?this.c.B(d+this.c.Da,g+this.c.Ea):(this.bu&&(k=this.c.width/this.c.height,b/c<k?(g+=(c-b/k)/2,c=
b/k):(d+=(b-c*k)/2,b=c*k)),this.c.Og(d,g,b,c,f.context.alpha))):this.c instanceof h&&(b=0<this.width?this.width:this.c.width,c=0<this.height?this.height:this.c.height,d=-b/2,g=-c/2,this.nc&&(d=Math.floor(d),g=Math.floor(g)),a=this.hr?this.ra:Math.min(this.c.N-1,Math.floor(this.ra)),this.tb?this.c.Mc(a,d,g,b,c,f.context.alpha,Math.floor(this.c.width/2)-2,Math.floor(this.c.width/2)-2,Math.floor(this.c.height/2)-2,Math.floor(this.c.height/2)-2):this.Ng?(b=0<this.width?this.width:this.c.vj,c=0<this.height?
this.height:this.c.uj,d=-b/2,g=-c/2,this.nc&&(d=Math.floor(d),g=Math.floor(g)),b===this.c.vj&&c===this.c.uj?wa(this.c,d+this.c.Da,g+this.c.Ea):(this.bu&&(k=this.c.vj/this.c.uj,b/c<k?(g+=(c-b/k)/2,c=b/k):(d+=(b-c*k)/2,b=c*k)),a=this.c,k=f.context.alpha,0!==a.vj&&0!==a.uj&&(b/=a.vj,c/=a.uj,ya(a,d+a.Da*b,g+a.Ea*c,b,c,k)))):b===this.c.width&&c===this.c.height?this.c.B(a,d+this.c.Da,g+this.c.Ea):(this.bu&&(k=this.c.width/this.c.height,b/c<k?(g+=(c-b/k)/2,c=b/k):(d+=(b-c*k)/2,b=c*k)),this.c.Og(a,d,g,b,
c,f.context.alpha))))};V.J.Jf={ja:Qh,YQ:null,Vg:Ph,Te:"slice",xP:"right",$E:0,aF:0,ZE:0,YE:0,Nd:0,Ar:0,Eh:!0,hr:!0,NH:0,Hn:null,OH:100,nc:!0,e:[],tu:null,dH:null,Xd:null};function bm(a){this.name="ProgressBar";this.n(V.J.Jf);void 0!==a&&this.f(a)}zl(bm,s);e=bm.prototype;e.Pc=function(){return this.width?this.width:this.ja&&this.ja.width?this.ja.width:0};e.Oc=function(){return this.height?this.height:this.ja&&this.ja.height?this.ja.height:0};e.pg=function(a,b){this.Bb=a;b&&(this.Qd=this.Bb)};
e.tF=function(a){return a?this.Qd:this.Bb};e.w=function(){var a;for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.da=function(){this.ra=this.Ar;this.pg(this.NH,!0)};
e.Cf=function(a){var b,c,d;this.Hn&&(this.Bb=this.Hn());b=this.Qd;c=this.Bb-this.Qd;d=this.OH*a/1E3;this.Qd=Math.abs(c)<=d?this.Bb:0>c?this.Qd-d:this.Qd+d;this.Qd=Math.min(100,Math.max(0,this.Qd));100>b&&100<=this.Qd&&this.tu?this.tu(this):0<b&&0>=this.Qd&&this.dH&&this.dH(this);null!==this.ja&&this.ja instanceof h&&(a=this.ra+this.Nd*a/1E3,this.ra<this.ja.N&&a>=this.ja.N?(this.ra=this.Eh?a-this.ja.N:this.ja.N,this.Xd&&this.Xd(this)):0<this.ra&&0>a?(this.ra=this.Eh?this.ja.N+a:0,this.Xd&&this.Xd(this)):
this.ra=a)};
e.drawImage=function(a,b,c,d,g,k){var l;if(null!==a)if(a instanceof za)switch(k){case "slice":a.Mc(b,c,d,g,f.context.alpha,Math.floor(a.width/2)-2,Math.floor(a.width/2)-2,Math.floor(a.height/2)-2,Math.floor(a.height/2)-2);break;case "stretch":a.Og(b,c,d,g,f.context.alpha);break;case "tile":a.Uk(a.Da,a.Ea,b,c,d,g,f.context.alpha)}else if(a instanceof h)switch(l=this.hr?this.ra:Math.min(a.N-1,Math.floor(this.ra)),k){case "slice":a.Mc(l,b,c,d,g,f.context.alpha,Math.floor(a.width/2)-2,Math.floor(a.width/2)-
2,Math.floor(a.height/2)-2,Math.floor(a.height/2)-2);break;case "stretch":a.Og(l,b,c,d,g,f.context.alpha);break;case "tile":a.Uk(l,a.Da,a.Ea,b,c,d,g,f.context.alpha)}};
e.jc=function(){var a=0<this.width?this.width:this.ja.width,b=0<this.height?this.height:this.ja.height,c=-a/2,d=-b/2,g,k,l,m;this.nc&&(c=Math.floor(c),d=Math.floor(d));g=c+this.$E;k=d+this.aF;l=a+this.ZE;m=b+this.YE;this.drawImage(this.ja,c,d,a,b,"slice");switch(this.xP){case "right":l*=this.Qd/100;break;case "left":g+=l*(1-this.Qd/100);l*=this.Qd/100;break;case "down":m*=this.Qd/100;break;case "up":k+=m*(1-this.Qd/100),m*=this.Qd/100}this.drawImage(this.Vg,g,k,l,m,this.Te);this.drawImage(this.YQ,
c,d,a,b,"slice")};V.J.yj={width:void 0,height:void 0,Jm:"#000000",Rd:.6,duration:.2,TV:!0,e:[],bH:null,xz:null};function cm(a){this.name="Darkener";this.n(V.J.yj);void 0!==a&&this.f(a)}zl(cm,s);e=cm.prototype;e.Pc=function(){return this.width?this.width:f.width};e.Oc=function(){return this.height?this.height:f.height};function dm(a,b,c){void 0===b&&(b=a.duration);void 0===c&&(c=0);a.mode="lighting";a.Of=a.Rd;a.by=0;a.dx=b;a.xj=b+c}e.w=function(){var a;this.mode="idle";for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
e.da=function(){if(this.TV){var a,b;void 0===a&&(a=this.duration);void 0===b&&(b=0);this.mode="darkening";this.Of=0;this.by=this.Rd;this.dx=a;this.xj=a+b}};e.Cf=function(a){"idle"===this.mode||0>=this.xj||(this.xj-=a/1E3,0>=this.xj&&("darkening"===this.mode&&null!==this.bH&&this.bH(this),"lighting"===this.mode&&null!==this.xz&&this.xz(this)))};
e.jc=function(){var a=0,b,c=this.Pc(),d=this.Oc();f.canvas===r.k&&"idle"!==this.mode&&(a=this.xj>=this.dx?this.Of:0>=this.xj?this.by:this.Of+(1-this.xj/this.dx)*(this.by-this.Of),0!==a&&(b=f.context.globalAlpha,f.context.globalAlpha*=a,qa(-c/2,-d/2,c,d,this.Jm),f.context.globalAlpha=b))};
V.J.button={c:P,tb:!0,marginLeft:y(24),marginRight:y(24),marginTop:y(24),marginBottom:y(24),icon:null,qa:"left",Ue:y(24),text:"",s:"",al:null,T:S,pc:!1,Gq:0,Hq:0,Fq:0,lg:0,Nf:Aj,ur:null,$a:0,bj:!1,Ua:0,Va:0,Fe:null,Oo:!1,gk:!1,vc:!0,nh:!1,nc:!0,e:[],j:null,tM:1E4};function D(a){this.name="Button";this.n(V.J.button);this.cj=new da(0,0);void 0!==a&&this.f(a)}zl(D,s);e=D.prototype;e.Pc=function(){return this.ta.width};e.Oc=function(){return this.ta.height};e.Xa=function(){this.Af()};
e.findText=function(){var a=this.text,b=this.s;"[object Array]"===Object.prototype.toString.call(this.text)&&(a=this.text[this.$a%this.text.length]);"[object Array]"===Object.prototype.toString.call(this.s)&&(b=this.s[this.$a%this.s.length]);""!==b&&(a=E(b,"<"+b+">"));return a};
e.zp=function(a,b){var c="up"===b?0:1,d=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(d=this.c[this.$a%this.c.length]);if(d)if(d instanceof za)if(this.tb){var g=this.gT||0,k=this.hT||0;d.Mc(0,0,a.width,a.height,1,Math.floor(d.width/2)-2+g,Math.floor(d.width/2)-2-g,Math.floor(d.height/2)-2+k,Math.floor(d.height/2)-2-k)}else a.width===d.width&&a.height===d.height?d.B(d.Da,d.Ea):d.Og(0,0,a.width,a.height,1);else d instanceof h&&(this.tb?(g=this.gT||0,k=this.hT||0,d.Mc(c,
0,0,a.width,a.height,1,Math.floor(d.width/2)-2+g,Math.floor(d.width/2)-2-g,Math.floor(d.height/2)-2+k,Math.floor(d.height/2)-2-k)):a.width===d.width&&a.height===d.height?d.B(c,d.Da,d.Ea):d.Og(c,0,0,a.width,a.height,1))};
e.Ap=function(a,b){var c="up"===b?0:1,d,g,k=this.icon;this.icon&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(k=this.icon[this.$a%this.icon.length]);if(k){switch(this.qa){case "left":d=this.marginLeft;g=(a.height-k.height)/2;break;case "center":d=(a.width-k.width)/2;g=(a.height-k.height)/2;break;case "right":d=a.width-k.width-this.marginRight;g=(a.height-k.height)/2;break;case "top":d=(a.width-k.width)/2;g=this.marginTop;break;case "bottom":d=(a.width-k.width)/2,g=a.width-k.width-
this.marginBottom}this.nc&&(d=Math.floor(d),g=Math.floor(g));"down"===b?(d+=this.Fq,g+=this.lg):(d+=this.Gq,g+=this.Hq);k instanceof za?k.B(d+k.Da,g+k.Ea):k instanceof h&&k.B(c,d+k.Da,g+k.Ea)}};
e.dg=function(a,b){var c,d,g,k,l,m,p=this.findText();(l=this.icon)&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(l=this.icon[this.$a%this.icon.length]);c="down"===b?null!==this.al?this.al:this.T:null!==this.T?this.T:this.al;c instanceof Fa?m=c:(m=new Fa,m.f(c));c=this.marginLeft;d=this.marginTop;g=a.width-this.marginLeft-this.marginRight;k=a.height-this.marginTop-this.marginBottom;if(l)switch(this.qa){case "left":c+=l.width+this.Ue;g-=l.width+this.Ue;break;case "right":g-=l.width+
this.Ue;break;case "top":d+=l.height+this.Ue;k-=l.height+this.Ue;break;case "bottom":k-=l.height+this.Ue}switch(m.align){case "center":c+=g/2;break;case "right":c+=g}switch(m.ua){case "middle":d+=k/2;break;case "bottom":d+=k}this.nc&&(c=Math.floor(c),d=Math.floor(d));"down"===b?(c+=this.Fq,d+=this.lg):(c+=this.Gq,d+=this.Hq);l=m.fontSize;k=Va(m,p,g,k,this.pc);k<l&&Ga(m,k);this.pc?m.B(p,c,d,g):m.B(p,c,d);Ga(m,l)};
e.Af=function(){var a=this.width,b=this.height,c=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(c=this.c[this.Ua%this.c.length]);c&&0===a&&(a=c.width);c&&0===b&&(b=c.height);this.ta=new za(a,b);Aa(this.ta);this.zp(this.ta,"down");this.Ap(this.ta,"down");this.dg(this.ta,"down");Ba(this.ta);this.He=new za(a,b);Aa(this.He);this.zp(this.He,"up");this.Ap(this.He,"up");this.dg(this.He,"up");Ba(this.He)};
e.Yb=function(a,b){this.state!==a&&("down"===a?(this.state="down",b&&(this.Nf&&U.play(this.Nf),this.gk&&(this.bj&&1<this.Ua&&(this.$a=(this.$a+1)%this.Ua,this.Af()),this.j&&this.j(this)))):(this.state="up",b&&(this.ur&&U.play(this.ur),this.gk||(this.bj&&1<this.Ua&&(this.$a=(this.$a+1)%this.Ua,this.Af()),this.j&&this.j(this)))))};
e.w=function(){var a;0>=this.Ua&&(this.Ua=1,"[object Array]"===Object.prototype.toString.call(this.c)&&(this.Ua=Math.max(this.Ua,this.c.length)),"[object Array]"===Object.prototype.toString.call(this.icon)&&(this.Ua=Math.max(this.Ua,this.icon.length)),"[object Array]"===Object.prototype.toString.call(this.text)&&(this.Ua=Math.max(this.Ua,this.text.length)),"[object Array]"===Object.prototype.toString.call(this.s)&&(this.Ua=Math.max(this.Ua,this.s.length)));this.Af();this.Yb("up",!1);this.ha=-1;for(a=
0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.He=this.ta=void 0};e.me=function(a,b,c){if(!this.nh)return this.Rk(a,b,c)};e.Bf=function(a,b,c){if(!this.nh)return this.Sk(a,b,c)};e.zj=function(a,b,c){if(this.nh)return this.Rk(a,b,c)};e.Aj=function(a,b,c){if(this.nh)return this.Sk(a,b,c)};e.Rk=function(a,b,c){var d=this.ta.width+2*this.Va,g=this.ta.height+2*this.Va;if(b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&("up"===this.state&&(this.Yb("down",!0),this.ha=a,this.cj=this.Vs(b,c)),this.vc))return!0};
e.Sk=function(a,b,c){var d=this.ta.width+2*this.Va,g=this.ta.height+2*this.Va;if(this.ha===a&&(this.ha=-1,b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&("down"===this.state&&this.Yb("up",!0),this.vc)))return!0};e.Bj=function(a){if(this.Oo||this.Fe&&a===this.Fe)if(this.Yb("down",!0),this.vc)return!0};e.xi=function(a){if(this.Oo||this.Fe&&a===this.Fe)if(this.Yb("up",!0),this.vc)return!0};
e.$c=function(){var a,b,c=this.ta.width+2*this.Va,d=this.ta.height+2*this.Va;-1!==this.ha&&(a=this.hd(this.ha),b=this.Uc(this.ha),this.Vs(a,b).bP(this.cj)>=this.tM?("down"===this.state&&this.Yb("up",!1),this.ha=-1):a>=-c/2&&a<=c/2&&b>=-d/2&&b<=d/2?this.Yb("down",!1):this.Yb("up",!1))};e.wh=function(a){"languageSet"===a&&this.Af()};e.jc=function(){var a=-this.ta.width/2,b=-this.ta.height/2;this.nc&&(a=Math.floor(a),b=Math.floor(b));"down"===this.state?this.ta.B(a,b):this.He.B(a,b)};
V.J.vV={ja:Vc,we:Wc,icon:null,qy:void 0,qa:"left",direction:"horizontal",minValue:0,maxValue:100,jR:50,GU:!1,RA:!1,bK:"left",cm:y(48),am:y(48),Db:R,Td:y(8),Va:y(8),vc:!0,nc:!0,e:[],nn:null,pn:null};function em(a){this.name="Slider";this.n(V.J.vV);void 0!==a&&this.f(a)}zl(em,s);e=em.prototype;e.Pc=function(){return this.width?this.width:this.ja&&this.ja.width?this.ja.width:0};e.Oc=function(){return this.height?this.height:this.ja&&this.ja.height?this.ja.height:0};e.Xa=function(){this.tp()};
e.Ta=function(a,b){a=Math.max(this.minValue,Math.min(this.maxValue,a));this.GU&&(a=Math.round(a));if(a!==this.value){this.value=a;!b&&this.nn&&this.nn(this,this.value);var c=0,d=0,g=0===this.width?this.ja.width:this.width,k=0===this.height?this.ja.height:this.height;"vertical"===this.direction?(this.icon&&("bottom"===this.qa?(this.We=Math.round(d+k/2-this.icon.height/2),this.Ve=0,k-=this.icon.height+this.Td,d-=Math.round((this.icon.height+this.Td)/2)):(this.We=Math.round(d-k/2+this.icon.height/2),
this.Ve=0,k-=this.icon.height+this.Td,d+=Math.round((this.icon.height+this.Td)/2))),this.RA&&("bottom"===this.bK?(this.Ob=Math.round(d+k/2-this.am/2),this.Wb=0,k-=this.am+this.Td,d-=Math.round((this.am+this.Td)/2)):(this.Ob=Math.round(d-k/2+this.am/2),k-=this.am+this.Td,d+=Math.round((this.am+this.Td)/2))),this.Ru=Math.round(d-k/2),this.Qu=Math.round(d+k/2),this.Nl=Math.round(this.Qu-(this.Qu-this.Ru)*(this.value-this.minValue)/(this.maxValue-this.minValue)),this.Ml=0):(this.icon&&("right"===this.qa?
(this.Ve=Math.round(c+g/2-this.icon.width/2),this.We=0,g-=this.icon.width+this.Td,c-=Math.round((this.icon.width+this.Td)/2)):(this.Ve=Math.round(c-g/2+this.icon.width/2),this.We=0,g-=this.icon.width+this.Td,c+=Math.round((this.icon.width+this.Td)/2))),this.RA&&("right"===this.bK?(this.Wb=Math.round(c+g/2-this.cm/2),this.Ob=0,g-=this.cm+this.Td,c-=Math.round((this.cm+this.Td)/2)):(this.Wb=Math.round(c-g/2+this.cm/2),this.Ob=0,g-=this.cm+this.Td,c+=Math.round((this.cm+this.Td)/2))),this.sr=Math.round(c-
g/2),this.ZA=Math.round(c+g/2),this.Ml=Math.round(this.sr+(this.ZA-this.sr)*(this.value-this.minValue)/(this.maxValue-this.minValue)),this.Nl=0);a:if(d=0,g=100*(this.value-this.minValue)/(this.maxValue-this.minValue),void 0===this.qy)1===this.icon.N?this.il=0:2===this.icon.N?this.il=this.value===this.minValue?0:1:(this.il=1+Math.floor(g/100*(this.icon.N-2)),this.value===this.minValue&&(this.il=0),this.value===this.maxValue&&(this.il=this.icon.N-1));else{for(c=0;c<this.qy.length;c+=1)if(d+=this.qy[c],
g<=d){this.il=c;break a}this.il=this.icon.N-1}this.Xa()}};e.ea=function(){return this.value};
e.tp=function(){var a=0===this.width?this.ja.width:this.width,b=0===this.height?this.ja.height:this.height,a=Math.max(a,this.we.width)+4,b=Math.max(b,this.we.height)+4;this.H=new za(a,b);Aa(this.H);var c=this.H.context,a=Math.round(a/2),b=Math.round(b/2),d;if("vertical"===this.direction){d=this.ja;var g=b+this.Ru,k=b+this.Nl,l=b+this.Qu,m=a+Math.round(-this.ja.width/2),p=Math.floor(d.width/2),w=Math.floor(d.height/2);d instanceof za?d.Mc(m,g,d.width,l-g,1,p-2,p-2,w-2,w-2):1===d.N?d.Mc(0,m,g,d.width,
l-g,1,p-2,p-2,w-2,w-2):(c.save(),d.Mc(0,m,g,d.width,l-g,1,p-2,p-2,w-2,w-2),c.rect(0,k,c.canvas.width,l-k),c.clip(),d.Mc(1,m,g,d.width,l-g,1,p-2,p-2,w-2,w-2),c.restore())}else d=this.ja,g=a+this.sr,k=a+this.Ml,l=a+this.ZA,m=b+Math.round(-this.ja.height/2),p=Math.floor(d.width/2),w=Math.floor(d.height/2),d instanceof za?d.Mc(g,m,l-g,d.height,1,p-2,p-2,w-2,w-2):1===d.N?d.Mc(0,g,m,l-g,d.height,1,p-2,p-2,w-2,w-2):(c.save(),d.Mc(0,g,m,l-g,d.height,1,p-2,p-2,w-2,w-2),c.rect(k,0,l-k,c.canvas.height),c.clip(),
d.Mc(1,g,m,l-g,d.height,1,p-2,p-2,w-2,w-2),c.restore());c=a+Math.round(-this.we.width/2)+this.we.Da;d=b+Math.round(-this.we.height/2)+this.we.Ea;this.we instanceof za?this.we.B(this.Ml+c,this.Nl+d):this.we.B(0,this.Ml+c,this.Nl+d);this.icon&&(c=a+Math.round(-this.icon.width/2)+this.icon.Da,d=b+Math.round(-this.icon.height/2)+this.icon.Ea,this.icon instanceof za?this.icon.B(this.Ve+c,this.We+d):this.icon.B(this.il,this.Ve+c,this.We+d));this.RA&&(c=Math.round(this.value).toString(),this.Db instanceof
Fa?d=this.Db.Zc():(d=new Fa,d.f(this.Db)),d.rY="middle",d.align="center",d.size=Va(d,c,this.cm,this.am),d.B(c,a+this.Wb,b+this.Ob));Ba(this.H)};e.w=function(){var a;this.value=void 0;this.Ta(this.jR,!0);this.ha=-1;for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.H=void 0};
e.me=function(a,b,c){var d=this.we.width/2,g=this.we.height/2;this.Va&&(d+=this.Va,g+=this.Va);if(b>=this.Ml-d&&b<=this.Ml+d&&c>=this.Nl-g&&c<=this.Nl+g&&(this.ha=a,this.DW=b-this.Ml,this.EW=c-this.Nl,this.vc)||this.icon&&this.pn&&(a=this.icon.width/2,d=this.icon.height/2,this.Va&&(a+=this.Va,d+=this.Va),b>=this.Ve-a&&b<=this.Ve+a&&c>=this.We-d&&c<=this.We+d&&(this.pn(this),this.vc)))return!0};e.Bf=function(a){this.ha===a&&(this.ha=-1)};
e.$c=function(){var a,b;-1!==this.ha&&(a=this.hd(this.ha)-this.DW,b=this.Uc(this.ha)-this.EW,a="vertical"===this.direction?this.maxValue-(this.maxValue-this.minValue)*(b-this.Ru)/(this.Qu-this.Ru):this.minValue+(this.maxValue-this.minValue)*(a-this.sr)/(this.ZA-this.sr),this.Ta(a))};e.jc=function(){this.nc?this.H.B(Math.round(-this.H.width/2),Math.round(-this.H.height/2)):this.H.B(-this.H.width/2,-this.H.height/2)};var Tl=1;
V.J.MU={ja:Qh,Zp:Ph,direction:0,width:void 0,height:y(200),marginLeft:0,marginRight:0,marginTop:0,marginBottom:0};function Sl(a){this.name="ScrollBar";this.n(V.J.MU);void 0!==a&&this.f(a);this.Il=0;this.Jl=this.height;this.eo=-1;this.fo=void 0}zl(Sl,s);e=Sl.prototype;
e.drawImage=function(a,b,c,d,g,k){if(null!==a)if(a instanceof za)switch(k){case "slice":a.Mc(b,c,d,g,f.context.alpha,Math.floor(a.width/2)-2,Math.floor(a.width/2)-2,Math.floor(a.height/2)-2,Math.floor(a.height/2)-2);break;case "stretch":a.Og(b,c,d,g,f.context.alpha);break;case "tile":a.Uk(a.Da,a.Ea,b,c,d,g,f.context.alpha)}else if(a instanceof h)switch(k){case "slice":a.Mc(0,b,c,d,g,f.context.alpha,Math.floor(a.width/2)-2,Math.floor(a.width/2)-2,Math.floor(a.height/2)-2,Math.floor(a.height/2)-2);
break;case "stretch":a.Og(0,b,c,d,g,f.context.alpha);break;case "tile":a.Uk(0,a.Da,a.Ea,b,c,d,g,f.context.alpha)}};e.Sa=function(a,b,c){var d=this.gf(b,c);b=this.hf(b,c);c=this.Pc();var g=this.Oc();return d>-c/2+this.marginLeft&&d<c/2-this.marginRight&&b>-g/2+this.marginTop&&b<g/2-this.marginBottom?(this.eo=a,fm(this,d,b),!0):!1};e.qb=function(a){return this.eo===a?(this.eo=-1,this.fo=void 0,!0):!1};
e.Ga=function(){if(-1!==this.eo){var a=q.hd(this.eo),b=q.Uc(this.eo);fm(this,this.gf(a,b),this.hf(a,b))}};
function fm(a,b,c){var d=a.Pc()-a.marginLeft-a.marginRight,g=a.Oc()-a.marginTop-a.marginBottom;b-=a.marginLeft;var k=c-a.marginTop,l;0===a.direction?(c=g,l=Math.ceil(a.Zp.height/3*2)):(c=d,l=Math.ceil(a.Zp.width/3*2));l=Math.min(c,Math.max(l,c/a.Jl*c));isNaN(l)&&(l=c);d=0===a.direction?k+g/2:b+d/2;isNaN(d)&&(d=0);a.Il=Math.min(a.Jl,Math.max(0,(d-l/2)/(c-l)*a.Jl));isNaN(a.Il)&&(a.Il=0);a.fo=a.Il}e.Pc=function(){return 0<this.width?this.width:this.ja.width+this.marginLeft+this.marginRight};
e.Oc=function(){return 0<this.height?this.height:this.ja.height+this.marginTop+this.marginBottom};
e.jc=function(){var a=0<this.width?this.width-this.marginLeft-this.marginRight:this.ja.width,b=0<this.height?this.height-this.marginTop-this.marginBottom:this.ja.height,c=-(a+this.marginLeft+this.marginRight)/2,d=-(b+this.marginTop+this.marginBottom)/2,c=c+this.marginLeft,d=d+this.marginTop;this.nc&&(c=Math.floor(c),d=Math.floor(d));var g=c,k=d,l=a,m=b,p,w;0===this.direction?(p=b,w=Math.ceil(this.Zp.height/3*2)):(p=a,w=Math.ceil(this.Zp.width/3*2));w=Math.min(p,Math.max(w,p/this.Jl*p));isNaN(w)&&
(w=p);p=this.Il/this.Jl*(p-w);isNaN(p)&&(p=0);this.drawImage(this.ja,c,d,a,b,"slice");switch(this.direction){case 0:k+=p;m=w;break;case Tl:g+=p,l=w}this.drawImage(this.Zp,g,k,l,m,"slice")};var gm={};V.p={};function hm(a,b){function c(){}c.prototype=b.prototype;a.prototype=new c;a.Cb=b.prototype;a.prototype.constructor=a}V.p.Ra={canvas:null,W:-1E3,depth:0,x:0,y:0,width:0,height:0,Kf:!0};function yc(a){this.n();void 0!==a&&this.f(a)}e=yc.prototype;
e.n=function(a){this.f(V.p.Ra);this.f(a);this.parent=null;this.kind="dialog";this.t=[];this.C=this.eb=this.Wg=!1;null===this.canvas&&(this.canvas=r.k)};e.f=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};e.gf=function(a,b){return null!==this.parent?this.parent.gf(a,b)-this.x:a-this.x};e.hf=function(a,b){return null!==this.parent?this.parent.hf(a,b)-this.y:b-this.y};e.pp=function(a,b){return null!==this.parent?this.parent.pp(a+this.x,b+this.y):a+this.x};
e.qp=function(a,b){return null!==this.parent?this.parent.qp(a+this.x,b+this.y):b+this.y};e.Vs=function(a,b){return new da(this.pp(a,b),this.qp(a,b))};e.hd=function(a){return this.gf(q.hd(a),q.Uc(a))};e.Uc=function(a){return this.hf(q.hd(a),q.Uc(a))};e.d=function(a){a.parent=this;this.t.push(a)};e.ya=function(){this.t=[]};e.br=function(a){void 0===a&&(a=!0);if(!(this.Wg||this.Cz&&this.Cz(this))&&(this.Wg=!0,this.w&&this.w(),a))for(a=0;a<this.t.length;a+=1)this.t[a].br()};
e.gg=function(a){void 0===a&&(a=!0);if(this.Wg&&(!this.vz||!this.vz(this))){this.eb&&this.i();this.Wg=!1;if(a)for(a=0;a<this.t.length;a+=1)this.t[a].gg();this.I&&this.I()}};e.show=function(a){void 0===a&&(a=!0);null===this.canvas&&(this.canvas=r.k);if(!this.eb&&(this.Wg||this.br(),!this.xu||!this.xu())){this.eb=!0;this.ka();if(a)for(a=0;a<this.t.length;a+=1)this.t[a].show();this.da&&this.da();this.D=this.visible=!0;Mb(this)}};
e.i=function(a){void 0===a&&(a=!0);if(this.eb&&(!this.Ia||!this.Ia(this))){this.ga();this.eb=!1;if(a)for(a=0;a<this.t.length;a+=1)this.t[a].i();this.pa&&this.pa();this.D=this.visible=!1;Xb(q,this)}};e.ka=function(a){void 0===a&&(a=!0);if(!(this.C||this.Iq&&this.Iq(this))){this.C=!0;if(a)for(a=0;a<this.t.length;a+=1)this.t[a].ka();this.$f&&this.$f()}};e.ga=function(a){void 0===a&&(a=!0);if(this.C&&(!this.sz||!this.sz(this))&&(this.C=!1,a))for(a=0;a<this.t.length;a+=1)this.t[a].ga()};e.Za=function(){};
e.Qa=function(){};e.wa=function(a){var b;if(this.C)for(b=0;b<this.t.length;b+=1)if(this.t[b].wa(a))return this.Kf};e.Sa=function(a,b,c){var d;if(this.C)for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Sa(a,b,c))return this.Kf};e.qb=function(a,b,c){var d;if(this.C)for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].qb(a,b,c))return this.Kf};e.Ug=function(a,b,c){var d;if(this.C)for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Ug(a,b,c))return this.Kf};
e.el=function(a,b,c){var d;if(this.C)for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].el(a,b,c))return this.Kf};e.Dh=function(a,b,c){var d;if(this.C)for(d=this.t.length-1;0<=d;d-=1)if(this.t[d].Dh(a,b,c))return this.Kf};e.pb=function(a){var b;if(this.C)for(b=0;b<this.t.length;b+=1)if(this.t[b].pb(a))return this.Kf};e.Jb=function(a){var b;if(this.C)for(b=0;b<this.t.length;b+=1)if(this.t[b].Jb(a))return this.Kf};e.Sb=function(a){var b;if(this.C)for(b=0;b<this.t.length;b+=1)if(this.t[b].Sb(a))return this.Kf};
e.xb=function(a,b){var c;if(this.C)for(c=0;c<this.t.length;c+=1)if(this.t[c].xb(a,b))return this.Kf};e.Ga=function(a){var b,c=!1;if(this.C)for(b=0;b<this.t.length;b+=1)if(this.t[b].Ga(a)){c=this.Kf;break}if(this.eb)for(b=0;b<this.t.length;b+=1)if(Pl(this.t[b],a)){c=this.Kf;break}return c};e.Ha=function(){var a,b=!1;if(this.eb){f.context.save();f.context.translate(this.x,this.y);for(a=0;a<this.t.length;a+=1)if(this.t[a].Ha()){b=this.Kf;break}f.context.restore();return b}};V.p.xB={e:[]};
function im(a){this.name="Template";this.n(V.p.xB);void 0!==a&&this.f(a)}hm(im,yc);im.prototype.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};im.prototype.I=function(){this.ya()};im.prototype.da=function(){};im.prototype.pa=function(){};V.p.g={e:[],$w:null};function jm(a){this.name="Container";this.n(V.p.g);void 0!==a&&this.f(a)}hm(jm,yc);jm.prototype.w=function(){var a;this.g=new am({});this.g.f(this.$w);this.d(this.g);for(a=0;a<this.e.length;a+=1)this.g.d(this.e[a])};
jm.prototype.I=function(){this.ya();this.g=void 0};V.p.ar={x:void 0,y:void 0,backgroundImage:null,bb:!1,Pa:{h:Cl,duration:0},sa:{h:Dl,duration:0},Dc:99999,le:!1,e:[],ic:null,sb:null};function km(a){this.name="PopUp";this.n(V.p.ar);void 0!==a&&this.f(a)}hm(km,yc);km.prototype.Z=function(){this.ga();X(this.g,2)};km.prototype.Fa=function(a,b,c,d,g){b=new b(c);void 0!==d&&b.f(d);void 0!==g&&b.f(g);a.d(b);return b};
km.prototype.w=function(){var a,b=this,c;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);this.bb&&(c=this.Fa(this,cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.Fa(this,u,{c:this.backgroundImage,tb:!0,width:0===this.width&&this.backgroundImage?this.backgroundImage.width:this.width,height:0===this.height&&this.backgroundImage?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:this.Dc},this.sa],Kh:function(a,g){g===b.sa&&b.bb&&dm(c,c.duration,
b.g.S[2].duration-c.duration)},yb:function(){b.i()}},this.sb);this.le&&(this.g.ak=function(){lm.prototype.Z.call(b)});for(a=0;a<this.e.length;a+=1)this.g.d(this.e[a])};km.prototype.I=function(){this.ya();this.g=void 0};
V.p.Wo={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:10,Lb:0,je:90,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),Qw:"close",qj:!1,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!1,Me:P,qi:S,si:null,buttons:[],bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};
function lm(a){this.name="ButtonBox";this.n(V.p.Wo);void 0!==a&&this.f(a)}hm(lm,yc);e=lm.prototype;e.Z=function(){this.ga();X(this.g,2)};e.Fa=function(a,b,c,d,g){b=new b(c);void 0!==d&&b.f(d);void 0!==g&&b.f(g);a.d(b);return b};
e.Sf=function(a,b,c,d,g,k){var l=this;return this.Fa(a,D,{x:d,y:g,width:void 0===b.uV?k:0,height:0,c:void 0===b.c?this.Me:b.c,text:void 0===b.text?"":b.text,s:void 0===b.key?"":b.key,icon:b.icon,qa:"left",font:void 0===b.font?this.qi:b.font,Ib:void 0===b.id?c:b.id,Ik:void 0===b.i?this.ri:b.i,vc:!0,j:function(a){a.Ik&&lm.prototype.Z.call(l);l.j&&l.j(l,a.Ib)}},this.si,b.Cd)};
e.w=function(){var a=this,b,c,d,g=[],k=[],l=[];b=[];var m,p,w,z,v,C;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);m=0===this.width?this.backgroundImage.width:this.width;p=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);k[0]=Math.round(-p/2+this.marginTop);b[0]=Math.round(this.Hc*(p-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);k[1]=Math.round(k[0]+b[0]);b[1]=Math.round(this.Lb*(p-this.marginTop-this.marginBottom)/100);this.xa&&(l[2]=this.xa.width,g[2]=g[1]+l[1]-l[2],k[2]=k[1],b[2]=b[1],l[1]-=l[2]+y(32),"left"===this.qa&&(g[2]=g[1],g[1]+=l[2]+y(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Yc&&(g[3]=Math.round(-this.Yc/2),l[3]=this.Yc);k[3]=Math.round(k[1]+b[1]);b[3]=Math.round(this.je*(p-this.marginTop-this.marginBottom)/100);this.bb&&
(C=this.Fa(this,cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.Fa(this,u,{c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:this.Dc},this.sa],Kh:function(b,c){c===a.sa&&a.bb&&dm(C,C.duration,a.g.S[2].duration-C.duration)},yb:function(){a.i()}},this.sb);this.le&&(this.g.ak=function(){a.P&&a.P(a);lm.prototype.Z.call(a)});this.Hc&&this.Fa(this.g,F,{x:Math.round(g[0]+
l[0]/2),y:Math.round(k[0]+b[0]/2),width:l[0],height:b[0],text:this.Fd,s:this.ce,font:this.cc,Sd:!0,pc:!1,Ca:y(20)},this.fd);this.Lb&&this.Fa(this.g,F,{x:Math.round(g[1]+l[1]/2),y:Math.round(k[1]+b[1]/2),width:l[1],height:b[1],text:this.ef,s:this.Hf,font:this.wd,Sd:!0,pc:!0,Ca:y(20)},this.ze);this.Lb&&this.xa&&this.Fa(this.g,u,{c:this.xa,x:Math.round(g[2]+l[2]/2),y:Math.round(k[2]+b[2]/2)},this.td);this.Zb&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.wc/2),p=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.qd/2),this.Fa(this.g,D,{x:m,y:p,width:this.wc,height:this.qd,c:Pc,Ib:this.Qw,j:function(b){a.P&&a.P(a);a.j&&a.j(a,b.Ib);lm.prototype.Z.call(a)}},this.zf));if(this.je){m=this.qj?[this.buttons]:this.buttons;c=this.Me.height;p=c+this.Od;k=Math.round(k[3]+c/2);switch(this.rj){case "top":break;case "bottom":k+=b[3]-m.length*p-this.Od;break;default:k+=Math.round((b[3]-m.length*p-this.Od)/2)}for(b=d=0;b<m.length;b+=1)if("[object Array]"===Object.prototype.toString.call(m[b]))for(v=
Math.round((l[3]-this.Kg*(m[b].length-1))/m[b].length),z=v+this.Kg,w=Math.round(g[3]+v/2),c=0;c<m[b].length;c+=1)this.Sf(this.g,m[b][c],d,w+c*z,k+b*p,v),d+=1;else this.Sf(this.g,m[b],d,Math.round(g[3]+l[3]/2),k+b*p,l[3]),d+=1}for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){this.ya();this.g=void 0};
V.p.ES={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:25,Lb:75,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:4,le:!0,e:[],P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};function mm(a){this.name="MessageBox";this.n(V.p.ES);void 0!==a&&this.f(a)}hm(mm,lm);
V.p.kA={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:15,Lb:55,je:30,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),qj:!0,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!0,Me:P,qi:S,si:null,buttons:[],bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};
function jl(a){this.name="QuestionBox";this.n(V.p.kA);void 0!==a&&this.f(a)}hm(jl,lm);V.J.DV={wr:void 0,Pl:void 0,No:"animation",L:-1,repeat:!1,Tb:null,play:!0,FF:!0,e:[]};function Bc(a){this.name="SpineComponent";this.n(V.J.DV);void 0!==a&&this.f(a)}zl(Bc,s);e=Bc.prototype;e.Rc=function(a,b){this.Pl.Rc(a,this.repeat);vc(this.Pl,function(){b&&b()})};function nm(a){a.Pl.Rc(a.No,a.repeat);vc(a.Pl,function(){a.Tb&&a.Tb()})}
e.w=function(){var a;this.play&&0<this.L&&(this.L=-1);this.Pl=this.wr.Zc();nm(this);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};e.sd=function(a){!this.FF||0<this.L?this.L-=a:this.play=!0};e.me=function(){};e.Bf=function(){};e.Qk=function(){};e.zj=function(){};e.Aj=function(){};e.Bj=function(){};e.xi=function(){};e.wh=function(){};e.$c=function(a){this.play&&this.Pl.Vb(a)};e.Cf=function(){};
e.jc=function(){this.play&&this.Pl.B(this.x,this.y)};e.ag=function(){};
V.mM={fk:"none",Ub:void 0,viewport:void 0,Pz:0,Um:!0,Yp:!1,Uz:!1,YB:!1,yB:!0,LF:!1,cx:-1,lc:!1,KS:"none",mj:y(-1),Ou:-1,ky:!1,dM:!1,HC:!0,eM:"ca-app-pub-9362790118294805/1178913377",hM:"ca-app-pub-9362790118294805/3214049773",gM:"ca-app-pub-9362790118294805/5050709772",jM:"ca-app-pub-9362790118294805/3573976572",fM:"ca-app-pub-9362790118294805/9480909379",iM:"ca-app-pub-9362790118294805/8004176173",gw:{},nq:"",oq:"",IN:"565eaaadf789823be08c4b1d",KN:"5f1ed7c97da30349b3797ed3b09ec383dae8d43c",JN:"565eafbaa8b63c592bcd1c50",
LN:"4e1d6b0510d750f9a2c294a240da48b3856c64db",CI:"8420994579",kM:"http://googleads.g.doubleclick.net/pagead/ads",ip:"ca-games-pub-7949653012476008",description:"http://www.tinglygames.com/html5-games",KF:!1,GQ:!0,gF:void 0,dw:void 0,AQ:"//imasdk.googleapis.com/js/sdkloader/ima3.js",AA:!1,jQ:!0,Vd:void 0,cy:void 0,hY:void 0,Tg:-1,tf:-1,bU:{nj:{OB:!0,TA:!0,text:!0,fF:!0,c:!0},Wy:12E4,iT:15E3},eq:{nj:{OB:!0,TA:!0,text:!0,fF:!0,c:!0},Wy:12E4,iT:15E3},YT:0,XT:0,ZT:"//game-cdn.poki.com/scripts/1.0.0/poki-ads.min.js",
BA:!1,mI:!1,r_:void 0,Vz:void 0,rX:17726,sX:0,tX:"http://js.tokenads.com/woobi-min.js",w0:"http://js.tokenads.com/vidget.css",tZ:"//ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js",nI:!1,v0:void 0,zl:null};function om(){}e=om.prototype;e.n=function(a){this.Na(V.mM);this.Na(a);if(!this.lc)if("[object Array]"===Object.prototype.toString.call(this.fk))for(a=0;a<this.fk.length;a++)pm(this,this.fk[a]);else pm(this,this.fk);qm(this)};
e.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};function qm(a){a.Ou=6E4*a.mj;vl.mj=a.Ou}
function rm(a){var b;b=a.KF?a.bU:a.eq;var c,d=[];c=""+a.kM;c+="?ad_type=";ca.Ae.Kt&&ca.yh.ju||(b.nj.TA&&b.nj.OB?d.push("video"):b.nj.TA?d.push("skippablevideo"):b.nj.OB&&d.push("standardvideo"));b.nj.c&&d.push("image");b.nj.text&&d.push("text");b.nj.fF&&d.push("flash");for(var g=0;g<d.length;++g)c+=d[g],g<d.length-1&&(c+="_");c+="&client="+a.ip;a.CI&&(c+="&slotname="+a.CI);c=c+"&videoad_start_delay=0"+("&description_url="+encodeURIComponent(a.description));a.gF&&(c+="&hl="+a.gF);b.Wy&&(c+="&max_ad_duration="+
b.Wy);a.yB&&(c+="&adtest=on");return c}
function pm(a,b){var c=document.getElementsByTagName("script")[0],d=document.createElement("script");d.type="text/javascript";d.async=!0;switch(b){case "google":d.src=a.AQ;break;case "poki":d.src=a.ZT;break;case "woobi":d.src=a.tX}void 0!==typeof d.addEventListener&&(d.addEventListener("load",function(){switch(b){case "google":a.AA=!0;break;case "poki":a.BA=!0;break;case "woobi":a.nI=!0}a.yB&&console.log(b+" SDK LOADED")},!1),d.addEventListener("error",function(){a.ky=!0;console.log("ERRor")},!1));
c.parentNode.insertBefore(d,c)}function sm(a,b,c,d,g,k){a.mv=!1;a.Yp=!1;a.Uz=!1;a.YB=!1;a.Pz=0;switch(b){case "google":a.AA&&tm(a,c,d,g,k);break;case "poki":a.BA&&um(a,c,d,g,k);break;case "woobi":a.nI&&vm(a)}}function wm(){var a=xm;!a.mv&&a.AA?(a.dw.initialize(),a.mv=!0):!a.mv&&a.BA&&a.mI&&(POKI_ADS.requestAd({position:poki.ads.position.preroll}),a.mv=!0)}
function ym(){var a=xm;a.gw=/(android)/i.test(navigator.userAgent)?{qw:a.eM,eq:a.hM}:/(ipod|iphone|ipad)/i.test(navigator.userAgent)?{qw:a.gM,eq:a.jM}:{qw:a.fM,eq:a.iM};/(ipad|iphone|ipod|android|windows phone)/i.test(navigator.userAgent)&&(document.addEventListener("deviceready",function(){AdMob?a.dM?AdMob&&AdMob.GY({aY:a.gw.qw,rZ:!0,eY:"SMART_BANNER",position:AdMob.xX.BX,EM:!0}):a.HC&&AdMob&&AdMob.v_({bY:a.gw.eq,EM:!1}):alert("admob plugin not ready")},!1),document.addEventListener("onAdFailLoad",
function(a){alert("error: "+a.error+", reason: "+a.reason+", adNetwork:"+a.dY+", adType:"+a.fY+", adEvent:"+a.$X)}))}function zm(){var a=xm;if(navigator.userAgent.match(/Android/i))a.nq=a.IN,a.oq=a.KN;else if(navigator.userAgent.match(/iPhone/i)||navigator.userAgent.match(/iPad/i))a.nq=a.JN,a.oq=a.LN;console.log("Made chartboost container "+a.nq+"   "+a.oq);document.addEventListener("deviceready",function(){Am(a)},!1)}
function Am(a){console.log("Init ids "+a.nq+"   "+a.oq);window.Oe.V_(a.nq,a.oq);window.Oe.WZ=function(a){console.log("onInterstitialAdPreloaded: "+a)};window.Oe.VZ=function(a){console.log("onInterstitialAdLoaded: "+a)};window.Oe.XZ=function(a){console.log("onInterstitialAdShown: "+a)};window.Oe.UZ=function(a){console.log("onInterstitialAdHidden: "+a)};window.Oe.a_=function(a){console.log("onMoreAppsAdPreloaded: "+a)};window.Oe.$Z=function(a){console.log("onMoreAppsAdLoaded: "+a)};window.Oe.b_=function(a){console.log("onMoreAppsAdShown: "+
a)};window.Oe.ZZ=function(a){console.log("onMoreAppsAdHidden: "+a)};window.Oe.i_=function(a){console.log("onRewardedVideoAdPreloaded: "+a)};window.Oe.h_=function(a){console.log("onRewardedVideoAdLoaded: "+a)};window.Oe.j_=function(a){console.log("onRewardedVideoAdShown: "+a)};window.Oe.g_=function(a){console.log("onRewardedVideoAdHidden: "+a)};window.Oe.f_=function(a){console.log("onRewardedVideoAdCompleted: "+a)};console.log("Chartboost INIT")}
function tm(a,b,c,d,g){function k(a){v.Yp=!1;console.log(a.getError());v.Vd&&v.Vd.LY();v.qh(a)}function l(){console.log("Completeeeed")}function m(){v.XJ=!0;v.sf()}function p(){v.Tg=-1;v.tf=-1;v.Yp=!0}function w(){v.Tg=1E3*v.Vd.getRemainingTime();v.tf=v.Tg;0>v.Tg&&(v.KF?(v.Tg=v.preroll.max_ad_duration,v.tf=v.Tg):v.GQ&&(v.Tg=v.interstitial.max_ad_duration,v.tf=v.Tg))}function z(){console.log("Ad Closed");v.Ub.style.display="none";v.sf()}var v=a;a.Ub=document.createElement("div");a.viewport=r.g;a.Ub.id=
"adContainer";a.viewport.appendChild(a.Ub);a.cy=document.getElementById("adContainer");a.dw=new google.ima.AdDisplayContainer(document.getElementById("adContainer"));var C=a.viewport.clientWidth/r.em,x=Math.round(d*C),t=Math.round(g*C);c=Math.round((c-r.wk)*C)+"px";b=Math.round((b-r.vk)*C)+"px";a.Ub.style.width=x+"px";a.Ub.style.height=t+"px";a.Ub.style["z-index"]=300;a.Ub.style.position="absolute";a.Ub.style.top=c;a.Ub.style.left=b;a.Ub.style.display="block";var A={currentTime:0};b=new google.ima.AdsLoader(a.dw);
b.addEventListener(google.ima.AdsManagerLoadedEvent.Type.ADS_MANAGER_LOADED,function(a){v.Vd=a.getAdsManager(A);v.Vd.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR,k);v.Vd.addEventListener(google.ima.AdEvent.Type.CONTENT_PAUSE_REQUESTED,l);v.Vd.addEventListener(google.ima.AdEvent.Type.CONTENT_RESUME_REQUESTED,m);v.Vd.addEventListener(google.ima.AdEvent.Type.COMPLETE,l);v.Vd.addEventListener(google.ima.AdEvent.Type.USER_CLOSE,z);v.Vd.addEventListener(google.ima.AdEvent.Type.STARTED,w);v.Vd.addEventListener(google.ima.AdEvent.Type.LOADED,
p);try{v.Vd.init(x,t,google.ima.ViewMode.NORMAL)}catch(b){v.Yp=!1,v.qh(b)}},!1);b.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR,k,!1);C=new google.ima.AdsRequest;C.adTagUrl="http://pubads.g.doubleclick.net/gampad/ads?sz=640x360&iu=/6062/iab_vast_samples/skippable&ciu_szs=300x250,728x90&impl=s&gdfp_req=1&env=vp&output=vast&unviewed_position_start=1&url=[referrer_url]&correlator=[timestamp]";ca.Ae.Kt&&ca.yh.ju&&(console.log("iOS"),C.adTagUrl="http://pubads.g.doubleclick.net/gampad/ads?sz=400x300&iu=%2F6062%2Fiab_vast_samples&ciu_szs=300x250%2C728x90&gdfp_req=1&env=vp&output=xml_vast2&unviewed_position_start=1&url=[referrer_url]&correlator=[timestamp]&cust_params=iab_vast_samples%3Dlinear");
a.jQ&&(C.adTagUrl=rm(a));250>x&&(x=250);250>t&&(t=250);C.linearAdSlotWidth=x;C.linearAdSlotHeight=t;C.nonLinearAdSlotWidth=x;C.nonLinearAdSlotHeight=t;b.requestAds(C)}
function um(a,b,c,d,g){a.Ub=document.createElement("div");a.viewport=r.g;a.Ub.id="poki-sdk-container";a.viewport.appendChild(a.Ub);var k=a.viewport.clientWidth/r.em;d=Math.round(d*k);g=Math.round(g*k);c=Math.round((c-r.wk)*k)+"px";b=Math.round((b-r.vk)*k)+"px";a.Ub.style.width=d+"px";a.Ub.style.height=g+"px";a.Ub.style["z-index"]=300;a.Ub.style.position="absolute";a.Ub.style.top=c;a.Ub.style.left=b;a.Ub.style.display="block";a.Vz=document.getElementById("poki-sdk-container");POKI_DISPATCHER.addEventListener(poki.ready,
function(){a.mI=!0});POKI_DISPATCHER.addEventListener(poki.ads.ready,function(){a.Uz=!0;console.log("ads start")});POKI_DISPATCHER.addEventListener(poki.ads.completed,function(){a.sf()});POKI_DISPATCHER.addEventListener(poki.ads.limit,function(b){a.qh(b)});POKI_DISPATCHER.addEventListener(poki.ads.error,function(b){a.qh(b)});POKI_DISPATCHER.addEventListener(poki.ads.update,function(b){a.Ou(b.percentageComplete)});250>d&&(d=250);250>g&&(g=250);b=a.yB?{timeUpdateInterval:100,debug:!0,staticAd:!0,width:d,
height:g}:{partnerId:a.YT,gameId:a.XT,timeUpdateInterval:100,debug:!1,width:d,height:g};if(POKI_ADS.publisherSettings&&POKI_ADS.publisherSettings.pokiads&&POKI_ADS.publisherSettings.pokiads.initParams)for(param in k=POKI_ADS.publisherSettings.pokiads.initParams,k)k.eZ(param)&&(b[param]=k[param]);POKI_ADS.init(b)}
function vm(a){tokenads.config.appId=[a.rX];tokenads.config.clientId=[a.sX];tokenads.settings.position.centerPlayer=!0;tokenads.settings.view.draggable=!1;tokenads.settings.offersLimit=1;tokenads.config.listener.onError=function(b){a.qh(b)};tokenads.config.listener.onClose=function(){a.sf()};tokenads.config.listener.onCredit=function(b){a.sf(b)};tokenads.checkInventory(function(b){0<b?a.YB=!0:a.qh()});tokenads.settings.view.colorTheme="#954217";tokenads.settings.view.showTitle=!1}
function Bm(a,b){window.addEventListener("resize",function(){a(b)},!0)}function Cm(a,b,c,d,g){var k=xm;250>d&&(d=250);250>g&&(g=250);switch(a){case "google":k.Vd.resize(d,g,google.ima.ViewMode.NORMAL);k.cy.style.top=c;k.cy.style.left=b;break;case "poki":POKI_ADS.resize(d,g),k.Vz.style.top=c,k.Vz.style.left=b}}function Dm(a){var b=xm;switch(a){case "google":if(b.Yp)return!0;break;case "poki":if(b.Uz)return!0;break;case "woobi":if(b.YB)return!0;console.log(document.getElementById("ta-player"))}}
function Em(a){var b=xm;switch(a){case "google":b.Vd.start();break;case "poki":POKI_ADS.startAd();break;case "woobi":tokenads.showPlayer()}if(b.lc)switch(b.KS){case "admob":b.HC&&AdMob&&AdMob.Y_();break;case "chartboost":window.Oe.a0("Default"),console.log("Show chartboost ad")}}
e.sf=function(a){this.LF&&void 0===a&&0>this.cx?(a=0,la("Ad Reward",{js:a}),this.zl&&this.zl(a)):this.LF&&void 0===a&&-1<this.cx?(a=this.cx,la("Ad Reward",{js:a}),this.zl&&this.zl(a)):void 0!==a?(la("Ad Reward",{js:a}),this.zl&&this.zl(a)):la("Ad Completed",{});this.Ub&&(this.Ub.style.display="none");(a=document.getElementById("adContainer"))&&a.parentNode.removeChild(a)};e.qh=function(a){la("Ad Failed",{error:a})};e.Ou=function(a){this.Pz=a};
e.Ch=function(a,b){switch(a){case "google":if(-1<this.Tg&&-1<this.tf)return-1<this.Vd.getRemainingTime()?this.tf=1E3*this.Vd.getRemainingTime():this.tf-=b,Math.round((this.Tg-this.tf)/this.Tg*100);break;case "poki":return this.Pz}};var xm=new om;
V.zP={yP:"https://cdn.firebase.com/js/client/2.2.1/firebase.js",sZ:"https://ajax.googleapis.com/ajax/libs/jquery/2.2.0/jquery.min.js",uZ:"https://ajax.googleapis.com/ajax/libs/jqueryui/1.11.4/jquery-ui.min.js",KZ:"https://incandescent-inferno-1440.firebaseio.com/",i0:"https://testten.firebaseio.com/",JY:null,FQ:!1,vb:void 0,JO:"undefined"!==typeof s_avatar80?s_avatar80:void 0,KY:"undefined"!==typeof s_avatar140?s_avatar140:void 0,VE:void 0,WE:void 0,zx:void 0,ac:[]};function Fm(){}
Fm.prototype.n=function(a){this.Na(V.zP);this.Na(a);this.FQ&&(this.HO=firebaseLocal?testUrl:mainUrl,Gm(this))};Fm.prototype.Na=function(a){var b;if("object"===typeof a)for(b in a)a.hasOwnProperty(b)&&(this[b]=Tj(a[b]))};
function Gm(a){var b=document.getElementsByTagName("script")[0],c=document.createElement("script");c.type="text/javascript";c.async=!0;c.src=a.yP;void 0!==typeof c.addEventListener&&(c.addEventListener("load",function(){console.log("Create Reference");a.vb=new Firebase(a.HO)},!1),c.addEventListener("error",function(){console.log("Error loading")},!1));b.parentNode.insertBefore(c,b)}Fm.prototype.Xp=function(){if(this.vb)return this.vb};
function Hm(a){var b=Im;b.vb.mY("facebook",a,function(a,d){a?console.log("Login Failed!",a):(console.log("Authenticated successfully with payload:",d),Jm(b,d))})}
function Jm(a,b){Km(Lm,function(b){if(b.data||b.picture.data)a.VE=(b.data||b.picture.data).url});Km(Mm,function(b){if(b.data||b.picture.data)a.WE=(b.data||b.picture.data).url});var c=a.vb.Pe("players");c.Ez("value",function(d){d.DQ(b.uid)?c.Pe(b.uid).Ez("value",function(b){a.zx=b.lo()}):(c.Pe(b.uid).set({uid:b.uid,name:b.wP.$O,vX:0,El:0,Tw:0}),a.zx={uid:b.uid,name:b.wP.$O,vX:0,El:0,Tw:0})})}
function Nm(a,b){var c=Im;if(c.ac[a])return c.ac[a];if(void 0===a||"noUrl"===a)return c.JO;var d=va(a,a,b,b);return c.ac[a]=d}var Im=new Fm;function Om(a){yc.call(this,a)}hm(Om,yc);Om.prototype.I=function(){this.ya()};var Lm=80,Mm=130;
function Pm(){this.xy=this.lc=this.bR=!1;this.cS=["public_profile","user_friends"];this.JJ=0;this.Ex=this.Om=null;this.uu=[];this.BG=null;var a=this;this.lc||!this.bR?console.log("FB on Mobile or not in use"):(window.fbAsyncInit=function(){a.Om=window.FB;a.Ex=a.Om.api;a.Om.init({appId:facebook_config.lY,cookie:!0,xfbml:!1,version:"v2.5"});a.Om.getLoginStatus(function(b){Qm(a,b);for(b=0;b<a.uu.length;++b)a.uu[b]();a.uu=[]})},function(a,c,d){var g=a.getElementsByTagName(c)[0];a.getElementById(d)||(a=
a.createElement(c),a.id=d,a.src="//connect.facebook.net/en_US/sdk.js",g.parentNode.insertBefore(a,g))}(document,"script","facebook-jssdk"))}Pm.prototype.Wm=function(a){this.lc||a&&(this.Om?a():this.uu.push(a))};function Rm(a){!a.xy&&a.lc&&(console.log("MOBILE INIT CALLED"),facebookConnectPlugin.getLoginStatus(function(b){Qm(a,b)}))}
function Sm(a,b){var c=Tm;if(c.lc)facebookConnectPlugin.login(c.cS,function(a){console.log("FB Success Test: "+a);console.log("USERDATA: "+a.authResponse);c.xy=!1;Qm(c,a)},function(a){console.log("Mobile error: "+a)});else{var d=c.BG;"connected"===d.status?a&&a(d):c.Om.login(function(d){Qm(c,d);c.gn?a&&a(d):b&&b(d)},{scope:"user_friends"})}}
function Km(a,b){var c=Tm;void 0===a&&(a=Lm);c.xy||(c.lc?facebookConnectPlugin.api("me/?fields=picture.type(square).width("+a+").height("+a+")",["public_profile"],function(a){b(a)}):c.Ex("/me/picture","get",{type:"square",height:a,width:a},function(a){b(a)}))}
function Qm(a,b){console.log(b);a.gn||(a.lc?"unknown"===b.status&&3>a.JJ?(console.log("unknown response"),Rm(a),a.JJ++):b.authResponse&&(a.gn=!0,facebookConnectPlugin.api("me?fields=id,name,picture",["public_profile"],function(){}),GameSparksWrapper.kR.Wm(function(){GameSparksWrapper.kR.QY(b.authResponse.accessToken)})):(a.BG=b,b.authResponse&&(a.gn=!0,a.Ex("/me",function(){}),Hm(b.authResponse.accessToken))))}var Tm=new Pm;V.J.BD={c:P,eg:500,rf:45,zb:1,ke:7};
function Um(a){this.n(V.J.BD);this.index=0;this.eg=500;this.elements=[];this.Gd=-1;this.axis=new da(1,0);this.Lj=new da(0,0);this.speed=0;this.rf=45;this.ke=7;this.As=!1;this.LU=y(470);this.yA=y(200);this.nS=y(0);this.oS=y(0);this.GG=y(50);this.g=new s({});this.Pn=this.v=0;this.lI=1E3;this.Gn=null;void 0!==a&&this.f(a)}zl(Um,s);Math.round=Math.round;e=Um.prototype;
e.w=function(){this.As&&(this.H=new za(this.LU,this.yA),this.g.x=this.x,this.g.y=this.y,this.d(this.g),this.H.context.translate(Math.round(this.GG),Math.round(this.yA/2)))};e.addElement=function(a){this.As?this.g.d(a):this.d(a);this.elements.push(a);this.Vh(a,this.elements.length-1)};e.JC=function(a,b){this.d(a);this.elements[b]=a;this.Vh(a,b)};e.Vh=function(a,b){var c=this.axis.scale(this.eg*(b-this.v));a.x=c.x;a.y=c.y;this.Gn&&this.Gn(a)};
e.gB=function(a){this.v=Math.max(Math.min(this.elements.length-1,a),0);for(a=0;a<this.elements.length;++a)this.Vh(this.elements[a],a)};
e.sd=function(a){var b=this.v;if(0<=this.Gd){var c=new da(q.hd(this.Gd)-this.Lj.x,q.Uc(this.Gd)-this.Lj.y),d=-1/this.eg;c.x*=d;c.y*=d;this.v=ea(c,this.axis)+this.Pn;0>this.v?this.v=Math.atan(this.v*this.zb)/this.zb:this.v>this.elements.length-1&&(this.v=Math.atan(this.zb*(this.v-this.elements.length+1))/this.zb+this.elements.length-1);this.speed=Math.min(Math.max(1E3*(this.v-b)/a,-4),4)}else c=Math.round(this.v),c=Math.max(0,Math.min(this.elements.length-1,c)),this.speed+=a/1E3*((c-this.v)*this.rf-
this.speed*this.ke),this.v+=a/1E3*this.speed;if(b!==this.v)if(this.v>this.lI-.001)this.v=this.lI;else for(a=0;a<this.elements.length;++a)this.Vh(this.elements[a],a)};e.me=function(a){if(-1===this.Gd){this.Gd=a;var b=this.Lj,c=q.Uc(a);b.x=q.hd(a);b.y=c;this.Pn=this.v}};e.Bf=function(a){a===this.Gd&&(this.Gd=-1)};e.jc=function(){if(this.As){var a=Math.round(this.GG),b=Math.round(this.yA/2);Aa(this.H);this.H.context.clearRect(-a,-b,this.H.width,this.H.height)}};
e.ag=function(){this.As&&(Ba(this.H),this.H.B(this.nS,this.oS),this.vC=this.t,this.t=this.elements)};V.J.WM={Ie:void 0,GB:void 0};function Vm(a){this.n(V.J.BD);this.f(V.J.WM);this.index=0;this.eg=500;this.elements=[];this.Gd=-1;this.axis=new da(1,0);this.Lj=new da(0,0);this.speed=0;this.rf=45;this.ke=7;this.Pn=this.v=0;this.Gn=null;void 0!==a&&this.f(a)}zl(Vm,Um);Math.round=Math.round;Vm.prototype.w=function(){void 0!==this.GB&&this.d(this.GB);void 0!==this.Ie&&this.d(this.Ie)};
Vm.prototype.sd=function(a){Vm.Cb.sd.call(this,a);0<=this.Gd&&void 0!==this.Ie&&(void 0!==this.Ie.DJ&&(this.Ie.text=this.Ie.DJ[Math.round(this.v)]),this.Ie.Xa())};Vm.prototype.Ug=function(a,b,c){Vm.Cb.Ug.call(this,a,b,c);console.log("DELTA: "+a+" X: "+b+" Y: "+c)};V.J.DS={e:[]};function Wm(a){this.name="MenuScroll";this.n(V.J.DS);void 0!==a&&this.f(a)}zl(Wm,s);e=Wm.prototype;e.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};
e.$f=function(){};e.sd=function(){};e.me=function(){};e.Bf=function(){};e.Qk=function(){};e.zj=function(){};e.Aj=function(){};e.Bj=function(){};e.xi=function(){};e.wh=function(){};e.$c=function(){};e.Cf=function(){};e.jc=function(){};e.ag=function(){};V.J.xY={c:P,tb:!0,marginLeft:y(24),marginRight:y(24),marginTop:y(24),marginBottom:y(24),icon:null,qa:"left",Ue:y(24),text:"",s:"",al:null,T:S,pc:!1,Gq:0,Hq:0,Fq:0,lg:0,Nf:Aj,ur:null,$a:0,bj:!1,Ua:0,Va:0,Fe:null,Oo:!1,gk:!1,vc:!0,nh:!1,nc:!0,e:[],j:null};
function Xm(a){this.name="ButtonList";this.n(V.J.button);void 0!==a&&this.f(a)}zl(Xm,s);e=Xm.prototype;e.Pc=function(){return this.ta.width};e.Oc=function(){return this.ta.height};e.Xa=function(){this.Af()};e.findText=function(){var a=this.text,b=this.s;"[object Array]"===Object.prototype.toString.call(this.text)&&(a=this.text[this.$a%this.text.length]);"[object Array]"===Object.prototype.toString.call(this.s)&&(b=this.s[this.$a%this.s.length]);""!==b&&(a=E(b,"<"+b+">"));return a};
e.zp=function(a,b){var c="up"===b?0:1,d=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(d=this.c[this.$a%this.c.length]);d&&(d instanceof za?this.tb?d.Mc(0,0,a.width,a.height,1,Math.floor(d.width/2)-2,Math.floor(d.width/2)-2,Math.floor(d.height/2)-2,Math.floor(d.height/2)-2):a.width===d.width&&a.height===d.height?d.B(d.Da,d.Ea):d.Og(0,0,a.width,a.height,1):d instanceof h&&(this.tb?d.Mc(c,0,0,a.width,a.height,1,Math.floor(d.width/2)-2,Math.floor(d.width/2)-2,Math.floor(d.height/
2)-2,Math.floor(d.height/2)-2):a.width===d.width&&a.height===d.height?d.B(c,d.Da,d.Ea):d.Og(c,0,0,a.width,a.height,1)))};
e.Ap=function(a,b){var c="up"===b?0:1,d,g,k=this.icon;this.icon&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(k=this.icon[this.$a%this.icon.length]);if(k){switch(this.qa){case "left":d=this.marginLeft;g=(a.height-k.height)/2;break;case "center":d=(a.width-k.width)/2;g=(a.height-k.height)/2;break;case "right":d=a.width-k.width-this.marginRight;g=(a.height-k.height)/2;break;case "top":d=(a.width-k.width)/2;g=this.marginTop;break;case "bottom":d=(a.width-k.width)/2,g=a.width-k.width-
this.marginBottom}this.nc&&(d=Math.floor(d),g=Math.floor(g));"down"===b?(d+=this.Fq,g+=this.lg):(d+=this.Gq,g+=this.Hq);k instanceof za?k.B(d+k.Da,g+k.Ea):k instanceof h&&k.B(c,d+k.Da,g+k.Ea)}};
e.dg=function(a,b){var c,d,g,k,l,m,p=this.findText();(l=this.icon)&&"[object Array]"===Object.prototype.toString.call(this.icon)&&(l=this.icon[this.$a%this.icon.length]);c="down"===b?null!==this.al?this.al:this.T:null!==this.T?this.T:this.al;c instanceof Fa?m=c:(m=new Fa,m.f(c));c=this.marginLeft;d=this.marginTop;g=a.width-this.marginLeft-this.marginRight;k=a.height-this.marginTop-this.marginBottom;if(l)switch(this.qa){case "left":c+=l.width+this.Ue;g-=l.width+this.Ue;break;case "right":g-=l.width+
this.Ue;break;case "top":d+=l.height+this.Ue;k-=l.height+this.Ue;break;case "bottom":k-=l.height+this.Ue}switch(m.align){case "center":c+=g/2;break;case "right":c+=g}switch(m.ua){case "middle":d+=k/2;break;case "bottom":d+=k}this.nc&&(c=Math.floor(c),d=Math.floor(d));"down"===b?(c+=this.Fq,d+=this.lg):(c+=this.Gq,d+=this.Hq);l=m.fontSize;k=Va(m,p,g,k,this.pc);k<l&&Ga(m,k);this.pc?m.B(p,c,d,g):m.B(p,c,d);Ga(m,l)};
e.Af=function(){var a=this.width,b=this.height,c=this.c;this.c&&"[object Array]"===Object.prototype.toString.call(this.c)&&(c=this.c[this.Ua%this.c.length]);c&&0===a&&(a=c.width);c&&0===b&&(b=c.height);this.ta=new za(a,b);Aa(this.ta);this.zp(this.ta,"down");this.Ap(this.ta,"down");this.dg(this.ta,"down");Ba(this.ta);this.He=new za(a,b);Aa(this.He);this.zp(this.He,"up");this.Ap(this.He,"up");this.dg(this.He,"up");Ba(this.He)};
e.Yb=function(a,b){this.state!==a&&("down"===a?(this.state="down",b&&(this.Nf&&U.play(this.Nf),this.gk&&(this.bj&&1<this.Ua&&(this.$a=(this.$a+1)%this.Ua,this.Af()),this.j&&this.j(this)))):"up"===a&&(this.state="up",b&&(this.ur&&U.play(this.ur),this.gk||(this.bj&&1<this.Ua&&(this.$a=(this.$a+1)%this.Ua,this.Af()),this.j&&this.j(this)))))};
e.w=function(){var a;0>=this.Ua&&(this.Ua=1,"[object Array]"===Object.prototype.toString.call(this.c)&&(this.Ua=Math.max(this.Ua,this.c.length)),"[object Array]"===Object.prototype.toString.call(this.icon)&&(this.Ua=Math.max(this.Ua,this.icon.length)),"[object Array]"===Object.prototype.toString.call(this.text)&&(this.Ua=Math.max(this.Ua,this.text.length)),"[object Array]"===Object.prototype.toString.call(this.s)&&(this.Ua=Math.max(this.Ua,this.s.length)));this.Af();this.Yb("up",!1);this.ha=-1;for(a=
0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.He=this.ta=void 0};e.me=function(a,b,c){if(!this.nh)return this.Rk(a,b,c)};e.Bf=function(a,b,c){if(!this.nh)return this.Sk(a,b,c)};e.zj=function(a,b,c){if(this.nh)return this.Rk(a,b,c)};e.Aj=function(a,b,c){if(this.nh)return this.Sk(a,b,c)};e.Rk=function(a,b,c){var d=this.ta.width+2*this.Va,g=this.ta.height+2*this.Va;if(b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&("up"===this.state&&(this.Yb("down",!0),this.ha=a),this.vc))return!0};
e.Sk=function(a,b,c){var d=this.ta.width+2*this.Va,g=this.ta.height+2*this.Va;if(this.ha===a&&(this.ha=-1,b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&("down"===this.state&&this.Yb("up",!0),this.vc)))return!0};e.Bj=function(a){if(this.Oo||this.Fe&&a===this.Fe)if(this.Yb("down",!0),this.vc)return!0};e.xi=function(a){if(this.Oo||this.Fe&&a===this.Fe)if(this.Yb("up",!0),this.vc)return!0};
e.$c=function(){var a,b,c=this.ta.width+2*this.Va,d=this.ta.height+2*this.Va;-1!==this.ha&&(a=this.hd(this.ha),b=this.Uc(this.ha),a>=-c/2&&a<=c/2&&b>=-d/2&&b<=d/2?this.Yb("down",!1):this.Yb("up",!1))};e.wh=function(a){"languageSet"===a&&this.Af()};e.jc=function(){var a=-this.ta.width/2,b=-this.ta.height/2;this.nc&&(a=Math.floor(a),b=Math.floor(b));"down"===this.state?this.ta.B(a,b):this.He.B(a,b)};
V.p.yT={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:10,Lb:0,je:90,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),qj:!1,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!1,Me:P,qi:S,si:null,buttons:[],bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,bk:null,yl:null,Kq:null,Al:null,Oq:null,rn:null,mn:null,eh:[],Dl:[{x:y(0),y:y(-200)},{x:y(0),y:y(-100)},
{x:y(0),y:y(0)},{x:y(0),y:y(100)},{x:y(0),y:y(200)}],Ec:y(0),Fc:y(0),bp:P,WD:S,Iw:"Tutorial",cp:y(400),ap:y(80),Jw:"",lN:null,WA:Vc,XA:Wc,YA:y(400),UA:y(80),VA:ad,cB:Vc,dB:Wc,eB:y(400),aB:y(80),bB:cd,Zo:P,SD:S,Fw:"More Games",$o:y(400),Yo:y(80),Gw:"",bN:null,Hw:"http://www.tinglygames.com/html5-games/",Ns:P,CD:S,Aw:"About",Os:y(400),Ms:y(80),Bw:"",YM:null,Vo:[],rm:"undefined"!==typeof Kh?Kh:null,ss:"Developed by:",$v:"",ts:Xh,aw:y(0),us:y(-250),Tv:Rd,Vv:y(0),qs:y(-100),Uv:"http://www.tinglygames.com/",
Wv:"Tingly Games \n www.tinglygames.com \n \u00a9 2014 - 2015",Xv:y(0),rs:y(100),Yv:"http://www.tinglygames.com/",ns:P,Rv:"",Qv:"Back",ls:S,Sv:y(0),ps:y(200),os:y(400),ms:y(80),ic:null,sb:null,fd:null,ze:null,td:null,zf:null,LB:null,mu:null,Su:null,BR:null,az:null,Zv:null};function Ym(a){this.name="OptionButtonBox";this.n(V.p.yT);void 0!==a&&this.f(a)}hm(Ym,yc);e=Ym.prototype;e.Z=function(){this.ga();X(this.g,2)};
e.Gz=function(){var a;V.q.uI&&(V.q.gq?(a=new Zm(V.q.gq),a.j=function(a,c){Wb();a.Kk(c)},Ub(),a.show()):console.log("No languageScreenProperties can be found"))};e.Hz=function(){var a;V.q.QA&&(V.q.KB?(a=new $m(V.q.KB),a.j=function(){Wb()},Ub(),a.show()):console.log("No tutorialMenuProperties can be found"))};
e.uy=function(a){var b=new F({text:this.$v,s:this.ss,x:this.aw,y:this.us,T:this.ts});this.Vo.push(b);b=new u({c:this.Tv,x:this.Vv,y:this.qs,url:this.Uv,j:function(){window.open(this.url)}});this.Vo.push(b);b=new F({text:this.Wv,x:this.Xv,y:this.rs,url:this.Yv,j:function(){window.open(this.url)}});this.Vo.push(b);b=new D({c:this.ns,x:this.Sv,y:this.ps,width:this.os,height:this.ms,text:this.Rv,s:this.Qv,T:this.ls,j:function(){a.Jq?a.Jq():a.Z()}});this.Vo.push(b);return this.Vo};
e.Fz=function(){var a;a=new lm({backgroundImage:this.rm,Zb:!0,Jq:null});a.e=this.uy(a);a.Ia=function(){Wb()};Ub();a.show()};e.Hk=function(a){this.Ec=this.Dl[a].x;this.Fc=this.Dl[a].y};e.Fa=function(a,b,c,d,g){b=new b(c);void 0!==d&&b.f(d);void 0!==g&&b.f(g);a.d(b);return b};
e.Sf=function(a,b,c,d,g,k){var l=this;return this.Fa(a,D,{x:d,y:g,width:void 0===b.uV?k:0,height:0,c:void 0===b.c?this.Me:b.c,text:void 0===b.text?"":b.text,s:void 0===b.key?"":b.key,icon:b.icon,qa:"left",font:void 0===b.font?this.qi:b.font,Ib:void 0===b.id?c:b.id,Ik:void 0===b.i?this.ri:b.i,vc:!0,j:function(a){a.Ik&&lm.prototype.Z.call(l);l.j&&l.j(l,a.Ib)}},this.si,b.Cd)};
e.w=function(){var a=this,b;b=[];var c=[],d=[],g=[],k,l,m;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);k=0===this.width?this.backgroundImage.width:this.width;l=0===this.height?this.backgroundImage.height:this.height;b[0]=Math.round(-k/2+this.marginLeft);d[0]=Math.round(k-this.marginLeft-this.marginRight);c[0]=Math.round(-l/2+this.marginTop);g[0]=Math.round(this.Hc*(l-this.marginTop-this.marginBottom)/100);b[1]=Math.round(-k/2+this.marginLeft);d[1]=Math.round(k-this.marginLeft-
this.marginRight);c[1]=Math.round(c[0]+g[0]);g[1]=Math.round(this.Lb*(l-this.marginTop-this.marginBottom)/100);this.xa&&(d[2]=this.xa.width,b[2]=b[1]+d[1]-d[2],c[2]=c[1],g[2]=g[1],d[1]-=d[2]+y(32),"left"===this.qa&&(b[2]=b[1],b[1]+=d[2]+y(32)));b[3]=Math.round(-k/2+this.marginLeft);d[3]=Math.round(k-this.marginLeft-this.marginRight);0<this.Yc&&(b[3]=Math.round(-this.Yc/2),d[3]=this.Yc);c[3]=Math.round(c[1]+g[1]);g[3]=Math.round(this.je*(l-this.marginTop-this.marginBottom)/100);this.bb&&(m=this.Fa(this,
cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.Fa(this,u,{c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:this.Dc},this.sa],Kh:function(b,c){c===a.sa&&a.bb&&dm(m,m.duration,a.g.S[2].duration-m.duration)},yb:function(){a.i()}},this.sb);this.le&&(this.g.ak=function(){a.P&&a.P(a);lm.prototype.Z.call(a)});this.Hc&&this.Fa(this.g,F,{x:Math.round(b[0]+d[0]/2),
y:Math.round(c[0]+g[0]/2),width:d[0],height:g[0],text:this.Fd,s:this.ce,font:this.cc,Sd:!0,pc:!1,Ca:y(20)},this.fd);this.Lb&&this.Fa(this.g,F,{x:Math.round(b[1]+d[1]/2),y:Math.round(c[1]+g[1]/2),width:d[1],height:g[1],text:this.ef,s:this.Hf,font:this.wd,Sd:!0,pc:!0,Ca:y(20)},this.ze);this.Lb&&this.xa&&this.Fa(this.g,u,{c:this.xa,x:Math.round(b[2]+d[2]/2),y:Math.round(c[2]+g[2]/2)},this.td);this.Zb&&(b=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.wc/2),c=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.qd/2),this.Fa(this.g,D,{x:b,y:c,width:this.wc,height:this.qd,c:Pc,j:function(){a.P&&a.P(a);lm.prototype.Z.call(a)}},this.zf));for(b=0;b<this.eh.length;b++)switch(this.eh[b]){case "tutorial":this.Hk(b);this.$l=new D({c:this.bp,x:this.Ec,y:this.Fc,width:this.cp,height:this.ap,text:this.Jw,s:this.Iw,T:this.WD,j:function(){a.bk?a.bk(a):a.Hz()}});this.$l.f(this.LB);this.g.d(this.$l);break;case "music":this.Hk(b);this.Hh=new em({icon:this.VA,ja:this.WA,
we:this.XA,x:this.Ec,y:this.Fc,width:this.YA,height:this.UA,nn:function(b,c){a.Kq?a.Kq(a):ol(U,c/100)},pn:function(){a.yl&&a.yl(a)}});this.Hh.f(this.mu);this.g.d(this.Hh);break;case "audio":this.Hk(b);this.Xh=new em({icon:this.bB,ja:this.cB,we:this.dB,x:this.Ec,y:this.Fc,width:this.eB,height:this.aB,nn:function(b,c){a.Oq?a.Oq(a):nl(U,c/100)},pn:function(){a.Al&&a.Al(a)}});this.Xh.f(this.Su);this.g.d(this.Xh);break;case "moregames":this.Hk(b);this.tl=new D({c:this.Zo,x:this.Ec,y:this.Fc,width:this.$o,
height:this.Yo,text:this.Gw,link:this.Hw,s:this.Fw,T:this.SD,j:function(){a.rn?a.rn(a):window.open(this.link)}});this.tl.f(this.az);this.g.d(this.tl);break;case "about":this.Hk(b),this.Ek=new D({c:this.Ns,x:this.Ec,y:this.Fc,width:this.Os,height:this.Ms,text:this.Bw,s:this.Aw,T:this.CD,j:function(){a.mn?a.mn(a):a.Fz()}}),this.Ek.f(this.Zv),this.g.d(this.Ek)}for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){this.ya();this.Ek=this.tl=this.Xh=this.Hh=this.$l=this.g=void 0};
V.p.uR={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:10,Lb:0,je:90,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),qj:!1,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!1,Me:Qd,qi:S,si:null,buttons:[],Qs:y(500),Ps:y(500),dp:[],Jk:y(0),Qo:[],Ro:[],pd:[],bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null,
zA:null};function Zm(a){this.name="LanguageBox";this.n(V.p.uR);void 0!==a&&this.f(a)}hm(Zm,yc);e=Zm.prototype;e.Z=function(){this.ga();X(this.g,2)};e.Fa=function(a,b,c,d,g){b=new b(c);void 0!==d&&b.f(d);void 0!==g&&b.f(g);a.d(b);return b};e.Bv=function(a,b,c,d,g){a=new b(c);void 0!==d&&a.f(d);void 0!==g&&a.f(g);this.dp.push(a)};
e.Sf=function(a,b,c,d,g,k){var l=this;return this.Bv(a,an,{x:d,y:g,width:k,height:0,c:void 0===b.c?this.Me:b.c,text:this.Ro[c],$m:this.pd[c],s:void 0===b.key?"":b.key,icon:this.Qo[c],qa:"left",font:void 0===b.font?this.qi:b.font,Ib:void 0===b.id?c:b.id,Ik:void 0===b.i?this.ri:b.i,vc:!1,lg:2,threshold:y(1.5),j:function(a){a.Ik&&lm.prototype.Z.call(l);l.j&&l.j(l,a.Ib)}},this.si,b.Cd)};e.Kk=function(a){tk.kk(tk.Ei()[a]);this.ga();X(this.g,2)};
e.bq=function(){this.pd=tk.Ei();for(var a=0;a<this.pd.length;a++)this.Qo.push(uk(this.pd[a])),this.Ro.push(vk(this.pd[a]))};
e.w=function(){var a=this,b,c,d,g=[],k=[],l=[];b=[];var m,p,w,z,v,C;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);m=0===this.width?this.backgroundImage.width:this.width;p=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);k[0]=Math.round(-p/2+this.marginTop);b[0]=Math.round(this.Hc*(p-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);k[1]=Math.round(k[0]+b[0]);b[1]=Math.round(this.Lb*(p-this.marginTop-this.marginBottom)/100);this.xa&&(l[2]=this.xa.width,g[2]=g[1]+l[1]-l[2],k[2]=k[1],b[2]=b[1],l[1]-=l[2]+y(32),"left"===this.qa&&(g[2]=g[1],g[1]+=l[2]+y(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Yc&&(g[3]=Math.round(-this.Yc/2),l[3]=this.Yc);k[3]=Math.round(k[1]+b[1]);b[3]=Math.round(this.je*(p-this.marginTop-this.marginBottom)/100);this.bb&&
(C=this.Fa(this,cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.Fa(this,u,{c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:this.Dc},this.sa],Kh:function(b,c){c===a.sa&&a.bb&&dm(C,C.duration,a.g.S[2].duration-C.duration)},yb:function(){a.i()}},this.sb);this.le&&(this.g.ak=function(){a.P&&a.P(a);Zm.prototype.Z.call(a)});this.Hc&&this.Fa(this.g,F,{x:Math.round(g[0]+
l[0]/2),y:Math.round(k[0]+b[0]/2),width:l[0],height:b[0],text:this.Fd,s:this.ce,font:this.cc,Sd:!0,pc:!1,Ca:y(20)},this.fd);this.Lb&&this.Fa(this.g,F,{x:Math.round(g[1]+l[1]/2),y:Math.round(k[1]+b[1]/2),width:l[1],height:b[1],text:this.ef,s:this.Hf,font:this.wd,Sd:!0,pc:!0,Ca:y(20)},this.ze);this.Lb&&this.xa&&this.Fa(this.g,u,{c:this.xa,x:Math.round(g[2]+l[2]/2),y:Math.round(k[2]+b[2]/2)},this.td);this.Zb&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.wc/2),p=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.qd/2),this.Fa(this.g,D,{x:m,y:p,width:this.wc,height:this.qd,c:Pc,j:function(){a.P&&a.P(a);lm.prototype.Z.call(a)}},this.zf));this.bq();if(this.je){m=this.qj?[this.buttons]:this.buttons;c=this.Me.height;p=c+this.Od;k=Math.round(k[3]+c/2);switch(this.rj){case "top":break;case "bottom":k+=b[3]-m.length*p-this.Od;break;default:k+=Math.round((b[3]-m.length*p-this.Od)/2)}for(b=d=0;b<m.length;b+=1)if("[object Array]"===Object.prototype.toString.call(m[b]))for(v=
Math.round((l[3]-this.Kg*(m[b].length-1))/m[b].length),z=v+this.Kg,w=Math.round(g[3]+v/2),this.Jk+=p+this.Od,c=0;c<m[b].length;c+=1)this.Sf(this.g,m[b][c],d,w+c*z,k+b*p,v),d+=1;else this.Sf(this.g,m[b],d,Math.round(g[3]+l[3]/2),k+b*p,l[3]),d+=1}this.Fa(this.g,Rl,{On:!1,gD:0,hD:0,width:this.Qs,height:this.Ps,O:this.Me.width,M:this.Jk,e:this.dp},this.zA);for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){this.ya();this.g=void 0};
V.p.gQ={backgroundImage:void 0,uO:y(0),Ws:y(-700),wi:!1,hS:"",fS:"MAIN",iS:y(0),jS:y(-100),gS:Xh,MO:"",KO:"Second",NO:y(0),OO:y(0),LO:R,Pa:{h:Kl,duration:1,u:y(-700),G:y(0),o:ic,K:1.2,name:"appear"},sa:{h:Kl,duration:1,u:y(0),G:y(-700),o:hc,K:1.2,name:"disappear"},e:[],g:[],mc:null};function bn(a){this.name="GameStart";this.n(V.p.gQ);this.f(V.Yu);void 0!==a&&this.f(a)}hm(bn,yc);e=bn.prototype;e.Z=function(){this.ga();X(this.xc,2)};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;this.xc=new am({y:this.Ws,S:[this.Pa,{h:"show",duration:4},this.sa,{h:"show",duration:9999999999}],Kh:function(a,d){"disappear"===d.name&&(b.wi=!1)},dh:function(a,d){"appear"===d.name&&(b.wi=!0);"disappear"===d.name&&b.mc&&b.mc(b)}});this.Uf=new u({c:this.backgroundImage,x:this.pY,y:this.qY});this.g.push(this.Uf);this.CG=new F({text:this.hS,s:this.fS,x:this.iS,y:this.jS,IP:this.gS});this.g.push(this.CG);this.BE=new F({text:this.MO,
s:this.KO,x:this.NO,y:this.OO,IP:this.LO});this.g.push(this.BE);for(a=0;a<this.g.length;a++)this.xc.d(this.g[a]);this.d(this.xc);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.xc=this.BE=this.CG=this.Uf=void 0};e.da=function(){};e.pa=function(){};e.Dh=function(){this.wi&&this.Z()};V.DY={};
V.p.NR={backgroundImage:Rh,vG:"manual",Wt:"vertical",mode:V.la.bx,af:20,If:20,Gm:y(0),o_:y(0),my:!1,MF:!1,fv:0,Fh:2.8,qr:2,Lt:!0,Zg:0,lj:null,EQ:!0,qD:!0,CJ:!1,HF:!0,dR:P,ty:y(0),Ht:y(0),mZ:{h:Hl,duration:.5,qc:y(1),wb:y(1.2),o:gc,K:1},lZ:{h:Hl,duration:.5,qc:y(1.2),wb:y(1),o:gc,K:1},Jy:P,Xt:["Page 01","Page 02","Page 03"],EZ:"",en:void 0,fn:void 0,dn:y(300),cn:y(100),cO:"",aO:"ComingSoonText",bO:R,dO:y(576),eO:y(-335),Hy:y(3),bn:y(3),Ly:10,uG:void 0,PR:void 0,rG:void 0,MR:!1,IR:S,JR:S,an:[Sd,Td,
Ud,Vd,Wd],Vt:y(73),iq:y(64),sG:y(75),KR:y(50),DZ:y(0),BZ:y(4),CZ:!1,Rj:[{x:y(-79),y:y(232)},{x:y(-168),y:y(92)},{x:y(-26),y:y(90)},{x:y(96),y:y(128)},{x:y(224),y:y(130)},{x:y(178),y:y(-82)},{x:y(-62),y:y(-86)},{x:y(-275),y:y(-134)},{x:y(-138),y:y(-244)}],WT:[],cv:[{x:y(345),y:y(356)},{x:y(345),y:y(356)},{x:y(345),y:y(356)}],pl:P,xq:dd,rl:y(-300),sl:y(100),ql:y(0),ol:y(0),LZ:[P,P],pq:void 0,cu:void 0,AZ:[[P,P],[P]],yZ:-1E3,zZ:[[{x:y(500),y:y(100)},{x:y(560),y:y(100)}],[{x:y(559),y:y(100)}]],Di:[],
YY:["SPRINGFIELD","CLAY VALLEY","PALM BEACH","TUNDRA TOWN"],ZY:[{x:3,y:-23},{x:17,y:-25},{x:0,y:-28},{x:10,y:-26}],XY:[],j:null,Bz:null,xg:[],e:[],rd:[],Gy:null,sY:null};function cn(a){this.name="LevelMap";this.n(V.p.NR);this.f(V.Gy);void 0!==a&&this.f(a)}hm(cn,yc);e=cn.prototype;e.Z=function(){this.i()};e.uC=function(a){a.sort(function(a,c){return a.W-c.W});return a};e.nC=function(a){for(var b=0;b<a.length;b++)this.e.push(a[b])};
e.pb=function(a){var b;if(b=this.CJ)b=q.nm[90];if(b){if(49==a)for(b=0;b<this.rd.length;b++)1===this.rd[b].id&&(this.rd[b].mr(1),dn(this.Di[b],1));if(50==a)for(b=0;b<this.rd.length;b++)2===this.rd[b].id&&(this.rd[b].mr(2),dn(this.Di[b],2));if(51==a)for(b=0;b<this.rd.length;b++)3===this.rd[b].id&&this.rd[b].mr(3)}};
function en(a){a.rd.reverse();var b=0;if(a.lj.MK)for(var b=a.lj.MK.BS,c=0;c<b.length;c++){var d=b[c],g=Lk(qk,a.mode,d+1);d+1<a.Zg&&0<a.Zg?a.rd[c]&&(fn(a.rd[c],c+1),a.Di[c]&&(a.Di[c].Es=!0)):d<=a.Zg&&0<g.Qf?a.rd[c]&&0<g.Qf&&(fn(a.rd[c],c+1),a.Di[c]&&(a.Di[c].Es=!0)):d===a.Zg&&a.rd[c]&&(a.rd[c].mr(c+1),a.Di[c]&&dn(a.Di[c],c+1))}}e.Fa=function(a,b,c,d,g){b=new b(c);void 0!==d&&b.f(d);void 0!==g&&b.f(g);a.e.push(b)};
e.Sf=function(a,b,c,d,g,k,l,m,p,w){var z=this;return this.Fa(a,an,{x:l,y:m,width:p,height:w,c:c,text:this.MR?"":k.toString(),marginTop:y(-5),icon:void 0===this.rG?null:this.rG[g],qa:"top",T:d?this.JR:this.IR,Ib:g,RR:d,vc:!1,threshold:y(1.5),j:function(a){!this.RR&&z.j&&z.j(z,a.Ib)}},this.Gy)};
function gn(a){var b=new hn,c=0,d=0,g=b.Tj.tH;a.lj=jn();a.af=a.lj.af.length;var k=1,l,m,p;m=Kk(qk);k=m.hq;a.Zg=m.kn;void 0===a.en&&(a.en=f.width/2);void 0===a.fn&&(a.fn=f.height/8);void 0==a.pq&&(a.pq=f.width);void 0==a.cu&&(a.cu=f.height);switch(a.vG){case "grid":a.If=Math.ceil(a.af/(a.Hy*a.bn));b=a.iq*a.bn+a.sG*(a.bn-2);for(m=0;m<a.If;m++){var w=new am({});if(a.my&&!a.MF){var z=new am({}),v=new u({c:a.Jy,x:a.en,y:a.fn,width:a.dn,height:a.cn});l=new F({text:a.Xt[m],x:a.en,y:a.fn,width:a.dn,height:a.cn});
z.e.push(v);z.e.push(l);w.e.push(z)}c=void 0===a.uG?(f.width-b)/2:a.uG;d=void 0===a.PR?200:a.IX;for(z=0;z<a.Hy;z++)for(v=0;v<a.bn;v++){var C=z*a.bn+v+m*a.Hy*a.bn;p=Lk(qk,a.mode,C);C+1===k&&(a.Gm=m);if(C===a.af){a.xg.push(w);return}var x=c+v*(a.iq+a.sG),t=d+z*(a.Vt+a.KR),A=C+1;p.lR?l=a.an[p.$g]:(l=a.an[4],A="");a.Sf(w,a.tG,l,p.lR,C,A,x,t,a.iq,a.Vt)}a.xg.push(w)}break;case "manual":var B=!1,k=f.width/2,ja=f.height/2;a.If=g.length;var xa=new kn;m=a.If/a.qr;a.WT=xa.Tj.page.EY;a.ZB=xa.Tj.page.ZB;if(xa)for(a.Rj=
[],z=0;z<m;z++)for(v=0;v<xa.Tj.page.zE.length;v++)a.Rj.push(xa.Tj.page.zE[v]);for(var Xa=[],z=0;z<a.If;z++){w=new am({});m=b.Tj[g[z]].items;for(v=0;v<m.length;v++)"background"===m[v].id&&(l=a.qD?new u({c:m[v].c,x:k,y:ja,tb:!0,Ng:!0,width:a.pq,height:a.cu}):new u({c:m[v].c,x:k,y:ja,tb:!1,Ng:!0,width:a.pq,height:a.cu}),w.e.push(l));Xa[z]=w}for(m=0;m<Xa.length;m++){w=b.Tj[g[m]].items;w=a.uC(w);z=new ln({id:m,Lm:w});Xa[m].e.push(z);for(z=0;z<w.length;z++)"background"!==w[z].id&&"gate"===w[z].id&&(d++,
0!==c&&(v=new am({}),l=new mn({id:c,position:{x:577,y:540}}),a.Di.push(l),v.d(l),Xa[m].e.push(v)),c++);a.my&&(z=new am({}),v=new u({c:a.Jy,x:a.cv[m].x,y:a.cv[m].y,width:a.dn,height:a.cn}),l=new F({text:a.Xt[m],x:a.cv[m].x,y:a.cv[m].y,width:a.dn,height:a.cn}),z.e.push(v),z.e.push(l),Xa[m].e.push(z));w=new am({x:k,y:ja});for(z=0;z<a.Ly;z++)C=z+m*a.Ly,p=Lk(qk,a.mode,C+1),2!==C+1||p.jo||(a.ty=a.Rj[C-1].x,a.Ht=a.Rj[C-1].y,B=!0),p.jo&&1>p.Wj&&(a.Gm=m,a.ty=a.Rj[C].x,a.Ht=a.Rj[C].y,-100>a.Ht&&(a.Gm+=.2),
B=!0),x=a.Rj[C].x,t=a.Rj[C].y,a.lj.af[C]&&void 0!==xa.buttons[a.lj.af[C].Bh.mode].images&&(a.an=xa.buttons[a.lj.af[C].Bh.mode].images),A=C+1,a.CJ?(a.Lt=!1,l=a.an[p.$g]):!p.jo&&0<C?(l=a.an[4],a.Lt=!0):(a.Lt=!1,l=a.an[p.$g]),a.iq=l.width,a.Vt=l.height,C+=1,a.Sf(w,a.tG,l,a.Lt,C,A,x,t,a.iq,a.Vt);a.HF&&B&&(z=new u({c:a.dR,x:a.ty-4,y:a.Ht-117}),w.e.push(z),B=!1);Xa[m].e.push(w);a.xg.push(Xa[m])}}}
e.w=function(){var a=this,b,c=0;gn(this);switch(this.vG){case "grid":"horizontal"===this.Wt?(this.my&&this.MF&&(this.xG=new u({c:this.Jy,x:this.en,y:this.fn,width:this.dn,height:this.cn}),this.yG=new F({text:this.Xt[0],x:this.en,y:this.fn,width:this.dn,height:this.cn,DJ:this.Xt})),this.Uo=new Vm({y:0,zb:2,eg:y(f.width),rf:25,ke:4,axis:new da(1,0),GB:this.xG,Ie:this.yG})):"vertical"===this.Wt&&(this.Uo=new Vm({y:0,zb:2,eg:y(f.height),rf:25,ke:4,axis:new da(0,1)}));for(b=0;b<this.xg.length;b++)this.Uo.addElement(this.xg[b]);
this.Uo.gB(this.Gm);this.d(this.Uo);break;case "manual":if("horizontal"===this.Wt)for(this.Ji=new nn({y:0,zb:1E4,eg:this.pq,rf:25,ke:4,axis:new da(1,0)}),b=this.xg.length-1;-1<b;b--)this.Ji.addElement(this.xg[b]);else if("vertical"===this.Wt&&(this.Ji=new nn({y:0,zb:1E4,eg:y(f.height),rf:25,ke:4,axis:new da(0,-1)}),this.EQ))for(b=this.xg.length-1;-1<b;b--){var d=new on({zz:function(b){var c=a.Fh;b*=a.qr;for(var d=0;d<b;d++)c+=1;0<a.fv&&c>a.fv&&(c=a.fv);a.Ji&&pn(a.Ji,c)}});c==this.qr&&(d.id=(b+1)/
this.qr,this.rd.push(d),this.xg[b].e.push(d),b===this.lj.MK.BS.length+this.qr&&(c=new F({text:this.cO,s:this.aO,font:this.bO,x:this.dO,y:this.eO}),this.xg[b].e.push(c)),c=0);c++;this.Ji.JC(this.xg[b],b)}this.fv=this.xg.length;this.Ji.gB(this.Gm);pn(this.Ji,this.Fh);this.d(this.Ji)}b=new qn({});this.zu=new D({c:this.pl,x:this.rl,y:this.sl,width:this.ql,height:this.ol,Va:y(30),j:function(){a.Bz&&a.Bz(a)}});this.zu.f(this.zu);b.d(this.zu);this.d(b);if(this.e)for(b=0;b<this.e.length;b+=1)this.d(this.e[b])};
e.I=function(){this.ya();this.zu=this.yG=this.xG=this.Ji=this.Uo=this.tG=void 0};e.da=function(){en(this);this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k))};e.Iq=function(){en(this)};e.pa=function(){};
V.p.cM={backgroundImage:null,depth:-5,fr:0,st:S,Mx:$d,Px:y(0),Qx:y(0),Ox:y(480),Lx:y(480),lF:{h:rn,duration:.4,pk:1,Ej:1.8,qk:1,Fj:1.3,o:$b,name:"frameScale"},OP:{h:Gl,duration:1,u:y(-1500),G:y(0),o:$b,K:1.2,name:"frameAppear"},qt:{h:Gl,duration:1,u:y(0),G:y(-1500),o:$b,K:1.2},ww:Xd,yw:y(0),zw:y(-61),xw:y(470),vw:y(450),Mh:ce,Oh:y(0),Ph:y(138),Nh:y(96),Lh:y(96),An:{h:sn,duration:4,pk:1,Ej:1.25,qk:1,Fj:.9,K:1,name:"elastic"},yn:{h:Hl,duration:.5,qc:y(0),wb:y(1),o:gc,K:1},zn:{h:Jl,Of:y(1),Dj:y(0),duration:10,
o:$b,name:"hide"},Xx:"undefined"!==typeof s_title_gamelogo?s_title_gamelogo:void 0,Ah:y(-320),Rg:y(220),Zx:y(280),Wx:y(160),qF:{h:Kl,duration:.4,aa:this.Ah,u:this.Rg,Aa:y(-300),G:y(230),qc:1,wb:.6},hA:{h:Jl,duration:.2,Of:1,Dj:0,name:"endBar"},j:null,Yd:null,lT:null,kT:null,Dn:null,Bi:null,Nx:null,SM:null,iA:null,viewport:void 0,Jo:0,Ko:150,Gg:void 0,Fg:void 0,Vm:!1,Cj:!0,Ch:!1,Ja:"none",Um:!1,lc:!1,kH:null,e:[]};function tn(a){this.name="AdDialogStage";this.n(V.p.cM);void 0!==a&&this.f(a)}
hm(tn,yc);e=tn.prototype;e.create=function(){sm(xm,this.Ja,this.Nj(),this.Oj(),this.Pj(),this.Mj());Bm(this.Nq,this)};e.Nq=function(a){var b=a.viewport.clientWidth/r.em,c=a.Pj(),d=a.Mj(),c=Math.round(c*b),d=Math.round(d*b),g=a.Nj(),k=a.Oj(),k=Math.round((k-r.wk)*b)+"px",b=Math.round((g-r.vk)*b)+"px";Cm(a.Ja,b,k,c,d)};e.Pj=function(){return this.Gg-y(32)-y(32)};e.Mj=function(){return this.Fg-y(32)-y(156)};e.Nj=function(){return this.Ko+y(32)};e.Oj=function(){return this.Jo+y(32)};
e.ew=function(){this.Ba&&X(this.Ba,3)};e.fw=function(){this.zc||(console.log("adDialogStage "+this.Ja),Em(this.Ja))};e.sf=function(){this.ga();this.zc?X(this.xc,2):this.i();this.Tb&&this.Tb(this.fr)};e.jz=function(){this.zc&&X(this.xc,2);this.Ba&&X(this.Ba,3)};e.qh=function(){this.ga();this.zc?X(this.xc,2):this.i()};e.AE=function(){};e.XH=function(a){void 0!==this.kb&&this.kb.pg(a,!1)};e.sE=function(){void 0!==this.kb&&this.kb.pg(100,!0)};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;if(Dm(this.Ja)){void 0===this.Gg&&(this.Gg=r.De);void 0===this.Fg&&(this.Fg=r.Ur);this.viewport=r.g;this.create();this.lc=xm.lc;this.xc=new am({});if(this.lc)switch(this.Ja){case "admob":ym();break;case "chartboost":zm()}this.Um?(a=new cm({width:this.width,height:this.height}),this.d(a),this.xc=new am({y:y(0),x:y(0),S:[this.OP,{h:"show",duration:99999999},{h:"show",duration:1},this.qt],dh:function(a,d){"frameAppear"===d.name&&Em(b.Ja)},
yb:function(){b.i()}}),this.zc=new u({c:this.Mx,x:this.Px,y:this.Qx,width:this.Ox,height:this.Lx,tb:!0,mb:1.8,Fb:1.3}),this.zc.f(this.Nx),this.xc.d(this.zc),a=new u({c:this.ww,x:this.yw,y:this.zw,height:this.vw,width:this.xw,mb:1.74,Fb:1}),this.xc.d(a),this.ob=new u({c:this.Xx,x:this.Ah,y:this.Rg,width:this.Zx,height:this.Wx,mb:.6,Fb:.6}),this.ob.f(this.Bi),this.xc.d(this.ob),a=new F({s:"is continuing in",x:y(-137),y:y(232),T:this.st,width:y(200),height:y(100)}),this.xc.d(a),this.kb=new bm({x:y(200),
y:y(230),width:y(400),S:[{h:"show",duration:99999999},this.hA],dh:function(a,d){"endBar"===d.name&&b.kb.i()}}),this.kb.f(this.iA),this.xc.d(this.kb),this.Ba=new D({c:this.Mh,x:this.Oh,y:this.Ph,width:this.Nh,height:this.Lh,S:[this.yn,this.An,{h:"show",duration:99999999},this.zn],j:function(){b.Cj=!0;b.lc||"none"!==b.Ja?b.lc&&"none"===b.Ja?(b.sf(),Em(b.Ja)):b.Yd?b.Yd(b):b.ew():b.jz()},dh:function(a,d){"elastic"===d.name&&X(b.Ba,1);"hide"===d.name&&b.Ba.i()}}),this.d(this.xc)):(a=new cm({width:this.width,
height:this.height}),this.d(a));if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a]);qm(xm)}else xm.sf(),this.i()};e.I=function(){this.ya();this.xc=this.kb=this.Bm=this.ob=this.zc=this.Ba=void 0};e.da=function(){this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k))};e.xb=function(a,b){"Ad Failed"===a?(this.Cj&&this.qh(),console.log(b.error)):"Ad Completed"===a?(this.Cj&&this.sf(),console.log("Did Complete")):"Ad Reward"===a&&(console.log(b.js),this.fr++)};
e.Ga=function(a){un.Cb.Ga.call(this,a);!this.Vm&&this.Cj&&Dm(this.Ja)&&(this.fw(),this.Vm=this.Ch=!0);this.Ch&&void 0!==this.kb&&0<xm.Ch(this.Ja,a)&&this.kb.pg(xm.Ch(this.Ja,a),!1)};e.pa=function(){};e.Sa=function(a,b,c){un.Cb.Sa.call(this,a,b,c);return!0};e.Dh=function(){wm()};
V.p.li={backgroundImage:null,depth:-5,fr:0,Mx:$d,Px:y(0),Qx:y(0),Ox:y(480),Lx:y(480),lF:{h:rn,duration:.6,pk:1,Ej:1.8,qk:1,Fj:1.3,o:$b,name:"frameScale"},qt:{h:Gl,duration:1,u:y(-100),G:y(-1500),o:$b,K:1.2},ww:Xd,yw:y(0),zw:y(-50),xw:y(250),vw:y(550),Mh:ce,Oh:y(0),Ph:y(80),Nh:y(154),Lh:y(152),An:{h:sn,duration:4,pk:1,Ej:1.25,qk:1,Fj:.9,K:1,name:"elastic"},yn:{h:Hl,duration:.5,qc:y(0),wb:y(1),o:gc,K:1},zn:{h:Jl,Of:y(1),Dj:y(0),duration:10,o:$b,name:"hide"},Xx:"undefined"!==typeof s_title_gamelogo?
s_title_gamelogo:void 0,Ah:y(0),Rg:y(-115),Zx:y(417),Wx:y(219),qF:{h:Kl,duration:.6,aa:this.Ah,u:this.Rg,Aa:y(-300),G:y(230),qc:1,wb:.6},QP:"",PP:"Click To Play",RP:y(0),SP:y(195),st:S,hA:{h:Jl,duration:.2,Of:1,Dj:0,name:"endBar"},j:null,Yd:null,lT:null,kT:null,Dn:null,Bi:null,Nx:null,SM:null,iA:null,Rp:null,viewport:void 0,Zk:Zd,Kp:60,Df:y(200),Jo:0,Ko:150,Gg:void 0,Fg:void 0,Vm:!1,Cj:!1,Ch:!1,Ja:"none",Um:!1,lc:!1,kH:null,e:[]};
function un(a){this.name="AdDialog";this.n(V.p.li);void 0!==a&&this.f(a)}hm(un,yc);e=un.prototype;e.create=function(){sm(xm,this.Ja,this.Nj(),this.Oj(),this.Pj(),this.Mj());Bm(this.Nq,this)};e.Nq=function(a){var b=a.viewport.clientWidth/r.em,c=a.Pj(),d=a.Mj(),c=Math.round(c*b),d=Math.round(d*b),g=a.Nj(),k=a.Oj(),k=Math.round((k-r.wk)*b)+"px",b=Math.round((g-r.vk)*b)+"px";Cm(a.Ja,b,k,c,d)};e.Pj=function(){return this.Gg-y(32)-y(32)};e.Mj=function(){return this.Fg-y(32)-y(156)};
e.Nj=function(){return this.Ko+y(32)};e.Oj=function(){return this.Jo+y(32)};e.ew=function(){this.Ba&&X(this.Ba,3)};e.fw=function(){this.zc?(this.Bm.show(),X(this.zc,1),X(this.ob,1)):Em(this.Ja)};e.sf=function(){this.ga();this.zc?(X(this.zc,3),X(this.ob,3)):this.i();"none"!==this.Ja&&this.kb&&X(this.kb,1);this.Tb&&this.Tb(this.fr);xm.ky&&(this.Ba.i(),this.rt.i())};e.jz=function(){this.zc&&(X(this.zc,3),X(this.ob,3));this.Ba&&X(this.Ba,3)};
e.qh=function(){this.ga();this.Vm?(this.zc?(X(this.zc,3),X(this.ob,3)):this.i(),"none"!==this.Ja&&X(this.kb,1)):this.i()};e.AE=function(){var a=this,b=new F({s:"is loading now",x:y(-310),y:y(5),T:this.st,width:y(200),height:y(100)});this.kb=new bm({x:y(200),y:y(230),width:y(400),S:[{h:"show",duration:99999999},this.hA],dh:function(c,d){"endBar"===d.name&&(a.kb.i(),b.i())}});this.kb.f(this.iA);this.kb.e.push(b);this.d(this.kb);"woobi"!==this.Ja&&(this.kb.ka(),this.kb.show())};
e.XH=function(a){void 0!==this.kb&&this.kb.pg(a,!1)};e.sE=function(){void 0!==this.kb&&this.kb.pg(100,!0)};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;void 0===this.Gg&&(this.Gg=r.De);void 0===this.Fg&&(this.Fg=r.Ur);this.viewport=r.g;this.create();this.lc=xm.lc;this.Rp=new am({});if(this.lc)switch(this.Ja){case "admob":ym();break;case "chartboost":zm()}null!==this.Zk&&(a=function(a,d,g){a.x=b.Df/2*Math.sin(2*Math.PI*g/b.Kp);a.y=b.Df/2*-Math.cos(2*Math.PI*g/b.Kp)},this.$k=new s({S:{h:a,duration:9999999}}),this.$k.tz=function(){b.Zk.jx(0,-b.x-b.Df/2,-b.y-b.Df/2,f.width+b.Df,f.height+
b.Df,1)},this.d(this.$k));this.Um?(this.zc=new u({c:this.Mx,x:this.Px,y:this.Qx,width:this.Ox,height:this.Lx,tb:!0,S:[{h:"show",duration:99999999},this.lF,{h:"show",duration:99999999},{h:"show",duration:1},this.qt],dh:function(a,d){"frameScale"===d.name&&Em(b.Ja)},yb:function(){b.i()}}),this.zc.f(this.Nx),this.Bm=new u({c:this.ww,x:this.yw,y:this.zw,height:this.vw,width:this.xw,mb:1.74,Fb:1.37}),this.zc.e.push(this.Bm),this.Rp.d(this.zc),this.ob=new u({c:this.Xx,x:this.Ah,y:this.Rg,width:this.Zx,
height:this.Wx,S:[{h:"show",duration:99999999},this.qF,{h:"show",duration:99999999},{h:"show",duration:1},this.qt]}),this.ob.f(this.Bi),this.Rp.d(this.ob),this.Ba=new D({c:this.Mh,x:this.Oh,y:this.Ph,width:this.Nh,height:this.Lh,S:[this.yn,this.An,{h:"show",duration:99999999},this.zn],j:function(){b.Cj=!0;xm.ky?b.sf():b.lc||"none"!==b.Ja?b.lc&&"none"===b.Ja?(b.sf(),Em(b.Ja)):b.Yd?b.Yd(b):b.ew():b.jz()},dh:function(a,d){"elastic"===d.name&&X(b.Ba,1);"hide"===d.name&&(b.Ba.i(),b.rt.i())}}),this.Ba.f(this.Dn),
this.Rp.d(this.Ba),this.d(this.Rp),this.rt=new F({text:this.QP,x:this.RP,y:this.SP,s:this.PP,T:this.st}),this.d(this.rt)):(a=new cm({width:this.width,height:this.height}),this.d(a));if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.$k=this.kb=this.Bm=this.rt=this.ob=this.zc=this.Ba=void 0};e.da=function(){this.Bm&&this.Bm.i();this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k))};
e.xb=function(a,b){"Ad Failed"===a?(this.qh(),console.log(b.error)):"Ad Completed"===a?(this.Cj&&this.sf(),console.log("Did Complete")):"Ad Reward"===a&&(console.log(b.js),this.fr++)};e.Ga=function(a){un.Cb.Ga.call(this,a);!this.Vm&&this.Cj&&Dm(this.Ja)&&(this.fw(),this.AE(),this.Vm=this.Ch=!0);this.Ch&&void 0!==this.kb&&0<xm.Ch(this.Ja,a)&&this.kb.pg(xm.Ch(this.Ja,a),!1)};e.pa=function(){};e.Sa=function(a,b,c){un.Cb.Sa.call(this,a,b,c);return!0};e.Dh=function(){wm()};
V.J.jO={$Q:"undefined"!==typeof s_gate_closed?s_gate_closed:null,SF:"undefined"!==typeof s_gate_open?s_gate_open:null,XQ:"undefined"!==typeof s_gate_lock?s_gate_lock:null,mP:"undefined"!==typeof s_glitter?s_glitter:null,NE:y(0),OA:!1,IE:1,AG:1,VJ:0,position:[],id:0,Yt:0,dc:!1,Es:!1,La:5E3,Ra:null,q0:3E3,xh:1E3,e:[]};function mn(a){this.name="ComponentGate";this.n(V.J.jO);void 0!==a&&this.f(a);this.Y=new kc(this)}zl(mn,s);e=mn.prototype;
e.mr=function(a){a===this.id&&(this.dc=!0);console.log("ID: "+a+"THIS ID: "+this.id)};
function dn(a,b){var c;b===a.id&&(a.Y.dj=[],a.Y.Wa=[],a.Y.setTime(0),c=lc(a.Y,"function",a,function(b){a.IE=b}),mc(a.Y,c,[{time:0,value:1},{time:1E3,value:0}]),c=lc(a.Y,"function",a,function(b){a.AG=b}),mc(a.Y,c,[{time:1E3,value:1},{time:2E3,value:0}]),pc(a.Y,a,1E3,a.sI),c=lc(a.Y,"function",a,function(b){a.NE=Math.floor(b)}),mc(a.Y,c,[{time:1E3,value:0},{time:2E3,value:6}]),c=lc(a.Y,"function",a,function(b){a.VJ=b}),mc(a.Y,c,[{time:1500,value:0},{time:2200,value:1}]),pc(a.Y,a,2200,a.sI))}
e.sI=function(){this.OA=this.OA?!1:!0};e.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};e.sd=function(a){this.Y.Vb(a)};e.me=function(){};e.Bf=function(){};e.Qk=function(){};e.zj=function(){};e.Aj=function(){};e.Bj=function(){};e.xi=function(){};e.wh=function(){};e.$c=function(){};e.Cf=function(){};
e.jc=function(){this.Es||(this.dc||(this.$Q.ib(0,this.position.x,this.position.y,1,1,0,this.AG),this.SF.ib(0,this.position.x,this.position.y,1,1,0,this.VJ),this.XQ.ib(0,this.position.x,this.position.y,1,1,0,this.IE)),this.OA&&this.mP.ib(this.NE,this.position.x,this.position.y,1,1,0,1));this.Es&&this.SF.ib(0,this.position.x,this.position.y,1,1,0,1)};e.ag=function(){};
V.J.LV={Xe:null,Vg:null,ab:null,Nd:0,Ar:0,Eh:!1,hr:!0,Ng:!1,tb:!1,Xd:null,nc:!0,bu:!0,e:[],id:0,lb:0,tk:.2,wi:!1,b0:!1,zr:!1,jf:void 0,mc:null};function vn(a){this.name="Star";this.n(V.J.LV);void 0!==a&&this.f(a)}zl(vn,s);e=vn.prototype;e.Pc=function(){return 0<this.width?this.width:this.Xe?this.Ng?this.Xe.vj:this.Xe.width:0};e.Oc=function(){return 0<this.height?this.height:this.Xe?this.Ng?this.Xe.uj:this.Xe.height:0};e.w=function(){var a;for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
e.da=function(){0===this.id&&(this.zr=!0);this.ra=this.Ar;this.tk*=1E3};e.Cf=function(a){0<this.tk&&this.zr?this.tk-=1E3*a/1E3:(1>this.tk&&(this.tk=0),null!==this.ab&&this.ab instanceof h&&!this.wi&&this.zr&&(a=this.ra+this.Nd*a/1E3,this.ra<this.ab.N&&a>=this.ab.N?(this.ra=this.Eh?a-this.ab.N:this.ab.N,this.Xd&&(this.Xd(this,this.id),this.wi=!0)):0<this.ra&&0>a?(this.ra=this.Eh?this.ab.N+a:0,this.Xd&&(this.Xd(this,this.id),this.wi=!0)):this.ra=a))};
e.jc=function(){var a,b,c;null!==this.Xe&&(b=this.Xe.width,a=this.Xe.height,this.Xe.B(0,-b/2+this.Xe.Da,-a/2+this.Xe.Ea));this.id<this.lb&&0===this.tk&&(null===this.ab||this.wi||(b=this.ab.width,a=this.ab.height,b=-b/2,c=-a/2,a=this.hr?this.ra:Math.min(this.c.N-1,Math.floor(this.ra)),this.ab.B(a,b+this.ab.Da,c+this.ab.Ea)),null!==this.Vg&&(b=this.Vg.width,a=this.Vg.height,this.Vg.B(0,-b/2+this.Vg.Da,-a/2+this.Vg.Ea)))};
V.J.iO={c:"undefined"!==typeof s_fogofwar_cloud_transparent?s_fogofwar_cloud_transparent:null,backgroundImage:"undefined"!==typeof s_fogofwar_gradient?s_fogofwar_gradient:null,Ab:[{x:100,y:-150},{x:50,y:-400},{x:70,y:-270},{x:200,y:-300},{x:300,y:-200},{x:300,y:-350},{x:450,y:-250},{x:530,y:-300},{x:600,y:-250},{x:700,y:-300},{x:800,y:-200},{x:950,y:-300},{x:1100,y:-150},{x:1100,y:-250}],id:0,Yt:0,dz:!1,La:5E3,Ra:null,zz:null,aG:!0,e:[]};
function on(a){this.name="ComponentCloud";this.n(V.J.iO);void 0!==a&&this.f(a);a=new fa;for(var b=0;b<this.Ab.length;b++)this.Ab[b].kw=0+a.random(6),this.Ab[b].lw=0+a.random(6)}zl(on,s);e=on.prototype;e.mr=function(a){a===this.id&&(this.dz=!0)};function fn(a,b){a.zz&&b===a.id&&(a.zz(a.id),a.aG=!1)}e.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};e.sd=function(){};e.me=function(){};e.Bf=function(){};
e.Qk=function(){};e.zj=function(){};e.Aj=function(){};e.xi=function(){};e.wh=function(){};e.$c=function(a){this.dz&&(this.Yt+=a,this.y-=80/a,this.Yt>this.La&&(this.dz=!1,fn(this,this.id)));if(0!==a)for(var b=0;b<this.Ab.length;b++){var c=this.Ab[b].kw,d=this.Ab[b].lw,c=c+.06/a,d=d+.0833/a;6.2831852<c&&(c%=6.2831852);6.2831852<d&&(d%=6.2831852);this.Ab[b].kw=c;this.Ab[b].lw=d}};e.Cf=function(){};
e.jc=function(){if(this.aG){ya(this.backgroundImage,0,-730,1,1,1);for(var a=0;a<this.Ab.length;a++)this.c.ib(0,this.Ab[a].x+20*Math.sin(this.Ab[a].kw),this.Ab[a].y+5*Math.sin(this.Ab[a].lw),1,1,0,1)}};e.ag=function(){};V.J.aM={Hs:null,viewport:void 0,Jo:0,Ko:150,Gg:void 0,Fg:void 0,Ja:"google",j:null,kH:null,e:[]};function wn(a){this.name="Ad";this.n(V.J.aM);void 0!==a&&this.f(a)}zl(wn,s);e=wn.prototype;e.create=function(){sm(xm,this.Ja,this.Nj(),this.Oj(),this.Pj(),this.Mj());Bm(this.Nq,this)};
e.Nq=function(a){var b=a.viewport.clientWidth/r.em,c=a.Pj(),d=a.Mj(),c=Math.round(c*b),d=Math.round(d*b),g=a.Nj(),k=a.Oj(),k=Math.round((k-r.wk)*b)+"px",b=Math.round((g-r.vk)*b)+"px";Cm(a.Ja,b,k,c,d)};e.Pj=function(){return this.Gg-y(32)-y(32)};e.Mj=function(){return this.Fg-y(32)-y(156)};e.Nj=function(){return this.Ko+y(32)};e.Oj=function(){return this.Jo+y(32)};
e.w=function(){var a;void 0===this.Gg&&(this.Gg=r.De);void 0===this.Fg&&(this.Fg=r.Ur);this.viewport=r.g;this.create();if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.sd=function(){if(this.Br&&-1<this.tf&&!this.XJ){this.tf=1E3*this.cY.aZ();var a=Math.round((this.lM-this.tf)/this.lM*100);null!==this.Hs&&this.Hs.XH(a);0>this.tf&&(this.Br=!1)}else this.XJ&&null!==this.Hs&&this.Hs.sE()};V.J.lS={c:P,eg:500,rf:45,zb:1,ke:7,index:0};
function nn(a){this.n(V.J.lS);this.index=0;this.eg=500;this.elements=[];this.Gd=-1;this.axis=new da(1,0);this.Lj=new da(0,0);this.speed=0;this.rf=45;this.ke=7;this.Fh=-1;this.Pn=this.v=0;this.Gn=null;this.WS=.1;this.isMap=!0;void 0!==a&&this.f(a)}zl(nn,s);Math.round=Math.round;e=nn.prototype;e.addElement=function(a){this.d(a);this.elements.push(a);this.Vh(a,this.elements.length-1)};e.JC=function(a,b){this.d(a);this.elements[b]=a;this.Vh(a,b)};
e.Vh=function(a,b){var c=this.axis.scale(this.eg*(b-this.v));a.x=Math.round(c.x);a.y=Math.round(c.y);this.Gn&&this.Gn(a)};e.gB=function(a){this.v=Math.max(Math.min(this.elements.length-1,a),0);for(a=0;a<this.elements.length;++a)this.Vh(this.elements[a],a)};function pn(a,b){b&&(a.Fh=b)}
e.sd=function(a){if(this.isMap){if(0!==Math.round(this.v)){this.elements[Math.round(this.v)].show();this.elements[Math.round(this.v)].ka();this.elements[Math.round(this.v)+1].show();this.elements[Math.round(this.v)+1].ka();this.elements[Math.round(this.v)-1].show();this.elements[Math.round(this.v)-1].ka();1<Math.round(this.v)&&this.elements[0].i();for(var b=Math.round(this.v)-2;0<b;b--)this.elements[b]&&this.elements[b].i();for(b=Math.round(this.v)+2;b<this.elements.length;b++)this.elements[b]&&this.elements[b].i()}else if(0>=
Math.round(this.v))for(this.elements[Math.round(this.v)].show(),this.elements[Math.round(this.v)].ka(),b=2;b<this.elements.length;b++)this.elements[b].i();b=this.v}if(0<=this.Gd){var c=new da(q.hd(this.Gd)-this.Lj.x,q.Uc(this.Gd)-this.Lj.y),d=-1/this.eg;c.x*=d;c.y*=d;this.v=ea(c,this.axis)+this.Pn;0>this.Fh?0>this.v?this.v=Math.atan(this.v*this.zb)/this.zb:this.v>this.elements.length-1&&(this.v=Math.atan(this.zb*(this.v-this.elements.length+1))/this.zb+this.elements.length-1):0>this.v?this.v=Math.atan(this.v*
this.zb)/this.zb:this.v>this.Fh-1&&(this.v=Math.atan(this.zb*(this.v-this.Fh+1))/this.zb+this.Fh-1);this.speed=Math.min(Math.max(1E3*(this.v-b)/a,-4),4)}else 0>this.v?(this.v=Math.atan(this.v*this.zb)/this.zb,c=Math.round(this.v),c=Math.max(0,Math.min(this.elements.length-1,c)),c-=this.v,c=c*this.rf-this.speed*this.ke,this.speed+=a/1E3*c,this.v+=a/1E3*this.speed):this.v>this.elements.length-1&&(this.v=Math.atan(this.zb*(this.v-this.elements.length+1))/this.zb+this.elements.length-1,c=Math.round(this.v),
c=Math.max(0,Math.min(this.elements.length-1,c)),c-=this.v,c=c*this.rf-this.speed*this.ke,this.speed+=a/1E3*c,this.v+=a/1E3*this.speed);if(b!==this.v)for(b=0;b<this.elements.length;++b)this.Vh(this.elements[b],b)};e.me=function(a){if(-1===this.Gd){this.Gd=a;var b=this.Lj,c=q.Uc(a);b.x=q.hd(a);b.y=c;this.Pn=this.v}};e.Bf=function(a){a===this.Gd&&(this.Gd=-1)};
e.Ug=function(a){if(!(2>this.elements.length))for(this.v+=a*this.WS,a=this.Fh,0>a&&(a=this.elements.length-1),0>this.v?(this.v=Math.atan(this.v*this.zb)/this.zb,a=Math.round(this.v),a=Math.max(0,Math.min(this.elements.length-1,a)),a-=this.v,a=a*this.rf-this.speed*this.ke,this.speed+=2E-4*a,this.v+=2E-4*this.speed):this.v>a-1&&(this.v=Math.atan(this.zb*(this.v-a+1))/this.zb+a-1,a=Math.round(this.v),a=Math.max(0,Math.min(this.elements.length-1,a)),a-=this.v,a=a*this.rf-this.speed*this.ke,this.speed+=
2E-4*a,this.v+=2E-4*this.speed),a=0;a<this.elements.length;++a)this.Vh(this.elements[a],a)};V.J.tP={C:!1,threshold:y(0),dv:0,ev:0,QJ:y(3),$m:""};function an(a){this.name="ExtButton";this.n(V.J.button);this.f(V.J.tP);this.cj=new da(0,0);void 0!==a&&this.f(a)}zl(an,D);e=an.prototype;e.Yb=function(a,b){"active"===a?this.j&&this.j(this):an.Cb.Yb.call(this,a,b)};
e.me=function(a,b,c){this.dv=this.hd(a);this.ev=this.Uc(a);this.threshold=void 0===this.threshold?0:this.threshold;if(!this.nh)return this.Rk(a,b,c)};e.Bf=function(a,b,c){this.ev=this.dv=0;if(!this.nh)return this.Sk(a,b,c)};e.Rk=function(a,b,c){var d=this.ta.width+2*this.Va,g=this.ta.height+2*this.Va;if(b>=-d/2&&b<=d/2&&c>=-g/2&&c<=g/2&&("up"===this.state||"active"===this.state?(this.Yb("down",!0),this.ha=a,this.cj=this.Vs(b,c)):this.ha=a,this.vc))return!0};
e.Sk=function(a){this.ha===a&&(this.ha=-1,this.Yb("active"),this.C=!0,this.$a=this.QJ,this.Af())};e.w=function(){an.Cb.w.call(this);""!==this.$m&&tk.Xf===this.$m&&(this.C=!0,this.Yb("down",!1),this.$a=this.QJ,this.Af())};e.$c=function(a){var b,c;-1!==this.ha&&(b=this.hd(this.ha),c=this.Uc(this.ha),b>this.dv+this.threshold||b<this.dv-this.threshold||c<this.ev-this.threshold||c>this.ev+this.threshold?("down"===this.state&&this.Yb("up",!1),this.ha=-1):an.Cb.$c.call(this,a))};
function sn(a,b,c){var d=jc([ic,function(a,b,c,d){return gc(a,b,c,d,3,2)},Zb],[!0,!1,!1],[.02,.1,.88]),g=void 0===b.K?void 0:b.K,d=void 0===b.Wk?d:b.Wk,g=void 0===b.Cp?g:b.Cp,k=void 0===b.pk?1:b.pk,l=void 0===b.qk?1:b.qk,m=void 0===b.Fj?1:b.Fj;a.mb=d(c,k,(void 0===b.Ej?1:b.Ej)-k,b.duration,g);a.Fb=d(c,l,m-l,b.duration,g)}
function rn(a,b,c){var d=void 0===b.o?$b:b.o,g=void 0===b.K?void 0:b.K,d=void 0===b.Wk?d:b.Wk,g=void 0===b.Cp?g:b.Cp,k=void 0===b.pk?1:b.pk,l=void 0===b.qk?1:b.qk,m=void 0===b.Fj?1:b.Fj;a.mb=d(c,k,(void 0===b.Ej?1:b.Ej)-k,b.duration,g);a.Fb=d(c,l,m-l,b.duration,g)}V.J.IO={id:0,Lm:[],e:[]};function ln(a){this.name="Decalls";this.n(V.J.IO);void 0!==a&&this.f(a);this.UI=!1}zl(ln,s);e=ln.prototype;e.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};
e.da=function(){this.UI=!0};e.pa=function(){};e.$f=function(){};e.sd=function(){};e.$c=function(){};e.Cf=function(){};e.jc=function(){if(this.UI)for(var a=0;a<this.Lm.length;a++)"background"!==this.Lm[a].id&&this.Lm[a].c.ib(0,this.Lm[a].x,this.Lm[a].y,1,1,0,1)};e.ag=function(){};function xn(a,b,c,d,g,k){s.call(this,a);this.width=d;this.height=g;this.Ca=2;this.alpha=1;this.text="";this.font=k?k:fonts.la.PY;this.H=new za(d+2*this.Ca,g+2*this.Ca);yn(this,"LOREM IPSUM")}zl(xn,s);
function yn(a,b){if(a.text!==b){a.text=b;a.H.clear();Aa(a.H);var c=1,d=a.font.Lr(a.text)+(a.font.stroke?a.font.ug:0),g=a.font.vg(a.text)+(a.font.stroke?a.font.ug:0),k=a.font.fontSize;d>a.width&&(c=a.width/d);g>a.height&&(c=Math.min(c,a.height/g));Ga(a.font,Math.floor(k*c));switch(a.font.align){case "left":a.font.B(a.text,a.Ca,a.H.height/2+.085*a.H.height);break;case "center":a.font.B(a.text,a.H.width/2,a.H.height/2+.085*a.H.height);break;case "right":a.font.B(a.text,a.H.width-a.Ca,a.H.height/2+.085*
a.H.height)}Ga(a.font,k);Ba(a.H)}}xn.prototype.ix=function(){yl.MY&&qa(this.x,this.y,this.width,this.height,"red",!0);1!==this.alpha&&(f.context.save(),f.context.globalAlpha*=this.alpha);this.H.B(this.x-this.Ca,this.y-this.Ca);1!==this.alpha&&f.context.restore()};function zn(a,b,c,d,g,k,l,m,p){xn.call(this,null,0,0,c,d,g);this.canvas=p;this.depth=k?k:-900;this.W=l?l:-901;this.visible=this.D=!0;this.P=m;Mb(this)}zl(zn,xn);zn.prototype.Ha=function(){this.ix()};
function An(a,b,c,d,g,k,l,m,p,w,z,v){void 0===d&&(d=0);void 0===g&&(g=OpenSansBold);g=g.Zc();void 0!==l&&g.setFillColor(l);void 0!==m&&g.setStrokeColor(m);void 0!==k&&Ga(g,g.fontSize*k);Na(g,"middle");zn.call(this,0,0,g.Lr(a)+(g.stroke?g.ug:0),g.vg(a)+50+(g.stroke?g.ug:0),g,p,w,z,v);this.La=0;this.duration=2200;this.lP=jc([Zb,Zb,dc],[!1,!1,!1],[.2,0,1.3]);this.kx=jc([Zb,Zb,fc],[!1,!1,!1],[.2,.4,.9]);this.Wk=jc([ic,Zb,Zb],[!1,!1,!1],[.2,.4,.9]);this.x=b;this.y=c;this.La=-d;yn(this,a);this.mF=c;this.zW=
c-y(50);this.D=!0;this.scale=0;this.alpha=1}zl(An,zn);An.prototype.wa=function(a){this.La+=a;0<this.La&&(this.La>=this.duration?Xb(q,this):(this.y=this.lP(this.La,this.mF,this.zW-this.mF,this.duration),this.alpha=this.kx(this.La,1,-1,this.duration),this.scale=this.Wk(this.La,0,1,this.duration)))};An.prototype.ix=function(){0<this.La&&this.H.ib(this.x-this.H.width/2*this.scale,this.y-this.H.height/2*this.scale,this.scale,this.scale,0,this.alpha)};An.prototype.Qa=function(){this.P&&this.P()};
V.J.ET={k_:void 0,e:[]};function Bn(a,b,c){this.c=a;this.Ab=b;this.ZB=c;this.Mk;this.direction=.1;this.name="Pathfinding";this.n(V.J.ET);this.Y=new kc(this);this.QC=0;this.Mk=b[0];Cn(this)}zl(Bn,s);
function Cn(a){var b;a.Y.dj=[];a.Y.Wa=[];b=lc(a.Y,"function",a,function(b){var d=Math.floor(b),g=Math.ceil(b);b-=d;var k=.5*(this.Ab[d].x+this.Ab[g].x),l=.5*(this.Ab[d].y+this.Ab[g].y),l=l+a.ZB[d],d=this.Ab[d],g=this.Ab[g],g={x:Math.pow(1-b,2)*d.x+2*(1-b)*b*k+Math.pow(b,2)*g.x,y:Math.pow(1-b,2)*d.y+2*(1-b)*b*l+Math.pow(b,2)*g.y};b=Math.atan2(-(g.x-a.Mk.x),g.y-a.Mk.y);0>b&&(b+=2*Math.PI);a.QC=Math.round(b/(2*Math.PI)*8);a.Mk=g});mc(a.Y,b,[{time:0,value:0},{time:1500*Math.abs(19),value:19}])}
Bn.prototype.wa=function(a){this.Y.Vb(a)};Bn.prototype.Ha=function(){this.Mk&&this.c.ib(this.QC,this.Mk.x,this.Mk.y,1,1,0,1)};Bn.prototype.w=function(){var a;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};var Y=Y||{};Y["nl-nl"]=Y["nl-nl"]||{};Y["nl-nl"].optionsAbout_header_publisher="Published by:";Y["nl-nl"].challengeForfeitMessage_winnings="<NAME> heeft <AMOUNT> Fairplay munten gewonnen!";Y["nl-nl"].challengeEndScreenChallengeSend_submessage_stranger="Als niemand binnen 72 uur je uitdaging accepteert, worden je inzet en uitdagingskosten teruggestort.";
Y["nl-nl"].challengeEndScreenChallengeSend_submessage="<NAME> heeft 72 uur om de uitdaging aan te nemen of te weigeren. Als <NAME> je uitdaging weigert of niet accepteert binnen 72 uur worden je inzet en uitdagingskosten teruggestort.";Y["nl-nl"].levelEndScreenHighScore_number="Topscore:";Y["nl-nl"].levelEndScreenTotalScore_number="Totale score:";Y["nl-nl"].optionsExit="Stoppen";Y["nl-nl"]["optionsLang_ru-ru"]="Russisch";Y["nl-nl"]["optionsLang_pt-br"]="Braziliaans-Portugees";
Y["nl-nl"]["optionsLang_es-es"]="Spaans";Y["nl-nl"]["optionsLang_ar-eg"]="Arabisch";Y["nl-nl"]["optionsLang_ko-kr"]="Koreaans";Y["nl-nl"]["optionsLang_fr-fr"]="Frans";Y["nl-nl"].levelEndScreenTotalScore_time="Totale tijd:";Y["nl-nl"].levelEndScreenHighScore_time="Beste tijd:";Y["nl-nl"].challengeLoadingError_notStarted="Kan de server niet bereiken. Probeer het later nog een keer.";Y["nl-nl"].challengeLoadingError_notValid="Sorry, deze uitdaging kan niet meer gespeeld worden.";
Y["nl-nl"].optionsChallengeCancel="Stop";Y["nl-nl"].optionsChallengeForfeit="Geef op";Y["nl-nl"].challengeForfeitMessage_error="Er is een fout opgetreden tijdens het opgeven van de uitdaging. Probeer het later nog een keer.";Y["nl-nl"].challengeForfeitMessage_success="Je hebt de uitdaging opgegeven.";Y["nl-nl"].challengeForfeitConfirmBtn_no="Nee";Y["nl-nl"].challengeForfeitConfirmBtn_yes="Ja";Y["nl-nl"].challengeForfeitConfirmText="Je staat op het punt de uitdaging op te geven. Weet je zeker dat je dit wilt doen?";
Y["nl-nl"].challengeStartTextScore_challenger="Speel het spel en zet een score neer.";Y["nl-nl"].challengeStartTextTime_challenger="Speel het spel en zet een tijd neer.";Y["nl-nl"].challengeStartScreenTitle_challenger_stranger="Je zet een uitdaging voor:";Y["nl-nl"].challengeStartScreenTitle_challenger_friend="Jouw tegenstander:";Y["nl-nl"].challengeStartScreenTitle_challengee_stranger="Jouw tegenstander:";Y["nl-nl"].challengeEndScreenScoreSend_error="Er is een fout opgetreden tijdens de communicatie met de server. Probeer het later nog een keer.";
Y["nl-nl"].challengeCancelMessage_success="De uitdaging is geannuleerd.";Y["nl-nl"].challengeCancelMessage_error="Er is een fout opgetreden bij het annuleren van de uitdaging. Probeer het later nog een keer.";Y["nl-nl"].challengeEndScreenChallengeSend_success="Je uitdaging is verstuurd!";Y["nl-nl"].challengeEndScreenChallengeSend_error="Er is een fout opgetreden bij het versturen van de uitdaging. Probeer het later nog een keer.";Y["nl-nl"].challengeEndScreenName_you="Jij";
Y["nl-nl"].challengeEndScreenBtn_cancel="Annuleer uitdaging";Y["nl-nl"].challengeEndScreensBtn_submit="Verstuur uitdaging";Y["nl-nl"].challengeCancelConfirmBtn_no="Nee";Y["nl-nl"].challengeCancelConfirmBtn_yes="Ja";Y["nl-nl"].challengeCancelConfirmText="Je staat op het punt de uitdaging te annuleren. Je inzet wordt teruggestort minus de uitdagingskosten. Weet je zeker dat je de uitdaging wilt annuleren? ";Y["nl-nl"].challengeEndScreenOutcomeMessage_TIED="Jullie hebben gelijk gespeeld.";
Y["nl-nl"].challengeEndScreenOutcomeMessage_LOST="Je hebt de uitdaging verloren.";Y["nl-nl"].challengeEndScreenOutcomeMessage_WON="Je hebt de uitdaging gewonnen!";Y["nl-nl"].challengeEndScreenWinnings="Je hebt <AMOUNT> Fairplay munten gewonnen!";Y["nl-nl"].challengeStartScreenToWin="Te winnen aantal Fairplay munten:";Y["nl-nl"].challengeStartTextTime="Tijd van <NAME>:";Y["nl-nl"].challengeStartTextScore="Punten van <NAME>:";Y["nl-nl"].challengeStartScreenTitle_challengee_friend="Je bent uitgedaagd door:";
Y["nl-nl"].levelEndScreenSubmitHighscoreBtn="Score verzenden";Y["nl-nl"].levelEndScreenViewHighscoreBtn="Scores bekijken";Y["nl-nl"].optionsAbout_header="Ontwikkeld door:";Y["nl-nl"]["optionsLang_tr-tr"]="Turks";Y["nl-nl"]["optionsLang_de-de"]="Duits";Y["nl-nl"].startScreenByTinglyGames="door: CoolGames";Y["nl-nl"].levelMapScreenWorld_0="Kies een level";Y["nl-nl"].startScreenQuestionaire="Wat vind jij?";Y["nl-nl"].levelEndScreenMedal="VERBETERD!";Y["nl-nl"].optionsAbout="Over ons";
Y["nl-nl"].optionsAbout_version="versie:";Y["nl-nl"].optionsAbout_backBtn="Terug";Y["nl-nl"].optionsAbout_text="CoolGames\nwww.coolgames.com\nCopyright \u00a9 2016";Y["nl-nl"].optionsAbout_title="Over ons";Y["nl-nl"].optionsSFXBig_off="Geluid uit";Y["nl-nl"].optionsSFXBig_on="Geluid aan";Y["nl-nl"].optionsRestart="Herstart";Y["nl-nl"].optionsRestartConfirmationText="Pas op!\n\nAls je nu herstart verlies je alle voortgang in dit level. Weet je zeker dat je wilt herstarten?";
Y["nl-nl"].levelMapScreenTitle="Kies een level";Y["nl-nl"].optionsQuitConfirmBtn_Yes="Ja, ik weet het zeker";Y["nl-nl"].optionsQuitConfirmBtn_No="Nee";Y["nl-nl"].optionsQuitConfirmationText="Pas op!\n\nAls je nu stopt verlies je alle voortgang in dit level. Weet je zeker dat je wilt stoppen?";Y["nl-nl"].optionsTitle="Instellingen";Y["nl-nl"].gameEndScreenBtnText="Ga verder";Y["nl-nl"].gameEndScreenTitle="Gefeliciteerd!\nJe hebt gewonnen.";Y["nl-nl"]["optionsLang_nl-nl"]="Nederlands";
Y["nl-nl"]["optionsLang_en-gb"]="Engels (GB)";Y["nl-nl"]["optionsLang_en-us"]="Engels (US)";Y["nl-nl"].optionsSFX_off="Uit";Y["nl-nl"].optionsSFX_on="Aan";Y["nl-nl"].optionsMusic_off="Uit";Y["nl-nl"].optionsMusic_on="Aan";Y["nl-nl"].optionsDifficulty_hard="Moeilijk";Y["nl-nl"].optionsDifficulty_medium="Gemiddeld";Y["nl-nl"].optionsDifficulty_easy="Makkelijk";Y["nl-nl"].optionsMoreGames="Meer Spellen";Y["nl-nl"].optionsHighScore="High scores";Y["nl-nl"].optionsTutorial="Speluitleg";
Y["nl-nl"].optionsResume="Terug naar spel";Y["nl-nl"].optionsQuit="Stop";Y["nl-nl"].optionsStartScreen="Hoofdmenu";Y["nl-nl"].levelEndScreenHighScore="High score";Y["nl-nl"].levelEndScreenTimeBonus="Tijdbonus";Y["nl-nl"].levelEndScreenTimeLeft="Tijd over";Y["nl-nl"].levelEndScreenSubTitle_levelFailed="Level niet gehaald";Y["nl-nl"].levelEndScreenTotalScore="Totale score";Y["nl-nl"].levelEndScreenTitle_endless="Level <VALUE>";Y["nl-nl"].levelEndScreenTitle_difficulty="Goed Gedaan!";
Y["nl-nl"].levelEndScreenTitle_level="Level <VALUE>";Y["nl-nl"].levelMapScreenTotalScore="Totale score";Y["nl-nl"].startScreenPlay="SPELEN";Y["nl-nl"].loadingScreenLoading="Laden...";Y["nl-nl"].RewardAd_button="video";Y["nl-nl"].RewardAd_header="coins";Y["nl-nl"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["nl-nl"].RewardAd_text_2="new video is available soon";Y["en-us"]=Y["en-us"]||{};Y["en-us"].optionsAbout_header_publisher="Published by:";
Y["en-us"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["en-us"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["en-us"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["en-us"].levelEndScreenHighScore_number="High score:";Y["en-us"].levelEndScreenTotalScore_number="Total score:";Y["en-us"].optionsExit="Exit";Y["en-us"]["optionsLang_ru-ru"]="Russian";Y["en-us"]["optionsLang_pt-br"]="Brazilian-Portuguese";Y["en-us"]["optionsLang_es-es"]="Spanish";Y["en-us"]["optionsLang_ar-eg"]="Arabic";Y["en-us"]["optionsLang_ko-kr"]="Korean";Y["en-us"]["optionsLang_fr-fr"]="French";Y["en-us"].levelEndScreenTotalScore_time="Total time:";
Y["en-us"].levelEndScreenHighScore_time="Best time:";Y["en-us"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["en-us"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["en-us"].optionsChallengeCancel="Quit";Y["en-us"].optionsChallengeForfeit="Forfeit";Y["en-us"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["en-us"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["en-us"].challengeForfeitConfirmBtn_no="No";Y["en-us"].challengeForfeitConfirmBtn_yes="Yes";Y["en-us"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["en-us"].challengeStartTextScore_challenger="Play the game and set a score.";Y["en-us"].challengeStartTextTime_challenger="Play the game and set a time.";Y["en-us"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["en-us"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["en-us"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["en-us"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["en-us"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["en-us"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["en-us"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["en-us"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["en-us"].challengeEndScreenName_you="You";Y["en-us"].challengeEndScreenBtn_cancel="Cancel challenge";Y["en-us"].challengeEndScreensBtn_submit="Submit challenge";Y["en-us"].challengeCancelConfirmBtn_no="No";Y["en-us"].challengeCancelConfirmBtn_yes="Yes";Y["en-us"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["en-us"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["en-us"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["en-us"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["en-us"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["en-us"].challengeStartScreenToWin="Amount to win:";Y["en-us"].challengeStartTextTime="<NAME>'s time:";Y["en-us"].challengeStartTextScore="<NAME>'s score:";
Y["en-us"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["en-us"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["en-us"].levelEndScreenViewHighscoreBtn="View scores";Y["en-us"].optionsAbout_header="Developed by:";Y["en-us"]["optionsLang_tr-tr"]="Turkish";Y["en-us"]["optionsLang_de-de"]="German";Y["en-us"].startScreenByTinglyGames="by: CoolGames";Y["en-us"].levelMapScreenWorld_0="Select a level";Y["en-us"].startScreenQuestionaire="What do you think?";
Y["en-us"].levelEndScreenMedal="IMPROVED!";Y["en-us"].optionsAbout="About";Y["en-us"].optionsAbout_version="version:";Y["en-us"].optionsAbout_backBtn="Back";Y["en-us"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["en-us"].optionsAbout_title="About";Y["en-us"].optionsSFXBig_off="Sound off";Y["en-us"].optionsSFXBig_on="Sound on";Y["en-us"].optionsRestart="Restart";Y["en-us"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";
Y["en-us"].levelMapScreenTitle="Select a level";Y["en-us"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Y["en-us"].optionsQuitConfirmBtn_No="No";Y["en-us"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Y["en-us"].optionsTitle="Settings";Y["en-us"].gameEndScreenBtnText="Continue";Y["en-us"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Y["en-us"]["optionsLang_nl-nl"]="Dutch";
Y["en-us"]["optionsLang_en-gb"]="English (GB)";Y["en-us"]["optionsLang_en-us"]="English (US)";Y["en-us"].optionsSFX_off="Off";Y["en-us"].optionsSFX_on="On";Y["en-us"].optionsMusic_off="Off";Y["en-us"].optionsMusic_on="On";Y["en-us"].optionsDifficulty_hard="Difficult";Y["en-us"].optionsDifficulty_medium="Medium";Y["en-us"].optionsDifficulty_easy="Easy";Y["en-us"].optionsMoreGames="More Games";Y["en-us"].optionsHighScore="High scores";Y["en-us"].optionsTutorial="How to play";
Y["en-us"].optionsResume="Resume";Y["en-us"].optionsQuit="Quit";Y["en-us"].optionsStartScreen="Main menu";Y["en-us"].levelEndScreenHighScore="High score";Y["en-us"].levelEndScreenTimeBonus="Time bonus";Y["en-us"].levelEndScreenTimeLeft="Time remaining";Y["en-us"].levelEndScreenSubTitle_levelFailed="Level failed";Y["en-us"].levelEndScreenTotalScore="Total score";Y["en-us"].levelEndScreenTitle_endless="Stage <VALUE>";Y["en-us"].levelEndScreenTitle_difficulty="Well done!";
Y["en-us"].levelEndScreenTitle_level="Level <VALUE>";Y["en-us"].levelMapScreenTotalScore="Total score";Y["en-us"].startScreenPlay="PLAY";Y["en-us"].loadingScreenLoading="Loading...";Y["en-us"].RewardAd_button="video";Y["en-us"].RewardAd_header="coins";Y["en-us"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["en-us"].RewardAd_text_2="new video is available soon";Y["en-gb"]=Y["en-gb"]||{};Y["en-gb"].optionsAbout_header_publisher="Published by:";
Y["en-gb"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["en-gb"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["en-gb"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["en-gb"].levelEndScreenHighScore_number="High score:";Y["en-gb"].levelEndScreenTotalScore_number="Total score:";Y["en-gb"].optionsExit="Exit";Y["en-gb"]["optionsLang_ru-ru"]="Russian";Y["en-gb"]["optionsLang_pt-br"]="Brazilian-Portuguese";Y["en-gb"]["optionsLang_es-es"]="Spanish";Y["en-gb"]["optionsLang_ar-eg"]="Arabic";Y["en-gb"]["optionsLang_ko-kr"]="Korean";Y["en-gb"]["optionsLang_fr-fr"]="French";Y["en-gb"].levelEndScreenTotalScore_time="Total time:";
Y["en-gb"].levelEndScreenHighScore_time="Best time:";Y["en-gb"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["en-gb"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["en-gb"].optionsChallengeCancel="Quit";Y["en-gb"].optionsChallengeForfeit="Forfeit";Y["en-gb"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["en-gb"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["en-gb"].challengeForfeitConfirmBtn_no="No";Y["en-gb"].challengeForfeitConfirmBtn_yes="Yes";Y["en-gb"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you wish to proceed?";Y["en-gb"].challengeStartTextScore_challenger="Play the game and set a score.";Y["en-gb"].challengeStartTextTime_challenger="Play the game and set a time.";Y["en-gb"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["en-gb"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["en-gb"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["en-gb"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["en-gb"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["en-gb"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["en-gb"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["en-gb"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["en-gb"].challengeEndScreenName_you="You";Y["en-gb"].challengeEndScreenBtn_cancel="Cancel challenge";Y["en-gb"].challengeEndScreensBtn_submit="Submit challenge";Y["en-gb"].challengeCancelConfirmBtn_no="No";Y["en-gb"].challengeCancelConfirmBtn_yes="Yes";Y["en-gb"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["en-gb"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["en-gb"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["en-gb"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["en-gb"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["en-gb"].challengeStartScreenToWin="Amount to win:";Y["en-gb"].challengeStartTextTime="<NAME>'s time:";Y["en-gb"].challengeStartTextScore="<NAME>'s score:";
Y["en-gb"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["en-gb"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["en-gb"].levelEndScreenViewHighscoreBtn="View scores";Y["en-gb"].optionsAbout_header="Developed by:";Y["en-gb"]["optionsLang_tr-tr"]="Turkish";Y["en-gb"]["optionsLang_de-de"]="German";Y["en-gb"].startScreenByTinglyGames="by: CoolGames";Y["en-gb"].levelMapScreenWorld_0="Select a level";Y["en-gb"].startScreenQuestionaire="What do you think?";
Y["en-gb"].levelEndScreenMedal="IMPROVED!";Y["en-gb"].optionsAbout="About";Y["en-gb"].optionsAbout_version="version:";Y["en-gb"].optionsAbout_backBtn="Back";Y["en-gb"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["en-gb"].optionsAbout_title="About";Y["en-gb"].optionsSFXBig_off="Sound off";Y["en-gb"].optionsSFXBig_on="Sound on";Y["en-gb"].optionsRestart="Restart";Y["en-gb"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";
Y["en-gb"].levelMapScreenTitle="Select a level";Y["en-gb"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";Y["en-gb"].optionsQuitConfirmBtn_No="No";Y["en-gb"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";Y["en-gb"].optionsTitle="Settings";Y["en-gb"].gameEndScreenBtnText="Continue";Y["en-gb"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";Y["en-gb"]["optionsLang_nl-nl"]="Dutch";
Y["en-gb"]["optionsLang_en-gb"]="English (GB)";Y["en-gb"]["optionsLang_en-us"]="English (US)";Y["en-gb"].optionsSFX_off="Off";Y["en-gb"].optionsSFX_on="On";Y["en-gb"].optionsMusic_off="Off";Y["en-gb"].optionsMusic_on="On";Y["en-gb"].optionsDifficulty_hard="Difficult";Y["en-gb"].optionsDifficulty_medium="Medium";Y["en-gb"].optionsDifficulty_easy="Easy";Y["en-gb"].optionsMoreGames="More Games";Y["en-gb"].optionsHighScore="High scores";Y["en-gb"].optionsTutorial="How to play";
Y["en-gb"].optionsResume="Resume";Y["en-gb"].optionsQuit="Quit";Y["en-gb"].optionsStartScreen="Main menu";Y["en-gb"].levelEndScreenHighScore="High score";Y["en-gb"].levelEndScreenTimeBonus="Time bonus";Y["en-gb"].levelEndScreenTimeLeft="Time remaining";Y["en-gb"].levelEndScreenSubTitle_levelFailed="Level failed";Y["en-gb"].levelEndScreenTotalScore="Total score";Y["en-gb"].levelEndScreenTitle_endless="Stage <VALUE>";Y["en-gb"].levelEndScreenTitle_difficulty="Well done!";
Y["en-gb"].levelEndScreenTitle_level="Level <VALUE>";Y["en-gb"].levelMapScreenTotalScore="Total score";Y["en-gb"].startScreenPlay="PLAY";Y["en-gb"].loadingScreenLoading="Loading...";Y["en-gb"].RewardAd_button="video";Y["en-gb"].RewardAd_header="coins";Y["en-gb"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["en-gb"].RewardAd_text_2="new video is available soon";Y["de-de"]=Y["de-de"]||{};Y["de-de"].optionsAbout_header_publisher="Published by:";
Y["de-de"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["de-de"].challengeEndScreenChallengeSend_submessage_stranger="Als niemanden Deine Herausforderung innerhalb von 72 Stunden annimmt, werden Dir Deinen Wetteinsatz Einsatzgeb\u00fchr zur\u00fcckerstattet.";Y["de-de"].challengeEndScreenChallengeSend_submessage="<NAME> hat 72 Stunden um die Wette anzunehmen oder abzulehnen. Sollte <NAME> nicht reagieren oder ablehnen werden Dir Dein Wetteinsatz und die Geb\u00fchr zur\u00fcckerstattet.";
Y["de-de"].levelEndScreenHighScore_number="Highscore:";Y["de-de"].levelEndScreenTotalScore_number="Gesamtpunktzahl:";Y["de-de"].optionsExit="Verlassen";Y["de-de"]["optionsLang_ru-ru"]="Russisch";Y["de-de"]["optionsLang_pt-br"]="Portugiesisch (Brasilien)";Y["de-de"]["optionsLang_es-es"]="Spanisch";Y["de-de"]["optionsLang_ar-eg"]="Arabisch";Y["de-de"]["optionsLang_ko-kr"]="Koreanisch";Y["de-de"]["optionsLang_fr-fr"]="Franz\u00f6sisch";Y["de-de"].levelEndScreenTotalScore_time="Gesamtzeit:";
Y["de-de"].levelEndScreenHighScore_time="Bestzeit:";Y["de-de"].challengeLoadingError_notStarted="Leider ist ein Fehler\u00a0aufgetreten. Es konnte keiner Verbindung zum Server hergestellt werden. Versuche es bitte nochmal sp\u00e4ter.";Y["de-de"].challengeLoadingError_notValid="Leider ist diese Partie nicht mehr aktuel.";Y["de-de"].optionsChallengeCancel="Zur\u00fcckziehen";Y["de-de"].optionsChallengeForfeit="Aufgeben";Y["de-de"].challengeForfeitMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Y["de-de"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["de-de"].challengeForfeitConfirmBtn_no="Nein";Y["de-de"].challengeForfeitConfirmBtn_yes="Ja";Y["de-de"].challengeForfeitConfirmText="Willst du Die Partie wirklich aufgeben?";Y["de-de"].challengeStartTextScore_challenger="Spiel um die hochste Punktzahl!";Y["de-de"].challengeStartTextTime_challenger="Spiel um die niedrigste Zeit!";Y["de-de"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["de-de"].challengeStartScreenTitle_challenger_friend="Du hast den folgenden Spieler herausgefordert:";Y["de-de"].challengeStartScreenTitle_challengee_stranger="Dein Gegner wird:";Y["de-de"].challengeEndScreenScoreSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Y["de-de"].challengeCancelMessage_success="Du hast die Wette erfolgreich zur\u00fcckgezogen.";Y["de-de"].challengeCancelMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
Y["de-de"].challengeEndScreenChallengeSend_success="Herausforderung verschickt!";Y["de-de"].challengeEndScreenChallengeSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";Y["de-de"].challengeEndScreenName_you="Du";Y["de-de"].challengeEndScreenBtn_cancel="Zur\u00fcckziehen";Y["de-de"].challengeEndScreensBtn_submit="Herausfordern";Y["de-de"].challengeCancelConfirmBtn_no="Nein";Y["de-de"].challengeCancelConfirmBtn_yes="Ja";Y["de-de"].challengeCancelConfirmText="Willst Du Deine Wette wirklich zur\u00fcckziehen? Dein Wetteinsatz wird Dir zur\u00fcckgegeben minus die Einsatzgeb\u00fchr.";
Y["de-de"].challengeEndScreenOutcomeMessage_TIED="Gleichstand!";Y["de-de"].challengeEndScreenOutcomeMessage_LOST="Leider hat Dein Gegner die Partie gewonnen.";Y["de-de"].challengeEndScreenOutcomeMessage_WON="Du hast die Partie gewonnen!";Y["de-de"].challengeEndScreenWinnings="Du hast <AMOUNT> Fairm\u00fcnzen gewonnen!";Y["de-de"].challengeStartScreenToWin="Einsatz:";Y["de-de"].challengeStartTextTime="Zeit von <NAME>:";Y["de-de"].challengeStartTextScore="Punktzahl von <NAME>:";
Y["de-de"].challengeStartScreenTitle_challengee_friend="Dein Gegner:";Y["de-de"].levelEndScreenSubmitHighscoreBtn="Punktzahl senden";Y["de-de"].levelEndScreenViewHighscoreBtn="Punktzahlen ansehen";Y["de-de"].optionsAbout_header="Entwickelt von:";Y["de-de"]["optionsLang_tr-tr"]="T\u00fcrkisch";Y["de-de"]["optionsLang_de-de"]="Deutsch";Y["de-de"].startScreenByTinglyGames="von: CoolGames";Y["de-de"].levelMapScreenWorld_0="W\u00e4hle ein Level";Y["de-de"].startScreenQuestionaire="Deine Meinung z\u00e4hlt!";
Y["de-de"].levelEndScreenMedal="VERBESSERT!";Y["de-de"].optionsAbout="\u00dcber";Y["de-de"].optionsAbout_version="Version:";Y["de-de"].optionsAbout_backBtn="Zur\u00fcck";Y["de-de"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["de-de"].optionsAbout_title="\u00dcber";Y["de-de"].optionsSFXBig_off="Sound AUS";Y["de-de"].optionsSFXBig_on="Sound EIN";Y["de-de"].optionsRestart="Neustart";Y["de-de"].optionsRestartConfirmationText="Achtung!\n\nWenn du jetzt neu startest, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich neu starten?";
Y["de-de"].levelMapScreenTitle="W\u00e4hle ein Level";Y["de-de"].optionsQuitConfirmBtn_Yes="Ja, ich bin mir sicher";Y["de-de"].optionsQuitConfirmBtn_No="NEIN";Y["de-de"].optionsQuitConfirmationText="Achtung!\n\nWenn du jetzt aufh\u00f6rst, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich aufh\u00f6ren?";Y["de-de"].optionsTitle="Einstellungen";Y["de-de"].gameEndScreenBtnText="Weiter";Y["de-de"].gameEndScreenTitle="Gl\u00fcckwunsch!\nDu hast das Spiel abgeschlossen.";
Y["de-de"]["optionsLang_nl-nl"]="Holl\u00e4ndisch";Y["de-de"]["optionsLang_en-gb"]="Englisch (GB)";Y["de-de"]["optionsLang_en-us"]="Englisch (US)";Y["de-de"].optionsSFX_off="AUS";Y["de-de"].optionsSFX_on="EIN";Y["de-de"].optionsMusic_off="AUS";Y["de-de"].optionsMusic_on="EIN";Y["de-de"].optionsDifficulty_hard="Schwer";Y["de-de"].optionsDifficulty_medium="Mittel";Y["de-de"].optionsDifficulty_easy="Einfach";Y["de-de"].optionsMoreGames="Weitere Spiele";Y["de-de"].optionsHighScore="Highscores";
Y["de-de"].optionsTutorial="So wird gespielt";Y["de-de"].optionsResume="Weiterspielen";Y["de-de"].optionsQuit="Beenden";Y["de-de"].optionsStartScreen="Hauptmen\u00fc";Y["de-de"].levelEndScreenHighScore="Highscore";Y["de-de"].levelEndScreenTimeBonus="Zeitbonus";Y["de-de"].levelEndScreenTimeLeft="Restzeit";Y["de-de"].levelEndScreenSubTitle_levelFailed="Level nicht geschafft";Y["de-de"].levelEndScreenTotalScore="Gesamtpunkte";Y["de-de"].levelEndScreenTitle_endless="Stufe <VALUE>";
Y["de-de"].levelEndScreenTitle_difficulty="Sehr gut!";Y["de-de"].levelEndScreenTitle_level="Level <VALUE>";Y["de-de"].levelMapScreenTotalScore="Gesamtpunkte";Y["de-de"].startScreenPlay="SPIELEN";Y["de-de"].loadingScreenLoading="Laden ...";Y["de-de"].RewardAd_button="video";Y["de-de"].RewardAd_header="coins";Y["de-de"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["de-de"].RewardAd_text_2="new video is available soon";Y["fr-fr"]=Y["fr-fr"]||{};Y["fr-fr"].optionsAbout_header_publisher="Published by:";
Y["fr-fr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["fr-fr"].challengeEndScreenChallengeSend_submessage_stranger="Si personne n\u2019accepte votre pari d\u2019ici 72 heures, on vous remboursera le montant du pari y compris les frais.";Y["fr-fr"].challengeEndScreenChallengeSend_submessage="<NAME> a 72 heures pour accepter votre d\u00e9fi. Si <NAME> refuse ou n\u2019accepte pas dans ce d\u00e9lai vous serez rembours\u00e9 le montant de votre pari et les frais de pari.";
Y["fr-fr"].levelEndScreenHighScore_number="Meilleur score :";Y["fr-fr"].levelEndScreenTotalScore_number="Score total :";Y["fr-fr"].optionsExit="Quitter";Y["fr-fr"]["optionsLang_ru-ru"]="Russe";Y["fr-fr"]["optionsLang_pt-br"]="Portugais - Br\u00e9silien";Y["fr-fr"]["optionsLang_es-es"]="Espagnol";Y["fr-fr"]["optionsLang_ar-eg"]="Arabe";Y["fr-fr"]["optionsLang_ko-kr"]="Cor\u00e9en";Y["fr-fr"]["optionsLang_fr-fr"]="Fran\u00e7ais";Y["fr-fr"].levelEndScreenTotalScore_time="Temps total :";
Y["fr-fr"].levelEndScreenHighScore_time="Meilleur temps :";Y["fr-fr"].challengeLoadingError_notStarted="Une erreur de connexion est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeLoadingError_notValid="D\u00e9sol\u00e9, cette partie n'existe plus.";Y["fr-fr"].optionsChallengeCancel="Annuler";Y["fr-fr"].optionsChallengeForfeit="Abandonner";Y["fr-fr"].challengeForfeitMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";
Y["fr-fr"].challengeForfeitMessage_success="Vous avez abandonn\u00e9.";Y["fr-fr"].challengeForfeitConfirmBtn_no="Non";Y["fr-fr"].challengeForfeitConfirmBtn_yes="Oui";Y["fr-fr"].challengeForfeitConfirmText="Voulez-vous vraiment abandonner la partie ?";Y["fr-fr"].challengeStartTextScore_challenger="Essayez d\u2019atteindre le plus haut score !";Y["fr-fr"].challengeStartTextTime_challenger="Finissez le plus vite possible !";Y["fr-fr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["fr-fr"].challengeStartScreenTitle_challenger_friend="Votre adversaire\u00a0:";Y["fr-fr"].challengeStartScreenTitle_challengee_stranger="Votre adversaire\u00a0:";Y["fr-fr"].challengeEndScreenScoreSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeCancelMessage_success="D\u00e9fi annul\u00e9.";Y["fr-fr"].challengeCancelMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";
Y["fr-fr"].challengeEndScreenChallengeSend_success="D\u00e9fi lanc\u00e9.";Y["fr-fr"].challengeEndScreenChallengeSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";Y["fr-fr"].challengeEndScreenName_you="Moi";Y["fr-fr"].challengeEndScreenBtn_cancel="Annuler le d\u00e9fi";Y["fr-fr"].challengeEndScreensBtn_submit="Lancer le d\u00e9fi";Y["fr-fr"].challengeCancelConfirmBtn_no="Non";Y["fr-fr"].challengeCancelConfirmBtn_yes="Oui";Y["fr-fr"].challengeCancelConfirmText="Si vous annulez, on vous remboursera le montant du pari moins les frais de pari. Voulez-vous continuer\u00a0? ";
Y["fr-fr"].challengeEndScreenOutcomeMessage_TIED="Ex-aequo\u00a0!";Y["fr-fr"].challengeEndScreenOutcomeMessage_LOST="Zut\u00a0!";Y["fr-fr"].challengeEndScreenOutcomeMessage_WON="Vainqueur\u00a0!";Y["fr-fr"].challengeEndScreenWinnings="Vous avez gagn\u00e9 <AMOUNT> fairpoints.";Y["fr-fr"].challengeStartScreenToWin="\u00c0 gagner\u00a0:";Y["fr-fr"].challengeStartTextTime="Son temps\u00a0:";Y["fr-fr"].challengeStartTextScore="Son score :";Y["fr-fr"].challengeStartScreenTitle_challengee_friend="Votre adversaire\u00a0:";
Y["fr-fr"].levelEndScreenSubmitHighscoreBtn="Publier un score";Y["fr-fr"].levelEndScreenViewHighscoreBtn="Voir les scores";Y["fr-fr"].optionsAbout_header="D\u00e9velopp\u00e9 par :";Y["fr-fr"]["optionsLang_tr-tr"]="Turc";Y["fr-fr"]["optionsLang_de-de"]="Allemand";Y["fr-fr"].startScreenByTinglyGames="Un jeu CoolGames";Y["fr-fr"].levelMapScreenWorld_0="Choisir un niveau";Y["fr-fr"].startScreenQuestionaire="Un avis sur le jeu ?";Y["fr-fr"].levelEndScreenMedal="RECORD BATTU !";
Y["fr-fr"].optionsAbout="\u00c0 propos";Y["fr-fr"].optionsAbout_version="Version :";Y["fr-fr"].optionsAbout_backBtn="Retour";Y["fr-fr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["fr-fr"].optionsAbout_title="\u00c0 propos";Y["fr-fr"].optionsSFXBig_off="Sans son";Y["fr-fr"].optionsSFXBig_on="Avec son";Y["fr-fr"].optionsRestart="Recommencer";Y["fr-fr"].optionsRestartConfirmationText="Attention !\n\nEn recommen\u00e7ant maintenant, vous perdrez votre progression pour le niveau en cours. Recommencer quand m\u00eame ?";
Y["fr-fr"].levelMapScreenTitle="Choisir un niveau";Y["fr-fr"].optionsQuitConfirmBtn_Yes="Oui";Y["fr-fr"].optionsQuitConfirmBtn_No="Non";Y["fr-fr"].optionsQuitConfirmationText="Attention !\n\nEn quittant maintenant, vous perdrez votre progression pour le niveau en cours. Quitter quand m\u00eame ?";Y["fr-fr"].optionsTitle="Param\u00e8tres";Y["fr-fr"].gameEndScreenBtnText="Continuer";Y["fr-fr"].gameEndScreenTitle="F\u00e9licitations !\nVous avez termin\u00e9 le jeu.";
Y["fr-fr"]["optionsLang_nl-nl"]="N\u00e9erlandais";Y["fr-fr"]["optionsLang_en-gb"]="Anglais (UK)";Y["fr-fr"]["optionsLang_en-us"]="Anglais (US)";Y["fr-fr"].optionsSFX_off="Sans";Y["fr-fr"].optionsSFX_on="Avec";Y["fr-fr"].optionsMusic_off="Sans";Y["fr-fr"].optionsMusic_on="Avec";Y["fr-fr"].optionsDifficulty_hard="Difficile";Y["fr-fr"].optionsDifficulty_medium="Moyen";Y["fr-fr"].optionsDifficulty_easy="Facile";Y["fr-fr"].optionsMoreGames="Plus de jeux";Y["fr-fr"].optionsHighScore="Meilleurs scores";
Y["fr-fr"].optionsTutorial="Comment jouer";Y["fr-fr"].optionsResume="Reprendre";Y["fr-fr"].optionsQuit="Quitter";Y["fr-fr"].optionsStartScreen="Menu principal";Y["fr-fr"].levelEndScreenHighScore="Meilleur score";Y["fr-fr"].levelEndScreenTimeBonus="Bonus de temps";Y["fr-fr"].levelEndScreenTimeLeft="Temps restant";Y["fr-fr"].levelEndScreenSubTitle_levelFailed="\u00c9chec du niveau";Y["fr-fr"].levelEndScreenTotalScore="Score total";Y["fr-fr"].levelEndScreenTitle_endless="Sc\u00e8ne <VALUE>";
Y["fr-fr"].levelEndScreenTitle_difficulty="Bien jou\u00e9 !";Y["fr-fr"].levelEndScreenTitle_level="Niveau <VALUE>";Y["fr-fr"].levelMapScreenTotalScore="Score total";Y["fr-fr"].startScreenPlay="JOUER";Y["fr-fr"].loadingScreenLoading="Chargement...";Y["fr-fr"].RewardAd_button="video";Y["fr-fr"].RewardAd_header="coins";Y["fr-fr"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["fr-fr"].RewardAd_text_2="new video is available soon";Y["pt-br"]=Y["pt-br"]||{};
Y["pt-br"].optionsAbout_header_publisher="Published by:";Y["pt-br"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["pt-br"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["pt-br"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["pt-br"].levelEndScreenHighScore_number="Pontua\u00e7\u00e3o m\u00e1xima:";Y["pt-br"].levelEndScreenTotalScore_number="Pontua\u00e7\u00e3o total:";Y["pt-br"].optionsExit="Sa\u00edda";Y["pt-br"]["optionsLang_ru-ru"]="Russo";Y["pt-br"]["optionsLang_pt-br"]="Portugu\u00eas do Brasil";Y["pt-br"]["optionsLang_es-es"]="Espanhol";Y["pt-br"]["optionsLang_ar-eg"]="\u00c1rabe";Y["pt-br"]["optionsLang_ko-kr"]="Coreano";Y["pt-br"]["optionsLang_fr-fr"]="Franc\u00eas";
Y["pt-br"].levelEndScreenTotalScore_time="Tempo total:";Y["pt-br"].levelEndScreenHighScore_time="Tempo recorde:";Y["pt-br"].challengeLoadingError_notStarted="Imposs\u00edvel conectar ao servidor. Por favor, tente novamente mais tarde.";Y["pt-br"].challengeLoadingError_notValid="Desculpe, este desafio n\u00e3o \u00e9 mais v\u00e1lido.";Y["pt-br"].optionsChallengeCancel="Sair do Jogo";Y["pt-br"].optionsChallengeForfeit="Desistir";Y["pt-br"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["pt-br"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["pt-br"].challengeForfeitConfirmBtn_no="No";Y["pt-br"].challengeForfeitConfirmBtn_yes="Yes";Y["pt-br"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["pt-br"].challengeStartTextScore_challenger="Play the game and set a score.";Y["pt-br"].challengeStartTextTime_challenger="Play the game and set a time.";
Y["pt-br"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["pt-br"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["pt-br"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["pt-br"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["pt-br"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["pt-br"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["pt-br"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["pt-br"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["pt-br"].challengeEndScreenName_you="You";Y["pt-br"].challengeEndScreenBtn_cancel="Cancel challenge";Y["pt-br"].challengeEndScreensBtn_submit="Submit challenge";Y["pt-br"].challengeCancelConfirmBtn_no="No";Y["pt-br"].challengeCancelConfirmBtn_yes="Yes";Y["pt-br"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["pt-br"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["pt-br"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["pt-br"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["pt-br"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["pt-br"].challengeStartScreenToWin="Amount to win:";Y["pt-br"].challengeStartTextTime="<NAME>'s time:";Y["pt-br"].challengeStartTextScore="<NAME>'s score:";
Y["pt-br"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["pt-br"].levelEndScreenSubmitHighscoreBtn="Enviar recorde";Y["pt-br"].levelEndScreenViewHighscoreBtn="Ver pontua\u00e7\u00f5es";Y["pt-br"].optionsAbout_header="Desenvolvido por:";Y["pt-br"]["optionsLang_tr-tr"]="Turco";Y["pt-br"]["optionsLang_de-de"]="Alem\u00e3o";Y["pt-br"].startScreenByTinglyGames="da: CoolGames";Y["pt-br"].levelMapScreenWorld_0="Selecione um n\u00edvel";Y["pt-br"].startScreenQuestionaire="O que voc\u00ea achou?";
Y["pt-br"].levelEndScreenMedal="MELHOROU!";Y["pt-br"].optionsAbout="Sobre";Y["pt-br"].optionsAbout_version="vers\u00e3o:";Y["pt-br"].optionsAbout_backBtn="Voltar";Y["pt-br"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["pt-br"].optionsAbout_title="Sobre";Y["pt-br"].optionsSFXBig_off="Sem som";Y["pt-br"].optionsSFXBig_on="Com som";Y["pt-br"].optionsRestart="Reiniciar";Y["pt-br"].optionsRestartConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea reiniciar agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo reiniciar?";
Y["pt-br"].levelMapScreenTitle="Selecione um n\u00edvel";Y["pt-br"].optionsQuitConfirmBtn_Yes="Sim, tenho certeza.";Y["pt-br"].optionsQuitConfirmBtn_No="N\u00e3o";Y["pt-br"].optionsQuitConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea sair agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo sair?";Y["pt-br"].optionsTitle="Configura\u00e7\u00f5es";Y["pt-br"].gameEndScreenBtnText="Continuar";Y["pt-br"].gameEndScreenTitle="Parab\u00e9ns!\nVoc\u00ea concluiu o jogo.";
Y["pt-br"]["optionsLang_nl-nl"]="Holand\u00eas";Y["pt-br"]["optionsLang_en-gb"]="Ingl\u00eas (GB)";Y["pt-br"]["optionsLang_en-us"]="Ingl\u00eas (EUA)";Y["pt-br"].optionsSFX_off="N\u00e3o";Y["pt-br"].optionsSFX_on="Sim";Y["pt-br"].optionsMusic_off="N\u00e3o";Y["pt-br"].optionsMusic_on="Sim";Y["pt-br"].optionsDifficulty_hard="Dif\u00edcil";Y["pt-br"].optionsDifficulty_medium="M\u00e9dio";Y["pt-br"].optionsDifficulty_easy="F\u00e1cil";Y["pt-br"].optionsMoreGames="Mais jogos";
Y["pt-br"].optionsHighScore="Recordes";Y["pt-br"].optionsTutorial="Como jogar";Y["pt-br"].optionsResume="Continuar";Y["pt-br"].optionsQuit="Sair";Y["pt-br"].optionsStartScreen="Menu principal";Y["pt-br"].levelEndScreenHighScore="Recorde";Y["pt-br"].levelEndScreenTimeBonus="B\u00f4nus de tempo";Y["pt-br"].levelEndScreenTimeLeft="Tempo restante";Y["pt-br"].levelEndScreenSubTitle_levelFailed="Tente novamente";Y["pt-br"].levelEndScreenTotalScore="Pontua\u00e7\u00e3o";
Y["pt-br"].levelEndScreenTitle_endless="Fase <VALUE>";Y["pt-br"].levelEndScreenTitle_difficulty="Muito bem!";Y["pt-br"].levelEndScreenTitle_level="N\u00edvel <VALUE>";Y["pt-br"].levelMapScreenTotalScore="Pontua\u00e7\u00e3o";Y["pt-br"].startScreenPlay="JOGAR";Y["pt-br"].loadingScreenLoading="Carregando...";Y["pt-br"].RewardAd_button="video";Y["pt-br"].RewardAd_header="coins";Y["pt-br"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["pt-br"].RewardAd_text_2="new video is available soon";
Y["es-es"]=Y["es-es"]||{};Y["es-es"].optionsAbout_header_publisher="Published by:";Y["es-es"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["es-es"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["es-es"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["es-es"].levelEndScreenHighScore_number="Mejor puntuaci\u00f3n:";Y["es-es"].levelEndScreenTotalScore_number="Puntos totales:";Y["es-es"].optionsExit="Salir";Y["es-es"]["optionsLang_ru-ru"]="Ruso";Y["es-es"]["optionsLang_pt-br"]="Portugu\u00e9s brasile\u00f1o";Y["es-es"]["optionsLang_es-es"]="Espa\u00f1ol";Y["es-es"]["optionsLang_ar-eg"]="\u00c1rabe";Y["es-es"]["optionsLang_ko-kr"]="Coreano";Y["es-es"]["optionsLang_fr-fr"]="Franc\u00e9s";Y["es-es"].levelEndScreenTotalScore_time="Tiempo total:";
Y["es-es"].levelEndScreenHighScore_time="Mejor tiempo:";Y["es-es"].challengeLoadingError_notStarted="Imposible conectar con el servidor. Int\u00e9ntalo m\u00e1s tarde.";Y["es-es"].challengeLoadingError_notValid="Lo sentimos, este reto ya no es v\u00e1lido.";Y["es-es"].optionsChallengeCancel="Abandonar";Y["es-es"].optionsChallengeForfeit="Rendirse";Y["es-es"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["es-es"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["es-es"].challengeForfeitConfirmBtn_no="No";Y["es-es"].challengeForfeitConfirmBtn_yes="Yes";Y["es-es"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["es-es"].challengeStartTextScore_challenger="Play the game and set a score.";Y["es-es"].challengeStartTextTime_challenger="Play the game and set a time.";
Y["es-es"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["es-es"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["es-es"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["es-es"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["es-es"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["es-es"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["es-es"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["es-es"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["es-es"].challengeEndScreenName_you="You";Y["es-es"].challengeEndScreenBtn_cancel="Cancel challenge";Y["es-es"].challengeEndScreensBtn_submit="Submit challenge";Y["es-es"].challengeCancelConfirmBtn_no="No";Y["es-es"].challengeCancelConfirmBtn_yes="Yes";Y["es-es"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["es-es"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["es-es"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["es-es"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["es-es"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["es-es"].challengeStartScreenToWin="Amount to win:";Y["es-es"].challengeStartTextTime="<NAME>'s time:";Y["es-es"].challengeStartTextScore="<NAME>'s score:";
Y["es-es"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["es-es"].levelEndScreenSubmitHighscoreBtn="Enviar puntuaci\u00f3n";Y["es-es"].levelEndScreenViewHighscoreBtn="Ver puntuaciones";Y["es-es"].optionsAbout_header="Desarrollado por:";Y["es-es"]["optionsLang_tr-tr"]="Turco";Y["es-es"]["optionsLang_de-de"]="Alem\u00e1n";Y["es-es"].startScreenByTinglyGames="de: CoolGames";Y["es-es"].levelMapScreenWorld_0="Elige un nivel";Y["es-es"].startScreenQuestionaire="\u00bfQu\u00e9 te parece?";
Y["es-es"].levelEndScreenMedal="\u00a1SUPERADO!";Y["es-es"].optionsAbout="Acerca de";Y["es-es"].optionsAbout_version="versi\u00f3n:";Y["es-es"].optionsAbout_backBtn="Atr\u00e1s";Y["es-es"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["es-es"].optionsAbout_title="Acerca de";Y["es-es"].optionsSFXBig_off="Sonido no";Y["es-es"].optionsSFXBig_on="Sonido s\u00ed";Y["es-es"].optionsRestart="Reiniciar";Y["es-es"].optionsRestartConfirmationText="\u00a1Aviso!\n\nSi reinicias ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres reiniciar?";
Y["es-es"].levelMapScreenTitle="Elige un nivel";Y["es-es"].optionsQuitConfirmBtn_Yes="S\u00ed, seguro";Y["es-es"].optionsQuitConfirmBtn_No="No";Y["es-es"].optionsQuitConfirmationText="\u00a1Aviso!\n\nSi sales ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres salir?";Y["es-es"].optionsTitle="Ajustes";Y["es-es"].gameEndScreenBtnText="Continuar";Y["es-es"].gameEndScreenTitle="\u00a1Enhorabuena!\nHas terminado el juego.";Y["es-es"]["optionsLang_nl-nl"]="Neerland\u00e9s";
Y["es-es"]["optionsLang_en-gb"]="Ingl\u00e9s (GB)";Y["es-es"]["optionsLang_en-us"]="Ingl\u00e9s (EE.UU.)";Y["es-es"].optionsSFX_off="No";Y["es-es"].optionsSFX_on="S\u00ed";Y["es-es"].optionsMusic_off="No";Y["es-es"].optionsMusic_on="S\u00ed";Y["es-es"].optionsDifficulty_hard="Dif\u00edcil";Y["es-es"].optionsDifficulty_medium="Normal";Y["es-es"].optionsDifficulty_easy="F\u00e1cil";Y["es-es"].optionsMoreGames="M\u00e1s juegos";Y["es-es"].optionsHighScore="R\u00e9cords";Y["es-es"].optionsTutorial="C\u00f3mo jugar";
Y["es-es"].optionsResume="Seguir";Y["es-es"].optionsQuit="Salir";Y["es-es"].optionsStartScreen="Men\u00fa principal";Y["es-es"].levelEndScreenHighScore="R\u00e9cord";Y["es-es"].levelEndScreenTimeBonus="Bonif. tiempo";Y["es-es"].levelEndScreenTimeLeft="Tiempo restante";Y["es-es"].levelEndScreenSubTitle_levelFailed="Nivel fallido";Y["es-es"].levelEndScreenTotalScore="Punt. total";Y["es-es"].levelEndScreenTitle_endless="Fase <VALUE>";Y["es-es"].levelEndScreenTitle_difficulty="\u00a1Muy bien!";
Y["es-es"].levelEndScreenTitle_level="Nivel <VALUE>";Y["es-es"].levelMapScreenTotalScore="Punt. total";Y["es-es"].startScreenPlay="JUGAR";Y["es-es"].loadingScreenLoading="Cargando...";Y["es-es"].RewardAd_button="video";Y["es-es"].RewardAd_header="coins";Y["es-es"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["es-es"].RewardAd_text_2="new video is available soon";Y["tr-tr"]=Y["tr-tr"]||{};Y["tr-tr"].optionsAbout_header_publisher="Published by:";
Y["tr-tr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["tr-tr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["tr-tr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["tr-tr"].levelEndScreenHighScore_number="Y\u00fcksek Puan:";Y["tr-tr"].levelEndScreenTotalScore_number="Toplam Puan:";Y["tr-tr"].optionsExit="\u00c7\u0131k\u0131\u015f";Y["tr-tr"]["optionsLang_ru-ru"]="Rus\u00e7a";Y["tr-tr"]["optionsLang_pt-br"]="Brezilya Portekizcesi";Y["tr-tr"]["optionsLang_es-es"]="\u0130spanyolca";Y["tr-tr"]["optionsLang_ar-eg"]="Arap\u00e7a";Y["tr-tr"]["optionsLang_ko-kr"]="Korece";Y["tr-tr"]["optionsLang_fr-fr"]="Frans\u0131zca";Y["tr-tr"].levelEndScreenTotalScore_time="Toplam Zaman:";
Y["tr-tr"].levelEndScreenHighScore_time="En \u0130yi Zaman:";Y["tr-tr"].challengeLoadingError_notStarted="Sunucuya ba\u011flan\u0131lam\u0131yor. L\u00fctfen daha sonra tekrar deneyin.";Y["tr-tr"].challengeLoadingError_notValid="\u00dczg\u00fcn\u00fcz, bu zorluk art\u0131k ge\u00e7erli de\u011fil.";Y["tr-tr"].optionsChallengeCancel="\u00c7\u0131k\u0131\u015f";Y["tr-tr"].optionsChallengeForfeit="Vazge\u00e7";Y["tr-tr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["tr-tr"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["tr-tr"].challengeForfeitConfirmBtn_no="No";Y["tr-tr"].challengeForfeitConfirmBtn_yes="Yes";Y["tr-tr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["tr-tr"].challengeStartTextScore_challenger="Play the game and set a score.";Y["tr-tr"].challengeStartTextTime_challenger="Play the game and set a time.";
Y["tr-tr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["tr-tr"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["tr-tr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["tr-tr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["tr-tr"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["tr-tr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["tr-tr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["tr-tr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["tr-tr"].challengeEndScreenName_you="You";Y["tr-tr"].challengeEndScreenBtn_cancel="Cancel challenge";Y["tr-tr"].challengeEndScreensBtn_submit="Submit challenge";Y["tr-tr"].challengeCancelConfirmBtn_no="No";Y["tr-tr"].challengeCancelConfirmBtn_yes="Yes";Y["tr-tr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["tr-tr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["tr-tr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["tr-tr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["tr-tr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["tr-tr"].challengeStartScreenToWin="Amount to win:";Y["tr-tr"].challengeStartTextTime="<NAME>'s time:";Y["tr-tr"].challengeStartTextScore="<NAME>'s score:";
Y["tr-tr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["tr-tr"].levelEndScreenSubmitHighscoreBtn="Puan g\u00f6nder";Y["tr-tr"].levelEndScreenViewHighscoreBtn="Puanlar\u0131 g\u00f6ster:";Y["tr-tr"].optionsAbout_header="Haz\u0131rlayan:";Y["tr-tr"]["optionsLang_tr-tr"]="T\u00fcrk\u00e7e";Y["tr-tr"]["optionsLang_de-de"]="Almanca";Y["tr-tr"].startScreenByTinglyGames="taraf\u0131ndan: CoolGames";Y["tr-tr"].levelMapScreenWorld_0="Bir seviye se\u00e7";
Y["tr-tr"].startScreenQuestionaire="Ne dersin?";Y["tr-tr"].levelEndScreenMedal="\u0130Y\u0130LE\u015eT\u0130!";Y["tr-tr"].optionsAbout="Hakk\u0131nda";Y["tr-tr"].optionsAbout_version="s\u00fcr\u00fcm:";Y["tr-tr"].optionsAbout_backBtn="Geri";Y["tr-tr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["tr-tr"].optionsAbout_title="Hakk\u0131nda";Y["tr-tr"].optionsSFXBig_off="Ses kapal\u0131";Y["tr-tr"].optionsSFXBig_on="Ses a\u00e7\u0131k";Y["tr-tr"].optionsRestart="Tekrar ba\u015flat";
Y["tr-tr"].optionsRestartConfirmationText="Dikkat!\n\u015eimdi tekrar ba\u015flarsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. Ba\u015ftan ba\u015flamak istedi\u011finden emin misin?";Y["tr-tr"].levelMapScreenTitle="Bir seviye se\u00e7";Y["tr-tr"].optionsQuitConfirmBtn_Yes="Evet, eminim";Y["tr-tr"].optionsQuitConfirmBtn_No="Hay\u0131r";Y["tr-tr"].optionsQuitConfirmationText="Dikkat!\n\u015eimdi \u00e7\u0131karsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. \u00c7\u0131kmak istedi\u011finizden emin misiniz?";
Y["tr-tr"].optionsTitle="Ayarlar";Y["tr-tr"].gameEndScreenBtnText="Devam";Y["tr-tr"].gameEndScreenTitle="Tebrikler!\nOyunu tamamlad\u0131n.";Y["tr-tr"]["optionsLang_nl-nl"]="Hollandaca";Y["tr-tr"]["optionsLang_en-gb"]="\u0130ngilizce (GB)";Y["tr-tr"]["optionsLang_en-us"]="\u0130ngilizce (US)";Y["tr-tr"].optionsSFX_off="Kapal\u0131";Y["tr-tr"].optionsSFX_on="A\u00e7\u0131k";Y["tr-tr"].optionsMusic_off="Kapal\u0131";Y["tr-tr"].optionsMusic_on="A\u00e7\u0131k";Y["tr-tr"].optionsDifficulty_hard="Zorluk";
Y["tr-tr"].optionsDifficulty_medium="Orta";Y["tr-tr"].optionsDifficulty_easy="Kolay";Y["tr-tr"].optionsMoreGames="Daha Fazla Oyun";Y["tr-tr"].optionsHighScore="Y\u00fcksek skorlar";Y["tr-tr"].optionsTutorial="Nas\u0131l oynan\u0131r";Y["tr-tr"].optionsResume="Devam et";Y["tr-tr"].optionsQuit="\u00c7\u0131k";Y["tr-tr"].optionsStartScreen="Ana men\u00fc";Y["tr-tr"].levelEndScreenHighScore="Y\u00fcksek skor";Y["tr-tr"].levelEndScreenTimeBonus="S\u00fcre Bonusu";Y["tr-tr"].levelEndScreenTimeLeft="Kalan S\u00fcre";
Y["tr-tr"].levelEndScreenSubTitle_levelFailed="Seviye ba\u015far\u0131s\u0131z";Y["tr-tr"].levelEndScreenTotalScore="Toplam skor";Y["tr-tr"].levelEndScreenTitle_endless="B\u00f6l\u00fcm <VALUE>";Y["tr-tr"].levelEndScreenTitle_difficulty="Bravo!";Y["tr-tr"].levelEndScreenTitle_level="Seviye <VALUE>";Y["tr-tr"].levelMapScreenTotalScore="Toplam skor";Y["tr-tr"].startScreenPlay="OYNA";Y["tr-tr"].loadingScreenLoading="Y\u00fckleniyor...";Y["tr-tr"].RewardAd_button="video";Y["tr-tr"].RewardAd_header="coins";
Y["tr-tr"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["tr-tr"].RewardAd_text_2="new video is available soon";Y["ru-ru"]=Y["ru-ru"]||{};Y["ru-ru"].optionsAbout_header_publisher="Published by:";Y["ru-ru"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["ru-ru"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Y["ru-ru"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Y["ru-ru"].levelEndScreenHighScore_number="High score:";Y["ru-ru"].levelEndScreenTotalScore_number="Total score:";Y["ru-ru"].optionsExit="Exit";Y["ru-ru"]["optionsLang_ru-ru"]="\u0420\u0443\u0441\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_pt-br"]="\u0411\u0440\u0430\u0437\u0438\u043b\u044c\u0441\u043a\u0438\u0439 \u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439";
Y["ru-ru"]["optionsLang_es-es"]="\u0418\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_ar-eg"]="\u0410\u0440\u0430\u0431\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_ko-kr"]="\u041a\u043e\u0440\u0435\u0439\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_fr-fr"]="\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439";Y["ru-ru"].levelEndScreenTotalScore_time="Total time:";Y["ru-ru"].levelEndScreenHighScore_time="Best time:";
Y["ru-ru"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ru-ru"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ru-ru"].optionsChallengeCancel="Quit";Y["ru-ru"].optionsChallengeForfeit="Forfeit";Y["ru-ru"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["ru-ru"].challengeForfeitMessage_success="You have forfeited the challenge.";
Y["ru-ru"].challengeForfeitConfirmBtn_no="No";Y["ru-ru"].challengeForfeitConfirmBtn_yes="Yes";Y["ru-ru"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ru-ru"].challengeStartTextScore_challenger="Play the game and set a score.";Y["ru-ru"].challengeStartTextTime_challenger="Play the game and set a time.";Y["ru-ru"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
Y["ru-ru"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["ru-ru"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ru-ru"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ru-ru"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["ru-ru"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["ru-ru"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["ru-ru"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ru-ru"].challengeEndScreenName_you="You";Y["ru-ru"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ru-ru"].challengeEndScreensBtn_submit="Submit challenge";Y["ru-ru"].challengeCancelConfirmBtn_no="No";Y["ru-ru"].challengeCancelConfirmBtn_yes="Yes";Y["ru-ru"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["ru-ru"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ru-ru"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ru-ru"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["ru-ru"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ru-ru"].challengeStartScreenToWin="Amount to win:";Y["ru-ru"].challengeStartTextTime="<NAME>'s time:";Y["ru-ru"].challengeStartTextScore="<NAME>'s score:";
Y["ru-ru"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ru-ru"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ru-ru"].levelEndScreenViewHighscoreBtn="View scores";Y["ru-ru"].optionsAbout_header="Developed by:";Y["ru-ru"]["optionsLang_tr-tr"]="\u0422\u0443\u0440\u0435\u0446\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_de-de"]="\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439";Y["ru-ru"].startScreenByTinglyGames="\u0420\u0430\u0437\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0438: CoolGames";
Y["ru-ru"].levelMapScreenWorld_0="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Y["ru-ru"].startScreenQuestionaire="\u041a\u0430\u043a \u0432\u0430\u043c \u0438\u0433\u0440\u0430?";Y["ru-ru"].levelEndScreenMedal="\u041d\u041e\u0412\u042b\u0419 \u0420\u0415\u041a\u041e\u0420\u0414!";Y["ru-ru"].optionsAbout="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Y["ru-ru"].optionsAbout_version="\u0412\u0435\u0440\u0441\u0438\u044f:";
Y["ru-ru"].optionsAbout_backBtn="\u041d\u0430\u0437\u0430\u0434";Y["ru-ru"].optionsAbout_text="\u00a9 CoolGames\nwww.coolgames.com\n2016";Y["ru-ru"].optionsAbout_title="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";Y["ru-ru"].optionsSFXBig_off="\u0417\u0432\u0443\u043a \u0432\u044b\u043a\u043b.";Y["ru-ru"].optionsSFXBig_on="\u0417\u0432\u0443\u043a \u0432\u043a\u043b.";Y["ru-ru"].optionsRestart="\u0417\u0430\u043d\u043e\u0432\u043e";Y["ru-ru"].optionsRestartConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0441\u0435\u0439\u0447\u0430\u0441 \u043d\u0430\u0447\u043d\u0435\u0442\u0435 \u0438\u0433\u0440\u0443 \u0437\u0430\u043d\u043e\u0432\u043e, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043d\u0430\u0447\u0430\u0442\u044c \u0437\u0430\u043d\u043e\u0432\u043e?";
Y["ru-ru"].levelMapScreenTitle="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";Y["ru-ru"].optionsQuitConfirmBtn_Yes="\u0414\u0430, \u0432\u044b\u0439\u0442\u0438";Y["ru-ru"].optionsQuitConfirmBtn_No="\u041d\u0435\u0442";Y["ru-ru"].optionsQuitConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0432\u044b\u0439\u0434\u0435\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u0439\u0442\u0438?";
Y["ru-ru"].optionsTitle="\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438";Y["ru-ru"].gameEndScreenBtnText="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Y["ru-ru"].gameEndScreenTitle="\u041f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0435\u043c!\n\u0412\u044b \u043f\u0440\u043e\u0448\u043b\u0438 \u0438\u0433\u0440\u0443.";Y["ru-ru"]["optionsLang_nl-nl"]="\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438\u0439";Y["ru-ru"]["optionsLang_en-gb"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0412\u0411)";
Y["ru-ru"]["optionsLang_en-us"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0421\u0428\u0410)";Y["ru-ru"].optionsSFX_off="\u0412\u044b\u043a\u043b.";Y["ru-ru"].optionsSFX_on="\u0412\u043a\u043b.";Y["ru-ru"].optionsMusic_off="\u0412\u044b\u043a\u043b.";Y["ru-ru"].optionsMusic_on="\u0412\u043a\u043b.";Y["ru-ru"].optionsDifficulty_hard="\u0421\u043b\u043e\u0436\u043d\u044b\u0439";Y["ru-ru"].optionsDifficulty_medium="\u0421\u0440\u0435\u0434\u043d\u0438\u0439";
Y["ru-ru"].optionsDifficulty_easy="\u041b\u0435\u0433\u043a\u0438\u0439";Y["ru-ru"].optionsMoreGames="\u0411\u043e\u043b\u044c\u0448\u0435 \u0438\u0433\u0440";Y["ru-ru"].optionsHighScore="\u0420\u0435\u043a\u043e\u0440\u0434\u044b";Y["ru-ru"].optionsTutorial="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";Y["ru-ru"].optionsResume="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";Y["ru-ru"].optionsQuit="\u0412\u044b\u0439\u0442\u0438";Y["ru-ru"].optionsStartScreen="\u0413\u043b\u0430\u0432\u043d\u043e\u0435 \u043c\u0435\u043d\u044e";
Y["ru-ru"].levelEndScreenHighScore="\u0420\u0435\u043a\u043e\u0440\u0434";Y["ru-ru"].levelEndScreenTimeBonus="\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f";Y["ru-ru"].levelEndScreenTimeLeft="\u041e\u0441\u0442\u0430\u0432\u0448\u0435\u0435\u0441\u044f \u0432\u0440\u0435\u043c\u044f";Y["ru-ru"].levelEndScreenSubTitle_levelFailed="\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u043f\u0440\u043e\u0439\u0434\u0435\u043d";
Y["ru-ru"].levelEndScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";Y["ru-ru"].levelEndScreenTitle_endless="\u042d\u0442\u0430\u043f <VALUE>";Y["ru-ru"].levelEndScreenTitle_difficulty="\u0425\u043e\u0440\u043e\u0448\u0438\u0439 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442!";Y["ru-ru"].levelEndScreenTitle_level="\u0423\u0440\u043e\u0432\u0435\u043d\u044c <VALUE>";Y["ru-ru"].levelMapScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";
Y["ru-ru"].startScreenPlay="\u0418\u0413\u0420\u0410\u0422\u042c";Y["ru-ru"].loadingScreenLoading="\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430...";Y["ru-ru"].RewardAd_button="video";Y["ru-ru"].RewardAd_header="coins";Y["ru-ru"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["ru-ru"].RewardAd_text_2="new video is available soon";Y["ar-eg"]=Y["ar-eg"]||{};Y["ar-eg"].optionsAbout_header_publisher="Published by:";Y["ar-eg"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";
Y["ar-eg"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["ar-eg"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Y["ar-eg"].levelEndScreenHighScore_number="High score:";
Y["ar-eg"].levelEndScreenTotalScore_number="Total score:";Y["ar-eg"].optionsExit="Exit";Y["ar-eg"]["optionsLang_ru-ru"]="\u0627\u0644\u0631\u0648\u0633\u064a\u0629";Y["ar-eg"]["optionsLang_pt-br"]="\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644\u064a\u0629 - \u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629";Y["ar-eg"]["optionsLang_es-es"]="\u0627\u0644\u0625\u0633\u0628\u0627\u0646\u064a\u0629";Y["ar-eg"]["optionsLang_ar-eg"]="\u0627\u0644\u0639\u0631\u0628\u064a\u0629";
Y["ar-eg"]["optionsLang_ko-kr"]="\u0627\u0644\u0643\u0648\u0631\u064a\u0629";Y["ar-eg"]["optionsLang_fr-fr"]="\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629";Y["ar-eg"].levelEndScreenTotalScore_time="Total time:";Y["ar-eg"].levelEndScreenHighScore_time="Best time:";Y["ar-eg"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ar-eg"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ar-eg"].optionsChallengeCancel="Quit";
Y["ar-eg"].optionsChallengeForfeit="Forfeit";Y["ar-eg"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["ar-eg"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["ar-eg"].challengeForfeitConfirmBtn_no="No";Y["ar-eg"].challengeForfeitConfirmBtn_yes="Yes";Y["ar-eg"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ar-eg"].challengeStartTextScore_challenger="Play the game and set a score.";
Y["ar-eg"].challengeStartTextTime_challenger="Play the game and set a time.";Y["ar-eg"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["ar-eg"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["ar-eg"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ar-eg"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ar-eg"].challengeCancelMessage_success="Your challenge has been cancelled.";
Y["ar-eg"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["ar-eg"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["ar-eg"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ar-eg"].challengeEndScreenName_you="You";Y["ar-eg"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ar-eg"].challengeEndScreensBtn_submit="Submit challenge";
Y["ar-eg"].challengeCancelConfirmBtn_no="No";Y["ar-eg"].challengeCancelConfirmBtn_yes="Yes";Y["ar-eg"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Y["ar-eg"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ar-eg"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ar-eg"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";
Y["ar-eg"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ar-eg"].challengeStartScreenToWin="Amount to win:";Y["ar-eg"].challengeStartTextTime="<NAME>'s time:";Y["ar-eg"].challengeStartTextScore="<NAME>'s score:";Y["ar-eg"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ar-eg"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ar-eg"].levelEndScreenViewHighscoreBtn="View scores";Y["ar-eg"].optionsAbout_header="Developed by:";
Y["ar-eg"]["optionsLang_tr-tr"]="\u0627\u0644\u062a\u0631\u0643\u064a\u0629";Y["ar-eg"]["optionsLang_de-de"]="\u0627\u0644\u0623\u0644\u0645\u0627\u0646\u064a\u0629";Y["ar-eg"].startScreenByTinglyGames="\u0628\u0648\u0627\u0633\u0637\u0629: CoolGames";Y["ar-eg"].levelMapScreenWorld_0="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].startScreenQuestionaire="\u0645\u0627 \u0631\u0623\u064a\u0643\u061f";Y["ar-eg"].levelEndScreenMedal="\u0644\u0642\u062f \u062a\u062d\u0633\u0651\u0646\u062a!";
Y["ar-eg"].optionsAbout="\u062d\u0648\u0644";Y["ar-eg"].optionsAbout_version="\u0627\u0644\u0625\u0635\u062f\u0627\u0631:";Y["ar-eg"].optionsAbout_backBtn="\u0627\u0644\u0633\u0627\u0628\u0642";Y["ar-eg"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["ar-eg"].optionsAbout_title="\u062d\u0648\u0644";Y["ar-eg"].optionsSFXBig_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0635\u0648\u062a";Y["ar-eg"].optionsSFXBig_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0635\u0648\u062a";
Y["ar-eg"].optionsRestart="\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644";Y["ar-eg"].optionsRestartConfirmationText="\u0627\u0646\u062a\u0628\u0647!\n\n\u0625\u0630\u0627 \u0642\u0645\u062a \u0628\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644\u061f";
Y["ar-eg"].levelMapScreenTitle="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";Y["ar-eg"].optionsQuitConfirmBtn_Yes="\u0646\u0639\u0645\u060c \u0645\u062a\u0623\u0643\u062f";Y["ar-eg"].optionsQuitConfirmBtn_No="\u0644\u0627";Y["ar-eg"].optionsQuitConfirmationText="\u0627\u0646\u062a\u0628\u0647!n\n\u0625\u0630\u0627 \u062e\u0631\u062c\u062a \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629\u061f";
Y["ar-eg"].optionsTitle="\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a";Y["ar-eg"].gameEndScreenBtnText="\u0645\u062a\u0627\u0628\u0639\u0629";Y["ar-eg"].gameEndScreenTitle="\u062a\u0647\u0627\u0646\u064a\u0646\u0627!\n\u0644\u0642\u062f \u0623\u0643\u0645\u0644\u062a \u0627\u0644\u0644\u0639\u0628\u0629.";Y["ar-eg"]["optionsLang_nl-nl"]="\u0627\u0644\u0647\u0648\u0644\u0646\u062f\u064a\u0629";Y["ar-eg"]["optionsLang_en-gb"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";
Y["ar-eg"]["optionsLang_en-us"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";Y["ar-eg"].optionsSFX_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";Y["ar-eg"].optionsSFX_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";
Y["ar-eg"].optionsMusic_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";Y["ar-eg"].optionsMusic_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";Y["ar-eg"].optionsDifficulty_hard="\u0635\u0639\u0628";Y["ar-eg"].optionsDifficulty_medium="\u0645\u062a\u0648\u0633\u0637";Y["ar-eg"].optionsDifficulty_easy="\u0633\u0647\u0644";Y["ar-eg"].optionsMoreGames="\u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0623\u0644\u0639\u0627\u0628";
Y["ar-eg"].optionsHighScore="\u0623\u0639\u0644\u0649 \u0627\u0644\u0646\u062a\u0627\u0626\u062c";Y["ar-eg"].optionsTutorial="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";Y["ar-eg"].optionsResume="\u0627\u0633\u062a\u0626\u0646\u0627\u0641";Y["ar-eg"].optionsQuit="\u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629";Y["ar-eg"].optionsStartScreen="\u0627\u0644\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629";
Y["ar-eg"].levelEndScreenHighScore="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";Y["ar-eg"].levelEndScreenTimeBonus="\u0645\u0643\u0627\u0641\u0623\u0629 \u0627\u0644\u0648\u0642\u062a";Y["ar-eg"].levelEndScreenTimeLeft="\u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u062a\u0628\u0642\u064a";Y["ar-eg"].levelEndScreenSubTitle_levelFailed="\u0644\u0642\u062f \u0641\u0634\u0644\u062a \u0641\u064a \u0627\u062c\u062a\u064a\u0627\u0632 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649";
Y["ar-eg"].levelEndScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";Y["ar-eg"].levelEndScreenTitle_endless="\u0627\u0644\u0645\u0631\u062d\u0644\u0629 <VALUE>";Y["ar-eg"].levelEndScreenTitle_difficulty="\u0623\u062d\u0633\u0646\u062a!";Y["ar-eg"].levelEndScreenTitle_level="\u0627\u0644\u0645\u0633\u062a\u0648\u0649 <VALUE>";Y["ar-eg"].levelMapScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";
Y["ar-eg"].startScreenPlay="\u062a\u0634\u063a\u064a\u0644";Y["ar-eg"].loadingScreenLoading="\u064a\u062a\u0645 \u0627\u0644\u0622\u0646 \u0627\u0644\u062a\u062d\u0645\u064a\u0644...";Y["ar-eg"].RewardAd_button="video";Y["ar-eg"].RewardAd_header="coins";Y["ar-eg"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["ar-eg"].RewardAd_text_2="new video is available soon";Y["ko-kr"]=Y["ko-kr"]||{};Y["ko-kr"].optionsAbout_header_publisher="Published by:";
Y["ko-kr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["ko-kr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";Y["ko-kr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
Y["ko-kr"].levelEndScreenHighScore_number="High score:";Y["ko-kr"].levelEndScreenTotalScore_number="Total score:";Y["ko-kr"].optionsExit="Exit";Y["ko-kr"]["optionsLang_ru-ru"]="\ub7ec\uc2dc\uc544\uc5b4";Y["ko-kr"]["optionsLang_pt-br"]="\ud3ec\ub974\ud22c\uac08\uc5b4(\ube0c\ub77c\uc9c8)";Y["ko-kr"]["optionsLang_es-es"]="\uc2a4\ud398\uc778\uc5b4";Y["ko-kr"]["optionsLang_ar-eg"]="\uc544\ub77c\ube44\uc544\uc5b4";Y["ko-kr"]["optionsLang_ko-kr"]="\ud55c\uad6d\uc5b4";Y["ko-kr"]["optionsLang_fr-fr"]="\ud504\ub791\uc2a4\uc5b4";
Y["ko-kr"].levelEndScreenTotalScore_time="Total time:";Y["ko-kr"].levelEndScreenHighScore_time="Best time:";Y["ko-kr"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";Y["ko-kr"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["ko-kr"].optionsChallengeCancel="Quit";Y["ko-kr"].optionsChallengeForfeit="Forfeit";Y["ko-kr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
Y["ko-kr"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["ko-kr"].challengeForfeitConfirmBtn_no="No";Y["ko-kr"].challengeForfeitConfirmBtn_yes="Yes";Y["ko-kr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["ko-kr"].challengeStartTextScore_challenger="Play the game and set a score.";Y["ko-kr"].challengeStartTextTime_challenger="Play the game and set a time.";
Y["ko-kr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["ko-kr"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["ko-kr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";Y["ko-kr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["ko-kr"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["ko-kr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
Y["ko-kr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["ko-kr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";Y["ko-kr"].challengeEndScreenName_you="You";Y["ko-kr"].challengeEndScreenBtn_cancel="Cancel challenge";Y["ko-kr"].challengeEndScreensBtn_submit="Submit challenge";Y["ko-kr"].challengeCancelConfirmBtn_no="No";Y["ko-kr"].challengeCancelConfirmBtn_yes="Yes";Y["ko-kr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
Y["ko-kr"].challengeEndScreenOutcomeMessage_TIED="You tied.";Y["ko-kr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["ko-kr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["ko-kr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["ko-kr"].challengeStartScreenToWin="Amount to win:";Y["ko-kr"].challengeStartTextTime="<NAME>'s time:";Y["ko-kr"].challengeStartTextScore="<NAME>'s score:";
Y["ko-kr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";Y["ko-kr"].levelEndScreenSubmitHighscoreBtn="Submit score";Y["ko-kr"].levelEndScreenViewHighscoreBtn="View scores";Y["ko-kr"].optionsAbout_header="Developed by:";Y["ko-kr"]["optionsLang_tr-tr"]="\ud130\ud0a4\uc5b4";Y["ko-kr"]["optionsLang_de-de"]="\ub3c5\uc77c\uc5b4";Y["ko-kr"].startScreenByTinglyGames="\uc81c\uc791: CoolGames";Y["ko-kr"].levelMapScreenWorld_0="\ub808\ubca8 \uc120\ud0dd";
Y["ko-kr"].startScreenQuestionaire="\uc5b4\ub5bb\uac8c \uc0dd\uac01\ud558\uc138\uc694?";Y["ko-kr"].levelEndScreenMedal="\ud5a5\uc0c1\ud588\uad70\uc694!";Y["ko-kr"].optionsAbout="\uad00\ub828 \uc815\ubcf4";Y["ko-kr"].optionsAbout_version="\ubc84\uc804:";Y["ko-kr"].optionsAbout_backBtn="\ub4a4\ub85c";Y["ko-kr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["ko-kr"].optionsAbout_title="\uad00\ub828 \uc815\ubcf4";Y["ko-kr"].optionsSFXBig_off="\uc74c\ud5a5 \ub044\uae30";
Y["ko-kr"].optionsSFXBig_on="\uc74c\ud5a5 \ucf1c\uae30";Y["ko-kr"].optionsRestart="\ub2e4\uc2dc \uc2dc\uc791";Y["ko-kr"].optionsRestartConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \ub2e4\uc2dc \uc2dc\uc791\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \ub2e4\uc2dc \uc2dc\uc791\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Y["ko-kr"].levelMapScreenTitle="\ub808\ubca8 \uc120\ud0dd";Y["ko-kr"].optionsQuitConfirmBtn_Yes="\ub124, \ud655\uc2e4\ud569\ub2c8\ub2e4";
Y["ko-kr"].optionsQuitConfirmBtn_No="\uc544\ub2c8\uc624";Y["ko-kr"].optionsQuitConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \uc885\ub8cc\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \uc885\ub8cc\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";Y["ko-kr"].optionsTitle="\uc124\uc815";Y["ko-kr"].gameEndScreenBtnText="\uacc4\uc18d";Y["ko-kr"].gameEndScreenTitle="\ucd95\ud558\ud569\ub2c8\ub2e4!\n\uac8c\uc784\uc744 \uc644\ub8cc\ud588\uc2b5\ub2c8\ub2e4.";
Y["ko-kr"]["optionsLang_nl-nl"]="\ub124\ub35c\ub780\ub4dc\uc5b4";Y["ko-kr"]["optionsLang_en-gb"]="\uc601\uc5b4(GB)";Y["ko-kr"]["optionsLang_en-us"]="\uc601\uc5b4(US)";Y["ko-kr"].optionsSFX_off="\ub044\uae30";Y["ko-kr"].optionsSFX_on="\ucf1c\uae30";Y["ko-kr"].optionsMusic_off="\ub044\uae30";Y["ko-kr"].optionsMusic_on="\ucf1c\uae30";Y["ko-kr"].optionsDifficulty_hard="\uc0c1";Y["ko-kr"].optionsDifficulty_medium="\uc911";Y["ko-kr"].optionsDifficulty_easy="\uac04\ub2e8";Y["ko-kr"].optionsMoreGames="\ub354 \ub9ce\uc740 \uac8c\uc784";
Y["ko-kr"].optionsHighScore="\ucd5c\uace0 \uc810\uc218";Y["ko-kr"].optionsTutorial="\uac8c\uc784 \ubc29\ubc95";Y["ko-kr"].optionsResume="\uacc4\uc18d";Y["ko-kr"].optionsQuit="\uc885\ub8cc";Y["ko-kr"].optionsStartScreen="\uba54\uc778 \uba54\ub274";Y["ko-kr"].levelEndScreenHighScore="\ucd5c\uace0 \uc810\uc218";Y["ko-kr"].levelEndScreenTimeBonus="\uc2dc\uac04 \ubcf4\ub108\uc2a4";Y["ko-kr"].levelEndScreenTimeLeft="\ub0a8\uc740 \uc2dc\uac04";Y["ko-kr"].levelEndScreenSubTitle_levelFailed="\ub808\ubca8 \uc2e4\ud328";
Y["ko-kr"].levelEndScreenTotalScore="\ucd1d \uc810\uc218";Y["ko-kr"].levelEndScreenTitle_endless="\uc2a4\ud14c\uc774\uc9c0 <VALUE>";Y["ko-kr"].levelEndScreenTitle_difficulty="\uc798 \ud588\uc5b4\uc694!";Y["ko-kr"].levelEndScreenTitle_level="\ub808\ubca8 <VALUE>";Y["ko-kr"].levelMapScreenTotalScore="\ucd1d \uc810\uc218";Y["ko-kr"].startScreenPlay="PLAY";Y["ko-kr"].loadingScreenLoading="\ubd88\ub7ec\uc624\uae30 \uc911...";Y["ko-kr"].RewardAd_button="video";Y["ko-kr"].RewardAd_header="coins";
Y["ko-kr"].RewardAd_text_1="watch a video and get <COINS> coins!";Y["ko-kr"].RewardAd_text_2="new video is available soon";Y["jp-jp"]=Y["jp-jp"]||{};Y["jp-jp"].optionsAbout_header_publisher="Published by:";Y["jp-jp"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";Y["jp-jp"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
Y["jp-jp"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";Y["jp-jp"].levelEndScreenHighScore_number="\u30cf\u30a4\u30b9\u30b3\u30a2";Y["jp-jp"].levelEndScreenTotalScore_number="\u30b9\u30b3\u30a2";Y["jp-jp"].optionsExit="\u623b\u308b";Y["jp-jp"]["optionsLang_ru-ru"]="\u30ed\u30b7\u30a2\u8a9e";Y["jp-jp"]["optionsLang_pt-br"]="\u30dd\u30eb\u30c8\u30ac\u30eb\u8a9e\uff08\u30d6\u30e9\u30b8\u30eb\uff09";
Y["jp-jp"]["optionsLang_es-es"]="\u30b9\u30da\u30a4\u30f3\u8a9e";Y["jp-jp"]["optionsLang_ar-eg"]="\u30a2\u30e9\u30d3\u30a2\u8a9e";Y["jp-jp"]["optionsLang_ko-kr"]="\u97d3\u56fd\u8a9e";Y["jp-jp"]["optionsLang_fr-fr"]="\u30d5\u30e9\u30f3\u30b9\u8a9e";Y["jp-jp"].levelEndScreenTotalScore_time="\u30c8\u30fc\u30bf\u30eb\u30bf\u30a4\u30e0\uff1a";Y["jp-jp"].levelEndScreenHighScore_time="\u30d9\u30b9\u30c8\u30bf\u30a4\u30e0\uff1a";Y["jp-jp"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";
Y["jp-jp"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";Y["jp-jp"].optionsChallengeCancel="\u3084\u3081\u308b";Y["jp-jp"].optionsChallengeForfeit="\u964d\u53c2";Y["jp-jp"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";Y["jp-jp"].challengeForfeitMessage_success="You have forfeited the challenge.";Y["jp-jp"].challengeForfeitConfirmBtn_no="No";Y["jp-jp"].challengeForfeitConfirmBtn_yes="Yes";
Y["jp-jp"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";Y["jp-jp"].challengeStartTextScore_challenger="Play the game and set a score.";Y["jp-jp"].challengeStartTextTime_challenger="Play the game and set a time.";Y["jp-jp"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";Y["jp-jp"].challengeStartScreenTitle_challenger_friend="You are challenging:";Y["jp-jp"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";
Y["jp-jp"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";Y["jp-jp"].challengeCancelMessage_success="Your challenge has been cancelled.";Y["jp-jp"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";Y["jp-jp"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";Y["jp-jp"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";
Y["jp-jp"].challengeEndScreenName_you="You";Y["jp-jp"].challengeEndScreenBtn_cancel="Cancel challenge";Y["jp-jp"].challengeEndScreensBtn_submit="Submit challenge";Y["jp-jp"].challengeCancelConfirmBtn_no="No";Y["jp-jp"].challengeCancelConfirmBtn_yes="Yes";Y["jp-jp"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";Y["jp-jp"].challengeEndScreenOutcomeMessage_TIED="You tied.";
Y["jp-jp"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";Y["jp-jp"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";Y["jp-jp"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";Y["jp-jp"].challengeStartScreenToWin="Amount to win:";Y["jp-jp"].challengeStartTextTime="<NAME>'s time:";Y["jp-jp"].challengeStartTextScore="<NAME>'s score:";Y["jp-jp"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";
Y["jp-jp"].levelEndScreenSubmitHighscoreBtn="\u30b9\u30b3\u30a2\u9001\u4fe1";Y["jp-jp"].levelEndScreenViewHighscoreBtn="\u30b9\u30b3\u30a2\u3092\u898b\u308b";Y["jp-jp"].optionsAbout_header="Developed by:";Y["jp-jp"]["optionsLang_tr-tr"]="\u30c8\u30eb\u30b3\u8a9e";Y["jp-jp"]["optionsLang_de-de"]="\u30c9\u30a4\u30c4\u8a9e";Y["jp-jp"].startScreenByTinglyGames="by: CoolGames";Y["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb\u3092\u9078\u629e";Y["jp-jp"].startScreenQuestionaire="\u3069\u3046\u3067\u3059\u304b\uff1f";
Y["jp-jp"].levelEndScreenMedal="\u8a18\u9332\u66f4\u65b0\uff01";Y["jp-jp"].optionsAbout="About";Y["jp-jp"].optionsAbout_version="version:";Y["jp-jp"].optionsAbout_backBtn="\u3082\u3069\u308b";Y["jp-jp"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";Y["jp-jp"].optionsAbout_title="About";Y["jp-jp"].optionsSFXBig_off="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30d5";Y["jp-jp"].optionsSFXBig_on="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30f3";Y["jp-jp"].optionsRestart="\u518d\u30b9\u30bf\u30fc\u30c8";
Y["jp-jp"].optionsRestartConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068<br>\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c<br>\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Y["jp-jp"].levelMapScreenTitle="\u30ec\u30d9\u30eb\u9078\u629e";Y["jp-jp"].optionsQuitConfirmBtn_Yes="\u306f\u3044\u3001\u3084\u3081\u307e\u3059\u3002";Y["jp-jp"].optionsQuitConfirmBtn_No="\u3044\u3044\u3048\u3001\u7d9a\u3051\u307e\u3059\u3002";
Y["jp-jp"].optionsQuitConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u3084\u3081\u308b\u3068<br>\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c<br>\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";Y["jp-jp"].optionsTitle="\u8a2d\u5b9a";Y["jp-jp"].gameEndScreenBtnText="\u7d9a\u3051\u308b";Y["jp-jp"].gameEndScreenTitle="\u304a\u3081\u3067\u3068\u3046\uff01\n\u5168\u3066\u30af\u30ea\u30a2\u306d\uff01";Y["jp-jp"]["optionsLang_nl-nl"]="\u30aa\u30e9\u30f3\u30c0\u8a9e";
Y["jp-jp"]["optionsLang_en-gb"]="\u82f1\u8a9e\uff08\u82f1\u56fd\uff09";Y["jp-jp"]["optionsLang_en-us"]="\u82f1\u8a9e\uff08\u7c73\u56fd\uff09";Y["jp-jp"].optionsSFX_off="\u30aa\u30d5";Y["jp-jp"].optionsSFX_on="\u30aa\u30f3";Y["jp-jp"].optionsMusic_off="\u30aa\u30d5";Y["jp-jp"].optionsMusic_on="\u30aa\u30f3";Y["jp-jp"].optionsDifficulty_hard="\u96e3\u3057\u3044";Y["jp-jp"].optionsDifficulty_medium="\u666e\u901a";Y["jp-jp"].optionsDifficulty_easy="\u7c21\u5358";Y["jp-jp"].optionsMoreGames="\u305d\u306e\u4ed6\u306e\u30b2\u30fc\u30e0";
Y["jp-jp"].optionsHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";Y["jp-jp"].optionsTutorial="\u3042\u305d\u3073\u65b9";Y["jp-jp"].optionsResume="\u518d\u958b";Y["jp-jp"].optionsQuit="\u3084\u3081\u308b";Y["jp-jp"].optionsStartScreen="\u30e1\u30a4\u30f3\u30e1\u30cb\u30e5\u30fc";Y["jp-jp"].levelEndScreenHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";Y["jp-jp"].levelEndScreenTimeBonus="\u30dc\u30fc\u30ca\u30b9\u30bf\u30a4\u30e0\uff01";Y["jp-jp"].levelEndScreenTimeLeft="\u6b8b\u308a\u6642\u9593";
Y["jp-jp"].levelEndScreenSubTitle_levelFailed="\u30ec\u30d9\u30eb\u5931\u6557";Y["jp-jp"].levelEndScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Y["jp-jp"].levelEndScreenTitle_endless="\u30b9\u30c6\u30fc\u30b8 <VALUE>";Y["jp-jp"].levelEndScreenTitle_difficulty="\u30af\u30ea\u30a2\uff01";Y["jp-jp"].levelEndScreenTitle_level="\u30ec\u30d9\u30eb <VALUE>";Y["jp-jp"].levelMapScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";Y["jp-jp"].startScreenPlay="\u30d7\u30ec\u30a4";
Y["jp-jp"].loadingScreenLoading="\u30ed\u30fc\u30c7\u30a3\u30f3\u30b0";Y["jp-jp"].RewardAd_button="\u30d3\u30c7\u30aa";Y["jp-jp"].RewardAd_header="\u30b3\u30a4\u30f3";Y["jp-jp"].RewardAd_text_1="\u30d3\u30c7\u30aa\u3092\u89b3\u3066\n<COINS>\u30b3\u30a4\u30f3\u3092\u30b2\u30c3\u30c8\u3057\u3088\u3046\uff01";Y["jp-jp"].RewardAd_text_2="\u65b0\u3057\u3044\u30d3\u30c7\u30aa\u306f\u8fd1\u65e5\u516c\u958b\u3067\u3059";
V.p.Un={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:25,Lb:75,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:4,le:!0,e:[],P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};function Dn(a){this.name="StartPlay";this.n(V.p.Un);this.f(V.Yu);void 0!==a&&this.f(a)}hm(Dn,mm);
V.p.lt={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:10,Lb:60,je:30,Fd:"",ce:"",bv:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),qj:!0,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!0,Me:P,qi:S,si:null,buttons:[],bb:!0,Pa:{h:Gl,duration:.8,u:y(-500),G:y(0),o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null,OR:"",Kb:void 0,Hl:0,time:0,lb:0,
ul:0,fl:0,Tw:0,aR:!1,Ll:[],yr:[Jd,Md,Od],nB:[Kd,Nd,Pd],mB:Id,qB:[y(-177),y(0),y(177)],rB:[y(-117),y(-140),y(-117)],pB:[y(0),y(0),y(0)],oB:[y(0),y(0),y(0)],Rl:[],RV:[Ti,Ui,Vi],rx:"",px:"",sx:y(0),tx:y(15),qx:Xh,Pg:"",nx:"",ux:y(0),vx:y(50),ox:Xh,$z:"",Eu:"TOTAL SCORE:",aA:y(0),bA:y(15),Zz:R,hh:"",Xz:"",cA:y(0),dA:y(50),Yz:R,FA:"",Nu:"HIGH SCORE:",GA:y(0),HA:y(85),EA:R,jh:"",CA:"",IA:y(0),JA:y(120),DA:R,VN:R,WN:y(0),XN:y(0),Cx:"",mt:"Level Failed",Dx:y(0),nt:y(-15),Bx:R,JF:!0,ou:ee,XG:y(162),YG:y(184),
hz:"next",ly:!0,rA:we,sA:y(12),tA:y(214),qA:"restart",re:!1,se:!1,te:!1,Dt:!1,e:[],mc:null};function En(a){this.name="EndPlayWon";this.n(V.p.kA);this.f(V.p.lt);this.f(V.pP);void 0!==a&&this.f(a)}hm(En,jl);e=En.prototype;e.ax=function(a,b,c){var d=this;b=new b({Xe:this.yr[c],Vg:this.nB[c],ab:this.mB,Eh:!1,Nd:10,x:this.qB[c],y:this.rB[c],width:this.pB[c],height:this.oB[c],id:c,lb:this.lb,jf:this.RV[c],Xd:function(a,b){d.Sx(b)}});this.Rl.push(b);a.d(b)};
e.Sx=function(a){void 0!==this.lb&&a<this.lb-1&&(this.Rl[a+1].zr=!0)};
e.ub=function(a){switch(a){case "emphasized":this.re&&(this.Gp=new F({text:this.rx,s:this.px,x:this.sx,y:this.tx,font:this.qx}),this.g.d(this.Gp),this.Fp=new F({text:this.Pg,s:this.nx,x:this.ux,y:this.vx,font:this.ox}),this.g.d(this.Fp),this.re=!1);break;case "primary":this.se&&(this.dr=new F({text:this.$z,s:this.Eu,x:this.aA,y:this.bA,font:this.Zz}),this.g.d(this.dr),this.cr=new F({text:this.hh,s:this.Xz,x:this.cA,y:this.dA,font:this.Yz}),this.g.d(this.cr),this.se=!1);break;case "secondary":this.te&&
(this.kr=new F({text:this.FA,s:this.Nu,x:this.GA,y:this.HA,font:this.EA}),this.g.d(this.kr),this.jr=new F({text:this.jh,s:this.CA,x:this.IA,y:this.JA,font:this.DA}),this.g.d(this.jr),this.te=!1)}};
e.w=function(){this.Fd=E(this.bv).replace("<VALUE>",V.la.Yf.toString());En.Cb.w.call(this);var a,b=this;this.xc=new am({y:this.Ws,S:[this.Pa,{h:"show",duration:99999999},this.sa,{h:"show",duration:9999999999}]});for(var c=0;c<this.Ll.length;c++)switch(this.Ll[c]){case "stars":for(a=0;3>a;a++)this.ax(this.g,vn,a);this.re=!1;break;case "score":this.re?(this.Pg=this.Hl.toString(),this.ub("emphasized")):this.se?(this.hh=this.Hl.toString(),this.ub("primary")):this.te&&(this.jh=this.Hl.toString(),this.ub("secondary"));
break;case "time":this.re?(this.Pg=this.time.toString(),this.ub("emphasized")):this.se?(this.hh=this.time.toString(),this.ub("primary")):this.te&&(this.jh=this.time.toString(),this.ub("secondary"));break;case "moves":this.re?(this.Pg=this.ul.toString(),this.ub("emphasized")):this.se?(this.hh=this.ul.toString(),this.ub("primary")):this.te&&(this.jh=this.ul.toString(),this.ub("secondary"));break;case "highscore":this.re?(this.Pg=this.fl.toString(),this.ub("emphasized")):this.se?(this.hh=this.fl.toString(),
this.ub("primary")):this.te&&(this.jh=this.fl.toString(),this.ub("secondary"));break;case "coins":a=new F({text:this.Tw.toString(),font:this.VN,x:this.WN,y:this.XN}),this.g.d(a)}this.JF&&(c=new D({c:this.ou,x:this.XG,y:this.YG,Ib:this.hz,j:function(a){b.j&&b.j(b,a.Ib)}}),this.g.d(c));this.ly&&(c=new D({c:this.rA,x:this.sA,y:this.tA,Ib:this.qA,j:function(a){b.j&&b.j(b,a.Ib)}}),this.g.d(c));this.Dt&&(this.Ip=new F({text:this.Cx,s:this.mt,x:this.Dx,y:this.nt,font:this.Bx}),this.g.d(this.Ip));if(this.e)for(a=
0;a<this.e.length;a+=1)this.g.d(this.e[a])};e.I=function(){this.ya();this.xc=this.Ip=this.jr=this.kr=this.cr=this.dr=this.Fp=this.Gp=this.Uf=void 0};e.da=function(){if(this.Rl)for(var a=0;a<this.lb;a++){var b=this.Rl[a];a===b.id&&U.play(b.jf,730*(b.id+1))}};e.pa=function(){};
V.p.kt={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:10,Lb:60,je:30,Fd:"",ce:"",bv:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),qj:!0,Yc:y(0),Kg:y(8),Od:y(8),rj:"middle",ri:!0,Me:P,qi:S,si:null,buttons:[],bb:!0,Pa:{h:Gl,duration:.8,u:y(-500),G:y(0),o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Dc:9999999,le:!1,e:[],j:null,P:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null,uO:y(0),Ws:y(-700),wi:!1,OR:"",
Kb:void 0,Hl:0,time:0,lb:0,ul:0,fl:0,aR:!1,Ll:[],yr:[Jd,Md,Od],nB:[Kd,Nd,Pd],mB:Id,qB:[y(-165),y(0),y(165)],rB:[y(-90),y(-160),y(-90)],pB:[y(0),y(0),y(0)],oB:[y(0),y(0),y(0)],Rl:[],rx:"",px:"",sx:y(0),tx:y(15),qx:Xh,Pg:"",nx:"",ux:y(0),vx:y(50),ox:Xh,$z:"",Eu:"TOTAL SCORE:",aA:y(0),bA:y(-65),Zz:R,hh:"",Xz:"",cA:y(0),dA:y(-30),Yz:R,FA:"",Nu:"HIGH SCORE:",GA:y(0),HA:y(5),EA:R,jh:"",CA:"",IA:y(0),JA:y(40),DA:R,Cx:"",mt:"Level Failed",Dx:y(0),nt:y(-135),Bx:R,ly:!0,rA:xe,sA:y(162),tA:y(184),qA:"restart",
re:!1,se:!1,te:!1,Dt:!1,e:[],j:null,mc:null};function Fn(a){this.name="EndPlayLost";this.n(V.p.kA);this.f(V.p.kt);this.f(V.oP);void 0!==a&&this.f(a)}hm(Fn,jl);e=Fn.prototype;e.ax=function(a,b,c){var d=this;b=new b({Xe:this.yr[c],Vg:this.nB[c],ab:this.mB,Eh:!1,Nd:10,x:this.qB[c],y:this.rB[c],width:this.pB[c],height:this.oB[c],id:c,lb:this.lb,Xd:function(a,b){d.Sx(b)}});this.Rl.push(b);a.d(b)};e.Sx=function(a){void 0!==this.lb&&a<this.lb-1&&(this.Rl[a+1].zr=!0)};
e.ub=function(a){switch(a){case "emphasized":this.re&&(this.Gp=new F({text:this.rx,s:this.px,x:this.sx,y:this.tx,font:this.qx}),this.g.d(this.Gp),this.Fp=new F({text:this.Pg,s:this.nx,x:this.ux,y:this.vx,font:this.ox}),this.g.d(this.Fp),this.re=!1);break;case "primary":this.se&&(this.dr=new F({text:this.$z,s:this.Eu,x:this.aA,y:this.bA,font:this.Zz}),this.g.d(this.dr),this.cr=new F({text:this.hh,s:this.Xz,x:this.cA,y:this.dA,font:this.Yz}),this.g.d(this.cr),this.se=!1);break;case "secondary":this.te&&
(this.kr=new F({text:this.FA,s:this.Nu,x:this.GA,y:this.HA,font:this.EA}),this.g.d(this.kr),this.jr=new F({text:this.jh,s:this.CA,x:this.IA,y:this.JA,font:this.DA}),this.g.d(this.jr),this.te=!1)}};
e.w=function(){Fn.Cb.w.call(this);var a,b=this;this.xc=new am({y:this.Ws,S:[this.Pa,{h:"show",duration:99999999},this.sa,{h:"show",duration:9999999999}]});for(var c=0;c<this.Ll.length;c++)switch(this.Ll[c]){case "stars":for(a=0;3>a;a++)this.ax(this.g,vn,a);this.re=!1;break;case "score":this.re?(this.Pg=this.Hl.toString(),this.ub("emphasized")):this.se?(this.hh=this.Hl.toString(),this.ub("primary")):this.te&&(this.jh=this.Hl.toString(),this.ub("secondary"));break;case "time":this.re?(this.Pg=this.time.toString(),
this.ub("emphasized")):this.se?(this.hh=this.time.toString(),this.ub("primary")):this.te&&(this.jh=this.time.toString(),this.ub("secondary"));break;case "moves":this.re?(this.Pg=this.ul.toString(),this.ub("emphasized")):this.se?(this.hh=this.ul.toString(),this.ub("primary")):this.te&&(this.jh=this.ul.toString(),this.ub("secondary"));break;case "highscore":this.re?(this.Pg=this.fl.toString(),this.ub("emphasized")):this.se?(this.hh=this.fl.toString(),this.ub("primary")):this.te&&(this.jh=this.fl.toString(),
this.ub("secondary"))}this.JF&&(a=new D({c:this.ou,x:this.XG,y:this.YG,Ib:this.hz,j:function(a){b.j&&b.j(b,a.Ib)}}),this.g.d(a));this.ly&&(a=new D({c:this.rA,x:this.sA,y:this.tA,Ib:this.qA,j:function(a){b.j&&b.j(b,a.Ib)}}),this.g.d(a));this.Dt&&(this.Ip=new F({text:this.Cx,s:this.mt,x:this.Dx,y:this.nt,font:this.Bx}),this.g.d(this.Ip));if(this.e)for(a=0;a<this.e.length;a+=1)this.g.d(this.e[a])};e.I=function(){this.ya();this.xc=this.Ip=this.jr=this.kr=this.cr=this.dr=this.Fp=this.Gp=this.Uf=void 0};
e.da=function(){};e.pa=function(){};V.p.FV={c:null,color:"white",duration:2,e:[],zH:null,Yl:null};function Gn(a){this.name="SplashScreen";this.n(V.p.FV);this.f(V.Wu);void 0!==a&&this.f(a)}hm(Gn,yc);e=Gn.prototype;e.Z=function(){this.i()};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;this.c&&(this.xn=new u({c:this.c}),this.xn.f(this.zH),this.d(this.xn));this.Gc=new $l({interval:this.duration,repeat:1,$j:function(){b.i()}});this.Gc.f(this.Yl);this.d(this.Gc);for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.Gc=this.xn=void 0};e.da=function(){this.color&&(pa(f,r.sh),f.clearColor(this.color),pa(f,r.k))};e.pa=function(){};
V.p.ZR={x:void 0,y:void 0,width:y(480),height:y(480),backgroundImage:Rc,Ai:null,vi:null,Ah:y(0),Rg:y(-100),Yx:void 0,qE:y(0),Ww:y(276),LM:y(0),tD:y(100),sD:y(300),JM:0,Hn:null,Pa:{h:Jl,duration:.2,Of:0,o:ec},sa:{h:Jl,duration:.2,Dj:0,o:dc},bb:!1,Zk:null,Kp:60,Df:y(200),e:[],Tb:null,ic:null,$w:null,sb:null,Bi:null,op:null,KM:null};function Hn(a){this.name="LoadScreen";this.n(V.p.ZR);this.f(V.$R);void 0!==a&&this.f(a)}hm(Hn,yc);e=Hn.prototype;e.Z=function(){this.ga();X(this.g,2)};
e.w=function(){var a,b=this;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);this.bb&&(this.yj=new cm({width:r.k.width,height:r.k.height}),this.yj.f(this.ic),this.d(this.yj));null!==this.Zk&&(a=function(a,d,g){a.x=b.Df/2*Math.sin(2*Math.PI*g/b.Kp);a.y=b.Df/2*-Math.cos(2*Math.PI*g/b.Kp)},this.$k=new s({S:{h:a,duration:9999999}}),this.$k.tz=function(){b.Zk.jx(0,-b.x-b.Df/2,-b.y-b.Df/2,f.width+b.Df,f.height+b.Df,1)},this.d(this.$k));this.g=new am({S:[this.Pa,{h:"show",duration:99999999},
this.sa],Kh:function(a,d){d===b.sa&&b.bb&&dm(b.yj,b.yj.duration,b.g.S[2].duration-b.yj.duration)},yb:function(){b.i()}});this.g.f(this.$w);this.d(this.g);this.backgroundImage&&(this.background=new u({c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height}),this.background.f(this.sb),this.g.d(this.background));a=Math.min(1,this.width/this.Ai.width,this.height/2/this.Ai.height);this.Yx&&(a=this.Yx);this.ob=
new u({x:this.Ah,y:this.Rg,mb:a,Fb:a,c:this.Ai});this.ob.f(this.Bi);this.g.d(this.ob);this.Wf=new u({x:this.qE,y:this.Ww,c:this.vi});this.Wf.f(this.op);this.g.d(this.Wf);this.rw=new bm({x:this.LM,y:this.tD,width:this.sD,height:this.JM,Hn:this.Hn,tu:function(){b.Tb&&b.Tb(b);Hn.prototype.Z.call(b)}});this.rw.f(this.KM);this.g.d(this.rw);for(a=0;a<this.e.length;a+=1)this.g.d(this.e[a])};e.I=function(){this.ya();this.rw=this.Wf=this.ob=this.$k=this.yj=this.g=this.background=void 0};e.da=function(){};
e.pa=function(){};V.p.tW={backgroundImage:null,Ai:null,vt:{h:Gl,duration:.8,u:y(-500),G:y(-100),o:ic,K:1.2},wt:{h:Gl,duration:.8,u:y(-100),G:y(-500),o:hc,K:1.2},vi:null,qE:y(0),Ww:y(276),Mh:P,Zq:"",Bn:S,Cn:ed,Oh:y(0),Ph:y(100),Nh:y(300),Lh:y(0),pl:P,xq:dd,rl:y(-300),sl:y(100),ql:y(0),ol:y(0),e:[],Yd:null,qn:null,Bi:null,op:null,Dn:null,Xy:null};function In(a){this.name="TitleScreen";this.n(V.p.tW);this.f(V.LJ);void 0!==a&&this.f(a)}hm(In,yc);e=In.prototype;e.Z=function(){this.ga();X(this.ob,2)};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;this.ob=new u({c:this.Ai,S:[this.vt,{h:"show",duration:99999999},this.wt],yb:function(){b.i()}});this.ob.f(this.Bi);this.d(this.ob);this.Ba=new D({c:this.Mh,x:this.Oh,y:this.Ph,width:this.Nh,height:this.Lh,text:"PLAY",s:this.Zq,T:this.Bn,lg:2,icon:this.Cn,qa:"right",Va:y(30),Fe:14,j:function(){b.Yd&&b.Yd(b);b.Ba.i();b.Gh.i();In.prototype.Z.call(b)}});this.Ba.f(this.Dn);this.d(this.Ba);this.Gh=new D({c:this.pl,x:this.rl,y:this.sl,width:this.ql,
height:this.ol,icon:this.xq,qa:"center",Va:y(30),j:function(){b.qn&&b.qn(b)}});this.Gh.f(this.Xy);this.d(this.Gh);for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.Gh=this.Ba=this.Wf=this.ob=void 0};e.da=function(){this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k))};e.pa=function(){};
V.p.jd={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:20,QF:30,Lb:30,je:20,jd:[],cc:Xh,wd:R,cU:Uc,ou:Tc,MN:Sc,tI:!0,interval:999999,jA:!1,bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},e:[],ic:null,sb:null,fd:null,sy:null,jW:null,Yl:null,dN:null,cN:null,ZM:null};function $m(a){this.name="Tutorial";this.n(V.p.jd);this.f(V.n0);void 0!==a&&this.f(a)}hm($m,yc);e=$m.prototype;
e.Z=function(){this.ga();X(this.g,2)};e.Kl=function(a){var b;0>=this.jd.length||(0>a&&(a=0),a>=this.jd.length&&(a=this.jd.length-1),this.page=a,b=this.jd[a],this.title.f({s:b.qW}),this.title.Xa(),this.c.f({c:b.c}),void 0!==b.Nd&&this.c.f({Nd:b.Nd}),this.message.f({s:b.FS}),this.message.Xa(),this.tI&&(0>=a?(this.gh.f({alpha:.4}),this.gh.ga(0)):(this.gh.f({alpha:1}),this.gh.ka(0)),a>=this.jd.length-1?(this.Ih.f({alpha:.4}),this.Ih.ga(0)):(this.Ih.f({alpha:1}),this.Ih.ka(0))),this.La.reset())};
e.kj=function(a,b,c,d){a=new a(b);void 0!==c&&a.f(c);void 0!==d&&a.f(d);this.d(a);return a};function Jn(a,b,c,d){b=new b(c);void 0!==d&&b.f(d);a.e.push(b);return b}
e.w=function(){var a=this,b,c,d;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);this.bb&&(c=this.kj(cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.kj(u,{c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:999999},this.sa],Kh:function(b,d){d===a.sa&&a.bb&&dm(c,c.duration,a.g.S[2].duration-c.duration)},yb:function(){a.i()}},this.sb);
b=0===this.width?this.backgroundImage.width:this.width;b-=this.marginLeft+this.marginRight;d=0===this.height?this.backgroundImage.height:this.height;d-=this.marginTop+this.marginBottom;d=Jn(this.g,Yl,{x:Math.round((this.marginLeft-this.marginRight)/2),y:Math.round((this.marginTop-this.marginBottom)/2),width:b,height:d,Mo:[!0,!1,!0,!1],Lo:[!0,!1,!0,!0],Fm:0,tE:[Math.round(this.Hc*d/100),Math.round(this.QF*d/100),Math.round(this.Lb*d/100),Math.round(this.je*d/100)]});this.title=Jn(d,F,{font:this.cc},
this.fd);this.c=Jn(d,u,{},this.sy);this.message=Jn(d,F,{font:this.wd,pc:!0},this.ze);this.tI&&(b=Jn(d,Zl,{width:b-y(100),Mo:!1,Lo:!1,xs:"spread"}),this.gh=Jn(b,D,{c:this.cU,Fe:37,Va:y(20),gk:!0,j:function(){$m.prototype.Kl.call(a,a.page-1)}},this.dN),this.Ih=Jn(b,D,{c:this.ou,Fe:39,Va:y(20),gk:!0,j:function(){$m.prototype.Kl.call(a,a.page+1)}},this.cN),this.Lg=Jn(b,D,{c:this.MN,Fe:27,Va:y(20),gk:!0,j:function(){$m.prototype.Z.call(a)}},this.ZM));this.La=Jn(this.g,$l,{jt:!0,interval:this.interval,
repeat:this.jd.length,$j:function(){a.page>=a.jd.length-1?$m.prototype.Z.call(a):$m.prototype.Kl.call(a,a.page+1)}},this.Yl);this.jA&&(this.La.ak=this.La.$j);for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){this.ya();this.Lg=this.Ih=this.gh=this.message=this.c=this.title=this.g=void 0};e.da=function(){this.Kl(0)};V.p.hQ={vW:0,wW:y(-200),$p:0,aq:0,GS:0,HS:y(200),jd:[],cc:Xh,wd:R,interval:3,jA:!0,bb:!0,Jm:"white",Rd:.6,e:[],ic:null,fd:null,sy:null,jW:null,Yl:null};
function Kn(a){this.name="GameTutorial";this.n(V.p.hQ);this.f(V.iQ);void 0!==a&&this.f(a)}hm(Kn,yc);e=Kn.prototype;e.Z=function(){this.ga();this.at?dm(this.at,this.at.duration,0):this.i()};e.Kl=function(a){0>=this.jd.length||(0>a&&(a=0),a>=this.jd.length&&(a=this.jd.length-1),this.page=a,a=this.jd[a],this.Ie.f({s:a.qW}),this.Ie.Xa(),this.ry.f({c:a.c}),void 0!==a.Nd&&this.ry.f({Nd:a.Nd}),this.Yy.f({s:a.FS}),this.Yy.Xa(),this.Gc.reset())};
e.kj=function(a,b,c,d){a=new a(b);void 0!==c&&a.f(c);void 0!==d&&a.f(d);this.d(a);return a};
e.w=function(){var a=this,b;this.x=r.k.width/2;this.y=r.k.height/2;this.bb&&(this.at=this.kj(cm,{width:r.k.width,height:r.k.height,Jm:this.Jm,Rd:this.Rd,xz:function(){a.i()}},this.ic));this.Ie=this.kj(F,{x:this.vW,y:this.wW,font:this.cc},this.fd);this.ry=this.kj(u,{x:this.$p,y:this.aq},this.sy);this.Yy=this.kj(F,{x:this.GS,y:this.HS,width:r.k.width/2,height:r.k.height/4,font:this.wd,pc:!0,Sd:!0},this.ze);this.Gc=this.kj($l,{jt:!0,interval:this.interval,repeat:this.jd.length,$j:function(){a.page>=
a.jd.length-1?Kn.prototype.Z.call(a):Kn.prototype.Kl.call(a,a.page+1)}},this.Yl);this.jA&&(this.Gc.ak=this.Gc.$j);for(b=0;b<this.e.length;b+=1)this.d(this.e[b])};e.I=function(){this.ya();this.Gc=this.Yy=this.ry=this.Ie=this.at=void 0};e.da=function(){this.Kl(0)};
V.p.fO={backgroundImage:null,Xw:null,uE:"flowCompletionCongratulations",vE:Xh,rO:0,sO:y(-100),pO:0,qO:0,lO:{h:Gl,duration:.8,u:y(-400),G:y(-100),o:ic,K:1.2},mO:{h:Gl,duration:.8,u:y(-100),G:y(-400),o:hc,K:1.2},yE:P,vO:"flowCompletionContinue",xE:S,xO:null,yO:"left",BO:y(0),CO:y(200),AO:y(400),wO:y(0),e:[],su:null,oO:null,nO:null,zO:null};function Ln(a){this.name="CompletionScreen";this.n(V.p.fO);this.f(V.hO);void 0!==a&&this.f(a)}hm(Ln,yc);e=Ln.prototype;e.Z=function(){this.ga();X(this.rp,2)};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;this.rp=new am({x:this.rO,y:this.sO,S:[this.lO,{h:"show",duration:99999999},this.mO],yb:function(){b.i()}});this.d(this.rp);this.Xw&&(this.Zw=new u({c:this.Xw}),this.Zw.f(this.oO),this.rp.d(this.Zw));""!==this.uE&&(this.Yw=new F({x:this.pO,y:this.qO,s:this.uE,font:this.vE}),this.Yw.f(this.nO),this.rp.d(this.Yw));this.Xs=new D({c:this.yE,x:this.BO,y:this.CO,width:this.AO,height:this.wO,text:"<CONTINUE>",s:this.vO,T:this.xE,lg:2,icon:this.xO,
qa:this.yO,Va:y(30),Fe:14,j:function(){b.su&&b.su(b);b.Xs.i();Ln.prototype.Z.call(b)}});this.Xs.f(this.zO);this.d(this.Xs);for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.Xs=this.Yw=this.Zw=this.rp=void 0};e.da=function(){this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k))};e.pa=function(){};
V.p.uW={backgroundImage:null,jZ:[],kZ:[],Ai:null,Ah:y(0),Rg:y(-500),vt:{h:Gl,duration:.8,u:y(-500),G:y(-135),o:ic,K:1.2},wt:{h:Gl,duration:.8,u:y(-135),G:y(-500),o:hc,K:1.2},Mh:P,Zq:"startScreenPlay",Qz:"",Bn:S,Cn:ed,Oh:y(0),Ph:y(120),Nh:y(300),Lh:y(104),yn:{h:Hl,duration:.5,qc:y(0),wb:y(1),o:gc,K:1},zn:{h:Hl,duration:.5,qc:y(1),wb:y(0),o:gc,NY:0},An:{h:sn,duration:4,pk:1,Ej:1.25,qk:1,Fj:.9,K:1,name:"elastic"},pl:P,xq:dd,rl:y(-300),sl:y(100),ql:y(0),ol:y(0),CS:"",MG:S,LG:"",QS:P,LS:["Easy","Medium",
"Hard"],MS:S,PS:"right",SS:[],OS:[Xc,Zc,Yc],US:y(0),VS:y(200),TS:y(400),NS:y(0),SG:!1,RG:y(0),vi:de,np:[{x:y(0),y:y(276)}],pE:y(0),oE:y(0),Vw:"http://www.tinglygames.com",wR:P,Ey:[],zR:y(-300),AR:y(200),yR:y(0),vR:y(0),Dy:!1,hG:y(0),pN:P,rN:y(200),nN:y(92),qN:"Buy",oN:De,sN:y(-200),tN:y(-400),EF:!1,YP:ke,ZP:y(300),XP:y(100),$P:y(0),aQ:y(350),Tx:"Gallery",GF:!1,ZX:!1,dV:!1,IF:!1,HQ:!1,bT:ke,ZS:"Random Match",$S:S,dT:y(0),eT:y(138),cT:y(420),aT:y(104),e:[],Yd:null,qn:null,wz:null,jH:null,aH:null,Az:null,
YZ:null,hH:null,qH:null,xl:null,Bi:null,op:null,Dn:null,Xy:null,RS:null,xR:null};function Mn(a){this.name="TitleScreen";this.n(V.p.uW);this.f(V.LJ);void 0!==a&&this.f(a)}hm(Mn,yc);e=Mn.prototype;e.Z=function(){this.ga();void 0!==this.Ba&&X(this.Ba,3);void 0!==this.Gh&&this.Gh.i();void 0!==this.ob&&X(this.ob,2);void 0!==this.Eq&&this.Eq.i();void 0!==this.Fi&&this.Fi.i()};
e.Gz=function(){var a=this,b;V.q.uI&&(V.q.gq?(b=new Nn(V.q.gq),b.j=function(a,b){Wb();a.Kk(b)},b.Ia=function(){a.Fi.icon=uk(tk.Xf);a.Fi.Xa()},Ub(),b.show()):console.log("No languageScreenProperties can be found"))};function On(){var a;V.q.yI&&(V.q.sW?(a=new Pn(V.q.sW),a.j=function(){},a.Ia=function(){Wb()},Ub(),a.show()):console.log("No titleMenuProperties can be found"))}function Qn(a){for(var b=tk.Ei(),c=tk.Xf,d=0;d<b.length;d++)a.Ey.push(uk(b[d])),b[d]===c&&(a.hG=d)}
e.uC=function(a){a.sort(function(a,c){return a.W-c.W});this.nC(a)};e.nC=function(a){console.log(a);for(var b=0;b<a.length;b++)this.e.push(a[b])};e.XE=function(){var a=this;Tm.gn?(this.Jj.i(),this.Kj.show(),this.Kj.ka()):Sm(function(){console.log("Fb Success");a.Jj.i();a.Kj.show();a.Kj.ka()},function(){console.log("Fb Fail")})};e.uN=function(){console.log("Buy Callback Success")};
e.w=function(){var a,b=this;this.x=r.k.width/2;this.y=r.k.height/2;window.addEventListener("orientationchange",function(){console.log(window.availHeight+"  OR   "+window.innerHeight);r.g.style.height=window.availHeight||window.innerHeight},!1);this.ob=new u({c:this.Ai,y:this.Rg,x:this.Ah,S:[this.vt,{h:"show",duration:99999999},this.wt],yb:function(){b.i()}});this.ob.f(this.Bi);this.d(this.ob);this.IF||(this.Ba=new D({c:this.Mh,x:this.Oh,y:this.Ph,width:this.Nh,height:this.Lh,text:this.Qz,s:this.Zq,
T:this.Bn,lg:2,S:[this.yn,this.An,{h:"show",duration:99999999},this.zn],icon:this.Cn,qa:"right",Va:y(30),Fe:14,dh:function(a,d){"elastic"===d.name&&X(b.Ba,1)},j:function(){b.Yd&&b.Yd("play");Mn.prototype.Z.call(b)}}),this.Ba.f(this.Dn),this.d(this.Ba));this.IF&&(this.fz=new D({c:this.bT,x:this.dT,y:this.eT,S:[this.yn,this.An,{h:"show",duration:99999999},this.zn],s:this.ZS,width:this.cT,height:this.aT,T:this.$S,dh:function(a,d){"elastic"===d.name&&X(b.fz,1)},j:function(){b.Az&&b.Az(b);b.ga()}}),this.d(this.fz));
this.GF&&(this.VP=new D({c:this.YP,width:this.ZP,height:this.XP,x:this.$P,y:this.aQ,text:this.Tx,j:function(){b.xl&&b.xl("gallery")}}),this.d(this.VP));this.qG=new qn({});this.dV&&(this.Jj=new D({c:s_button_default_facebook,icon:s_button_default_icon_facebook,x:y(0),y:y(185),marginRight:y(0),marginLeft:y(50),Ue:y(2),text:"Login to Facebook",T:NotSoStoutDeco,width:y(400),height:y(104),j:function(){b.XE&&b.XE()}}),this.d(this.Jj),this.Kj=new D({c:s_button_default_green,text:"Challenge a friend",width:y(400),
height:y(104),T:NotSoStoutDeco,x:y(0),y:y(185),j:function(){b.hH&&b.hH()}}),this.d(this.Kj));this.Gh=new D({c:this.pl,text:this.CS,T:this.MG,s:this.LG,x:this.rl,y:this.sl,width:this.ql,height:this.ol,icon:this.xq,qa:"center",Va:y(30),j:function(){b.qn?b.qn(b):On()}});this.Gh.f(this.Xy);this.qG.d(this.Gh);this.d(this.qG);this.SG&&(this.Eq=new D({c:this.QS,icon:this.OS,qa:this.PS,text:this.SS,s:this.LS,T:this.MS,lg:2,x:this.US,y:this.VS,width:this.TS,height:this.NS,$a:this.RG,bj:!0,j:function(a){b.jH&&
b.jH(b);this.RG=a.$a}}),this.Eq.f(this.RS),this.d(this.Eq));this.EF&&(this.mN=new D({c:this.pN,icon:this.oN,width:this.rN,height:this.nN,x:this.sN,y:this.tN,text:this.qN,j:function(){G.JT(b.uN)}}),this.d(this.mN));this.Dy&&(0===this.Ey.length&&Qn(this),this.Fi=new D({c:this.wR,icon:this.Ey[this.hG],x:this.zR,y:this.AR,width:this.yR,height:this.vR,j:function(){b.wz?b.wz(b):b.Gz()}}),this.Fi.f(this.xR),this.d(this.Fi));this.Jn=new qn({zs:new da(1,0)});this.HQ&&(this.fK=new D({c:s_button_drop_right,
icon:De,text:"0",T:NotSoStoutDeco,x:y(-100),y:y(580),width:y(153),height:y(114),j:function(){b.qH&&b.qH()}}),this.Jn.d(this.fK),this.d(this.Jn));if("[object Array]"===Object.prototype.toString.call(this.vi))for(a=0;a<this.vi.length;a++)this.Wf=new u({c:this.vi[a],x:this.np[a].x,y:this.np[a].y,width:this.pE,height:this.oE,link:this.Vw[a],TQ:a,j:function(){b.aH?b.aH[this.TQ].call():""!==this.link&&window.open(this.link)}}),this.Wf.f(this.op),this.Jn.d(this.Wf),this.d(this.Jn);else this.Wf=new u({c:this.vi,
x:this.np[0].x,y:this.np[0].y,width:this.pE,height:this.oE,link:this.Vw,j:function(){""!==this.link&&window.open(this.link,"_blank")}}),this.Wf.f(this.op),this.Jn.d(this.Wf),this.d(this.Jn);this.Dy&&(this.Fi.icon=uk(tk.Xf),this.Fi.Xa());for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.fK=this.Kj=this.fz=this.Jj=this.Fi=this.Eq=this.Wf=this.Gh=this.Ba=this.Wf=this.ob=void 0};
e.da=function(){this.backgroundImage&&(pa(f,r.sh),wa(this.backgroundImage,0,0),pa(f,r.k));Tm&&this.Jj&&(Tm.gn?this.Jj.i():this.Kj.i())};e.$f=function(){Tm&&this.Jj&&(Tm.gn?this.Jj.i():this.Kj.i())};e.Iq=function(){tk.kk(tk.Xf);this.Ba&&this.Ba.Xa()};e.pa=function(){};V.p.CR={Qs:y(500),Ps:y(500),dp:[],Jk:y(0),Qo:[],Ro:[],pd:[],e:[],zA:null};function Nn(a){this.name="LanguageScreen";this.n(V.p.Wo);this.f(V.p.CR);this.f(V.rW);void 0!==a&&this.f(a)}hm(Nn,lm);e=Nn.prototype;
e.Z=function(){this.ga();X(this.g,2)};function Rn(a,b,c){b=new Rl(b);void 0!==c&&b.f(c);a.d(b)}e.Bv=function(a,b,c,d,g){a=new b(c);void 0!==d&&a.f(d);void 0!==g&&a.f(g);this.dp.push(a)};
e.Sf=function(a,b,c,d,g,k){var l=this;return this.Bv(a,an,{x:d,y:g,width:k,height:0,c:void 0===b.c?this.Me:b.c,text:this.Ro[c],$m:this.pd[c],s:void 0===b.key?"":b.key,icon:this.Qo[c],qa:"left",font:void 0===b.font?this.qi:b.font,Ib:void 0===b.id?c:b.id,Ik:void 0===b.i?this.ri:b.i,vc:!1,lg:2,threshold:y(1.5),j:function(a){a.Ik&&lm.prototype.Z.call(l);l.j&&l.j(l,a.Ib)}},this.si,b.Cd)};e.Kk=function(a){tk.kk(tk.Ei()[a]);this.ga();X(this.g,2)};
e.bq=function(){this.pd=tk.Ei();for(var a=0;a<this.pd.length;a++)this.Qo.push(uk(this.pd[a])),this.Ro.push(vk(this.pd[a]))};
e.w=function(){var a=this,b,c,d,g=[],k=[],l=[];b=[];var m,p,w,z,v,C;void 0===this.x&&(this.x=r.k.width/2);void 0===this.y&&(this.y=r.k.height/2);m=0===this.width?this.backgroundImage.width:this.width;p=0===this.height?this.backgroundImage.height:this.height;g[0]=Math.round(-m/2+this.marginLeft);l[0]=Math.round(m-this.marginLeft-this.marginRight);k[0]=Math.round(-p/2+this.marginTop);b[0]=Math.round(this.Hc*(p-this.marginTop-this.marginBottom)/100);g[1]=Math.round(-m/2+this.marginLeft);l[1]=Math.round(m-
this.marginLeft-this.marginRight);k[1]=Math.round(k[0]+b[0]);b[1]=Math.round(this.Lb*(p-this.marginTop-this.marginBottom)/100);this.xa&&(l[2]=this.xa.width,g[2]=g[1]+l[1]-l[2],k[2]=k[1],b[2]=b[1],l[1]-=l[2]+y(32),"left"===this.qa&&(g[2]=g[1],g[1]+=l[2]+y(32)));g[3]=Math.round(-m/2+this.marginLeft);l[3]=Math.round(m-this.marginLeft-this.marginRight);0<this.Yc&&(g[3]=Math.round(-this.Yc/2),l[3]=this.Yc);k[3]=Math.round(k[1]+b[1]);b[3]=Math.round(this.je*(p-this.marginTop-this.marginBottom)/100);this.bb&&
(C=this.Fa(this,cm,{width:r.k.width,height:r.k.height},this.ic));this.g=this.Fa(this,u,{c:this.backgroundImage,tb:!0,width:0===this.width?this.backgroundImage.width:this.width,height:0===this.height?this.backgroundImage.height:this.height,S:[this.Pa,{h:"show",duration:this.Dc},this.sa],Kh:function(b,c){c===a.sa&&a.bb&&dm(C,C.duration,a.g.S[2].duration-C.duration)},yb:function(){a.i()}},this.sb);this.le&&(this.g.ak=function(){a.P&&a.P(a);lm.prototype.Z.call(a)});this.Hc&&this.Fa(this.g,F,{x:Math.round(g[0]+
l[0]/2),y:Math.round(k[0]+b[0]/2),width:l[0],height:b[0],text:this.Fd,s:this.ce,font:this.cc,Sd:!0,pc:!1,Ca:y(20)},this.fd);this.Lb&&this.Fa(this.g,F,{x:Math.round(g[1]+l[1]/2),y:Math.round(k[1]+b[1]/2),width:l[1],height:b[1],text:this.ef,s:this.Hf,font:this.wd,Sd:!0,pc:!0,Ca:y(20)},this.ze);this.Lb&&this.xa&&this.Fa(this.g,u,{c:this.xa,x:Math.round(g[2]+l[2]/2),y:Math.round(k[2]+b[2]/2)},this.td);this.Zb&&(m=Math.round((0===this.width?this.backgroundImage.width:this.width)/2-this.wc/2),p=Math.round(-(0===
this.height?this.backgroundImage.height:this.height)/2+this.qd/2),this.Fa(this.g,D,{x:m,y:p,width:this.wc,height:this.qd,c:Pc,j:function(){a.P&&a.P(a);lm.prototype.Z.call(a)}},this.zf));this.bq();if(this.je){m=this.qj?[this.buttons]:this.buttons;c=this.Me.height;p=c+this.Od;k=Math.round(k[3]+c/2);switch(this.rj){case "top":break;case "bottom":k+=b[3]-m.length*p-this.Od;break;default:k+=Math.round((b[3]-m.length*p-this.Od)/2)}for(b=d=0;b<m.length;b+=1)if("[object Array]"===Object.prototype.toString.call(m[b]))for(v=
Math.round((l[3]-this.Kg*(m[b].length-1))/m[b].length),z=v+this.Kg,w=Math.round(g[3]+v/2),this.Jk+=p+this.Od,c=0;c<m[b].length;c+=1)this.Sf(this.g,m[b][c],d,w+c*z,k+b*p,v),d+=1;else this.Sf(this.g,m[b],d,Math.round(g[3]+l[3]/2),k+b*p,l[3]),d+=1}Rn(this.g,{On:!1,gD:0,hD:0,width:this.Qs,height:this.Ps,O:this.Me.width,M:this.Jk,e:this.dp},this.zA);for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){Nn.Cb.I.call(this)};
V.p.zT={eh:[],Dl:[{x:y(0),y:y(-180)},{x:y(0),y:y(-80)},{x:y(0),y:y(20)},{x:y(0),y:y(120)},{x:y(0),y:y(220)}],Ec:y(0),Fc:y(0),$m:void 0,qe:S,eF:void 0,GP:y(0),HP:y(0),bp:ke,WD:S,Iw:"optionsTutorial",cp:y(400),ap:y(92),Jw:"",lN:null,WA:Vc,XA:Wc,YA:y(400),UA:y(92),VA:ad,cB:Vc,dB:Wc,eB:y(400),aB:y(92),bB:cd,Zo:ke,SD:S,Fw:"optionsMoreGames",$o:y(400),Yo:y(92),Gw:"",bN:null,Hw:"http://www.coolgames.com/",Ns:ke,CD:S,Aw:"optionsAbout_title",Os:y(400),Ms:y(92),Bw:"",YM:null,GD:ke,tY:S,ED:"Close",HD:y(400),
FD:y(92),$M:"",uY:null,MD:ke,vY:S,JD:"optionsExit",OD:y(400),LD:y(92),ND:"",wY:null,KD:!1,UD:ke,BY:S,jN:"optionsResume",VD:y(400),TD:y(92),kN:"",CY:null,gN:ke,zY:S,eN:"optionsQuit",iN:y(400),fN:y(92),hN:"",AY:null,nU:"",oU:y(0),pU:y(-120),Iu:y(400),Hu:y(200),lU:"optionsRestartConfirmationText",mU:R,C_:"",D_:y(0),E_:y(-80),A_:"If you quit now you will \n lose all progress made \n during this level. Are you \n sure you want to quit?",B_:S,UH:ke,sU:y(0),tU:y(120),VH:y(400),TH:y(92),rU:"",qU:"optionsQuitConfirmBtn_Yes",
mA:"",QH:ke,jU:y(0),SH:y(220),RH:y(400),PH:y(92),iU:"",hU:"optionsQuitConfirmBtn_No",Dw:ke,PD:[],QD:[],RD:0,pd:[],Ew:y(400),Cw:y(92),Im:void 0,qz:ke,pz:[qe,pe],rz:y(200),oz:y(92),mz:ke,lz:[ue,te],nz:y(200),kz:y(92),DF:!1,bk:null,yl:null,Kq:null,Al:null,Oq:null,rn:null,mn:null,P:null,uz:null,nH:null,lH:null,Mq:null,d_:null,Ra:null,ad:null,Uh:null,LB:null,mu:null,Su:null,BR:null,az:null,Zv:null,NN:null,sP:null,CU:null,kU:null};
function Pn(a){this.name="OptionScreen";this.n(V.p.Wo);this.f(V.p.zT);void 0!==a&&this.f(a)}hm(Pn,lm);e=Pn.prototype;e.Z=function(){this.ga();X(this.g,2)};e.Gz=function(){var a;V.q.uI&&(V.q.gq?(a=new Nn(V.q.gq),a.j=function(a,c){Wb();a.Kk(c)},Ub(),a.show()):console.log("No languageScreenProperties can be found"))};e.Hz=function(){var a;V.q.QA&&(V.q.KB?(a=new $m(V.q.KB),a.j=function(){Wb()},Ub(),a.show()):console.log("No tutorialMenuProperties can be found"))};
e.Fz=function(){var a;a=new Sn({backgroundImage:this.rm,Zb:!0});a.Ia=function(){Wb()};Ub();a.show()};e.Hk=function(a){this.Ec=this.Dl[a].x;this.Fc=this.Dl[a].y};e.Kk=function(a){this.$m=a;var b=tk.Ei();tk.kk(b[a]);qk.kk(b[a])};e.bq=function(){var a=tk.Xf;this.pd=tk.Ei();for(var b=0;b<this.pd.length;b++)this.PD.push(uk(this.pd[b])),this.QD.push(vk(this.pd[b])),a===this.pd[b]&&(this.RD=b)};
e.w=function(){var a=this,b,c=0;Pn.Cb.w.call(this);this.ad=new am({});this.Uh=new am({});this.eF&&(this.FP=new u({c:this.eF,x:this.GP,y:this.HP}),this.ad.d(this.FP));for(b=0;b<this.eh.length;b++)if(G.ay()||"moregames"!==this.eh[b])if(void 0===G.sF||!G.sF()||"audio"!==this.eh[b]&&"oldSound"!==this.eh[b])switch(this.Hk(b-c),this.eh[b]){case "tutorial":this.$l=new D({c:this.bp,T:this.qe,x:this.Ec,y:this.Fc,width:this.cp,height:this.ap,text:this.Jw,s:this.Iw,j:function(){a.bk?a.bk(a):a.Hz()}});this.$l.f(this.LB);
this.ad.d(this.$l);break;case "music":this.Hh=new em({icon:this.VA,ja:this.WA,we:this.XA,x:this.Ec,y:this.Fc,width:this.YA,height:this.UA,nn:function(b,c){a.Kq?a.Kq(a):ol(U,c/100)},pn:function(){a.yl&&a.yl(a)}});this.Hh.f(this.mu);this.ad.d(this.Hh);break;case "audio":this.Xh=new em({icon:this.bB,ja:this.cB,we:this.dB,x:this.Ec,y:this.Fc,width:this.eB,height:this.aB,nn:function(b,c){a.Oq?a.Oq(a):nl(U,c/100)},pn:function(){a.Al&&a.Al(a)}});this.Xh.f(this.Su);this.ad.d(this.Xh);break;case "oldSound":var d=
this.Ec/2,g=2*this.Ec;0===d&&(d=this.Im?-this.Im:y(-100));0===g&&(g=this.Im?this.Im:y(100));var k=pk(qk),l=1;k.yi||(l=0);var m=1;k.Mi||(m=0);this.Hh=new D({c:this.qz,x:d,y:this.Fc,icon:this.pz,qa:"center",T:this.qe,width:this.rz,height:this.oz,$a:m,bj:!0,j:function(b){a.yl&&a.yl(a);switch(b.$a){case 0:sl(U);Nk(void 0,!1);break;case 1:rl(U),Nk(void 0,!0)}}});this.Hh.f(this.mu);this.ad.d(this.Hh);this.Xh=new D({c:this.mz,x:g,y:this.Fc,icon:this.lz,qa:"center",T:this.qe,width:this.nz,height:this.kz,
$a:l,bj:!0,j:function(b){a.Al&&a.Al(a);switch(b.$a){case 0:ql(U);Nk(!1,void 0);break;case 1:pl(U),Nk(!0,void 0)}}});this.Xh.f(this.Su);this.ad.d(this.Xh);break;case "oldLanguage":this.bq();d=new D({c:this.Dw,icon:this.PD,qa:"left",marginLeft:y(40),text:this.QD,$a:this.RD,width:this.Ew,height:this.Cw,x:this.Ec,y:this.Fc,T:this.qe,bj:!0,j:function(b){a.Kk(b.$a)}});this.ad.d(d);break;case "moregames":this.tl=new D({c:this.Zo,x:this.Ec,y:this.Fc,width:this.$o,height:this.Yo,text:this.Gw,link:this.Hw,
s:this.Fw,T:this.qe,j:function(){a.rn?a.rn():void 0!==G.yt()&&window.open(G.yt())}});this.tl.f(this.az);this.ad.d(this.tl);break;case "about":this.Ek=new D({c:this.Ns,x:this.Ec,y:this.Fc,width:this.Os,height:this.Ms,text:this.Bw,s:this.Aw,T:this.qe,j:function(){a.mn?a.mn(a):a.Fz()}});this.Ek.f(this.Zv);this.ad.d(this.Ek);break;case "close":this.Rw=new D({c:this.GD,x:this.Ec,y:this.Fc,width:this.HD,height:this.FD,text:this.$M,s:this.ED,T:this.qe,Ib:this.mA,j:function(b){a.DF?(a.Z(),a.Mq&&a.Mq(a,b.Ib)):
a.P&&a.P(a)}});this.Rw.f(this.NN);this.ad.d(this.Rw);break;case "exit":this.Ax=new D({c:this.MD,x:this.Ec,y:this.Fc,width:this.OD,height:this.LD,text:this.ND,s:this.JD,T:this.qe,j:function(){a.uz?a.uz(a):a.KD&&Pn.prototype.Z.call(a)}});this.Ax.f(this.sP);this.ad.d(this.Ax);break;case "resume":this.uA=new D({c:this.UD,x:this.Ec,y:this.Fc,width:this.VD,height:this.TD,text:this.kN,s:this.jN,T:this.qe,j:function(){a.nH?a.nH(a):a.Z()}});this.uA.f(this.CU);this.ad.d(this.uA);break;case "quit":this.lA=new D({c:this.gN,
x:this.Ec,y:this.Fc,width:this.iN,height:this.fN,text:this.hN,s:this.eN,T:this.qe,j:function(){a.lH?a.lH(a):(a.ad.i(),a.Uh.show(),a.Uh.ka())}}),this.lA.f(this.kU),this.ad.d(this.lA),d=new F({text:this.nU,s:this.lU,x:this.oU,y:this.pU,width:this.Iu,height:this.Hu,font:this.mU,pc:!0,Sd:!0}),this.Uh.d(d),d=new D({c:this.UH,x:this.sU,y:this.tU,width:this.VH,height:this.TH,s:this.qU,T:this.qe,text:this.rU,Ib:this.mA,j:function(b){a.Z();a.Mq&&a.Mq(a,b.Ib)}}),this.Uh.d(d),d=new D({c:this.QH,x:this.jU,y:this.SH,
width:this.RH,height:this.PH,s:this.hU,T:this.qe,text:this.iU,j:function(){a.Uh.i();a.ad.show();a.ad.ka()}}),this.Uh.d(d),this.g.d(this.Uh)}else c++;else c++;this.g.d(this.ad);for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.da=function(){this.Uh.i()};e.I=function(){Pn.Cb.I.call(this);this.lA=this.uA=this.Ax=this.Rw=this.Ek=this.tl=this.Xh=this.Hh=this.$l=void 0};
V.p.QR={$T:"undefined"!==typeof Kh?Kh:null,Xg:0,mode:V.la.bx,gZ:0,RY:[],xZ:null,$F:!1,Fd:"",l0:"",NJ:"",cc:Xh,Mh:ke,Cn:ed,Oh:y(0),Ph:y(200),Nh:y(300),Lh:y(92),RT:"rigth",Qz:"",Zq:"startScreenPlay",Bn:S,PV:!0,SV:[Jd,Md,Od],QI:[{x:y(-177),y:y(-117)},{x:y(0),y:y(-140)},{x:y(177),y:y(-114)}],AP:Kd,BP:y(-177),CP:y(-117),OU:Nd,PU:y(0),QU:y(-140),mW:Pd,nW:y(177),oW:y(-117),rR:"",fq:"Goal",sR:y(0),tR:y(20),qR:Xh,Zm:"",Ay:"",Cy:y(0),Mt:y(60),fG:y(500),cG:y(400),By:R,X_:!0,e:[],Yd:null};
function Tn(a){this.name="LevelPopUp";this.n(V.p.Wo);this.f(V.p.QR);this.f(V.wG);void 0!==a&&this.f(a)}hm(Tn,lm);Tn.prototype.Z=function(){this.ga();X(this.g,2)};Tn.prototype.TT=function(){this.ga();X(this.g,2)};
function Un(a){var b=jn(),c=Lk(qk,a.mode,a.Xg);if(a.PV){for(var c=c.$g,d=0;3>d;d++){var g=new u({c:a.SV[d],x:a.QI[d].x,y:a.QI[d].y});a.g.d(g)}0<c&&(d=new u({c:a.AP,x:a.BP,y:a.CP}),a.g.d(d));1<c&&(d=new u({c:a.OU,x:a.PU,y:a.QU}),a.g.d(d));2<c&&(d=new u({c:a.mW,x:a.nW,y:a.oW}),a.g.d(d))}a.Ba=new D({c:a.Mh,x:a.Oh,y:a.Ph,width:a.Nh,height:a.Lh,icon:a.Cn,qa:a.RT,text:a.Qz,s:a.Zq,T:a.Bn,lg:2,Ib:a.Xg,j:function(){Tn.prototype.TT.call(a);a.$F=!0}});a.g.d(a.Ba);c=void 0;switch(b.af[a.Xg-1].Bh.mode){case "points":d=
b.af[a.Xg-1].El.Q_;a.Zm=E("GoalText_01").replace("<TARGET>",d.toString());a.fq="LevelTheme_01";c=s_ui_highscore;break;case "type":d=b.af[a.Xg-1].type.jY;b=b.af[a.Xg-1].type.o0;a.Zm=E("GoalText_02").replace("<TARGET>",d.toString());a.fq="LevelTheme_02";switch(b){case "BIGCORNER":c=s_shape_bigcorner;break;case "BIGSQUARE":c=s_shape_bigsquare;break;case "DASH":c=s_shape_dash;break;case "DOT":c=s_shape_dot;break;case "FRIKANDEL":c=s_shape_frikandel;break;case "KROKET":c=s_shape_kroket;break;case "LINE":c=
s_shape_line;break;case "MINICORNER":c=s_shape_minicorner;break;case "SQUARE":c=s_shape_square}break;case "counter":d=b.af[a.Xg-1].wj.FY.length,a.Zm=E("GoalText_03").replace("<TARGET>",d.toString()),a.fq="LevelTheme_03",c=s_shape_blockerblock}c&&(b=new u({c:c,x:y(0),y:y(113)}),a.g.d(b));a.eG=new F({x:a.sR,y:a.tR,text:a.rR,s:a.fq,font:a.qR});a.g.d(a.eG);a.Bc=new F({x:a.Cy,y:a.Mt,text:a.Zm,s:a.Ay,font:a.By});a.g.d(a.Bc)}
Tn.prototype.w=function(){var a=this,b;this.backgroundImage=this.$T;this.Fd=E(this.NJ).replace("<VALUE>",this.Xg.toString());this.marginTop=y(20);Tn.Cb.w.call(this);Un(this);this.g.Ia=function(){a.Yd&&a.$F&&a.Yd(a,a.Xg)};for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};Tn.prototype.I=function(){Sn.Cb.I.call(this);this.eG=this.Bc=this.Ba=void 0};
V.p.BL={rm:"undefined"!==typeof Kh?Kh:null,ss:"optionsAbout_header_publisher",$v:"",ts:Xh,aw:y(0),us:y(-250),Tv:Yd,Vv:y(0),qs:y(-100),Uv:"http://www.coolgames.com/",Wv:"",AL:"optionsAbout_text",Xv:y(0),rs:y(100),Yv:"http://www.coolgames.com/",zC:R,ns:ke,Rv:"",Qv:"optionsAbout_backBtn",ls:S,Sv:y(0),ps:y(200),os:y(400),ms:y(92),OJ:y(0),Jq:null,e:[],fd:null,zH:null,vZ:null,yY:null};function Sn(a){this.name="AboutScreen";this.n(V.p.Wo);this.f(V.p.BL);this.f(V.AT);void 0!==a&&this.f(a)}hm(Sn,lm);
Sn.prototype.Z=function(){this.ga();X(this.g,2)};
Sn.prototype.uy=function(){var a=this;this.Ie=new F({text:this.$v,s:this.ss,x:this.aw,y:this.us,font:this.ts,width:this.rm.width-this.OJ});this.g.d(this.Ie);this.xn=new u({c:this.Tv,x:this.Vv,y:this.qs,url:this.Uv,j:function(){var a=this.url;a&&window.open(a)}});this.g.d(this.xn);this.gG=new F({text:this.Wv,s:this.AL,x:this.Xv,y:this.rs,url:this.Yv,font:this.zC,j:function(){var a=this.url;a&&window.open(a)}});this.g.d(this.gG);this.ID=new D({c:this.ns,x:this.Sv,y:this.ps,width:this.os,height:this.ms,
text:this.Rv,s:this.Qv,T:this.ls,j:function(){a.Jq?a.Jq(a):a.Z()}});this.g.d(this.ID)};Sn.prototype.w=function(){var a;this.backgroundImage=this.rm;Sn.Cb.w.call(this);this.uy();for(a=0;a<this.e.length;a+=1)this.g.d(this.e[a])};Sn.prototype.I=function(){tgfDialog.zX.Cb.I.call(this);this.ID=this.gG=this.xn=this.Ie=void 0};
V.p.rS={x:void 0,y:void 0,backgroundImage:Rc,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:25,Lb:75,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Gl,duration:.8,u:y(0),G:y(-500),o:hc,K:1.2},Dc:9999999999,le:!1,e:[],P:null,xp:"undefined"!==typeof s_avatar140?s_avatar140:void 0,Ce:y(130),bc:R,Yn:void 0,ei:void 0,av:"Guest",Mr:y(-235),Nr:y(-97),Rq:void 0,fh:void 0,Kz:"Guest",Tq:y(235),Uq:y(-97),
AN:"undefined"!==typeof s_button_default_green?s_button_default_green:void 0,BN:"Cancel",DN:y(0),EN:y(190),CN:y(200),zN:y(104),yN:"undefined"!==typeof NotSoStoutDeco?NotSoStoutDeco:void 0,YD:!1,yz:null,TZ:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};function Vn(a){this.name="MatchMaking";this.vb=null;this.im={bs:0,YK:1,aL:2};this.Hm;this.Tz;this.Qq;this.Sz=-1;this.Nc;this.Mb;this.gr="";this.qS=this.vA=!1;this.n(V.p.rS);this.f(V.Yu);void 0!==a&&this.f(a);this.Xp()}hm(Vn,mm);e=Vn.prototype;
e.Xp=function(){if(this.vb=Im.Xp()){var a=Im;this.Nc={fA:a.VE,gA:a.WE,info:a.zx};this.Hm=this.im.bs;Wn(this)}else console.log("NO FIREBASE REFERENCE SET")};function Wn(a){a.vb.Ez("value",function(b){b.DQ("game")||a.vb.Pe("game").set({eP:0});Xn(a)})}
function Xn(a){var b,c=a.vb.Pe("game");c.Ez("value",function(d){var g=d.RZ();d.forEach(function(d){var l=d.lo();if(0<l.la&&2>l.la)return void 0!==a.Nc.info?l.q_.uid===a.Nc.info.uid?(d=c.push({la:0}),d=d.key(),Yn(a,d)):(b=d.key(),Yn(a,b)):(b=d.key(),Yn(a,b)),!0;g--;if(0===g)return d=c.push({la:0}),d=d.key(),Yn(a,d),!0})})}
function Yn(a,b){a.vb.Pe("game/"+b+"/player0/online").ru("value",function(c){null===c.lo()&&a.Hm===a.im.bs&&Zn(a,0,b)});a.vb.Pe("game/"+b+"/player1/online").ru("value",function(c){null===c.lo()&&a.Hm===a.im.bs&&Zn(a,1,b)});a.vb.Pe("game/"+b+"/game").ru("value",function(b){2===b.lo()&&(a.vA=!0,$n(a))})}
function Zn(a,b,c){a.Hm=a.im.YK;a.vb.Pe("game/"+c+"/player"+b+"/online").transaction(function(a){if(null===a)return!0},function(d,g){g?(a.Hm=a.im.aL,a.vb.Pe("game/"+c+"/player"+b).transaction(function(){var b="guest123456789";void 0!==a.Nc.info&&(b=a.Nc.info.uid);var d="GUEST123";void 0!==a.Nc.info&&(d=a.Nc.info.name);var g="noUrl";void 0!==a.Nc.fA&&(g=a.Nc.fA);var p="noUrl";void 0!==a.Nc.gA&&(p=a.Nc.gA);b={m_:!0,uid:b,name:d,url:g,ko:p};a.gr=c;return b}),ao(a,b,c)):a.Hm=a.im.bs})}
function $n(a){var b=0;a.vA&&(a.Qq.ru("value",function(c){a.Mb=c.lo();null===a.Mb||1<=b||(console.log("runs once"),a.Mb&&(a.Mb.ko&&"noUrl"!==a.Mb.ko&&(a.rH=Nm(a.Mb.ko,a.Ce),a.Iz=Nm(a.Mb.url,Lm)),a.Mb.name&&(a.sn,c=a.Mb.name.indexOf(" "),a.sn=-1!==c?a.Mb.name.substr(0,c):a.Mb.name)),b++)}),a.XD.i(),a.HJ.i(),a.vA=!1)}
function ao(a,b,c){var d=0;a.Sz=b;a.Tz=a.vb.Pe("game/"+c+"/player"+b);a.Qq=a.vb.Pe("game/"+c+"/player"+(1-b));a.vb.Pe("game/"+c+"/game").transaction(function(a){return a+1});a.Qq.ru("value",function(b){a.Mb=b.lo();if(!(null===a.Mb||1<=d)){console.log("runs once");a.Mb&&(a.Mb.ko&&"noUrl"!==a.Mb.ko&&(a.rH=Nm(a.Mb.ko,a.Ce),a.Iz=Nm(a.Mb.url,Lm)),a.Mb.name&&(a.sn,b=a.Mb.name.indexOf(" "),a.sn=-1!==b?a.Mb.name.substr(0,b):a.Mb.name));b=a.sn;var c=a.rH;void 0!==c&&(a.fh.c=c);void 0!==b&&(a.Sq.text=b,a.Sq.Xa());
a.qS=!0;a.yz&&a.yz({vb:a.vb,Sz:a.Sz,Tz:a.Tz,Qq:a.Qq,Mb:a.Mb,gr:a.gr,sn:a.sn,Iz:a.Iz,Nc:a.Nc,MZ:a});d++}})}
e.or=function(){var a=this;this.ei=this.Yn?Nm(this.Yn,this.Ce):this.xp;this.ei=new u({c:this.ei,x:this.Mr,y:this.Nr,width:this.Ce,height:this.Ce});this.g.d(this.ei);this.EB=new F({text:this.av,x:this.Mr,y:this.Nr+125,font:this.bc});this.g.d(this.EB);this.fh=this.Rq?Nm(this.Rq,this.Ce):this.xp;this.fh=new u({c:this.fh,x:this.Tq,y:this.Uq,width:this.Ce,height:this.Ce});this.g.d(this.fh);this.Sq=new F({text:this.Kz,x:this.Tq,y:this.Uq+125,font:this.bc});this.g.d(this.Sq);this.XD=new D({c:this.AN,x:this.DN,
y:this.EN,width:this.CN,height:this.zN,text:this.BN,T:this.yN,j:function(){a.YD=!0;a.vb.Pe("game/"+a.gr).SZ();a.vb.Pe("game/"+a.gr).remove();a.i()}});this.g.d(this.XD);this.HJ=new u({c:s_throbber,Nd:10,x:y(0),y:y(-90)});this.g.d(this.HJ)};e.Z=function(){Vn.Cb.Z.call(this)};e.w=function(){Vn.Cb.w.call(this);this.Nc.fA&&(this.Yn=this.Nc.gA);if(this.Nc.info){var a=this.Nc.info.name.indexOf(" ");this.av=-1!==a?this.Nc.info.name.substr(0,a):this.Nc.info.name}this.or()};e.pa=function(){};e.I=function(){};
V.p.pS={x:void 0,y:void 0,backgroundImage:"undefined"!==typeof s_overlay_matchmaking?s_overlay_matchmaking:void 0,marginLeft:y(40),marginRight:y(40),marginTop:y(40),marginBottom:y(40),Hc:25,Lb:75,Fd:"",ce:"",cc:Xh,ef:"",Hf:"",wd:R,xa:null,qa:"right",Zb:!1,wc:y(96),qd:y(96),bb:!0,Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Gl,duration:.8,u:y(0),G:y(-500),o:hc,K:1.2},Dc:9999999999,le:!1,e:[],P:null,xp:"undefined"!==typeof s_avatar140?s_avatar140:void 0,Ce:y(130),bc:R,Yn:void 0,ei:void 0,av:"Guest",
Mr:y(-235),Nr:y(-97),Rq:void 0,fh:void 0,Kz:"NAME",Tq:y(235),Uq:y(-97),NQ:"undefined"!==typeof s_button_default_red?s_button_default_red:void 0,OQ:"Home",QQ:y(0),RQ:y(190),PQ:y(200),MQ:y(104),LQ:"undefined"!==typeof NotSoStoutDeco?NotSoStoutDeco:void 0,home:!1,F_:!1,iH:null,e_:null,SY:null,vb:null,ic:null,sb:null,fd:null,ze:null,td:null,zf:null};function bo(a){this.name="MatchEnd";this.n(V.p.pS);this.f(V.Yu);void 0!==a&&this.f(a)}hm(bo,mm);e=bo.prototype;e.Xp=function(){this.vb=Im.Xp()};
e.or=function(){var a=this;void 0===this.ei&&(this.ei=this.Yn?Nm(this.Yn,this.Ce):this.xp);this.ei=new u({c:this.ei,x:this.Mr,y:this.Nr,width:this.Ce,height:this.Ce});this.g.d(this.ei);this.EB=new F({text:this.av,x:this.Mr,y:this.Nr+125,font:this.bc});this.g.d(this.EB);this.fh&&(this.fh=this.Rq?Nm(this.Rq,this.Ce):this.xp);this.fh=new u({c:this.fh,x:this.Tq,y:this.Uq,width:this.Ce,height:this.Ce});this.g.d(this.fh);this.Sq=new F({text:this.Kz,x:this.Tq,y:this.Uq+125,font:this.bc});this.g.d(this.Sq);
this.KQ=new D({c:this.NQ,x:this.QQ,y:this.RQ,width:this.PQ,height:this.MQ,text:this.OQ,T:this.LQ,j:function(b){a.iH&&a.iH(b);a.home=!0;a.Z()}});this.g.d(this.KQ)};e.Z=function(){Vn.Cb.Z.call(this)};e.i=function(){Vn.Cb.i.call(this)};e.w=function(){Vn.Cb.w.call(this);this.or()};Vn.prototype.wa=function(){};Vn.prototype.pa=function(){};Vn.prototype.I=function(){};function qn(a){this.n();this.nZ;this.width=y(200);this.height=y(200);void 0!==a&&this.f(a);this.zs||(this.zs=new da(0,0))}zl(qn,s);
qn.prototype.setPosition=function(){var a=r.vk+r.em*this.zs.x,b=r.wk+r.Ur*this.zs.y;this.parent?(this.x=this.parent.gf(a,b),this.y=this.parent.hf(a,b)):(this.x=a,this.y=b)};qn.prototype.sd=function(){this.setPosition()};qn.prototype.w=function(){this.setPosition()};var co=null;function eo(){this.depth=0;this.W=1E7;this.visible=!1;this.D=!0;this.mj=-1;this.paused=0;this.r=this.EL;this.hw=void 0;Mb(this)}e=eo.prototype;e.Bu=function(){this.paused+=1};e.Pi=function(){this.paused-=1};
e.Pi=function(){this.paused=0};e.Un=function(a,b,c){var d;wl();d=G.cb("playStart");void 0!==d&&(a=d);d=function(){var a="Level"+V.la.Yf;xl();qk.Un(V.la.bx,V.la.Yf);Rk.hk(a,void 0,"Start");Qk("durationWon",a,"WonDuration");Qk("durationLost",a,"LostDuration");Qk("stageCompleted","Stage1","StageDuration");c&&c.call(Z)};"dialog"!==a?d():(a=V.q.SI?new V.q.SI(b):new Dn(b),a.Ia=d,a.show())};
function fo(a,b,c,d,g,k,l,m,p){var w,z;wl();z=b?G.cb("playWon",c,d,g,k):G.cb("playLost");void 0!==z&&(l=z);b?qk.lt(c,d,g,k):qk.kt();b?(Rk.hk("Level"+V.la.Yf,void 0,"Won"),Rk.hk("Level"+V.la.Yf,void 0,"Score",c),Sk("durationWon"),Tk("durationLost")):(Rk.hk("Level"+V.la.Yf,void 0,"Lost"),Sk("durationLost"),Tk("durationWon"));w=function(){xl();if(p)p.call(Z,a.ws);else{"continue"!==a.ws&&go();switch(a.ws){case "title":a.r=a.Tf;break;case "level":a.r=a.sm;break;case "restart":a.r=a.tm;break;case "next":V.la.Yf<
V.la.LR?(V.la.Yf+=1,a.r=a.tm):a.r=a.QL;break;case "continue":break;default:a.r=a.Tf}go();G.cb("playEnd",!1)}};"dialog"!==l?(a.ws=l,w()):(b=b?V.q.SE?new V.q.SE(m):new En(m):V.q.RE?new V.q.RE(m):new Fn(m),b.j=function(b,c){b.Z();a.ws=c},b.Ia=0>a.mj&&V.q.vI?function(){go();V.q.vI&&(a.NG=V.q.OG?new V.q.OG(V.IC):new tn(V.IC),a.NG.Ia=w,a.NG.show(),a.r=void 0);a.r=void 0}:w,b.show())}e.lt=function(a,b,c,d,g,k,l){fo(this,!0,a,b,c,d,g,k,l)};e.kt=function(a,b,c){fo(this,!1,void 0,void 0,void 0,void 0,a,b,c)};
e.Wh=function(a,b){var c;wl();c=V.q.xt?new V.q.xt(a):new Kn(a);c.Ia=function(){xl();b&&b.call(Z)};c.show()};
e.EL=function(){var a;Jj(V,{OC:{fk:"none",version:"1",Py:"analyticsUserId",bV:!0,nF:"http://api.gameanalytics.com/1/",Ux:void 0,Vx:void 0},Wu:{c:void 0,color:"#ff9900",duration:3},$R:{Zk:null,backgroundImage:void 0,Ai:Hh,vi:Yd,Ww:y(500),Yx:.7,Rg:y(-250),sD:y(700),tD:y(200)},LJ:{vt:{h:Gl,duration:1,u:y(-800),G:y(-320),o:ic,K:1.2},wt:{h:Gl,duration:1,u:y(-320),G:y(-1200),o:hc,K:1.2},backgroundImage:Rh,Ai:Hh,vi:[de],np:[{x:y(-1080),y:y(1450)}],Vw:["http://www.coolgames.com"],SG:!1,Dy:!1,Oh:y(0),Ph:y(240),
Ah:y(0),Rg:y(-320),Cn:void 0,Bn:ti,Mh:Q,Nh:y(688),Lh:y(121,"round"),xq:void 0,LG:"options_header",rl:y(1080),sl:y(1210),pl:bf,ql:y(314),ol:y(121,"round"),MG:vi,EF:!1,GF:!1},rW:{width:y(600),height:y(600),Qs:y(600),Ps:y(590),buttons:[[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}],[{c:[P,Qd]}]]},KJ:{backgroundImage:dh,Zb:!0,eh:["tutorial","oldSound","moregames","about","exit"],cc:{l:T.l,fontSize:65,fillColor:"#942600"},
ce:"options_header",marginTop:y(30),marginLeft:y(220),marginRight:y(170),pz:[of,qf],lz:[pf,rf],Dl:[{x:y(0),y:y(-288)},{x:y(0),y:y(-120)},{x:y(0),y:y(40)},{x:y(0),y:y(200)},{x:y(0),y:y(360)}],Im:y(180),bp:Q,cp:Q.width,ap:Q.height,qz:cf,rz:cf.width,oz:cf.height,mz:cf,nz:cf.width,kz:cf.height,Dw:Q,Ew:Q.width,Cw:Q.height,Zo:Q,$o:Q.width,Yo:Q.height,Ns:Q,Os:Q.width,Ms:Q.height,ND:"Close",KD:!0,MD:Q,OD:Q.width,LD:Q.height,qe:ti,Iu:y(780),Hu:y(250)},Gy:{rl:y(65),sl:y(1515),pl:he,ql:100,ol:92,Ly:5,qD:!1,
HF:!1,Fh:0},wG:{wc:y(400),Zb:!0,Xg:0,NJ:"LevelHeader",marginTop:y(16),fq:"",Mt:y(55)},AT:{width:dh.width,height:dh.height,us:y(-450),rm:dh,ss:"about_header",ts:{l:T.l,fontSize:65,fillColor:"#942600"},zC:{l:Ci.l,fontSize:22,fillColor:"#942600"},Zb:!0,rs:y(70),qs:y(-180),ps:y(400),ns:cf,os:cf.width,ms:cf.height,ls:ti,OJ:y(200)},sH:{width:y(578),height:y(600),Hc:18,QF:30,Lb:40,je:10,backgroundImage:Ih},hO:{backgroundImage:"undefined"!==typeof s_completion_background?s_completion_background:null,Xw:"undefined"!==
typeof s_completion_congratulation?s_completion_congratulation:null,vE:"undefined"!==typeof f_completion_congratulation?f_completion_congratulation:Xh,yE:"undefined"!==typeof s_completion_continue?s_completion_continue:P,xE:"undefined"!==typeof f_completion_continue?f_completion_continue:S},Yu:{width:y(780),height:y(300)},pP:{backgroundImage:"undefined"!==typeof s_overlay_win?s_overlay_win:void 0,Ll:["stars","score","highscore"],marginTop:y(16),marginLeft:y(450),marginRight:y(460),Zb:!0,wc:y(400),
Eu:"EndScore",Nu:"HighScore",Qw:"level",hz:"level",bv:"LevelHeader",se:!0,te:!0},oP:{backgroundImage:"undefined"!==typeof s_overlay_fail?s_overlay_fail:void 0,Ll:["score","highscore"],marginTop:y(16),marginLeft:y(450),marginRight:y(460),Zb:!0,wc:y(400),Qw:"level",bv:"LevelHeader",ce:"LevelFailedHeader",se:!1,te:!1,Dt:!0,nt:y(-145),mt:""},g0:{width:y(500),height:y(300)},iQ:{},rF:{backgroundImage:Kh,Zb:!0,eh:["exit","oldSound","moregames","about"],JD:"optionsStartScreen",marginTop:y(16),marginLeft:y(170),
marginRight:y(175),qe:ti,Iu:y(780),Hu:y(250)},TF:{backgroundImage:dh,Zb:!0,eh:["resume","tutorial","oldSound","moregames","close"],marginTop:y(30),marginLeft:y(220),marginRight:y(170),DF:!0,ED:"optionsQuit",cc:{l:T.l,fontSize:65,fillColor:"#942600"},ce:"options_header",mA:"title",pz:[of,qf],lz:[pf,rf],Dl:[{x:y(0),y:y(-288)},{x:y(0),y:y(-120)},{x:y(0),y:y(40)},{x:y(0),y:y(200)},{x:y(0),y:y(360)}],Im:y(180),UD:Q,VD:Q.width,TD:Q.height,bp:Q,cp:Q.width,ap:Q.height,qz:cf,rz:cf.width,oz:cf.height,mz:cf,
nz:cf.width,kz:cf.height,Dw:Q,Ew:Q.width,Cw:Q.height,Zo:Q,$o:Q.width,Yo:Q.height,GD:Q,HD:Q.width,FD:Q.height,UH:Q,VH:Q.width,TH:Q.height,QH:Q,RH:Q.width,PH:Q.height,SH:y(255),qe:ti,Iu:y(780),Hu:y(250)},kW:{fk:"none",mj:1},lW:{},GC:{Ja:"none",Zk:Zd,Um:!0},IC:{Ja:"none",Um:!0},q:{Ql:Gn,Hi:void 0,tn:Sn,n_:$m,vd:cn,Sj:Tn,SI:gm.ZK,h0:gm.ZK,JG:Vn,SE:En,RE:Fn,f0:void 0,xt:ho,pe:Pn,jg:Pn,UE:gm.$K,xI:!0,nV:!0,lV:!1,mV:!1,eV:!1,li:un,OG:tn,gd:Mn,k0:Pn,uk:Nn,$U:!1,vI:!1,qV:!0,kV:!0,yI:!0,ZU:!0,QA:!0,MJ:yj,fV:!0,
iV:!0,Lk:void 0,aV:!0,gO:"title",Zt:["load","images","audio","fonts"],$t:["load","images","audio"],XR:.5,WR:2},Rm:{VY:!1},TE:{},za:{},AF:{O:y(2160),M:y(1620),Sh:y(0),Th:y(0),De:y(2160),ng:y(1620)},Xc:{},ct:{DE:[Y],kl:{pZ:"en-us",ow:["en-us"]}},la:{}});co=new io;new jo;G.n();void 0!==V.ia.PC&&(V.Rm.VF=V.ia.PC);void 0!==V.ia.Xm&&(V.ct.Xm=V.ia.Xm);void 0!==V.ia.Hb&&(V.ct.kl=V.ia.Hb);void 0!==V.ia.JI&&(V.Wu.c=V.ia.JI);void 0!==V.ia.HI&&(V.Wu.color=V.ia.HI);void 0!==V.ia.II&&(V.Wu.duration=V.ia.II,V.q.xI=
!0);a=G.cb("getSiteLocks");void 0===a?this.r=void 0:Qj(a)?(a=G.cb("getTimeLock"),void 0===a&&(void 0===a||(new Date).getTime()<=a)?(V.la.GE&&(document.title=V.la.GE),G.cb("beforeInitializing"),this.r=this.NL):this.r=void 0):this.r=void 0};e.NL=function(){il.n(V.Rm);ak("black");xm.n(V.kW);Im.n(V.lW);this.r=this.YL};e.YL=function(){il.Ye&&(this.canvas=r.k,this.visible=!0,G.cb("afterInitializing"),this.r=this.VL)};
e.VL=function(){var a=this;V.q.xI?(this.Ql=V.q.Ql?new V.q.Ql:new Gn,this.Ql.Ia=function(){a.r=a.KL},this.Ql.show(),this.r=void 0):this.r=this.EC};e.KL=function(){this.Ql.gg();this.Ql=void 0;this.r=this.EC};e.EC=function(){var a=this;Mj({Li:V.q.Zt,required:V.q.$t,ah:V.q.XR,Gf:V.q.WR});V.q.nV?(this.Hi=V.q.Hi?new V.q.Hi:new Hn,this.Hi.Hn=Oj,this.Hi.Ia=function(){a.Hi=void 0},this.Hi.show()):this.Hi=void 0;this.r=this.ZL};
e.ZL=function(){G.cb("loadingProgress",Oj());Nj()&&!this.Hi&&(G.cb("afterLoading"),this.r=this.DL)};e.DL=function(){var a;ck(r);V.q.MJ&&(a=U.play(V.q.MJ),U.lk(a,!0));this.r=this.XL};e.XL=function(){var a=this;V.q.$U?(this.li=V.q.li?new V.q.li(V.GC):new un(V.GC),this.li.Ia=function(){a.r=a.FL},this.li.show(),this.r=void 0):this.r=this.RL};e.FL=function(){this.li.gg();this.li=void 0;this.r=this.Tf};
e.RL=function(){var a=this;V.q.eV?(this.au=V.q.UE?new V.q.UE:new gm.$K,this.au.Ia=function(){a.r=a.HL},this.au.show(),this.r=void 0):this.r=this.Tf};e.HL=function(){this.au.gg();this.au=void 0;this.r=this.Tf};
e.Tf=function(){var a=this;V.q.qV?(G.cb("beforeTitleScreen"),this.gd=V.q.gd?new V.q.gd:new In,this.gd.Ia=function(){a.r=a.DC},this.gd.wz=function(){a.r=a.TL},this.gd.Yd=function(b){a.Fo=b},this.gd.Az=function(){a.Fo="multiplay";a.r=a.OL},this.gd.qn=function(){a.r=a.WL},this.gd.xl=function(b){a.hw="title";a.Fo=b;a.gd.i()},this.gd.show(),this.r=void 0):this.r=this.sm};
e.DC=function(){this.gd.gg();this.gd=void 0;"multiplay"===this.Fo?(this.r=void 0,co.UV()):"play"===this.Fo?this.r=this.sm:"gallery"===this.Fo&&(this.r=this.SL)};e.SL=function(){var a=this;this.ut=new ko;this.ut.Ia=function(){a.r=a.IL};this.ut.show();this.r=void 0};e.IL=function(){this.ut.I();this.ut=void 0;this.r="title"===this.hw?this.Tf:void 0;this.hw=void 0};
e.OL=function(){var a=this;this.ml=V.q.JG?new V.q.JG(V.sS):new Vn(V.sS);this.ml.yz=function(b){co.UV(b);a.r=a.DC;a.ml.I();a.ml.PW};this.ml.Ia=function(b){b.YD?(a.gd.ka(),a.ml.I(),a.ml.PW):co.oZ()};this.ml.show();this.r=void 0};e.TL=function(){var a=this;V.q.kV&&(this.uk=V.q.uk?new V.q.uk:new tgfDialog.FX,this.uk.j=function(b,c){a.uk.Kk(c)},this.uk.Ia=function(){a.gd.ka();a.uk=void 0;a.r=void 0;a.r=void 0},this.gd.ga(),this.uk.show(),this.r=void 0)};
e.WL=function(){var a=this;V.q.yI&&(this.de=V.q.de?new V.q.de(V.KJ):new Pn(V.KJ),this.de.bk=function(){a.r=a.bw},this.de.Ia=function(){a.r=a.LL},this.de.mn=function(){a.r=a.PL},this.gd.ga(),this.de.show(),this.r=void 0)};e.LL=function(){this.de.gg();this.de=void 0;void 0!==this.tn&&(this.r=this.AC);this.gd.ka();this.r=void 0};
function lo(a,b){var c;V.q.fV&&(c=G.cb("getMoreGamesFunction"),a.pe=V.q.pe?new V.q.pe(V.rF):new Pn(V.rF),c&&(a.pe.rn=c),a.pe.bk=function(){a.r=a.bw},a.pe.Ia=function(){a.r=a.BC},a.pe.uz=function(b){b.Ra.i();a.BC();a.r=a.Tf},a.pe.Ra=b,void 0!==a.vd&&a.vd.ga(),a.pe.show(),a.r=void 0)}e.BC=function(){this.pe.gg();this.pe=void 0;void 0!==this.vd&&this.vd.ka();this.r=void 0};
e.bw=function(){var a=this;V.q.QA&&(this.iv=V.q.xt?new V.q.xt(V.sH):new $m(V.sH),this.iv.Ia=function(){a.r=a.ML},this.de&&this.de.ga(),this.iv.show(),this.r=void 0)};e.ML=function(){this.iv.gg();this.iv=void 0;this.de?this.de.ka():this.jg&&(this.jg.ka(),this.jg.Uh.i());this.r=void 0};e.PL=function(){var a=this;V.q.ZU&&(this.tn=V.q.tn?new V.q.tn:new Sn,this.tn.Ia=function(){a.r=a.AC},void 0!==this.de?this.de.ga():void 0!==this.pe&&this.pe.ga(),this.tn.show(),this.r=void 0)};
e.AC=function(){void 0!==this.de?this.de.ka():void 0!==this.pe&&this.pe.ka();this.r=void 0};e.sm=function(){var a=this;V.q.lV?(G.cb("beforeLevelScreen"),this.vd=V.q.vd?new V.q.vd:new gm.HX,this.vd.Ia=function(){a.r=a.CC},this.vd.j=function(b,c){V.wG.Xg=c;a.r=a.UL},this.vd.Bz=function(){a.r=lo(a,a.vd)},this.vd.show(),this.r=void 0):(V.la.Yf=1,this.r=this.tm)};e.CC=function(){this.vd=void 0};
e.UL=function(a){var b=this;V.q.mV?(this.Sj=V.q.Sj?new V.q.Sj:new tgfDialog.GX,this.Sj.Ia=function(){b.r=b.JL},this.Sj.Yd=function(a,d){V.la.Yf=d;b.r=b.tm},this.Sj.show(),this.vd.ga(),this.r=void 0):(V.la.Yf=a,this.r=this.tm)};e.JL=function(){this.vd.ka();this.Sj.gg();this.r=this.Sj=void 0};
function mo(){var a=vl,b="";V.q.iV&&(a.jg=V.q.jg?new V.q.jg(V.TF):new Pn(V.TF),a.jg.Ia=function(){switch(b){case "title":a.r=a.Tf;break;case "level":a.r=a.sm;break;default:Vb(Z.A),xl()}this.jg=void 0},a.jg.xu=function(){Qb(Z.A);wl()},a.jg.bk=function(b){b.ga();a.r=a.bw},a.jg.Mq=function(a,d){b=d;go()},a.jg.show(),a.r=void 0)}e.tm=function(){co.Un();void 0!==this.vd&&(this.vd.i(),this.r=this.CC);this.r=void 0};
e.QL=function(){var a=this;V.q.aV?(this.Lk=V.q.Lk?new V.q.Lk:new Ln,this.Lk.Ia=function(){a.r=a.GL},this.Lk.show(),this.r=void 0):this.r=this.Tf};e.GL=function(){this.Lk.gg();this.Lk=void 0;switch(V.q.gO){case "title":this.r=this.Tf;break;case "level":this.r=this.sm;break;case "restart":V.la.Yf=1;this.r=this.tm;break;default:this.r=this.Tf}};e.Ga=function(a){0<this.paused||(this.r&&this.r(a),-1<this.mj&&(this.mj-=a))};
e.Ha=function(){var a=r,b;for(b=0;b<a.hc.length;b+=1)if(!a.hc[b].hp){var c=a.hc[b],d=c.getContext("2d");d.clearRect(0,0,c.width,c.height);d.beginPath();d.moveTo(0,0);d.lineTo(-1,-1);d.closePath();d.stroke()}};var vl=new eo;
V.J.OW={backgroundImage:"undefined"!==typeof Ge?Ge:void 0,Qp:"undefined"!==typeof He?He:void 0,Vk:function(a,b,c,d){return b+c*(1+-1*(1-Math.cos((d-a)/d*Math.PI/2)))},Bp:.5,jV:!0,fU:"#00AEEF",cR:"#BBDDFF",VM:!0,UM:9999999,AD:.5,TM:"#FFED93",yr:"undefined"!==typeof Ie?Ie:void 0,QV:"undefined"!==typeof Je?Je:void 0,MI:"undefined"!==typeof a_ui_star_empty?a_ui_star_empty:void 0,NI:"undefined"!==typeof a_ui_star_filled?a_ui_star_filled:void 0,KI:"undefined"!==typeof s_ui_star_animation_filled?s_ui_star_animation_filled:
void 0,LI:"undefined"!==typeof s_ui_star_animation_filled?s_ui_star_animation_filled:void 0,OV:10,MV:!0,NV:!0,OI:[20,50,90],Xu:void 0,dP:!0,BM:!0,nR:!0,Zm:"",Ay:"",Cy:0,Mt:y(80),fG:y(80),cG:y(64),By:R,pR:void 0,wu:void 0,vu:void 0,pH:void 0,oH:void 0,e:[]};function no(a){this.name="UiProgressRound";this.n(V.J.OW);void 0!==a&&this.f(a)}zl(no,s);e=no.prototype;
e.pg=function(a,b){var c=a,d=this.Bb;0>c&&(c=0);100<c&&(c=100);this.Fl=this.Ni;this.Ni=c;this.er=0;if(b||void 0===this.Vk)this.Fl=this.Ni;this.Bb=this.Fl;100===this.Bb&&100!==d&&this.wu&&this.wu(this);0===this.Bb&&0!==d&&this.vu&&this.vu(this)};e.tF=function(){return this.Ni};
e.w=function(){var a;this.width=this.Qp.width;this.height=this.Qp.height;this.nR&&(this.Bc=new F({x:this.Cy,y:this.Mt,width:this.fG,height:this.cG,text:this.Zm,s:this.Ay,font:this.By,Sd:!0,align:"center",ua:"middle"}),this.Bc.f(this.pR),this.d(this.Bc));if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.Bc=void 0};
e.da=function(){this.er=this.Bb=this.Ni=this.Fl=0;var a;this.lb=[];for(a=0;a<this.OI.length;a+=1)this.lb.push({vn:this.OI[a],filled:!1,he:!1,ab:void 0,Hg:0,Gk:0});this.To=0;this.Cm=!1;this.Is=0};
e.$c=function(a){var b=this.Bb;this.er+=a/1E3;this.er>=this.Bp?this.Bb=this.Fl=this.Ni:void 0!==this.Vk&&this.Bb!==this.Ni&&(this.Bb=this.Vk(this.er,this.Fl,this.Ni-this.Fl,this.Bp),this.Bb=Math.max(0,Math.min(100,this.Bb)),100===this.Bb&&100!==b&&this.wu&&this.wu(this),0===this.Bb&&0!==b&&this.vu&&this.vu(this));var b=a/1E3,c,d;for(c=0;c<this.lb.length;c+=1)if(d=this.lb[c],d.he&&(d.Hg+=b,d.Gk=Math.floor(d.Hg*this.OV),d.Gk>=d.ab.N&&(d.he=!1,d.ab=void 0,d.cg=d.filled)),this.BM)if(d.vn>this.Bb){d=c;
var g=void 0;0>d||d>=this.lb.length||(g=this.lb[d],g.filled&&(g.filled=!1,g.cg=!1,void 0!==this.KI&&(g.he=!0,g.ab=this.KI,g.Hg=0,this.MV&&(g.cg=!0)),this.MI&&U.play(this.MI),this.oH&&this.oH(this,d+1)))}else d=c,g=void 0,0>d||d>=this.lb.length||(g=this.lb[d],g.filled||(g.filled=!0,g.cg=!0,void 0!==this.LI&&(g.he=!0,g.ab=this.LI,g.Hg=0,this.NV&&(g.cg=!1)),this.NI&&U.play(this.NI),this.pH&&this.pH(this,d+1)));!this.Cm&&100<=this.Bb&&(this.Cm=!0);this.Cm&&100>this.Bb&&(this.Cm=!1,this.To=0);this.Cm&&
(this.Is+=a/1E3,this.Is>=this.UM?this.To=0:(a=this.Is%this.AD/this.AD+.5,this.To=(Math.cos(a*Math.PI*2)+1)/2))};e.yk=function(a,b,c,d){a&&(a instanceof za?a.B(c,d):a.B(b,c,d))};
e.jc=function(){var a=f.context,b=this.Qp.width/2-y(4),c=Math.PI,d,g,k,l;a.save();this.yk(this.backgroundImage,0,0,0);this.jV&&this.Bb<this.Ni&&(a.beginPath(),a.arc(0,0,b,-.5*c+2*c*this.Bb/100,-.5*c+2*c*this.Ni/100,!1),a.lineTo(0,0),a.fillStyle=this.cR,a.fill());a.beginPath();a.arc(0,0,b,-.5*c,-.5*c+2*c*this.Bb/100,!1);a.lineTo(0,0);a.fillStyle=this.fU;a.fill();this.VM&&this.Cm&&0<this.To&&(d=a.globalAlpha,a.globalAlpha*=this.To,a.beginPath(),a.arc(0,0,b,-.5*c,-.5*c+2*c*this.Bb/100,!1),a.lineTo(0,
0),a.fillStyle=this.TM,a.fill(),a.globalAlpha=d);if(this.dP)for(a.strokeStyle="white",a.lineWidth=y(2),d=0;d<this.lb.length;d+=1)g=-.5*c+this.lb[d].vn/100*c*2,a.beginPath(),a.moveTo(0,0),a.lineTo(Math.round(Math.cos(g)*b),Math.round(Math.sin(g)*b)),a.stroke();this.yk(this.Qp,0,0,0);for(d=0;d<this.lb.length;d+=1)k=this.lb[d].cg?this.QV:this.yr,g=-.5*c+this.lb[d].vn/100*c*2,l=void 0!==this.Xu?this.Xu:.65*b,this.yk(k,0,Math.round(Math.cos(g)*l),Math.round(Math.sin(g)*l));a.restore()};
e.ag=function(){var a=this.Qp.width/2-y(4),b=Math.PI,c,d,g,k;for(c=0;c<this.lb.length;c+=1)k=this.lb[c],k.he&&(d=-.5*b+k.vn/100*b*2,g=void 0!==this.Xu?this.Xu:.65*a,this.yk(k.ab,k.Gk,Math.round(Math.cos(d)*g),Math.round(Math.sin(d)*g)))};
V.J.Rf={backgroundImage:void 0,sb:void 0,width:y(100),height:y(80),margin:y(8),xa:void 0,Ve:0,We:y(-16),td:void 0,Qc:"",ln:"",yd:0,zd:y(-16),bc:R,gz:void 0,valueType:"number",ec:0,Wb:0,Ob:y(16),Db:R,$W:void 0,md:",",Po:1,ni:0,qM:!1,Vk:$b,Bp:1,lx:.1,gP:0,Gi:!1,wy:!1,NC:!1,ys:!1,CL:!1,qP:0,Pq:void 0,Cl:void 0,e:[]};function oo(a){this.name="UiValue";this.n(V.J.Rf);void 0!==a&&this.f(a)}zl(oo,s);e=oo.prototype;e.Ta=function(a,b){this.qm(a,b)};e.Md=function(a,b){this.qm(this.ea()+a,b)};e.ea=function(){return this.oh};
e.Hv=function(){this.value=this.oh=this.fi=this.ec;this.bm=0;this.QB=!1;po(this)};e.qm=function(a,b){(" number"===this.valueType||"time"===this.valueType)&&0>a&&!this.qM&&(a=0);if(this.oh!==a){this.fi=this.value;this.oh=a;this.bm=0;if(b||void 0===this.Vk||"number"!==this.valueType&&"time"!==this.valueType||Math.abs(a-this.fi)<=this.gP)this.fi=this.oh;po(this)}};
function po(a){var b=a.Ma.text,c=Math.round(a.value),d,g;switch(a.valueType){case "number":d=c.toString();a.Ma.text="";for(g=0;g<d.length;g+=1)0===(d.length-g)%3&&0!==g&&(a.Ma.text+=a.md),a.Ma.text+=d.charAt(g);a.Gi&&(a.My.text=a.wy?a.xd.text+" "+a.Ma.text:a.Ma.text+" "+a.xd.text,a.My.Xa());break;case "time":d=c;a.Ma.text="";3600<=c?(a.Ma.text+=Math.floor(d/3600).toString()+a.md,d%=3600):a.NC&&a.ys&&(a.Ma.text+="0"+a.md);600<=c?(a.Ma.text+=Math.floor(d/600).toString(),d%=600):a.NC&&a.ys&&(a.Ma.text+=
"0");60<=c?(a.Ma.text+=Math.floor(d/60).toString()+a.md,d%=60):a.ys&&(a.Ma.text+="0"+a.md);10<=c?(a.Ma.text+=Math.floor(d/10).toString(),d%=10):a.ys&&(a.Ma.text+="0");a.Ma.text+=d.toString();break;default:a.Ma.text=c}b!==a.Ma.text&&(a.Ma.Xa(),a.Pq&&a.Pq(a,c))}e.Fv=function(){this.Ig=0;this.nw=!0};e.Pv=function(a){this.nw&&0!==this.ni&&(this.Ig+=a,this.Ig>this.Po&&(this.Md(this.ni),this.Ig-=this.Po))};
e.w=function(){var a;!this.width&&this.backgroundImage&&(this.width=this.backgroundImage.width);!this.height&&this.backgroundImage&&(this.height=this.backgroundImage.height);this.backgroundImage&&(this.Uf=new u({x:0,y:0,width:this.width,height:this.height,c:this.backgroundImage,tb:!0}),this.Uf.f(this.sb),this.d(this.Uf));this.xa&&(this.hl=new u({x:this.Ve,y:this.We,c:this.xa}),this.hl.f(this.td),this.d(this.hl));a="";a=this.wy?this.name+" "+this.value:this.value+" "+this.name;this.My=new F({x:this.Wb,
y:this.Ob,width:this.width-2*this.margin,height:this.height/2,text:a,s:this.ln,font:this.Db,Sd:!0});this.Gi&&this.d(this.My);if(""!==this.Qc||""!==this.ln)this.xd=new F({x:this.yd,y:this.zd,width:this.width-2*this.margin,height:this.height/2,text:this.Qc,s:this.ln,font:this.bc,Sd:!0,align:"center",ua:"middle"}),this.xd.f(this.gz),this.Gi||this.d(this.xd);this.Ma=new F({x:this.Wb,y:this.Ob,width:this.width-2*this.margin,height:this.height/2,text:"",s:"",font:this.Db,Sd:!0,align:"center",ua:"middle"});
this.Ma.f(this.$W);this.Gi||this.d(this.Ma);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.xd=this.Ma=this.hl=this.Uf=void 0};e.da=function(){this.Hv();this.Fv()};
e.$c=function(a){a:{var b=this.value,c=this.bm;if("number"===this.valueType||"time"===this.valueType){this.bm+=a/1E3;if(this.bm>=this.Bp)this.value=this.fi=this.oh;else{if(Math.floor(0!==this.lx&&this.bm/this.lx)===Math.floor(c/this.lx)||void 0===this.Vk||this.value===this.oh)break a;this.value=this.Vk(this.bm,this.fi,this.oh-this.fi,this.Bp)}Math.round(this.value)!==Math.round(b)&&po(this)}}this.Pv(a/1E3);this.CL&&(a=Math.max(0,Math.ceil((this.qP-q.Ef)/1E3)),this.fi=this.value,this.value=this.oh=
a,po(this));this.QB||this.fi!==this.oh?this.fi!==this.oh&&(this.QB=!1):(this.Cl&&this.Cl(this,this.oh),this.QB=!0)};
V.J.KW={backgroundImage:void 0,sb:void 0,width:y(100),height:y(80),margin:y(8),xa:void 0,Ve:0,We:y(-16),td:void 0,Qc:"",ln:"",yd:0,zd:y(-16),bc:R,gz:void 0,cV:!0,YW:"undefined"!==typeof s_ui_value_empty?s_ui_value_empty:void 0,ZW:"undefined"!==typeof s_ui_value_filled?s_ui_value_filled:void 0,$J:void 0,aK:void 0,YJ:void 0,ZJ:void 0,WW:30,s0:!1,t0:!1,RB:3,ec:0,Wb:0,Ob:y(16),VW:"center",XW:"middle",nv:y(32),ov:y(0),Po:1,ni:0,Pq:void 0,e:[]};
function qo(a){this.name="UiImageValue";this.n(V.J.KW);void 0!==a&&this.f(a)}zl(qo,s);e=qo.prototype;e.Ta=function(a){this.qm(a)};e.Md=function(a){this.qm(this.ea()+a)};e.ea=function(){return this.value};
e.Hv=function(){var a,b,c,d,g,k,l,m;this.images=[];for(a=0;a<this.RB;a+=1)this.images.push({filled:!1,he:!1,ab:void 0,Hg:0,Gk:0});l=g=1E6;d=k=-1E6;for(a=c=b=0;a<this.images.length;a+=1)m=this.images[a],m.fe=b,m.Ld=c,g=Math.min(g,b),k=Math.max(k,b),l=Math.min(l,c),d=Math.max(d,c),b+=this.nv[a%this.nv.length],c+=this.ov[a%this.ov.length];b=k-g;d-=l;for(a=0;a<this.images.length;a+=1){m=this.images[a];switch(this.VW){case "left":m.fe+=this.Wb-g;break;case "right":m.fe+=this.Wb-g-b;break;default:m.fe+=
this.Wb-g-Math.round(b/2)}switch(this.XW){case "top":m.Ld+=this.Ob-l;break;case "bottom":m.Ld+=this.Ob-l-d;break;default:m.Ld+=this.Ob-l-Math.round(d/2)}}this.qm(this.ec)};
e.qm=function(a){var b,c=this.value;0>a&&(a=0);a>this.RB&&(a=this.RB);this.value=a;for(a=0;a<this.images.length;a+=1)b=this.images[a],a+1<=this.value?b.filled||(b.filled=!0,b.cg=!0,void 0!==this.ZJ&&(b.ab=this.ZJ,b.he=!0,b.Hg=0,this.iZ&&(b.cg=!1)),this.aK&&U.play(this.aK)):b.filled&&(b.filled=!1,b.cg=!1,void 0!==this.YJ&&(b.ab=this.YJ,b.he=!0,b.Hg=0,this.hZ&&(b.cg=!0)),this.$J&&U.play(this.$J));this.value!==c&&this.Pq&&this.Pq(this,this.value)};e.Fv=function(){this.Ig=0;this.nw=!0};
e.Pv=function(a){this.nw&&0!==this.ni&&(this.Ig+=a,this.Ig>this.Po&&(this.Md(this.ni),this.Ig-=this.Po))};
e.w=function(){var a;!this.width&&this.backgroundImage&&(this.width=this.backgroundImage.width);!this.height&&this.backgroundImage&&(this.height=this.backgroundImage.height);this.nv=[].concat(this.nv);this.ov=[].concat(this.ov);this.backgroundImage&&(this.Uf=new u({x:0,y:0,width:this.width,height:this.height,c:this.backgroundImage,tb:!0}),this.Uf.f(this.sb),this.d(this.Uf));this.xa&&(this.hl=new u({x:this.Ve,y:this.We,c:this.xa}),this.hl.f(this.td),this.d(this.hl));if(""!==this.Qc||""!==this.ln)this.xd=
new F({x:this.yd,y:this.zd,width:this.width-2*this.margin,height:this.height/2,text:this.Qc,s:this.ln,font:this.bc,Sd:!0,align:"center",ua:"middle"}),this.xd.f(this.gz),this.d(this.xd);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.xd=this.hl=this.Uf=void 0};e.da=function(){this.Hv();this.Fv()};
e.$c=function(a){this.Pv(a/1E3);a/=1E3;var b,c;for(b=0;b<this.images.length;b+=1)c=this.images[b],c.he&&(c.Hg+=a,c.Gk=Math.floor(c.Hg*this.WW),c.Gk>=c.ab.N&&(c.he=!1,c.ab=void 0,c.cg=c.filled))};e.yk=function(a,b,c,d){a&&(a instanceof za?a.B(c,d):a.B(b,c,d))};e.ag=function(){var a,b,c;for(a=0;a<this.images.length;a+=1)if(b=this.images[a],b.cg||this.cV)c=b.cg?this.ZW:this.YW,this.yk(c,a,b.fe,b.Ld);for(a=0;a<this.images.length;a+=1)b=this.images[a],b.he&&void 0!==b.ab&&this.yk(b.ab,b.Gk,b.fe,b.Ld)};
V.p.JW={W:-900,x:void 0,y:void 0,width:void 0,height:void 0,backgroundImage:"undefined"!==typeof Fe?Fe:void 0,mD:!1,CM:"left",DM:"middle",GM:!1,du:y(32),EG:y(32),Pa:{h:Hl,duration:.5,qc:0,o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},e:[],sb:null,Yl:null};function ro(a){this.name="UiEmpty";this.n(V.p.JW);this.f(V.p0);void 0!==a&&this.f(a)}hm(ro,yc);e=ro.prototype;e.Z=function(){this.ga();X(this.g,2)};
function so(a,b,c){b=new b(c);a.g?(a.g.d(b),a.g.eb&&b.show(),a.g.C&&b.ka()):a.e.push(b);return b}
e.iC=function(){var a,b,c,d;if(this.mD){this.GM?(a=r.vk,b=r.vk+r.em,c=r.wk,d=r.wk+r.Ur):(a=r.Sh,b=r.Sh+r.De,c=r.Th,d=r.Th+r.ng);switch(this.CM){case "left":a=a+Math.round(this.width/2)+this.du;break;case "right":a=b-Math.round(this.width/2)-this.du;break;case "center":a=Math.round((a+b)/2);break;default:a=a+Math.round(this.width/2)+this.du}switch(this.DM){case "top":c=c+Math.round(this.height/2)+this.EG;break;case "bottom":c=d-Math.round(this.height/2)-this.EG;break;case "middle":c=Math.round((c+
d)/2);break;default:a=c=Math.round((c+d)/2)}if(this.x!==a||this.y!==c)this.x=a,this.y=c}};
e.w=function(){var a=this,b;if(void 0===this.width||0===this.width)this.width=void 0===this.backgroundImage?0:this.backgroundImage.width;if(void 0===this.height||0===this.height)this.height=void 0===this.backgroundImage?0:this.backgroundImage.height;void 0===this.x&&(this.x=r.Sh+Math.round(this.width/2)+this.du);void 0===this.y&&(this.y=r.Th+Math.round(r.ng/2));this.g=new u({c:this.backgroundImage,tb:!0,width:this.width,height:this.height,S:[this.Pa,{h:"show",duration:9999999},this.sa],yb:function(){a.i()}});
this.g.f(this.sb);this.d(this.g);this.mD&&(this.La=new $l({jt:!0,interval:.05,repeat:999999999,$j:function(){ro.prototype.iC.call(a)}}),this.La.f(this.Yl),this.d(this.La));for(b=0;b<this.e.length;b+=1)this.g.d(this.e[b])};e.I=function(){this.ya();this.La=this.g=void 0};e.da=function(){this.iC()};var Z=null;
function io(){Jj(V,{la:{name:"<UNKNOWN>",id:"<UNKNOWN>",version:"1.0",GE:"SlotMachine",dZ:!1,NZ:[0,1,2],OZ:["Easy","Medium","Difficult"],cZ:!0,FZ:!1,LR:9,x0:[9],y0:["World1"],fZ:!0,T_:"numberUp",R_:!0,S_:!1,m0:[],eP:null},q:{},za:{Ux:"",Vx:""}})}io.prototype.Un=function(){Z=new to;Mb(Z);Ob(Z,["play"])};function go(){Xb(q,Z)}function wl(){Ub("play")}function xl(){Wb("play")}
function to(){this.W=this.depth=0;this.D=this.visible=!0;this.jF=y(5);this.kF=y(447);this.mX=y(4);this.kX=y(175);this.vm=!1;this.ca=null;this.ma=new uo;this.Kb=1;this.mode=V.la.bx;Lk(qk,this.mode,this.Kb+1);this.UT=jn();this.Iy=this.UT.af[this.Kb-1];this.Rn=new vo(this);this.$d=[L.ed,L.ed,L.ed,L.ed,Ke,L.ed,L.ed,L.ed,L.ed,Le,Me,Ne];this.BW=4;this.bd=wo;this.dk=wo.winlines;this.ye=this.dk.length;this.QG=50;this.Fs=wo.fixedLines;this.pw=wo.fixedBet;this.IB=this.hu=this.xD=this.bf=0;this.bX=wo.reels.visibility;
this.ih=4;this.Vc=8;this.mg=1;this.jG=this.kG=this.HH=this.Fn=this.FH=this.GH=0;this.Zy=wo.minMaxBet;this.$y=wo.minMaxLine;this.tj=this.YF=this.XF=this.WF=this.ie=this.Ty=this.IS=0;this.nf=this.Iy.Bh.kp;this.of=this.Iy.Bh.lp;this.pf=this.Iy.Bh.mp;this.Mg=[];this.zm=0;this.pr=this.$x=this.Ft=!1;this.nd=-1;this.Tp=0;this.$s=[0,0,0,0];this.Ln=void 0;this.hB=-1;this.Tn=this.ex=this.Dd=0;this.jd=!1;this.IW=this.bd.tutotialSpins;this.kB=this.Wh=this.io=!1;this.Ud=0;this.yy=r.O>r.M;this.Cc=y(0);this.yy&&
(this.Cc=r.O/2-Pg.width/2);this.Y=new kc(this);this.xr=new kc(this);this.ym=Zj(r,r.k,{wf:0,xf:0,uh:r.O,th:r.M});this.Tm=Zj(r,r.k,{wf:this.Cc+this.jF,xf:this.kF,uh:y(1070),th:y(950)});this.Mw=ik();this.Ac=this.Mw[3];this.sg=void 0;this.Eb=0;this.Uu=void 0;this.WO=!1;this.Je={$r:0,$B:1,Zr:2,Wr:3};this.EI=1;this.za=new xo}e=to.prototype;
e.Za=function(){G.Rz();Hj();pa(f,r.sh);wa(Rh,0,0);this.border=new yo(this.Cc,435);this.vU=new zo(0,460);this.F=new Ao;this.ca=this.ma.db;this.mg=this.ca.player.curLevel;this.GH=this.ca.player.unlockedLines;this.FH=this.ca.player.unlockedBet;this.Fn=this.ca.player.curCoins;this.HH=this.ca.player.curScore;this.bf=this.ca.player.lastLines;this.xD=this.ca.player.lastBet;this.kG=this.ca.player.lastProgressPercentage;this.jG=this.ca.player.lastProgressAmount;this.WF=this.ca.levels[this.Kb].objective.col1;
this.XF=this.ca.levels[this.Kb].objective.col2;this.YF=this.ca.levels[this.Kb].objective.col3;var a=this.tj=this.ca.player.collectableLevel;a>this.bd.collectables.length-1&&(a=this.bd.collectables.length-1);this.nf=this.bd.collectables[a][0];this.of=this.bd.collectables[a][1];this.pf=this.bd.collectables[a][2];this.Rn.jl();this.KA();this.Ud=this.bd.startTarget;for(a=1;a<this.mg;a++)this.Ud*=2;this.or();this.sg=new Bo(y(538),y(1542),y(538),y(1342),this.fj);this.Uu=new Bo(y(538),y(1542),y(538),y(1342),
this.NW);this.zh=new Bo(y(538),y(1542),y(538),y(1342),this.kv);this.wD=new Bo(y(882),y(1570),y(882),y(1450),this.LW);this.zG=new Bo(y(200),y(1570),y(200),y(1450),this.MW);this.yf();Co(this);a=this.jF+y(40);this.ba=[];for(var b=0;b<this.BW;b++){var c=new Do(a,this.kF+this.kX,this.Tm,b,this),a=a+(y(242)+this.mX);this.ba.push(c)}this.Mw=ik();this.Ac=this.Mw[3];this.ca.levels[this.Kb].showIntroDialog?(this.jd=!0,this.ma.db.levels[this.Kb].showIntroDialog=!1,this.ma.save()):(this.io=!0,this.kh());a:{a=
this.F;a.od(Z.Au);a.od(Z.Sm);a.od(Z.lq);a.od(Z.kq);a.od(Z.$q);a.od(Z.Dq);a.od(Z.Sc);a.od(Z.jv);for(b=0;11>b;b++)if(!1===Z.ca.player.tutorialStates[b]){a.state=b;a.Zs=a.ho[a.state].tg;a.Qe=a.ho[a.state].og;a.um=a.ho[a.state].za;break a}-1===a.state&&Xb(q,a)}this.F&&(this.F.Vu=this.ca.player.tutorialSpins,Eo(this.F.Ag.xv)?this.F.fb(this.F.Ag.xv):this.$x||this.F.fb(this.F.Ag.eL))};
e.KA=function(){this.ye=this.Fs[this.bf];this.QG=this.Fs[0];this.oi=this.xD;this.Ty=this.Zy[this.FH].maxBet;this.hu=this.$y[this.GH].maxLine;this.ie=this.pw[this.oi];this.zm=this.ye*this.ie*7};function Co(a){a.IB=a.ie*a.ye;a.HB.Ta(a.IB,!0)}
function Fo(a){var b=Z,c=!1;if(void 0!==a&&0!==a){var d=b.Sg.ea();d+a>b.Ud&&(a-=d+a-b.Ud,c=!0,b.Sg.Md(a,!0));c||b.Sg.Md(a,!0);c=b.Jf.tF(!0);b.Jf.pg(c+a/b.Ud*100);b.ca.player.lastProgressPercentage=c+a/b.Ud*100;b.ca.player.lastProgressAmount=b.Sg.ea();b.ma.save()}}
function Go(a){Ho(a.ma);for(var b=0;b<a.Zy.length;b++)if(a.mg===a.Zy[b].level){a.ma.KA();a.Ty++;b=new Io({rh:E("feedback_betunlock"),P:function(){a.F&&a.F.fb(6);a.kh()}});b.show();return}for(b=0;b<a.$y.length;b++)if(a.mg===a.$y[b].level){Jo(a.ma);a.hu++;b=new Io({rh:E("feedback_paylinesunlock"),P:function(){a.F&&a.F.fb(5)}});b.show();return}var b=Ko(a.Ud*a.bd.coinRewardPercentage),c=a.Ud*a.bd.coinRewardPercentage,b=new Io({rh:E("feedback_coinpackage").replace("{0}",b),P:function(){a.mf.Md(c)}});b.show();
Lo(a.ma,c)}
e.or=function(){var a=this;this.A=new ro({x:this.Cc,y:y(0),width:y(1080),height:y(300),backgroundImage:void 0,Pa:{h:Bl},sa:{h:Bl}});this.Sg=new oo({x:y(-328),y:y(-8),Gi:!0,yd:y(100),zd:y(16),bc:{l:gi.l,fontSize:42,fillColor:"#ffffff"},Qc:"/ "+Ko(this.Ud),width:uf.width-y(72),Wb:y(0),Ob:y(16),md:".",ec:this.jG,valueType:"number",Db:{l:gi.l,fontSize:48,fillColor:"#ffffff",align:"left"}});this.jq=new oo({x:y(-420),y:y(-8),ec:this.mg,md:".",valueType:"number",Db:{l:gi.l,fontSize:48,fillColor:"#ffffff"}});var b=
[];b.push(this.jq);b.push(this.Sg);this.Jf=so(this.A,bm,{x:y(540),y:y(380),ja:uf,Vg:vf,$E:y(62),aF:y(10),NH:this.kG,YE:y(-20),ZE:y(-72),OH:70,e:b,tu:function(){a.Jf.pg(0,!0);Qb(Z.A);a.kh()}});so(this.A,qo,{backgroundImage:hf,x:y(538),y:y(1542),width:y(400),height:y(215),Qc:"Off",bc:{l:T.l,fontSize:76,fillColor:"#ffffff"},yd:0,zd:0});this.NW=so(this.A,qo,{backgroundImage:kf,x:y(538,"round"),y:y(1542,"round"),width:y(400),height:y(215),Qc:E("feedback_notenough"),bc:{l:T.l,fontSize:52,fillColor:"#ffffff"},
yd:y(0,"round"),zd:y(-35,"round")});this.LW=so(this.A,qo,{backgroundImage:wf,x:y(882,"round"),y:y(1570,"round"),width:wf.width,height:wf.height,Qc:E("feedback_higherbets"),bc:{l:T.l,fontSize:52,fillColor:"#000000"},yd:y(0,"round"),zd:y(-35,"round")});this.MW=so(this.A,qo,{backgroundImage:wf,x:y(200,"round"),y:y(1570,"round"),width:wf.width,height:wf.height,Qc:E("feedback_morepaylines"),bc:{l:T.l,fontSize:52,fillColor:"#000000"},yd:y(0,"round"),zd:y(-35,"round")});this.fj=so(this.A,oo,{backgroundImage:jf,
x:y(538),y:y(1542),width:void 0,height:void 0,xa:Re,Ve:-jf.width/2+Re.width-y(16),We:y(-16),Qc:E("ui_win"),yd:0,zd:y(-76),bc:{l:Ci.l,fontSize:20,fillColor:"#ffffff"},md:".",ec:0,valueType:"number",Db:{l:T.l,fontSize:36,fillColor:"#ffffff"},Wb:.1*jf.width,Ob:y(-12),margin:.2*jf.width});this.kv=so(this.A,oo,{backgroundImage:tf,x:y(538),y:y(1542),width:void 0,height:void 0,xa:Re,Ve:-jf.width/2+Re.width-y(16),We:y(-16),md:".",Qc:E("ui_win"),yd:0,zd:y(-76),bc:{l:Ci.l,fontSize:20,fillColor:"#ffffff"},ec:0,
valueType:"number",Db:{l:T.l,fontSize:48,fillColor:"#ffffff"},Wb:.1*jf.width,Ob:y(-12),margin:.2*jf.width});so(this.A,u,{x:y(540),y:y(64),c:Xe});this.ui=so(this.A,u,{c:Re,x:y(106),y:y(80)});this.jv=so(this.A,D,{x:y(404),y:y(75),width:y(652),height:y(72),c:void 0,va:!0,j:function(b){b.va&&(a.F&&Mo(a.F,"more"),(new No({Jg:a.Ud})).show())}});this.mf=so(this.A,oo,{width:y(0),height:y(0),md:".",Wb:y(450,"round"),Ob:y(83,"round"),valueType:"number",Db:{l:Ai.l,fontSize:33,fillColor:"#942600"},ec:this.Fn,
Cl:function(){0<a.Eb&&(a.Eb=0)}});this.NB=so(this.A,oo,{yd:y(296,"round"),zd:y(22,"round"),Qc:E("ui_totalwinnings"),bc:{l:Ci.l,fontSize:36,fillColor:"#942600"},md:".",Wb:y(455,"round"),Ob:y(22,"round"),width:y(600),valueType:"number",Db:{l:Ci.l,fontSize:36,fillColor:"#942600"},ec:this.HH,Gi:!0,wy:!0});so(this.A,oo,{yd:y(800),zd:y(30),Qc:E("ui_win"),Wb:y(800),Ob:y(60),valueType:"number",ec:0});so(this.A,u,{x:y(540),y:y(1524),c:We});this.sc=so(this.A,oo,{yd:y(308),zd:y(339),Gi:!0,bc:{l:T.l,fontSize:42,
fillColor:"#ffffff"},Qc:"/ "+this.nf,Wb:y(296),Ob:y(339),valueType:"number",Db:{l:T.l,fontSize:42,fillColor:"#ffffff"},ec:this.WF,target:this.nf,id:0});this.Hd=so(this.A,u,{c:Sg,x:y(290),y:y(224)});this.tc=so(this.A,oo,{yd:y(548),zd:y(339),Gi:!0,Qc:"/ "+this.of,bc:{l:T.l,fontSize:42,fillColor:"#ffffff"},Wb:y(534),Ob:y(339),valueType:"number",Db:{l:T.l,fontSize:42,fillColor:"#ffffff"},ec:this.XF,target:this.of,id:1});this.Id=so(this.A,u,{c:Tg,x:y(530),y:y(224)});this.uc=so(this.A,oo,{yd:y(782),zd:y(339),
Gi:!0,Qc:"/ "+this.pf,bc:{l:T.l,fontSize:42,fillColor:"#ffffff"},Wb:y(770),Ob:y(339),valueType:"number",Db:{l:T.l,fontSize:42,fillColor:"#ffffff"},ec:this.YF,target:this.pf,id:2});this.Jd=so(this.A,u,{c:Ug,x:y(764),y:y(224)});this.Sc=so(this.A,D,{c:Pe,x:y(540),y:y(1530),va:!0,Nf:null,j:function(b){a.vm&&(rc(a.Y),a.Y.setTime(0),Oo(a),Yb("glow"),Yb("fx"),a.vm=!1,a.Sl());Po(a);b.va&&(a.F&&Mo(a.F,"spin"),a.WO=!0,a.Sl())}});this.$q=so(this.A,D,{c:Ze,x:y(946),y:y(1572),va:!0,text:"",Nf:Bj,j:function(b){b.va&&
(0>a.nd&&(a.oi+1>a.Ty?a.wD.fb(a.wD.Pb.jj):(a.oi++,b=a.oi,a.ca.player.lastBet=a.oi,a.ie=a.pw[b],a.TJ.Ta(a.ie,!0),a.zm=a.ye*a.ie*7),Co(a)),a.yf(),a.F&&Mo(a.F,"bet"))}});this.Dq=so(this.A,D,{c:Ye,x:y(812),y:y(1572),va:!0,text:"",Nf:Bj,j:function(b){b.va&&(0>a.nd&&(a.oi-1<a.IS||(a.oi--,b=a.oi,a.ca.player.lastBet=a.oi,a.ie=a.pw[b],a.TJ.Ta(a.ie,!0),a.zm=a.ye*a.ie*7),Co(a)),a.yf(),a.F&&Mo(a.F,"bet"))}});this.kq=so(this.A,D,{c:Ye,x:y(135),y:y(1570),va:!0,text:"",Nf:Bj,j:function(b){b.va&&(a.bf--,0>a.bf&&
(a.bf=0),a.ca.player.lastLines=a.bf,a.ye=a.Fs[a.bf],a.zm=a.ye*a.ie*7,a.UJ.Ta(a.ye,!0),b=a.bf,a.Wq&&Xb(q,a.Wq),a.Wq=new Qo(b),Co(a),a.yf(),a.F&&Mo(a.F,"line"))}});this.lq=so(this.A,D,{c:Ze,x:y(269),y:y(1570),va:!0,text:"",Nf:Bj,j:function(b){b.va&&(a.bf++,a.bf>a.hu&&(a.zG.fb(a.zG.Pb.jj),a.bf=a.hu),a.ca.player.lastLines=a.bf,a.ye=a.Fs[a.bf],a.zm=a.ye*a.ie*7,a.UJ.Ta(a.ye,!0),b=a.bf,a.Wq&&Xb(q,a.Wq),a.Wq=new Qo(b),Co(a),a.yf(),a.F&&Mo(a.F,"line"))}});this.Sc.va=!1;this.$q.va=!1;this.Dq.va=!1;this.lq.va=
!1;this.kq.va=!1;this.Sm=so(this.A,D,{x:y(814),y:y(60),c:af,Nf:Bj,va:!0,j:function(b){b.va&&(0>a.nd&&(new ko({canvas:a.Ac})).show(),a.F&&Mo(a.F,"gallery"))}});this.Au=so(this.A,D,{x:y(949),y:y(60),c:$e,Nf:Bj,va:!0,j:function(a){a.va&&mo()}});this.TJ=so(this.A,oo,{yd:y(830,"round"),zd:y(1501,"round"),Qc:E("ui_bet"),bc:{l:T.l,fontSize:44,fillColor:"#892a02"},md:".",Wb:y(967,"round"),Ob:y(1501,"round"),valueType:"number",Db:{l:T.l,fontSize:44,fillColor:"#892a02"},ec:this.ie,width:y(250)});this.UJ=so(this.A,
oo,{yd:y(150,"round"),zd:y(1501,"round"),Qc:E("ui_paylines"),bc:{l:T.l,fontSize:44,fillColor:"#892a02"},Wb:y(285,"round"),Ob:y(1501,"round"),valueType:"number",Db:{l:T.l,fontSize:44,fillColor:"#892a02"},ec:this.ye,width:y(250)});this.rg=so(this.A,F,{text:E("ui_button_spin"),width:Pe.width-y(10),height:Pe.height/2,x:y(540,"round"),y:y(1498,"round"),font:ri});so(this.A,u,{c:Re,x:y(462,"round"),y:y(1568,"round")});this.HB=so(this.A,oo,{md:".",Wb:y(578,"round"),Ob:y(1577,"round"),valueType:"number",Db:{l:T.l,
fontSize:60,fillColor:"#ffffff",jb:.6},ec:this.IB});Ob(this.A,"ui");this.A.show();this.sc.ea()===this.sc.target&&(this.Hd.c=Vg);this.tc.ea()===this.tc.target&&(this.Id.c=Wg);this.uc.ea()===this.uc.target&&(this.Jd.c=Xg);this.Hd.i();this.sc.i();this.Id.i();this.tc.i();this.Jd.i();this.uc.i();this.ej=new Ro;So(this);this.KU=new To(this.ui)};
e.Sl=function(){rc(this.Y);var a=this.ie*this.ye;this.xe=[];this.hB=-1;if(this.Ln){var b=this.Ln;b.it=[];b.elements=[];b.state=0;Xb(q,b);this.Ln=void 0}if(a>this.mf.ea()&&0>this.nd)Uo(this,this.Je.Zr),0>=this.Uu.state&&(this.Uu.fb(this.Uu.Pb.jj),U.play(sj)),this.oe&&Vo(this.oe);else{this.fj.Ta(0,!0);U.play(rj);U.play(lj,200);this.kB=!1;b=this.Rn;0>Z.nd&&b.wp++;b.co+=a;if(b.wp<=b.zS)Wo(b);else if(parseFloat(Math.random().toFixed(3))<=b.tt){b.tt=b.Rx;b.wp=0;if(parseFloat(Math.random().toFixed(3))<=
b.Sp){0<b.Sp-.05&&(b.Sp-=.05);b.ok=b.vr;b.jl();var c=[];b.dl=Xo(!0);for(var d=0;d<b.R.ba.length;d++){var g=c,k=d,l=b,m=d,p=[],w=1,z=0;p[0]=Math.round(Math.random()*(l.R.$d.length-4));for(var v=1;4>v;v++)for(var C=!1;!C;){var x=0,x=l.dl&&l.dl[m].tr===v?l.R.ih:Math.round(Math.random()*(l.R.$d.length-1));x===l.R.ih?l.dl[m].tr===v&&l.Gl<l.vS&&0!==w&&(l.Gl++,w--,p[v]=x,C=!0):x===l.R.Vc?l.gm<l.Vy&&0!==z&&(l.gm++,z--,p[v]=x,C=!0):9===x||10===x||11===x?l.ff<l.wl&&(l.ff++,p[v]=x,C=!0):(p[v]=x,C=!0)}g[k]=p}}else for(b.Sp=
b.Rx,b.wp=0,b.ok=b.vr,b.jl(),c=[],b.dl=Xo(!1),d=0;d<b.R.ba.length;d++){g=c;k=d;l=b;m=d;p=[];w=1;z=0;p[0]=Math.round(Math.random()*(l.R.$d.length-4));for(v=1;4>v;v++)for(C=!1;!C;)x=l.dl[m].tr===v?l.R.ih:Math.round(Math.random()*(l.R.$d.length-1)),x===l.R.ih?l.dl[m].tr===v&&l.Gl<l.uS&&0!==w&&(l.Gl++,w--,p[v]=x,C=!0):x===l.R.Vc?l.gm<l.Vy&&0!==z&&(l.gm++,z--,p[v]=x,C=!0):9===x||10===x||11===x?l.ff<l.wl&&(l.ff++,p[v]=x,C=!0):(p[v]=x,C=!0);g[k]=p}b.ff=0;b.R.Jh&&b.R.Jh(c);b.dl=[]}else b.tt+=b.UP,Wo(b);b=
Z.ma;b.db.player.tutorialSpins+=1;b.save();Z.F&&Z.F.Vu++;this.Sc.va=!1;this.$q.va=!1;this.Dq.va=!1;this.lq.va=!1;this.kq.va=!1;this.jv.va=!1;this.Sm.va=!1;this.Au.va=!1;if(this.F){b=this.F;switch(b.Vu){case 1:b.Mn=b.Nv[0];break;case 5:b.state=1;b.Mn=b.Nv[1];break;case 10:b.state=2,b.Mn=b.Nv[2]}if(this.F.Mn&&this.F.Vu===this.F.Mn.jB){this.JB=!0;switch(this.F.state){case 0:this.Wh=!0;this.F.bh=1;this.F.Ii();break;case 1:this.Wh=!0;this.F.bh=2;this.F.Ii();break;case 2:this.Wh=!0,this.F.bh=-1,this.F.Ii(),
this.Rn.wp=0}this.Jh(this.IW[this.F.Mn.Yh])}}0>this.nd&&(this.mf.Md(-a,!0),Lo(this.ma,-a),Uo(this,this.Je.$B));a=1E3;b=0;c=!1;d=-1;for(g=0;4>g;g++)1===this.$s[g]&&2>b&&(b++,2===b&&(d=g));2<=b&&(c=!0);for(g=0;g<this.ba.length;g++)c&&0===b&&(this.ba[g].Bt=!0),1===this.$s[g]&&b--,d===g&&(this.ba[g].sw=!0),this.ba[g].startTime(150*g),this.ba[g].Bt?(a+=5E3,k=this.ba[g],pc(k.Y,k,a+150*g,k.LA)):this.ba[g].sw?(k=this.ba[g],pc(k.Y,k,a+700*g,k.LA)):(k=this.ba[g],pc(k.Y,k,a+150*g,k.LA))}};
e.Jh=function(a){this.$s=[0,0,0,0];for(var b=0;b<this.ba.length;b++){for(var c=1;4>c;c++)a[b][c]===this.ih&&(this.$s[b]=1);this.ba[b].Wz=a[b]}};function Yo(a){var b=Z;void 0===b.Ln&&(b.Ln=new Zo(b.Tm,function(){$o(b)}));for(var c=0;c<b.ba[a].Xb.length;c++)b.ba[a].Xb[c].type===b.ih&&(Gj(a),b.hB++,Gj(b.hB),b.Ln.addElement(b.ba[a].Xb[c],{x:b.ba[a].Xb[c].x+Ke.width/2,y:b.ba[a].Xb[c].y+Ke.height/2-y(12)}))}
e.Kw=function(){for(var a=[],b=0;b<this.bX;b++){for(var c=[],d=0;d<this.ba.length;d++)c.push(this.ba[d].Xb[b]);a.push(c)}var g=0,c=b=!1,d=[],k=[];this.JB=!1;for(var l=0;l<this.ye;l++){for(var m=0,p=-1,w=!1,z=-1,v=[],C=[],x=-1,t=0;t<this.ba.length;){var A=this.dk[l][t],B=a[A][t].type;B!=this.Vc?(z=a[A][t],p=B):(z=a[A][t],w=!0);break}0>p&&w&&(p=this.Vc);for(t=1;t<this.ba.length;t++)if(A=this.dk[l][t],B=a[A][t].type,p===this.Vc&&B!==this.Vc&&-1===x&&(x=a[A][t]),p===B||this.Vc===B)m++;else if(p===this.Vc&&
x.type===B&&B!==this.ih||this.Vc===B)m++;else break;for(t=0;t<this.dk[l].length;t++)v[t]=a[this.dk[l][t]][t];for(t=0;t<m+1;t++)C[t]=a[this.dk[l][t]][t];0<m&&(0===z.Pf.type?(t=z.Pf.payouts[m],g+=t,0<t&&(d.push(v),k.push(C))):3===z.Pf.type&&-1<x?(t=x.Pf.payouts[m],g+=t,0<t&&(d.push(v),k.push(C))):3===z.Pf.type&&3===m&&(t=z.Pf.payouts[m],g+=t,0<t&&(d.push(v),k.push(C))))}v=[0,0,0];C=[[],[],[]];for(l=m=0;l<this.ba.length;l++)for(t=0;t<a.length;t++)switch(z=a[t][l],z.Pf.type){case 1:m+=1;break;case 2:9===
z.type?(v[0]+=1,C[0].push(z)):10===z.type?(v[1]+=1,C[1].push(z)):11===z.type&&(v[2]+=1,C[2].push(z))}3===m?(b=!0,this.nd=9,this.Pu=1,this.Dd++,(this.oe=new ap((r.O-df.width)/2,y(360)+df.height/2,-1,this.ym))&&bp(this.oe,(this.nd+1).toString())):4<=m&&(c=!0,this.nd=9,this.Pu=1,this.Dd++,(this.oe=new ap((r.O-df.width)/2,y(360)+df.height/2,-1,this.ym))&&bp(this.oe,(this.nd+1).toString()));a=this.ie*g;this.Ft?(this.Tp+=a,this.kv.Md(a)):(0<a?(this.Eb=a,this.sg.Eb=a,l=this.Ud,g=this.Sg.ea(),a+g>=l&&(this.ex=
1,this.ej.Ii())):b||(l=this.ma,l.db.ads.interstitials.wof&&l.db.ads.interstitials.level&&G.MA()),this.NB.Md(a),l=this.ma,l.db.player.curScore+=a,l.save(),a>this.zm?(this.yD=1,this.ao=a):0<a&&(this.ZG=1,this.ao=a));this.dd=300;for(l=0;l<v.length;l++)switch(l){case 0:if(this.sc.ea()<this.nf)if(v[l]+this.sc.ea()>this.nf)for(a=v[l]+this.sc.ea()-this.nf,this.ca.levels[this.Kb].objective.col1+=a,t=0;t<a;t++)new cp(Sg,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+y(100),Aa:this.Hd.x,
G:this.Hd.y,Wc:100,duration:800,L:this.dd,uf:this.sc,value:1,A:this.Hd,clip:"animCollect1"}),this.dd+=500;else for(this.ca.levels[this.Kb].objective.col1+=v[l],t=0;t<v[l];t++)new cp(Sg,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+y(100),Aa:this.Hd.x,G:this.Hd.y,Wc:100,duration:800,L:this.dd,uf:this.sc,value:1,A:this.Hd,clip:"animCollect1"}),this.dd+=500;break;case 1:if(this.tc.ea()<this.of)if(v[l]+this.tc.ea()>this.of)for(a=v[l]+this.tc.ea()-this.of,this.ca.levels[this.Kb].objective.col2+=
a,t=0;t<a;t++)new cp(Tg,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+y(80),Aa:this.Id.x,G:this.Id.y,Wc:100,duration:800,L:this.dd,uf:this.tc,value:1,A:this.Id,clip:"animCollect2"}),this.dd+=500;else for(this.ca.levels[this.Kb].objective.col2+=v[l],t=0;t<v[l];t++)new cp(Tg,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+y(100),Aa:this.Id.x,G:this.Id.y,Wc:100,duration:800,L:this.dd,uf:this.tc,value:1,A:this.Id,clip:"animCollect2"}),this.dd+=500;break;
case 2:if(this.uc.ea()<this.pf)if(v[l]+this.uc.ea()>this.pf)for(a=v[l]+this.uc.ea()-this.pf,this.ca.levels[this.Kb].objective.col3+=a,t=0;t<a;t++)new cp(Ug,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+y(100),Aa:this.Jd.x,G:this.Jd.y,Wc:100,duration:800,L:this.dd,uf:this.uc,value:1,A:this.Jd,clip:"animCollect3"}),this.dd+=500;else for(this.ca.levels[this.Kb].objective.col3+=v[l],t=0;t<v[l];t++)new cp(Ug,{canvas:this.Ac,Ne:!1,scale:1.4,aa:C[l][t].x+y(121),u:C[l][t].Lf+y(290)+
y(100),Aa:this.Jd.x,G:this.Jd.y,Wc:100,duration:800,L:this.dd,uf:this.uc,value:1,A:this.Jd,clip:"animCollect3"}),this.dd+=500}c||b&&this.ej.Ii();this.xe=d;this.Wd=k;So(this,this.ao)||dp(this,d)};
function dp(a,b,c){var d=300;a.PE=!1;a.Y.setTime(0);if(0<a.yD)a.yD--,new ep(a.ao);else if(0<a.ZG)a.ZG--,a.sg.fb(a.sg.Pb.jj),U.play(wj),new fp(a.ao);else if(c&&(d=5E3),a.xe)if(0<a.xe.length){rc(a.Y);a.wC=[];a.wC.push(0);for(c=0;c<a.Wd.length;c++)a.wC.push(a.Wd[c].length-1);pc(a.Y,a,d,a.tV,b[0]);gp(a);a.Kd=1}else Oo(a),rc(a.Y),pc(a.Y,a,d,a.yf);else Oo(a),rc(a.Y),pc(a.Y,a,d,a.yf)}
e.tV=function(a){this.yf();var b=this;this.PE=this.dF=!0;this.Kd=1;this.wg=[];this.Qr=[];for(var c=0;c<a.length;c++){this.Wd[0][c]&&c<this.Wd[0].length&&(new hp(this.Wd[0][c].x+y(121),this.Wd[0][c].y+y(145),-250,c),ip(this.Wd[0][c]),this.Wd[0][c].Yq(),this.Qr.push(this.Wd[0][c]));if(3>c){var d=new jp(c,a[c].x+y(121),a[c].y+y(145),a[c+1].x+y(145),a[c+1].y+y(145),function(a){3>a?(Mb(b.wg[a]),Ob(b.wg[a],"glow")):3===a&&(Yb("glow"),b.wg=[])});this.wg.push(d)}gp(this)}Mb(this.wg[0]);Ob(this.wg[0],"glow");
this.vm=!0;U.play(hj);this.kB||(this.fj.Ta(this.ao),this.ao=0,this.kB=!0)};
function kp(a){var b=Z;if(b.PE)if(0<b.Kd&&b.Kd<b.xe.length&&0===a){for(a=0;a<b.Qr.length;a++)lp(b.Qr[a]);b.Qr=[];for(a=0;a<b.xe[b.Kd].length;a++){b.Wd[b.Kd][a]&&a<b.Wd[b.Kd].length&&(new hp(b.Wd[b.Kd][a].x+y(121),b.Wd[b.Kd][a].y+y(145),-250,a),ip(b.Wd[b.Kd][a]),b.Wd[b.Kd][a].Yq(),b.Qr.push(b.Wd[b.Kd][a]));if(3>a){var c=new jp(a,b.xe[b.Kd][a].x+y(121),b.xe[b.Kd][a].y+y(145),b.xe[b.Kd][a+1].x+y(145),b.xe[b.Kd][a+1].y+y(145),function(a){3>a?(Mb(b.wg[a]),Ob(b.wg[a],"glow")):3===a&&(Yb("glow"),b.wg=[])});
b.wg.push(c)}gp(b)}Mb(b.wg[0]);Ob(b.wg[0],"glow");b.Kd++}else b.Kd>=b.xe.length&&b.dF&&(0===b.Dd&&(rc(b.Y),dp(b,b.xe,!0)),Oo(b),b.dF=!1)}function So(a,b){void 0===b&&(b=0);if(!(0<a.Dd||-1<a.nd||a.F&&Eo(a.F.Ag.xv))&&a.mf.ea()+b<a.QG){for(var c=0,d=!1,g=0;5>g;g++)c+=a.ca.artifacts[g].amount;0<c&&(d=!0);c=new mp({Ct:d,Ac:a.Ac,Jg:a.Ud});c.Ia=function(){a.ej.mh();a.kh();a.$x=!1};a.ej.Ii();c.show();a.za.Ka(a.za.no.TK);a.F&&(a.$x=!0);a.ma.db.player.tutorialStates[9]=!1;a.ma.save();return!0}return!1}
function Oo(a){a.sc.ea()>a.nf&&a.sc.Ta(a.nf,!0);a.tc.ea()>a.of&&a.tc.Ta(a.of,!0);a.uc.ea()>a.pf&&a.uc.Ta(a.pf,!0);if(a.sc.ea()===a.nf&&a.tc.ea()===a.of&&a.uc.ea()===a.pf&&0===a.Tn){a.ca.levels[a.Kb].objective.col1=0;a.ca.levels[a.Kb].objective.col2=0;a.ca.levels[a.Kb].objective.col3=0;var b=a.ma;b.db.player.collectableLevel+=1;b.save();a.tj++;a.Tn++;U.play(bj)}var c;void 0===c&&(c=0>=a.Dd?100:1200);rc(a.xr);a.xr.setTime(0);pc(a.xr,a,c,a.kh)}
e.kh=function(){var a=this;this.vm=!1;this.JB||(np(this),this.JB=!0);if(0<this.ex&&0>=this.Dd&&0>=this.Tn)U.play(ej),new op("lvlUp",function(){var b=a.jq.ea();b++;a.jq.Ta(b,!0);a.Sg.Ta(0,!0);a.Ud*=2;a.Sg.xd.text="/ "+Ko(a.Ud);a.Sg.xd.Xa();a.mg+=1;Go(a);a.Rn.jl();b=a.ma;b.db.player.curLevel+=1;b.db.player.lastProgressAmount=0;b.db.player.lastProgressPercentage=0;b.save();a.ej.mh()}),this.ex--;else if(0<this.Dd&&this.io)if(this.Ft=!0,this.Rn.Uy=0,0<this.Pu)this.Pu--;else if(-1<this.nd)this.oe&&bp(this.oe,
(this.nd+1).toString()),this.Sl(),this.nd--,this.oe&&bp(this.oe,(this.nd+1).toString());else{this.Dd--;this.Rn.Uy=2;this.Ft=!1;this.Am=new yc({canvas:this.Ac,depth:-1E3,W:-902,x:r.O/2,y:r.M/2});this.yc=new cm({Rd:.667});this.Am.d(this.yc);this.Am.show();var b=E("feedback_congratulations").replace("{0}",Ko(a.Tp));new An(b,r.O/2,r.M/2-y(100),200,ki,.55,"#00dfff","#094dc5",-2E3,-903,function(){var b=new pp({mo:a.Tp});b.P=function(){if(0>=a.Tn)new qp(function(){Vo(a.oe);rp(a.border);a.Jf.show();a.zh.fb(a.zh.Pb.xk);
a.kv.Ta(0,!1);a.Jf.ka();a.Jf.pg(a.ca.player.lastProgressPercentage,!0);a.Sg.Ta(a.ca.player.lastProgressAmount,!0);a.jq.Ta(a.mg);for(var b=0;b<a.ba.length;b++)for(var c=0;c<a.ba[b].Xb.length;c++)8<a.ba[b].Xb[c].type?sp(a.ba[b].Xb[c]):tp(a.ba[b].Xb[c]);a.cl&&(a.Hd.i(),a.sc.i(),a.Id.i(),a.tc.i(),a.Jd.i(),a.uc.i(),Xb(q,a.cl),a.cl=void 0);for(b=0;b<a.Mg.length;b++)Xb(q,a.Mg[b]);Yb("completeCol");a.Mg=[]},void 0,function(){Uo(a,a.Je.$r);Hj();up(a);a.pr=!1;a.ej.mh();a.kh();var b=a.NB.ea();G.NA&&G.NA(b,0,
void 0)}),a.Am.i(),a.Am=void 0;else{vp(a.ma);Qb(Z.A);var b=new wp(a);new qp(function(){b.Wm();Vo(a.oe);rp(a.border);a.Jf.show();a.zh.fb(a.zh.Pb.xk);a.kv.Ta(0,!1);a.Jf.ka();a.Jf.pg(a.ca.player.lastProgressPercentage,!0);a.Sg.Ta(a.ca.player.lastProgressAmount,!0);a.jq.Ta(a.mg);a.tj>a.bd.collectables.length-1&&(a.tj=a.bd.collectables.length-1);a.nf=a.bd.collectables[a.tj][0];a.of=a.bd.collectables[a.tj][1];a.pf=a.bd.collectables[a.tj][2];a.sc.Ta(0,!0);a.tc.Ta(0,!0);a.uc.Ta(0,!0);a.sc.xd.text="/ "+a.nf;
a.tc.xd.text="/ "+a.of;a.uc.xd.text="/ "+a.pf;a.sc.target=a.nf;a.tc.target=a.of;a.uc.target=a.pf;a.sc.xd.Xa();a.tc.xd.Xa();a.uc.xd.Xa();a.Hd.c=Sg;a.Id.c=Tg;a.Jd.c=Ug;for(var c=0;c<a.ba.length;c++)for(var k=0;k<a.ba[c].Xb.length;k++)8<a.ba[c].Xb[k].type?sp(a.ba[c].Xb[k]):tp(a.ba[c].Xb[k]);a.cl&&(a.Hd.i(),a.sc.i(),a.Id.i(),a.tc.i(),a.Jd.i(),a.uc.i(),Xb(q,a.cl),a.cl=void 0);for(c=0;c<a.Mg.length;c++)Xb(q,a.Mg[c]);Yb("completeCol");a.Mg=[];a.Am.i();a.Am=void 0},b,function(){Uo(a,a.Je.$r);var b;U.stop("music");
b=U.play(zj);U.lk(b,!0);up(a);a.pr=!1;a.ej.mh()})}};b.show();for(b=0;b<a.Mg.length;b++)Xb(q,a.Mg[b]);Yb("completeCol");a.Mg=[];a.Tp=0},a.Ac)}else 0<this.Tn?this.Tn--:rc(this.xr)};function np(a,b){if(void 0!==a.F&&(b&&(a.Wh=!0,a.F.bh=b),a.Wh))switch(a.F.bh){case 1:a.F.fb(a.F.bh);a.F.bh=-1;a.Wh=!1;break;case 2:a.F.fb(a.F.bh);a.F.bh=-1;a.Wh=!1;break;case 3:a.F.fb(a.F.bh),a.io=!1}}
function $o(a){a.Wh?(np(a,3),a.F.lr(function(){new op("freeSpins",function(){new qp(function(){var b=0;a.pr=!0;rp(a.border);a.Jf.i();for(var c=0;c<a.ba.length;c++)for(var d=0;d<a.ba[c].Xb.length;d++)a.ba[c].Xb[d].Qj?(xp(a.ba[c].Xb[d],b),b++):yp(a.ba[c].Xb[d])},void 0,function(){Ij();a.zh.fb(a.zh.Pb.jj);a.zh.$n=999999999;Uo(a,a.Je.Wr);a.cl=new zp([{x:a.Hd.x,y:a.Hd.y,A:a.Hd,clip:"animCollect1",text:a.sc,Rf:a.sc.ea(),call:void 0},{x:a.Id.x,y:a.Id.y,A:a.Id,clip:"animCollect2",text:a.tc,Rf:a.tc.ea(),call:void 0},
{x:a.Jd.x,y:a.Jd.y,A:a.Jd,clip:"animCollect3",text:a.uc,Rf:a.uc.ea(),call:function(){a.F.fb(4);a.F.bh=-1;a.F.lr(function(){Z.Pu=0;Z.io=!0;Z.Sl()})}}])})},y(200))}),a.Wh=!1):new op("freeSpins",function(){new qp(function(){var b=0;a.pr=!0;rp(a.border);a.Jf.i();for(var c=0;c<a.ba.length;c++)for(var d=0;d<a.ba[c].Xb.length;d++)a.ba[c].Xb[d].Qj?(xp(a.ba[c].Xb[d],b),b++):yp(a.ba[c].Xb[d])},void 0,function(){Ij();a.zh.fb(a.zh.Pb.jj);a.zh.$n=999999999;Uo(a,a.Je.Wr);a.cl=new zp([{x:a.Hd.x,y:a.Hd.y,A:a.Hd,
clip:"animCollect1",text:a.sc,Rf:a.sc.ea()},{x:a.Id.x,y:a.Id.y,A:a.Id,clip:"animCollect2",text:a.tc,Rf:a.tc.ea()},{x:a.Jd.x,y:a.Jd.y,A:a.Jd,clip:"animCollect3",text:a.uc,Rf:a.uc.ea()}])})},y(200))}function Ap(a){var b=Z;b.ca.artifacts[a].amount+=1;b.ma.save()}function Bp(a){var b=Z;b.mf.Md(a);Lo(b.ma,a)}
e.Qa=function(){this.ma.db.player.tutorialStates[10]=!1;this.ma.save();this.TO&&this.TO.i();this.Tm&&hk(this.Tm);this.ym&&hk(this.ym);Xb(q,this.A);Xb(q,this.vU);Yb("slot");Yb("glow");Yb("fx");G.MA&&G.MA()};e.wa=function(){};e.Sa=function(){this.vm&&(rc(this.Y),this.Y.setTime(0),this.xe=[],Oo(this),Yb("fx"),Yb("glow"),this.vm=!1);Po(this)};function up(a){rc(a.Y);a.Y.setTime(0);a.xe=[];Yb("fx");Yb("glow")}e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};
e.Ga=function(a){this.Y.Vb(a);this.xr.Vb(a)};e.Ha=function(){};function Po(a){void 0!==a.sg&&a.sg.state===a.sg.Pb.as&&a.sg.fb(a.sg.Pb.xk)}function gp(a){void 0!==a.sg&&(a.sg.$n=1E6)}
function Uo(a,b){if(a.EI!==b){switch(b){case a.Je.$r:a.Sc.c=Pe;a.Sc.Xa();a.rg.text=E("ui_button_spin");a.rg.font=ri;a.rg.Xa();break;case a.Je.$B:a.Sc.c=Qe;a.Sc.Xa();a.rg.text=E("ui_goodluck");a.rg.font=ni;a.rg.Xa();break;case a.Je.Zr:a.Sc.c=lf;a.Sc.Xa();a.rg.text=E("ui_button_spin");a.rg.font=xi;a.rg.Xa();break;case a.Je.Wr:a.Sc.c=sf,a.Sc.Xa(),a.rg.text=E("ui_freespins"),a.rg.font=pi,a.rg.Xa()}a.EI=b}}
e.yf=function(a){void 0!==a&&this.HB.ea()>this.mf.ea()+a&&0>=this.Dd?Uo(this,this.Je.Zr):this.HB.ea()>this.mf.ea()&&0>=this.Dd?Uo(this,this.Je.Zr):1<=this.Dd?(this.ej.Ii(),this.pr&&Uo(this,this.Je.Wr)):Uo(this,this.Je.$r);this.Sc.va=!0;this.$q.va=!0;this.Dq.va=!0;this.lq.va=!0;this.kq.va=!0;this.jv.va=!0;this.Sm.va=!0;this.Au.va=!0};function Ko(a){a=a.toString();for(var b="",c=0;c<a.length;c+=1)0===(a.length-c)%3&&0!==c&&(b+="."),b+=a.charAt(c);return b}
var wo={initialCredits:200,minimumBet:1,scoreSpin:50,tutotialSpins:{0:[[2,1,5,7],[3,3,5,0],[6,5,5,6],[7,7,0,2]],1:[[2,1,2,0],[3,2,4,3],[6,7,6,3],[7,8,7,5]],2:[[2,2,4,0],[3,1,4,3],[6,6,4,6],[7,5,7,2]]},fixedLines:[5,10,25,50],fixedBet:[1,5,10,25,50,100,250,500,1E3],startTarget:100,coinRewardPercentage:.1,minMaxBet:[{level:1,maxBet:0},{level:2,maxBet:1},{level:4,maxBet:2},{level:5,maxBet:3},{level:7,maxBet:4},{level:8,maxBet:5},{level:9,maxBet:6},{level:11,maxBet:7},{level:12,maxBet:8}],minMaxLine:[{level:1,
maxLine:0},{level:3,maxLine:1},{level:6,maxLine:2},{level:10,maxLine:3}],symbolTypes:[{type:"normal",combination:"winline",payout:"credit"},{type:"minigame",combination:"scatter",payout:"minigame"},{type:"collectible",combination:"any",payout:"score"},{type:"wild",combination:"winline",payout:"credits"}],symbols:[{type:0,payouts:[0,0,500,1E3]},{type:0,payouts:[0,0,250,500]},{type:0,payouts:[0,0,100,250]},{type:0,payouts:[0,0,50,100]},{type:1,payouts:[0,0,"freespins","random"]},{type:0,payouts:[0,
0,25,50]},{type:0,payouts:[0,0,10,25]},{type:0,payouts:[0,0,5,10]},{type:3,payouts:[0,0,0,2E3]},{type:2,payouts:[100,200,300,400,500,600,700,800,900,1E3,1100,1200]},{type:2,payouts:[100,200,300,400,500,600,700,800,900,1E3,1100,1200]},{type:2,payouts:[100,200,300,400,500,600,700,800,900,1E3,1100,1200]}],collectables:[[3,3,3],[5,3,4],[5,5,5],[6,5,7],[8,6,7],[8,7,9],[10,7,8],[11,8,8],[10,10,10],[10,12,11],[12,13,11],[13,12,14],[14,13,15],[15,15,15],[16,15,17],[16,18,16],[18,17,16],[17,19,18],[18,20,
19],[20,20,20],[22,20,21],[22,21,23],[23,23,24],[24,23,25],[25,25,25]],minigames:{freespins:{rewards:[{freespins:5}]},pachinko:{rewards:[{multiplier:1,probability:.6},{multiplier:2,probability:.3},{multiplier:3,probability:.1},{credits:1,probability:.39},{credits:2,probability:.35},{credits:5,probability:.2},{credits:10,probability:.04},{credits:20,probability:.01}]},"pick-a-treasure":{rewards:[{multiplier:2},{multiplier:5},{credits:1},{credits:2},{credits:2},{credits:2},{credits:3},{freespins:5},
{freespins:10}]}},reels:{visibility:3,config:[[6,5,7,8,1,1,5,2,1,3,2,3,5,3,1,3,5,3,4,9,4,7,4,8,4],[9,6,5,7,8,1,5,1,4,2,3,3,5,3,4,3,1,5,4,6,4,6,4,4,5],[9,6,7,8,1,5,1,2,6,8,2,2,3,3,5,3,3,3,3,4,7,4,6,4,1],[9,6,7,8,1,1,2,5,2,2,3,5,3,6,3,3,5,1,3,4,8,4,3,2,4]]},winlines:[[1,1,1,1],[2,2,2,2],[0,0,0,0],[2,2,0,0],[0,0,2,2],[2,1,1,0],[0,1,1,2],[1,1,1,0],[0,1,1,1],[1,2,2,1],[2,2,1,1],[1,1,2,2],[2,2,2,0],[0,2,2,2],[0,0,0,1],[1,0,0,0],[1,0,1,2],[2,1,0,1],[1,2,1,2],[2,1,2,1],[0,1,0,0],[0,0,1,0],[1,1,0,0],[0,0,
1,1],[2,1,2,2],[2,2,1,2],[1,1,0,2],[2,0,1,1],[1,2,2,0],[0,2,2,1],[2,0,2,2],[2,2,0,2],[1,0,1,0],[0,1,0,1],[1,2,1,1],[1,0,1,1],[0,0,1,2],[2,1,0,0],[0,0,2,1],[1,2,0,0],[2,0,0,1],[1,0,0,2],[1,1,2,1],[1,1,2,1],[0,1,2,0],[0,2,1,0],[2,0,1,0],[0,1,0,2],[0,2,1,2],[2,1,2,0]],treasureWheel:[0,0,1,1,2,2,3,4],levels:[{collectibles:[6,7,8]},{levelsPerWorld:4},{startNumber:4},{increaseFactor:1.5000000000000004},{increaseFactorAfterWheel:1.0836718089664803}]},Cp={global:{ver:"1.0"},player:{curLevel:1,curScore:0,
curCoins:0,lastLines:0,lastBet:0,unlockedLines:0,unlockedBet:0,lastProgressPercentage:0,lastProgressAmount:0,collectableLevel:0,inventory:{},artefactChance:{maxLevel:51,target:.2,startPercentage:[.5,.3,.15,.05,0]},winningChance:{maxLevel:10,winFrequencyTarget:.1,payoutPercentageTarget:.5},tutorialStates:{0:!1,1:!1,2:!1,3:!1,4:!1,5:!1,6:!1,7:!1,8:!1,9:!1,10:!1},tutorialSpins:0,doubleUpAd:{lastAdTimer:0,timeToWait:0,timerRest:1},gameoverAd:{lastAdTimer:0,timeToWait:0,timerRest:1},moreCoins:{lastAdTimer:0,
timeToWait:0,timerRest:.25,coinPercentage:.1},artefact:{lastAdTimer:0,timeToWait:0,timerRest:1}},levels:{1:{objective:{progressLevel:0,col1:0,col2:0,col3:0},showIntroDialog:!1,showTutorialDialog:!1,tutorialStep:0},2:{objective:{progressLevel:0,col1:0,col2:0,col3:0},showIntroDialog:!1},3:{objective:{progressLevel:0,col1:0,col2:0,col3:0},showIntroDialog:!1},4:{objective:{progressLevel:0,col1:0,col2:0,col3:0},showIntroDialog:!1},5:{objective:{progressLevel:0,col1:0,col2:0,col3:0},showIntroDialog:!1}},
artifacts:{0:{amount:0,value:1E4},1:{amount:0,value:7500},2:{amount:0,value:5E3},3:{amount:0,value:2500},4:{amount:0,value:1E3}},ads:{interstitials:{wof:!1,level:!1}}};function uo(){this.db=null;this.AU=!1;this.Ev()}uo.prototype.Ev=function(){var a;a=qk.m.ea("Additional");this.AU&&(a=void 0);if(void 0===a)Hk(qk,JSON.stringify(Cp)),this.db=Cp;else try{this.db=JSON.parse(a)}catch(b){Hk(qk,JSON.stringify(Cp)),this.db=Cp}};function Lo(a,b){a.db.player.curCoins+=b;a.save()}
function Jo(a){a.db.player.unlockedLines<Z.bd.fixedLines.length-1&&(a.db.player.unlockedLines+=1);a.save()}uo.prototype.KA=function(){this.db.player.unlockedBet<Z.bd.fixedBet.length-1&&(this.db.player.unlockedBet+=1);this.save()};function Ho(a){a.db.ads.interstitials.level=!0;a.save()}function vp(a){a.db.ads.interstitials.wof=!0;a.save()}uo.prototype.save=function(){Hk(qk,JSON.stringify(this.db))};
function vo(a){this.R=a;this.wp=this.co=this.wZ=this.Ys=0;this.zS=10;this.PG=this.Oz=1;this.xS=2;this.RM=4;this.PJ=0;this.QM=.04;this.vr=.5;this.Rx=.7;this.Nz=.3;this.Sp=.7;this.UP=this.CV=.05;this.Du=this.Nz;this.ok=this.vr;this.tt=this.Rx;this.Jh=null;this.iu=0;this.wl=this.KG=3;this.ff=0;this.Vy=5;this.Uy=2;this.gm=this.Gl=0;this.uS=3;this.vS=2}
vo.prototype.jl=function(){this.rv=Z.ma.db.player.winningChance;this.Du=this.Nz;this.ok-=Math.abs(this.rv.winFrequencyTarget-this.vr)/this.rv.maxLevel*(Z.mg-1);this.Du+=Math.abs(this.rv.payoutPercentageTarget-this.Nz)/this.rv.maxLevel*(Z.mg-1)};
function Wo(a){parseFloat(Math.random().toFixed(3))<=a.ok?(a.ok=a.vr,a.jl(),a.PJ=Math.round(a.co*a.Du),a.Oz=Math.round(Math.random()*(a.xS-a.PG))+a.PG,parseFloat(Math.random().toFixed(3))<=a.QM&&(a.Oz=a.RM),a.wl=-1<a.R.nd?Math.round(Math.random()*(a.KG-a.iu))+a.iu:0,Dp(a,100)):(a.ok+=a.CV,a.wl=-1<a.R.nd?Math.round(Math.random()*(a.KG-a.iu))+a.iu:0,Ep(a))}function Ep(a){for(var b=[],c=[],d=0;d<a.R.ba.length;d++)b[d]=Fp(a,!1,c),c=b[d];a.ff=0;a.R.Jh&&a.R.Jh(b)}
function Dp(a,b){for(var c=[],d=[],g=0;g<a.R.ba.length;g++)c[g]=Fp(a,!0,d),d=c[g];a.Kw(c,b)}
function Fp(a,b,c){var d=[];if(b){c=1;var g=2;d[0]=Math.round(Math.random()*(a.R.$d.length-4));Z.Dd&&4===d[0]&&(d[0]=Math.floor(3*Math.random()));for(b=1;4>b;b++)for(k=!1;!k;)l=Math.round(Math.random()*(a.R.$d.length-1)),l===a.R.ih?a.Gl>=a.Uy||0===c||(a.Gl++,c--,d[b]=l,k=!0):l===a.R.Vc?a.gm>=a.Vy||0===g||(a.gm++,g--,d[b]=l,k=!0):9===l||10===l||11===l?a.ff>=a.wl||(a.ff++,d[b]=l,k=!0):(d[b]=l,k=!0)}else if(0<c.length)for(d[0]=Math.round(Math.random()*(a.R.$d.length-4)),Z.Dd&&4===d[0]&&(d[0]=Math.floor(3*
Math.random())),b=1;4>b;b++)for(var k=!1;!k;){for(var l=Math.round(Math.random()*(a.R.$d.length-1)),g=0,m=1;m<c.length;m++)l!==c[m]&&l!==a.R.ih&&l!==a.R.Vc||g++;0===g&&(9===l||10===l||11===l?a.ff>=a.wl||(a.ff++,d[b]=l,k=!0):(d[b]=l,k=!0))}else for(d[0]=Math.round(Math.random()*(a.R.$d.length-4)),Z.Dd&&4===d[0]&&(d[0]=Math.floor(3*Math.random())),b=1;4>b;b++)for(k=!1;!k;)l=Math.round(Math.random()*(a.R.$d.length-1)),l!==a.R.ih&&l!==a.R.Vc&&(9===l||10===l||11===l?a.ff>=a.wl||(a.ff++,d[b]=l,k=!0):(d[b]=
l,k=!0));return d}
vo.prototype.Kw=function(a){for(var b=[],c=1;4>c;c++){for(var d=[],g=0;g<this.R.ba.length;g++)d.push(new Gp(0,0,a[g][c],!0));b.push(d)}for(d=c=0;d<this.R.ye;d++){for(var k=0,l=-1,m=!1,p=-1,g=-1,w=0;w<this.R.ba.length;){var z=this.R.dk[d][w],v=b[z][w].type;v!=this.R.Vc?(p=b[z][w],l=v):(p=b[z][w],m=!0);break}0>l&&m&&(l=this.R.Vc);for(w=1;w<this.R.ba.length;w++)if(z=this.R.dk[d][w],v=b[z][w].type,l===this.R.Vc&&v!==this.R.Vc&&-1===g&&(g=b[z][w]),l===v||this.R.Vc===v)k++;else if(l===this.R.Vc&&g.type===
v&&v!==this.R.ih||this.R.Vc===v)k++;else break;0<k&&(0===p.Pf.type?(k=p.Pf.payouts[k],c+=k):3===p.Pf.type&&-1<g?(k=g.Pf.payouts[k],console.log("AFTER WILD: "+g),c+=k):3===p.Pf.type&&3===k&&(k=p.Pf.payouts[k],c+=k))}b=this.R.ie*c;if(b>this.PJ*this.Oz||0===b)try{Dp(this)}catch(C){Ep(this)}else this.gm=this.Gl=this.ff=0,this.co=0<this.co-b?this.co-b:0,this.R.Jh&&this.R.Jh(a)};
function Xo(a){var b=[];a=Hp(0,a?2:3);for(var c=0;4>c;c++)if(-1!==a.indexOf(c))for(var d=Hp(1,1),g=0;4>g;g++)d===g&&b.push({fm:c,tr:g});else b.push({fm:c,tr:-1});return b}function Hp(a,b){for(var c=[],d=[],g=a;4>g;g++)c.push(g);for(g=0;g<b;g++){var k=Math.floor(Math.random()*c.length);1===b?(k=c.splice(k,1),d=k[0]):(k=c.splice(k,1),d.push(k[0]))}return d}
function jn(){return{af:[{name:"",Xr:"",Js:{},wj:{},Bh:{mode:"",kp:1,lp:1,mp:1,Gt:1},At:{},El:{lv:1E6}},{name:"",Xr:"",Js:{},wj:{},Bh:{mode:"",kp:4,lp:4,mp:4,Gt:1},At:{},El:{lv:1E3}},{name:"",Xr:"",Js:{},wj:{},Bh:{mode:"",kp:4,lp:4,mp:4,Gt:1},At:{},El:{lv:1E3}},{name:"",Xr:"",Js:{},wj:{},Bh:{mode:"",kp:4,lp:4,mp:4,Gt:1},At:{},El:{lv:1E3}},{name:"",Xr:"",Js:{},wj:{},Bh:{mode:"",kp:4,lp:4,mp:4,Gt:1},At:{},El:{lv:1E3}}]}}
function hn(){var a={},a={};a.Tj={main:{width:y(1080),height:y(1920),items:[{x:y(0),y:y(0),id:"background",c:Zg,W:0}]},tH:["main"]};return a}function kn(){var a={};return a={Tj:{page:{zE:[{x:-139,y:591},{x:26,y:223},{x:121,y:-59},{x:-251,y:-295},{x:-205,y:-601}]},tH:["page"]},buttons:{points:{width:103,height:94},type:{width:103,height:94},counter:{width:103,height:94},"":{}}}}
function yo(a,b){this.depth=-1E3;this.W=0;this.D=this.visible=!0;this.c=Pg;0===a&&(a=y(1));this.x=a;this.y=y(b);this.canvas=r.k;Mb(this);Ob(this,"slot")}yo.prototype.Za=function(){};yo.prototype.Qa=function(){};function rp(a){"border"===a.c.name?a.c=Qg:"borderBlue"===a.c.name&&(a.c=Pg)}yo.prototype.Ha=function(){wa(this.c,this.x,this.y)};
function Do(a,b,c,d,g){this.W=this.depth=0;this.D=this.visible=!0;this.canvas=c;this.x=a;this.y=b;this.R=g;this.Kn=d;this.bd=wo;this.qv=this.bd.reels.config[this.Kn];this.Vn=0;this.Zd=[];this.TB=this.VB=!1;this.Y=new kc(this);this.Wz=[];this.sw=this.Bt=!1;Mb(this);Ob(this,"slot")}e=Do.prototype;
e.Za=function(){this.Vn=Math.floor(Math.random()*this.qv.length);for(var a=this.y,b=0;3>b;b++)this.Zd[b]=a,a-=y(290);this.$i=[];a=this.Zd[0]+y(290);for(b=0;4>b;b++){var c=new Gp(this.x,a,this.qv[this.Vn]-1);c.canvas=this.canvas;Ip(this);a-=y(290);c.So=this;this.$i.push(c)}};e.wN=function(a){if(a.SC){var b=a.SC;b.id===a.Kn&&Xb(q,b)}3===a.Kn&&a.R.Kw();U.play(mj);var b=a.Kn,c=Z;3>b&&(b=c.ba[b+1],b.Bt&&(b.SC=new Jp(b.x+y(376),y(1470),-1300,b.Kn),U.play(kj),b.Bt=!1));a.sw=!1};e.vN=function(a){Yo(a.Kn)};
e.LA=function(){this.VB=!0};e.startTime=function(a){rc(this.Y);this.Y.setTime(0);0===a?this.Sl():pc(this.Y,this,a,this.Sl)};e.Sl=function(){this.TB=this.VB=!1;this.pu&&Xb(q,this.pu[1]);for(var a=0;a<this.$i.length;a++){this.$i[a].bt=this.Zd[0]+y(290);var b=this.Zd[0]+y(291);this.$i[a].kf=b;b=this.Zd[0]+y(291);this.$i[a].Lf=b;this.$i[a].sv=!1;this.$i[a].Yh=!0}};function Ip(a){var b=a.Vn+=1;a.Vn=b>a.qv.length-1?0:b}e.Qa=function(){};e.wa=function(a){this.Y.Vb(a)};e.Sa=function(){};e.qb=function(){};
e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){};
function Gp(a,b,c,d){this.depth=-100;this.W=0;this.D=this.visible=!0;this.x=a;this.y=b;this.Ra=null;this.type=c;this.Xl=this.x;this.Lf=this.kf=0;this.speed=30;this.$d=[L.ed,L.ed,L.ed,L.ed,Ke,L.ed,L.ed,L.ed,L.ed,Le,Me,Ne];this.Pf=wo.symbols[this.type];this.GI=Li;this.offset=0;this.Sn={0:{still:"symbol7Still",animation:"symbol7",stillBlue:"symbol7Still",animationBlue:"symbol7"},1:{still:"symbol6Still",animation:"symbol6",stillBlue:"symbol6Still",animationBlue:"symbol6"},2:{still:"symbol5Still",animation:"symbol5",
stillBlue:"symbol5BlueStill",animationBlue:"symbol5Blue"},3:{still:"symbol4Still",animation:"symbol4",stillBlue:"symbol4BlueStill",animationBlue:"symbol4Blue"},4:{still:"",animation:"",stillBlue:"",animationBlue:""},5:{still:"symbol3Still",animation:"symbol3",stillBlue:"symbol3BlueStill",animationBlue:"symbol3Blue"},6:{still:"symbol2Still",animation:"symbol2",stillBlue:"symbol2BlueStill",animationBlue:"symbol2Blue"},7:{still:"symbol1Still",animation:"symbol1",stillBlue:"symbol1BlueStill",animationBlue:"symbol1Blue"},
8:{still:"symbolWildStill",animation:"symbolWild",stillBlue:"symbolWildBlueStill",animationBlue:"symbolWildBlue"}};this.Qj=this.xA=this.qI=this.Ju=this.Yh=this.sv=!1;this.bt=this.So=this.c=void 0;this.EE=!1;jc([cc,ic],[!1,!0]);this.JS=this.depth;this.tS=-150;this.$=void 0;"symbolScatter"===this.$d[this.type].name&&(this.depth=-110,this.Qj=!0);void 0===d&&(Mb(this),Ob(this,"slot"));this.VI=!1;this.yu=void 0}e=Gp.prototype;
e.Za=function(){!this.Qj&&9>this.type&&(this.$=1>Z.Dd?new Kp({$:this.GI,clip:this.Sn[this.type].still},this):new Kp({$:this.GI,clip:this.Sn[this.type].stillBlue},this))};e.Qa=function(){this.$&&Xb(q,this.$)};e.Yq=function(){!1===Z.Ft&&this.$?this.$.$.Rc(this.Sn[this.type].animation,!1):this.$.$.Rc(this.Sn[this.type].animationBlue,!1)};function tp(a){a.$&&a.$.$.Rc(a.Sn[a.type].still,!1)}function yp(a){a.$&&a.$.$.Rc(a.Sn[a.type].stillBlue,!1)}function sp(a){a.type=4;a.xA=!1;a.Qj=!0;Nb(a,-110)}
function xp(a,b){switch(b){case 0:a.type=9;break;case 1:a.type=10;break;case 2:a.type=11}Yb("scatter");a.Qj=!1}
e.wa=function(){if(this.Yh){var a=this.Xl-this.x,b=this.Lf-this.y,a=Math.sqrt(a*a+b*b),b=b/a*this.speed;isNaN(b)&&(b=0);b>a&&(b=a);0<a?this.y+=b:(this.y=this.Lf,this.Ju=!0,this.Yh=!1)}if(this.bt&&this.y>this.bt){if(this.So&&!this.EE){b=this.So;if(b.VB){if(!b.TB){b.pu=[];b.Xb=[];b.$i=[];var c=b.Zd[2]-y(290),a=Math.floor(8*Math.random());0<Z.Dd&&4===a&&(a=Math.floor(3*Math.random()));b.Wz.push(a);for(var d=0;5>d;d++){a=new Gp(b.x,c,b.Wz[d]);Ip(b);a.canvas=b.canvas;a.So=b;a.Yh=!0;c-=y(290);if(0===d){var g=
b.Zd[0]+y(290);a.kf=g;a.sv=!0;g=b.Zd[0]+y(290);a.Lf=g;b.pu.push(a);a.Ra=b;a.yu=b.wN}else if(4>d)g=b.Zd[d-1]+y(145),a.Lf=g,a.kf=b.Zd[d-1],a.sv=!0,b.Xb.push(a);else{c=b.Zd[2]-y(290)+y(145);a.Lf=c;c=b.Zd[2]-y(290);a.kf=c;a.sv=!0;b.pu.push(a);a.Ra=b;a.yu=b.vN;break}b.$i.push(a)}b.TB=!0}}else a=b.qv[b.Vn]-1,0<Z.Dd&&4===a&&(a=Math.floor(3*Math.random())),a=new Gp(b.x,b.Zd[2]-y(290),a),a.canvas=b.canvas,a.bt=b.Zd[0]+y(290),a.So=b,Ip(b),c=b.Zd[0]+y(291),a.kf=c,b=b.Zd[0]+y(291),a.Lf=b,a.Yh=!0;this.Yh=!1;this.EE=
!0}Xb(q,this)}this.Ju&&(a=this.Xl-this.x,b=this.kf-this.y,a=Math.sqrt(a*a+b*b),b=b/a*this.speed/5,isNaN(b)&&(b=0),b>a&&(b=a),0<a?this.y+=b:(this.y=this.kf,this.Ju=!1,this.qI=!0));this.Ju||!this.qI||this.VI||(this.yu&&this.yu(this.Ra),this.VI=!0)};function ip(a){Nb(a.$,a.tS)}function lp(a){Nb(a.$,a.JS)}e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){!this.Qj&&this.$&&this.$.move({x:this.x,y:this.y})};
e.Ha=function(){this.Qj&&(this.xA||this.$d[this.type].B(0,this.x,this.y));8<this.type&&this.$d[this.type].B(0,this.x,this.y)};function hp(a,b,c,d){this.depth=c;this.W=0;this.D=this.visible=!0;this.x=a;this.y=b;this.h=Di.Zc();this.id=d;Mb(this);Ob(this,"fx")}e=hp.prototype;e.Za=function(){var a=this;this.h.Rc("animation",!1);vc(this.h,function(){kp(a.id);Yb(a)})};e.Qa=function(){};e.wa=function(a){this.h.Vb(a)};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};
e.xb=function(){};e.Ga=function(){};e.Ha=function(){this.h.B(this.x,this.y)};function wp(a){this.depth=-150;this.W=0;this.D=this.visible=!0;this.R=a;this.ZF=!1;this.y=this.x=0;Mb(this)}e=wp.prototype;e.Za=function(){Ub("ui")};e.Wm=function(){this.po=this.canvas=gk({wf:0,xf:0,uh:r.O,th:r.M});this.fm=new Lp({po:this.po,Ra:this,Ys:this.R.mf.ea(),ac:[jg,kg,lg,mg,ng],bG:["GOLD FLOWER","GOLD BUTTERFLY","GOLD FEATHER","GOLD FROG","GOLD BEETLE"],mc:this.yQ,P:this.CQ});this.fm.show();this.ZF=!0;U.play(ej)};
e.CQ=function(a){Z.kh();Xb(q,a)};e.yQ=function(){};e.Ha=function(){};e.Qa=function(){this.fm.I();this.fm.i();hk(this.po);Wb("ui")};e.Ga=function(a){this.ZF&&Mp(this.fm,a)};
function cp(a,b){this.depth=-1E3;this.W=-1100;this.D=this.visible=!0;this.canvas=b.canvas;this.aa=void 0===b.aa?0:b.aa;this.u=void 0===b.u?0:b.u;this.Aa=void 0===b.Aa?0:b.Aa;this.G=void 0===b.G?0:b.G;this.duration=void 0===b.duration?-1:b.duration;this.value=void 0===b.value?0:b.value;this.Ne=void 0===b.Ne?!0:b.Ne;this.Wc=void 0===b.Wc?-1:b.Wc;this.L=void 0===b.L?0:b.L;this.Nb=void 0===b.Nb?1:b.Nb;this.uf=void 0===b.uf?null:b.uf;this.A=void 0===b.A?null:b.A;this.clip=void 0===b.clip?null:b.clip;this.aa+=
Z.Cc;this.Aa+=Z.Cc;this.c=a;this.BJ=!1;this.time=0;this.aa-=this.c.width/2;this.u-=this.c.height/2;this.DH=!0;this.x=this.aa;this.y=this.u;this.Ok=this.Aa-this.aa;this.Pk=this.G-this.u;this.scale=void 0===b.scale?1:b.scale;this.fx=this.Nb-this.scale;var c=Math.sqrt(this.Ok*this.Ok+this.Pk*this.Pk);-1===this.duration&&(this.duration=300+.8*c);-1===this.Wc&&(this.Wc=300+.5*c);this.tB=this.duration/2;this.Oa=0;this.Ne&&(this.$H=(40*Math.random()+50)*(.5<Math.random()?1:-1));Mb(this)}
cp.prototype.Qa=function(){0!==this.value&&(this.uf&&this.uf.Md(this.value,!0),this.A&&(this.uf.ea()===this.uf.target&&(this.BJ=!0),new Np(this.Aa,this.G,this.A,this.clip,void 0,this.BJ,this.uf)))};
cp.prototype.Ga=function(a){0<this.L?this.L-=a:(this.DH&&(U.play(aj),this.DH=!1),this.Ne&&(this.Oa+=a/1E3*this.$H),this.time+=a,a=ac(this.time,0,1,this.duration,2),this.time>this.tB&&(this.x=this.aa+a/1*this.Ok,this.y=this.u+a/1*this.Pk,this.y+=this.Wc*(a*a-a)),this.scale=hc(this.time,this.scale,this.fx,this.duration),this.time>=this.duration&&(this.x=this.Aa,this.y=this.G,Xb(q,this)))};cp.prototype.Ha=function(){0<this.L||this.c.ib(0,this.x,this.y,this.scale,this.scale,this.Oa,1)};
function Jp(a,b,c,d){this.depth=c;this.W=0;this.D=this.visible=!0;this.h=Ei.Zc();this.id=d;this.x=Z.Cc+a;this.y=b;Mb(this)}e=Jp.prototype;e.Za=function(){this.h.Rc("animation2",!0)};e.Qa=function(){};e.wa=function(a){this.h.Vb(a)};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){this.h.B(this.x,this.y)};
function Np(a,b,c,d,g,k,l,m,p,w,z){this.depth=-900;this.W=-901;this.D=this.visible=!0;this.A=c;this.text=g;this.uM=d;this.$=Gi;this.eW=k;this.fW=l;this.Rf=m;this.AV=p;this.id=w;this.QE=z;this.x=a;this.y=b;Mb(this);Ob(this,"col")}e=Np.prototype;e.Za=function(){var a=this;this.ds=this.$.Zc();this.ds.Rc(this.uM,!1);vc(this.ds,function(){Xb(q,a)});this.A.i()};
e.Qa=function(){this.A.show();this.text&&(this.text.show(),this.text.ka(),this.text.Ta(this.Rf,!0));this.eW&&new Op(this.x-Z.Cc,this.y,this.fW,this.A);if(this.AV){var a=new Pp(this.x-Z.Cc,this.y,this.id,this.A);Z.Mg.push(a)}this.QE&&this.QE()};e.wa=function(a){this.ds.Vb(a)};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){this.ds.B(this.x,this.y)};
function zp(a){this.W=this.depth=0;this.D=this.visible=!0;this.c=Sh;this.Cd=a;this.R=Z;this.alpha=this.y=this.x=0;this.Y=new kc(this);this.canvas=Z.ym;Mb(this)}e=zp.prototype;e.Za=function(){var a,b=this,c=300;this.Y.setTime(0);a=lc(this.Y,"function",this,function(a){this.alpha=a});mc(this.Y,a,[{time:0,value:0},{time:500,value:1}]);for(a=0;3>a;a++)c+=300*a,pc(this.Y,this,c,b.GO,a);c+=1200;Z.F&&!Z.io?pc(this.Y,this,c,function(){b.R.F.zQ=!0}):pc(this.Y,this,c,function(){b.R.kh()})};
e.GO=function(a){0===a&&Z.oe.Rh.fb(Z.oe.Rh.Pb.jj);var b=!1;switch(a){case 0:this.Cd[a].Rf>=Z.nf&&(this.Cd[a].clip="animCollect1Gold",b=!0);break;case 1:this.Cd[a].Rf>=Z.of&&(this.Cd[a].clip="animCollect2Gold",b=!0);break;case 2:this.Cd[a].Rf>=Z.pf&&(this.Cd[a].clip="animCollect3Gold",b=!0)}new Np(Z.Cc+this.Cd[a].x,this.Cd[a].y,this.Cd[a].A,this.Cd[a].clip,this.Cd[a].text,void 0,void 0,this.Cd[a].Rf,b,a,this.Cd[a].call)};e.Qa=function(){};e.wa=function(a){this.Y.Vb(a)};e.Sa=function(){};e.qb=function(){};
e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){ya(this.c,this.x,this.y,1,1,this.alpha)};function zo(a,b){this.depth=-100;this.W=0;this.D=this.visible=!0;this.canvas=Z.ym;this.x=Z.Cc+y(20);this.y=y(b);Mb(this)}e=zo.prototype;e.Za=function(){};e.Qa=function(){};e.wa=function(){};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){wa(Yg,this.x,this.y)};
function op(a,b,c){this.depth=-1600;this.W=0;this.D=this.visible=!0;this.offsetY=c;this.x=r.O/2;this.y=r.M/2;this.canvas=Z.Ac;this.$=Ni;this.mi=this.$.Zc();this.clip=a;this.Qb=b;this.L=500;this.play=!1;Mb(this)}e=op.prototype;e.Za=function(){var a=this;this.offsetY&&(this.y+=this.offsetY);this.mi.Rc(this.clip,!1);U.play(ej);vc(this.mi,function(){a.Qb();Xb(q,a)})};e.Qa=function(){};e.wa=function(a){0<this.L?this.L-=a:this.mi.Vb(a)};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};
e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){0<this.L||this.mi.B(this.x,this.y)};function ep(a){this.depth=-1600;this.W=0;this.D=this.visible=!0;this.x=r.O/2;this.y=r.M/2;this.$=Ni;this.clip="bigWin";this.mi=this.$.Zc();this.canvas=Z.Ac;this.Eb=a;Mb(this);Ob(this,"fx")}e=ep.prototype;
e.Za=function(){var a=this;new Qp(r.O/2,r.M/2,this.Eb);dp(Z,Z.xe);this.mi.Rc(this.clip,!0);vc(this.mi,function(){Xb(q,a)});this.UB=new yc({canvas:this.canvas,depth:-1700});this.wj=new oo({md:".",width:r.O,height:y(900),Db:ki,Wb:Z.Cc+y(540,"round"),Ob:y(1200,"round")});this.UB.d(this.wj);this.UB.show();this.wj.Md(this.Eb)};e.Qa=function(){Z.mf.Md(this.Eb);Lo(Z.ma,this.Eb);Fo(this.Eb);this.UB.i();this.Eb=0};e.wa=function(a){this.mi.Vb(a)};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};
e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){this.mi.B(this.x,this.y)};function fp(a){this.depth=-1300;this.W=0;this.D=this.visible=!0;this.Eb=a;this.jn=7;this.y=this.x=0;this.L=1500;this.play=!0;Mb(this);Ob(this,"fx")}fp.prototype.Za=function(){dp(Z,Z.xe)};fp.prototype.wa=function(a){0<this.L?this.L-=a:this.play&&(this.sp(),this.play=!1)};
fp.prototype.sp=function(){var a=this;U.play(dj);for(var b=100,c=0;c<this.jn;c++)new Rp({aa:Z.Cc+Z.fj.x+Z.fj.Ve,u:Z.fj.y+Z.fj.We,Aa:Z.Cc+Z.ui.x,G:Z.ui.y,L:b,$:Ji,clip:"coinspin2",canvas:Z.Ac,id:c,sq:a.jn,gu:3,Bl:function(){Z.mf.Md(a.Eb);Lo(Z.ma,a.Eb);Fo(a.Eb);a.Eb=0},mc:function(){Xb(q,a)}}),b+=100};fp.prototype.Qa=function(){Z.mf.Md(this.Eb);Lo(Z.ma,this.Eb);Fo(this.Eb);this.Eb=0};
function Qo(a){this.depth=-1600;this.W=0;this.D=this.visible=!0;this.VQ=[$g,ah,bh,ch];this.JH=[{x:y(15),y:y(563)},{x:y(10),y:y(525)},{x:y(9),y:y(495)},{x:y(9),y:y(505)}];this.La=2E3;this.oV=a+1;this.x=y(0);this.y=y(0);this.canvas=Z.Ac;Mb(this)}e=Qo.prototype;e.Za=function(){};e.Qa=function(){};e.wa=function(){};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(a){this.La-=a;0>this.La&&Xb(q,this)};
e.Ha=function(){for(var a=0;a<this.oV;a++)this.VQ[a].B(0,Z.Cc+this.JH[a].x,this.JH[a].y)};
function Ao(a){this.depth=-2900;this.W=0;this.D=this.visible=!0;this.x=r.O/2;this.y=r.M/2;this.c=Sf;this.eu=Lf;this.canvas=a;this.Ss=0;this.fp=this.Br=!1;this.buttons=[];this.Ag={xv:0,TX:1,SX:2,RX:3,QX:4,dL:5,cL:6,yv:7,bC:8,yX:9,eL:10};this.Nv={0:{jB:1,Yh:0},1:{jB:5,Yh:1},2:{jB:10,Yh:2}};this.ho={0:{tg:2,og:[{action:!1,kind:"",dc:null},{action:!1,kind:"",dc:null},{action:!0,kind:"spin",dc:6}],Qb:function(){},za:["firsttime_start_dia1","firsttime_start_dia2","firsttime_spinbutton"]},1:{tg:1,og:[{action:!1,
kind:"",dc:null},{action:!1,kind:"",dc:null}],Qb:function(){},za:["firsttime_winlinehit_dia1","firsttime_winlinehit_dia2"]},2:{tg:0,og:[{action:!1,kind:"",dc:null}],Qb:function(){},za:["firsttime_scatter_dia1"]},3:{tg:0,og:[{action:!1,kind:"",dc:null}],Qb:function(){Z.io=!0;Z.kh()},za:["firsttime_scattercomplete_dia1"]},4:{tg:0,og:[{action:!0,kind:"",dc:null}],Qb:function(){},za:["firsttime_scattercomplete_dia2"]},5:{tg:0,og:[{action:!0,kind:"line",dc:2}],Qb:function(){},za:["firsttime_winlineunlock_dia1"]},
6:{tg:0,og:[{action:!0,kind:"bet",dc:4}],Qb:function(){},za:["firsttime_betunlock_dia1"]},7:{tg:0,og:[{action:!0,kind:"wheel",dc:null}],Qb:function(){},za:["firsttime_wofspinbutton"]},8:{tg:0,og:[{action:!0,kind:"gallery",dc:1}],Qb:function(){},za:["firsttime_collectionbutton"]},9:{tg:0,og:[{action:!0,kind:"more",dc:7}],Qb:function(){},za:["firsttime_warning_dia1"]},10:{tg:0,og:[{action:!0,kind:"",dc:null}],Qb:function(){},za:["firsttime_replay_dia1"]}};this.continue=!1;this.zQ=!0;this.Zs=this.Qe=
null;this.Rb=0;this.um=this.Mn=this.Ol=null;this.Vu=this.bh=-1;Mb(this)}e=Ao.prototype;e.Za=function(){Sp()};function Tp(a){hk(a.canvas);a.context=void 0}e.od=function(a){this.buttons.push(a)};e.Ii=function(a){if(0!==this.buttons.length)if(a)this.buttons[a].ga();else for(a=0;a<this.buttons.length;a++)this.buttons[a].ga()};e.mh=function(a){if(0!==this.buttons.length)if(a)this.buttons[a].ka();else for(a=0;a<this.buttons.length;a++)this.buttons[a].ka()};e.lr=function(a){this.Ol=a};
e.fb=function(a){!0!==Z.ca.player.tutorialStates[a]&&(this.fp=!1,this.ee&&(this.ee.i(),Tp(this),this.ee=void 0),this.Ii(),this.state=a,this.Zs=this.ho[this.state].tg,this.Qe=this.ho[this.state].og,this.um=this.ho[this.state].za,this.Rb=0,this.canvas=gk({wf:0,xf:0,uh:r.O,th:r.M}),this.context=this.canvas.getContext("2d"),this.ee=new Up({Ra:this,canvas:this.canvas,x:this.x,y:this.y,state:this.state,Ya:this.context}),this.ee.show(),this.Qe[this.Rb].dc&&this.mh(this.Qe[this.Rb].dc),a!==this.Ag.yv&&a!==
this.Ag.cL&&a!==this.Ag.dL?(this.Br=!0,this.Ss=1E3):this.fp=!0)};function Eo(a){return!1===Z.ca.player.tutorialStates[a]?!0:!1}e.Qa=function(){hk(this.canvas);this.ee.i();Tp(this);this.ee=void 0;Z.F=void 0};
e.Sa=function(){this.fp&&void 0!==this.ee&&(this.Rb<this.Zs?!1===this.Qe[this.Rb].action&&""===this.Qe[this.Rb].kind&&(this.Rb++,this.ee.nr(this.Rb),this.Qe[this.Rb].dc&&this.mh(this.Qe[this.Rb].dc),Z.za.Ka(this.um[this.Rb])):(""===this.Qe[this.Rb].kind&&(Z.za.Ka(this.um[this.Rb]),Z.ma.db.player.tutorialStates[this.state]=!0,Z.ma.save(),this.ee.i(),Tp(this),this.ee=void 0,3!==this.state&&4!==this.state&&this.mh()),Sp()),this.Ol&&(this.Ol(),this.Ol=void 0))};
function Mo(a,b){a.fp&&void 0!==a.ee&&(a.Rb<a.Zs?!0===a.Qe[a.Rb].action&&b===a.Qe[a.Rb].kind&&(a.Rb++,a.ee.nr(a.Rb),a.Qe[a.Rb].dc&&a.mh(a.Qe[a.Rb].dc),Z.za.Ka(a.um[a.Rb])):(b===a.Qe[a.Rb].kind&&(Z.za.Ka(a.um[a.Rb]),Z.ma.db.player.tutorialStates[a.state]=!0,Z.ma.save(),a.ee.i(),Tp(a),a.ee=void 0,3!==a.state&&4!==a.state&&a.mh()),Sp()),a.Ol&&(a.Ol(),a.Ol=void 0))}
function Sp(){if(Z.ma.db.player)Z.ma.db.player.tutorialStates[5]=!1,Z.ma.db.player.tutorialStates[6]=!1,Z.ma.save();else{var a=Z.ma;Hk(qk,JSON.stringify(Cp));a.db=Cp;a.save();window.location.reload(!0)}}e.pause=function(){};e.Ha=function(){if(this.ee){var a=this.ee;a.pause||(f.clear(),a.Ya.save(),a.WQ.ib(0,y(0),y(0),10,6.5,0,1),a.Ya.globalCompositeOperation="destination-out",a.c.ib(0,Z.Cc+a.ve[a.id].x,a.ve[a.id].y,a.cf[a.id],a.df[a.id],0,1),a.Ya.restore())}};
e.wa=function(a){this.Br&&(this.Ss-=a,0>=this.Ss&&(this.Br=!1,this.fp=!0))};function jp(a,b,c,d,g,k){this.depth=-109;this.W=0;this.D=this.visible=!0;this.x=b;this.y=c;this.c=gh;this.Oa=0;this.Lu=1;this.PO=d;this.QO=g;this.canvas=Z.Tm;this.id=a;this.speed=100;this.SJ=!1;this.mH=k}e=jp.prototype;
e.Za=function(){3<=this.id?Xb(q,this):(this.Zf=this.PO-this.x,this.Re=this.QO-this.y,this.yW=Math.sqrt(this.Zf*this.Zf+this.Re*this.Re)/y(8),this.Oa=-(180/Math.PI*Math.atan2(this.Re,this.Zf)),0>this.Oa&&(this.Oa+=360))};e.Qa=function(){};e.wa=function(){};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(a){a/=1E3;this.Lu<this.yW?this.Lu+=this.speed*a:this.mH&&!this.SJ&&(this.mH(this.id+1),this.SJ=!0)};
e.Ha=function(){this.c.ib(0,this.x,this.y,this.Lu,1,this.Oa,1)};function Bo(a,b,c,d,g){this.W=this.depth=0;this.D=this.visible=!0;this.y=this.x=0;this.ar=g;this.Eb=-1;this.aU=b;this.IH=0;this.uH=2.1;this.transition=0;this.Nw=y(140);this.duration=.25;this.Or=0;this.$n=3;this.Pb={Yr:0,jj:1,xk:2,as:3,CX:4};this.state=-1;Mb(this)}e=Bo.prototype;e.Za=function(){this.fb(this.Pb.Yr)};e.Qa=function(){};e.wa=function(){};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};
e.xb=function(){};
e.Ga=function(a){switch(this.state){case this.Pb.jj:this.ar.y=ic(this.transition,this.aU,-this.Nw,this.duration,this.uH);this.transition<this.duration?this.transition=Math.min(this.transition+a/1E3,this.duration):(this.IH=this.ar.y,this.fb(this.Pb.as));break;case this.Pb.as:this.Or<this.$n?this.Or+=a/1E3:this.Or>=this.$n&&this.fb(this.Pb.xk);break;case this.Pb.xk:this.ar.y=hc(this.transition,this.IH,this.Nw,this.duration,this.uH),this.transition<this.duration?this.transition=Math.min(this.transition+a/
1E3,this.duration):this.fb(this.Pb.Yr)}};e.Ha=function(){};e.fb=function(a){if(this.state!==a)switch(this.state=a,this.state){case this.Pb.Yr:Z.sg===this&&(this.Eb=0,Z.fj.Ta(this.Eb,!0));break;case this.Pb.xk:this.transition=0;break;case this.Pb.as:this.Or=0}};function ap(a,b,c,d){this.depth=c;this.W=0;this.D=this.visible=!0;this.x=a;this.y=b;this.canvas=d;this.font=new Fa(gi.l);this.$V="";this.s="ui_freespinsremaining";this.FI=E(this.s).replace("{0}",this.$V);this.pI=!1;this.Rh=void 0;Mb(this)}
e=ap.prototype;e.Za=function(){this.font.f({fontSize:28,fill:!0,fillColor:"#ffffff",align:"center",ua:"middle"});this.Rh=new Bo(0,this.y,0,0,this);this.Rh.$n=1E6;this.Rh.Nw=y(125)};e.Qa=function(){Xb(q,this.Rh)};e.wa=function(){};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){!0===this.pI&&this.Rh.state===this.Rh.Pb.Yr&&Xb(q,this)};function bp(a,b){a.FI=E(a.s).replace("{0}",b)}
e.Ha=function(){ef.B(0,this.x,this.y);this.font.B(this.FI,this.x+df.width/2,this.y+df.height/2-y(70),df.width)};function Vo(a){a.pI=!0;a.Rh.fb(a.Rh.Pb.xk)}
function Vp(a,b,c){this.depth=c;this.W=0;this.D=this.visible=!0;this.canvas=b.canvas;this.aa=void 0===b.aa?0:b.aa;this.u=void 0===b.u?0:b.u;this.Aa=void 0===b.Aa?0:b.Aa;this.G=void 0===b.G?0:b.G;this.duration=void 0===b.duration?-1:b.duration;this.value=void 0===b.value?0:b.value;this.Ne=void 0===b.Ne?!0:b.Ne;this.Wc=void 0===b.Wc?-1:b.Wc;this.tv=void 0===b.tv?-1:b.Wc;this.L=void 0===b.L?0:b.L;this.Nb=void 0===b.Nb?1:b.Nb;this.clip=void 0===b.clip?null:b.clip;this.mc=void 0===b.mc?null:b.mc;this.jn=
b.jn;this.Sw=b.id;this.$=a.Zc();this.time=0;this.x=this.aa;this.y=this.u;this.Ok=this.Aa-this.aa;this.Pk=this.G-this.u;this.scale=void 0===b.scale?1:b.scale;this.fx=this.Nb-this.scale;a=Math.sqrt(this.Ok*this.Ok+this.Pk*this.Pk);-1===this.duration&&(this.duration=300+.8*a);-1===this.Wc&&(this.Wc=300+.5*a);-1===this.tv&&(this.tv=300+.5*a);this.tB=0;this.Oa=Math.round(360*Math.random());this.Ne&&(this.$H=(40*Math.random()+50)*(.5<Math.random()?1:-1));Mb(this);Ob(this,"fx")}e=Vp.prototype;
e.Za=function(){this.$.Rc(this.clip,!0)};e.Qa=function(){this.mc&&this.Sw===this.jn-1&&this.mc()};e.wa=function(a){0<this.L?this.L-=a:(this.$.Vb(a),this.time+=a,a=ac(this.time,0,1,this.duration,2),this.time>this.tB&&(this.x=this.aa+a/1*this.Ok,this.y=this.u+a/1*this.Pk,this.y+=this.Wc*(a*a-a)),this.scale=hc(this.time,this.scale,this.fx,this.duration),this.time>=this.duration&&(this.x=this.Aa,this.y=this.G,Xb(q,this)))};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};
e.xb=function(){};e.Ga=function(){};e.Ha=function(){0<this.L||this.$.ib(this.x,this.y,this.scale,this.scale,this.Oa,1)};function Qp(a,b,c){this.W=this.depth=0;this.D=this.visible=!0;this.x=a;this.y=b;this.ZD=120;this.OK=y(-100);this.wX=r.M+y(100);this.NK=y(-100);this.uX=r.O+y(100);this.L=900;this.play=!0;this.Eb=c;Mb(this);Ob(this,"fx")}Qp.prototype.Za=function(){};Qp.prototype.wa=function(a){0<this.L?this.L-=a:this.play&&(this.sp(),U.play(Yi),this.play=!1)};
Qp.prototype.sp=function(){var a=this;Z.fj.Ta(this.Eb);for(var b=0;b<this.ZD;b++){Math.random();y(200);y(-200);y(-200);var c=Math.random()*(this.uX-this.NK)+this.NK,d=Math.random()*(this.wX-this.OK)+this.OK;new Vp(Ji,{canvas:Z.Ac,aa:a.x,u:a.y,Aa:c,G:d,tv:0,Wc:0,clip:"coinspin1",duration:700,scale:1.2,Nb:1.2,L:27*b,jn:a.ZD,id:b,mc:function(){Xb(q,a)}},-1400)}};Qp.prototype.Qa=function(){};
function Rp(a){this.depth=-3200;this.W=-3100;this.D=this.visible=!0;this.x=a.aa;this.y=a.u;this.$=a.$.Zc();this.aa=a.aa;this.u=a.u;this.Aa=a.Aa;this.G=a.G;this.L=a.L||0;this.clip=a.clip;this.canvas=a.canvas;this.id=void 0===a.id?-1:a.id;this.sq=void 0===a.sq?0:a.sq;this.gu=void 0===a.id?-1:a.gu;this.time=0;this.scale=.6;this.mc=a.mc;this.Bl=a.Bl;Mb(this);Ob(this,"fx")}e=Rp.prototype;
e.Za=function(){this.Zf=this.Aa-this.aa;this.Re=this.G-this.u;this.aP=Math.sqrt(this.Zf*this.Zf+this.Re*this.Re);this.duration=.5*(1600+this.aP);this.$.Rc(this.clip,!0)};e.Qa=function(){this.mc&&this.id===this.sq-1&&this.mc();this.Bl&&this.id===this.gu&&this.Bl();var a=Z.KU;a.play=!0;a.time=0;U.play(Zi)};
e.wa=function(a){0<this.L?this.L-=a:(this.time<this.duration&&(this.time=Math.min(this.time+a,this.duration)),this.x=this.aa+this.time/this.duration*this.Zf,this.y=this.u+this.time/this.duration*this.Re,this.$.Vb(a),this.time>=this.duration&&(this.x=this.Aa,this.y=this.G,Xb(q,this)))};e.Sa=function(){};e.qb=function(){};e.pb=function(){};e.Jb=function(){};e.Sb=function(){};e.xb=function(){};e.Ga=function(){};e.Ha=function(){0<this.L||this.$.ib(this.x,this.y,this.scale,this.scale,0,1)};
function Kp(a,b){this.parent=b;this.depth=b.depth;this.W=b.W;this.D=this.visible=!0;this.x=b.x;this.y=b.y;this.canvas=Z.Tm;this.$=a.$.Zc();this.clip=a.clip;this.eu=Qf;this.show=!0;Mb(this)}e=Kp.prototype;e.Za=function(){this.$.Rc(this.clip,!1)};e.Qa=function(){};e.move=function(a){this.x=a.x;this.y=a.y};e.wa=function(a){this.$.Vb(a)};e.Ga=function(){};e.Ha=function(){this.$.B(this.x+this.parent.$d[this.parent.type].width/2,this.y+this.parent.$d[this.parent.type].height/2)};
function Op(a,b,c,d){this.W=this.depth=0;this.D=this.visible=!0;this.x=a;this.y=b;this.aa=this.x-d.c.width;this.u=this.y+d.c.height;this.Aa=this.x+d.c.width;this.G=this.y-d.c.height;this.Lp=this.aa;this.Mp=this.u;this.Zf=this.Aa-this.aa;this.Re=this.G-this.u;this.time=this.L=0;this.duration=1600;this.$N=c;this.yF=[Vg,Wg,Xg];this.Ts=d;this.sj=d.c;this.$p=d.x;this.aq=d.y;this.eu=Tf;this.YU=ph;this.MB=this.$N.id;this.canvas=gk({wf:Z.Cc,xf:0,uh:r.O,th:r.M});this.Ya=this.canvas.getContext("2d");Mb(this)}
Op.prototype.Za=function(){U.play(bj)};Op.prototype.Qa=function(){hk(this.canvas);this.Ts.c=this.yF[this.MB];var a=new Pp(this.Ts.x,this.Ts.y,this.MB,this.Ts);Z.Mg.push(a)};Op.prototype.wa=function(a){0<this.L?this.L-=a:(this.time<this.duration&&(this.time=Math.min(this.time+a,this.duration)),this.Lp=this.aa+this.time/this.duration*this.Zf,this.Mp=this.u+this.time/this.duration*this.Re,this.time>=this.duration&&(this.Lp=this.Aa,this.Mp=this.G,Xb(q,this)))};
Op.prototype.Ha=function(){this.Ya.clearRect(0,0,r.O,r.M);this.eu.B(0,this.Lp,this.Mp);this.Ya.globalCompositeOperation="source-in";this.eu.B(0,this.Lp,this.Mp);this.yF[this.MB].B(0,this.$p-this.sj.width/2,this.aq-this.sj.height/2);this.Ya.globalCompositeOperation="destination-atop";this.sj.B(0,this.$p-this.sj.width/2,this.aq-this.sj.height/2);this.Ya.globalCompositeOperation="source-over";this.YU.B(0,this.Lp,this.Mp);this.Ya.globalCompositeOperation="destination-in";this.sj.B(0,this.$p-this.sj.width/
2,this.aq-this.sj.height/2);this.Ya.globalCompositeOperation="copy";this.Ya.restore()};function Zo(a,b){this.W=this.depth=-400;this.D=this.visible=!0;this.canvas=a;this.y=this.x=0;this.$=Ki.Zc();this.state=0;this.elements=[];this.it=[];this.IJ=[];this.Dm=["ScatterState1Start","ScatterState2Start","ScatterState3Start"];this.DI=["ScatterState3PlayTucan","ScatterState3PlayFrog","ScatterState3PlayFlower"];this.zU=[Le,Me,Ne];this.lr=!1;this.Tb=b;Mb(this);Ob(this,"scatter")}e=Zo.prototype;e.Za=function(){};
e.Qa=function(){};e.wa=function(a){for(var b=0;b<this.elements.length;b++)this.elements[b].Vb(a)};e.Ga=function(){};e.Ha=function(){for(var a=0;a<this.elements.length;a++)this.elements[a].B(this.it[a].x,this.it[a].y)};e.addElement=function(a,b){this.it.push(b);a.c=this.zU[this.state];this.IJ.push(a);this.elements.push(this.$.Zc());Wp(this,this.state);this.state++};
function Wp(a,b){for(var c=0;c<a.elements.length;c++)if(a.elements[c].Rc(a.Dm[b],!1),2===b&&2===b){for(var d=0;d<a.DI.length;d++)a.elements[d].Rc(a.DI[d],!1);Gj(4);a.IJ[c].xA=!0;a.lr||(vc(a.elements[2],function(){a.Tb&&a.Tb()}),a.lr=!0)}}function qp(a,b,c){this.W=this.depth=0;this.D=this.visible=!0;this.Qb=a;this.eH=c;this.LK=b;this.y=this.x=0;this.L=2E3;this.nr=!1;Mb(this)}qp.prototype.Za=function(){this.gx=new Xp({Tb:this.Qb});U.play(fj);this.gx.show()};
qp.prototype.Qa=function(){this.gx.i();this.LK&&this.LK.fm.Hj.Yq()};qp.prototype.wa=function(a){var b=this;0<this.L?this.L-=a:this.nr||(this.gx.next(function(){b.eH&&b.eH();Xb(q,b)}),this.nr=!0)};function To(a,b,c){this.W=this.depth=0;this.D=this.visible=!0;this.y=this.x=0;this.duration=29;this.time=0;this.FE=.3;this.play=!1;this.L=void 0===b?0:b;this.repeat=c;this.vh=a;Mb(this)}
To.prototype.Za=function(){this.xC=this.vh.mb;this.yC=this.vh.Fb;this.XO=this.xC+this.FE-this.xC;this.YO=this.yC+this.FE-this.yC};To.prototype.Qa=function(){};To.prototype.wa=function(a){this.play?(this.time<this.duration?this.time=Math.min(this.time+a,this.duration):(this.play=!1,this.vh.mb=1,this.vh.Fb=1),this.vh.mb=ic(this.time,this.vh.mb,this.XO,this.duration),this.vh.Fb=ic(this.time,this.vh.Fb,this.YO,this.duration)):(this.vh.mb=1,this.vh.Fb=1)};
function Pp(a,b,c,d){this.depth=-901;this.W=-902;this.D=this.visible=!0;this.x=Z.Cc+a;this.y=b;this.duration=800;this.L=this.time=0;this.id=c;this.YN=d;this.$=Gi.Zc();this.Dm=["animCollect1Complete","animCollect2Complete","animCollect3Complete"];this.play=!1;Mb(this);Ob(this,"completeCol")}e=Pp.prototype;e.Za=function(){this.YN.i();this.u=this.y;this.$.Rc(this.Dm[this.id],!0)};e.Qa=function(){};e.remove=function(){Xb(q,this)};e.play=function(){this.play=!0};
e.wa=function(a){this.$.Vb(a);this.play&&this.time<this.duration&&(this.time=Math.min(this.time+a,this.duration),a=y(40),this.y=this.u+this.time/this.duration*a)};e.Ha=function(){this.$.B(this.x,this.y)};
function xo(){this.no={EX:"firsttime_playbutton",NX:"firsttime_start_dia1",OX:"firsttime_start_dia2",PX:"firsttime_spinbutton",VX:"firsttime_winlinehit_dia1",WX:"firsttime_winlinehit_dia2",XX:"firsttime_winlineunlock_dia1",MX:"firsttime_scatter_dia1",KX:"firsttime_scattercomplete_dia1",LX:"firsttime_scattercomplete_dia2",AX:"firsttime_betunlock_dia1",YX:"firsttime_wofspinbutton",DX:"firsttime_collectionbutton",JX:"firsttime_replay_dia1",UX:"firsttime_warning_dia1",TK:"gameover",QK:"video_doubleup",
SK:"video_gameover",RK:"video_extracoins",bL:"video_spinagain"}}xo.prototype.Ka=function(a){try{$.Ka(a)}catch(b){console.log("error calling analytics.menu: "+b)}};function Ro(){this.buttons=[];this.Wm()}Ro.prototype.Wm=function(){this.od(Z.Au);this.od(Z.Sm);this.od(Z.lq);this.od(Z.kq);this.od(Z.$q);this.od(Z.Dq);this.od(Z.Sc);this.od(Z.jv)};Ro.prototype.od=function(a){this.buttons.push(a)};Ro.prototype.Ii=function(a){if(0!==this.buttons.length)if(a)this.buttons[a].ga();else for(a=0;a<this.buttons.length;a++)this.buttons[a].ga()};
Ro.prototype.mh=function(a){if(0!==this.buttons.length)if(a)this.buttons[a].ka();else for(a=0;a<this.buttons.length;a++)this.buttons[a].ka()};
V.p.hX={Ra:null,po:null,ac:[],bG:[],wM:Ni,xM:["artefactWin1","artefactWin2","artefactWin3","artefactWin4","artefactWin5"],mw:["artefact_diamond_header","artefact_butterfly_header","artefact_feather_header","artefact_toad_header","artefact_beetle_header"],jD:[{x:y(6),y:y(-160)},{x:y(-250),y:y(4)},{x:y(-168),y:y(298)},{x:y(156),y:y(306)},{x:y(262),y:y(22)}],Ys:0,background:Th,et:!0,zF:og,Qy:Wf,mS:Xf,FG:Yf,ek:void 0,LH:void 0,Vr:[],jX:[th,vh,xh,zh,Ch],nE:[Vg,Wg,Xg],lE:[{x:y(-250),y:y(-586)},{x:y(-8),
y:y(-586)},{x:y(224),y:y(-586)}],mE:[{x:y(-436),y:y(-332)},{x:y(436),y:y(-330)},{x:y(4),y:y(702)}],Pr:[],mc:null,P:null,Yj:null,e:[]};function Lp(a){this.name="WheelDialog";this.n(V.p.hX);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2;this.gi=this.zg=0;this.rk=-1;this.wB=0;this.Ul=void 0;this.ll=0;this.SB=!1;this.ke=.7;this.stop=0;this.Qn=10;this.mk=0;this.gp=!1;this.yS=500;this.xm=y(0);this.pD=y(0)}hm(Lp,yc);
function Yp(a,b,c,d){var g=new s({y:y(-100),x:y(0)});c&&new F({text:c,y:y(-260)});b=new u({c:d,x:a.jD[b].x,y:a.jD[b].y});a.Vr.push(b);g.d(b);return g}e=Lp.prototype;e.cw=function(a){Z.F&&Eo(Z.F.Ag.yv)&&Z.F.fb(Z.F.Ag.yv);a.SB=!1;a.stop=0;a.Sc.show();a.Sc.ka()};e.ON=function(a){a.P&&a.P(a.Ra)};
e.jl=function(){var a=[];this.pj=Z.ma.db.player.artefactChance;for(var b=0;b<this.pj.startPercentage.length;b++)a.push((this.pj.target-this.pj.startPercentage[b])/(this.pj.maxLevel-1));for(b=0;b<a.length;b++)this.pj.startPercentage[b]+=a[b]*Z.mg};
e.w=function(){var a,b=this;this.jl();this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});a=!1;Z.yy&&(a=!0);this.ud=new u({c:this.background,x:y(0),y:y(0),Ng:a});this.frame.d(this.ud);this.pv=new u({c:Vf,x:y(0),y:y(100)});this.frame.d(this.pv);this.lX=new u({c:fg,x:y(0),y:y(-332)});this.frame.d(this.lX);this.BV=new u({c:pg,y:y(100)});this.frame.d(this.BV);
this.Sc=new D({c:eg,y:y(100,"round"),T:ai,text:E("wheel_button_spin"),Nf:uj,j:function(){var a=-1,c=Math.random(),d=[],m=0;d.push(m);for(var p=b.pj.startPercentage.length-1;-1<p;p--)m+=b.pj.startPercentage[p],d.push(m);for(p=0;p<d.length-1;p++)d[p]<=c&&d[p+1]>=c&&(a=p);b.rk=a;b.ek=b.jX[b.rk];b.MH=b.bG[b.rk];b.LH=b.mw[b.rk];b.gp=!0;b.Qn=10;b.mk=0;b.wB=72*b.rk;b.ll=7;b.Ul=360*b.ll+b.wB-b.zg;b.gi=0;b.Sc.i();U.play(tj,100);U.lk("sfx",!0);Z.F&&Mo(Z.F,"wheel")}});this.frame.d(this.Sc);this.Qm=new s({});
this.HR=new u({c:dg,x:y(-340),y:y(-570)});this.Qm.d(this.HR);this.FU=new u({c:ag,x:y(450),y:y(-570)});this.Qm.d(this.FU);this.bl=new s({});this.XM=new u({c:cg,x:y(0),y:y(-570)});this.bl.d(this.XM);this.CT=new u({c:Zf,width:Zf.width+y(20),height:Zf.height+y(5),x:y(525),y:y(-608)});this.bl.d(this.CT);this.DT=new u({c:$f,width:$f.width+y(20),height:$f.height+y(5),x:y(-525),y:y(-608)});this.bl.d(this.DT);this.OT=new u({c:hg,x:y(-720),y:y(580)});this.bl.d(this.OT);this.PT=new u({c:ig,x:y(720),y:y(580)});
this.Qm.d(this.PT);for(a=0;5>a;a++){this.gW=this.ac[a];var c=Yp(this,a,a.toString(),this.gW);this.pv.d(c)}this.iF=new s({});c=400;for(a=0;a<this.nE.length;a++){var d=new Zp({c:this.nE[a],aa:this.lE[a].x,u:this.lE[a].y,Xl:this.mE[a].x,kf:this.mE[a].y,id:a,L:c,Tb:function(a){if(2===a)for(a=b.Hj,a.et=!0,a.state=a.Xk.wv,a.duration=a.ME[a.state],$p(a),b.Hj.Yq(),a=0;a<b.Pr.length;a++)b.Pr[a].i()}}),c=c+c;this.Pr.push(d);this.iF.d(d)}this.d(this.frame);this.d(this.Qm);this.d(this.bl);this.d(this.iF);if(this.e)for(a=
0;a<this.e.length;a+=1)this.d(this.e[a]);this.Hj=new aq({Ra:b,canvas:b.po,Dz:function(){for(var a=0;a<b.Vr.length;a++)b.Vr[a].show()}});this.Hj.Ia=function(){b.Hj=void 0;b.cw(b)};this.Hj.show()};
function Mp(a,b){a.Hj&&a.Hj.Dv(b);a.yp=b/1E3;if(void 0!==a.Ul){a.SB?(a.gi=a.Ul*a.ke,15>a.gi&&(a.gi=15)):2>=a.ll&&(a.SB=!0);a.zg+=a.gi*a.yp;360<a.zg?(a.zg-=360,a.ll-=1):0>a.zg&&(a.zg+=360,a.ll-=1);if(a.Ul-3>a.stop)a.Ul-=a.gi*a.yp,a.pv.Oa=-a.zg;else{a.zg=a.wB;a.Ul=void 0;a.pv.Oa=-a.zg;a.gi=0;Ap(a.rk);a.gp=!1;U.stop("sfx");U.play(vj);a.mc&&a.mc(a.rk);var c=new yc({x:r.O/2,y:r.M/2,depth:-1E4,W:-3E3}),d=new cm({Rd:.667}),g=new Bc({wr:a.wM,No:a.xM[a.rk],Tb:function(){var b=new bq({Ra:a,ek:a.ek,eA:a.MH,
Lq:a.cw,P:a.ON,Uw:1200,Fn:a.Ys});(new cq({Ra:a,ek:a.ek,eA:a.MH,Et:a.LH,Lq:a.cw,Uw:1200,Fn:a.Ys,iz:b})).show();c.i()}});c.d(d);c.d(g);c.show();U.play(Xi)}a.gi<=a.yS&&3<a.Qn&&(a.gi+=2);3<a.Qn?10>a.mk&&a.gp&&(a.mk+=2.2*a.yp):0<a.mk&&a.gp&&(a.mk-=2.2*a.yp)}a.Qn-=a.yp;0<a.Qn&&a.gp?dq(a,a.mk):(a.frame.x=a.xm,a.frame.y=a.pD)}
function dq(a,b){var c=(Math.random()-.5)*b,d=(Math.random()-.5)*b;a.frame.x=a.xm+y(c);a.frame.y=a.pD+y(d);c=(Math.random()-.5)*b;Math.random();a.Qm.x=a.xm+y(c);a.Qm.y=a.xm+y(c);c=(Math.random()-.5)*b;Math.random();a.bl.x=a.xm+y(c);a.bl.y=a.xm+y(c)}e.I=function(){this.ya();this.frame=void 0};e.da=function(){for(var a=0;a<this.Vr.length;a++)this.Vr[a].i();this.Sc.i()};e.pa=function(){};
V.p.nX={Ra:null,depth:-1E4,W:-3E3,Lc:dh,ek:void 0,eA:void 0,MC:"spinagain_txt",Et:"spinagain_header",ue:{l:T.l,fontSize:65,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600",align:"center",ua:"middle"},Fn:0,Uw:0,Ef:0,WG:0,Pd:!1,Lq:null,P:null,Yj:null,e:[]};function bq(a){this.name="WheelWinDialog";this.n(V.p.nX);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(bq,yc);
bq.prototype.w=function(){var a,b=this,c=Z.ma,d=c.db.player.artefact,g=new Date;a=0;d.lastAdTimer+36E5*d.timerRest<=g.getTime()&&0<d.lastAdTimer||0===d.lastAdTimer?this.Pd=!0:a=d.lastAdTimer+36E5*d.timerRest-g.getTime();this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.yc=new cm({Rd:.667});this.frame.d(this.yc);this.ud=new u({c:this.Lc,
x:y(0),y:y(0)});this.frame.d(this.ud);this.hm=new F({text:E(this.Et),font:this.ue,width:this.Lc.width-y(200),x:y(0),y:y(-500)});this.frame.d(this.hm);this.ZQ=new u({c:lh,x:y(0),y:y(130)});this.frame.d(this.ZQ);this.gU=new F({font:this.rc,text:E(this.MC),width:lh.width-y(30),x:y(0),y:y(0)});this.frame.d(this.gU);this.Pd||(this.Gc=new oo({width:y(600),height:y(200),y:y(150),valueType:"time",Db:this.rc,ec:a/1E3,md:":",ni:-1,Cl:function(a,c){0===c&&(b.Gc.i(),b.Kc.show(),b.Kc.ka())}}),this.frame.d(this.Gc),
this.Vi=new F({text:E("spinagain_txtNo"),font:this.rc,x:y(0),y:y(120)}),this.frame.d(this.Vi));this.Kc=new D({c:Q,x:y(0),y:y(160),text:E("spinagain_button_video"),T:ti,j:function(){Z.za.Ka(Z.za.no.bL);b.Yj&&b.Yj();c.db.player.artefact.lastAdTimer=g.getTime();c.db.player.artefact.timeToWait=g.getTime()+36E5*d.timerRest;c.save();G.vs(function(){b.Lq&&b.Lq(b.Ra);Vb(Z.A)},function(){Vb(Z.A)});Qb(Z.A);b.i()}});this.frame.d(this.Kc);this.Lg=new D({c:mf,x:y(0),y:y(310),text:E("spinagain_button_continue"),
T:vi,j:function(){b.P&&(b.P(b.Ra),b.i(),Z.F&&Eo(Z.F.Ag.bC)&&Z.F.fb(Z.F.Ag.bC),G.NA&&G.NA(Z.NB.ea(),0,void 0))}});this.frame.d(this.Lg);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};bq.prototype.I=function(){this.ya();this.frame=void 0};bq.prototype.da=function(){Ej();this.Pd||this.Kc.i()};bq.prototype.pa=function(){Fj();Hj();Vb(Z.A)};
V.p.gX={Ra:null,depth:-1E4,W:-3E3,placeholder:kh,Lc:dh,ek:void 0,eA:void 0,MC:"spinagain_txt",Et:"PLACEHOLDER",ue:{l:T.l,fontSize:65,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600"},Fn:0,Uw:0,iz:null,Lq:null,P:null,Yj:null,e:[]};function cq(a){this.name="WheelArtifactDialog";this.n(V.p.gX);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(cq,yc);
cq.prototype.w=function(){var a,b=this;this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.yc=new cm({Rd:.667});this.frame.d(this.yc);this.ud=new u({c:this.Lc,x:y(0),y:y(0)});this.frame.d(this.ud);this.hm=new F({text:E(this.Et),font:this.ue,width:this.Lc.width-y(200),height:y(120),x:y(0),y:y(-500)});this.frame.d(this.hm);this.Xq=new u({c:this.placeholder,
x:y(0),y:y(310)});this.frame.d(this.Xq);this.oX=new F({font:this.rc,width:this.placeholder.width-y(50),text:E("winartefact_txt"),x:y(0),y:y(200)});this.frame.d(this.oX);this.dU=new u({c:this.ek,x:y(0),y:y(-206)});this.frame.d(this.dU);this.Lg=new D({c:mf,x:y(0),y:y(430),text:E("doubleup_button_continue"),T:vi,j:function(){b.i()}});this.frame.d(this.Lg);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};cq.prototype.I=function(){this.ya();this.frame=void 0};cq.prototype.da=function(){Ej()};
cq.prototype.pa=function(){Fj();this.iz&&this.iz.show()};V.p.pM={Ra:null,Lc:Ih,rh:"",Zj:null,on:null,e:[]};function eq(a){this.name="AlertDialog";this.n(V.p.pM);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(eq,yc);
eq.prototype.w=function(){var a,b=this;this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.yc=new cm({Jm:"#000745",Rd:.667});this.frame.d(this.yc);this.ud=new u({c:this.Lc,x:y(0),y:y(0)});this.frame.d(this.ud);this.Bc=new F({text:this.rh,x:y(0),y:y(-100)});this.frame.d(this.Bc);this.iw=new D({c:ke,width:y(200),height:y(92),x:y(160),
y:y(165),text:"Agree",j:function(){b.Zj&&b.Zj();var a=vl;go();a.r=a.sm;b.i()}});this.frame.d(this.iw);this.ZO=new D({c:ke,width:y(200),height:y(92),x:y(-145),y:y(165),text:"Stay",j:function(){if(b.on)b.on();b.i()}});this.frame.d(this.ZO);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};eq.prototype.I=function(){this.ya();this.frame=void 0};eq.prototype.da=function(){Ej()};eq.prototype.pa=function(){Fj()};V.p.GN={HN:void 0,UO:void 0,Ed:[],rh:"",C:!1,VV:0,fH:null,e:[]};
function fq(a){this.name="CharacterDialog";this.n(V.p.GN);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(fq,yc);e=fq.prototype;e.dt=function(){X(this.frame,2)};
e.w=function(){var a,b=this;this.C=!0;this.rh=this.Ed[this.VV].text;this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:1,o:ec}],yb:function(){b.fH&&b.fH();b.i()}});this.d(this.frame);this.yc=new cm({Jm:"#000745",Rd:.667});this.frame.d(this.yc);this.UQ=new u({c:this.UO,x:y(0),y:y(0)});this.frame.d(this.UQ);this.ud=new u({c:this.HN,x:y(0),y:y(-300)});this.frame.d(this.ud);this.Bc=new F({text:this.rh,
width:y(800),height:y(200),pc:!0,font:{l:gi.l,fontSize:22,fillColor:"#ffffff"},x:y(0),y:y(300)});this.frame.d(this.Bc);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya();this.frame=void 0};e.da=function(){};e.pa=function(){};
V.p.WP={backgroundImage:Uh,mw:["artefact_diamond_header","artefact_butterfly_header","artefact_feather_header","artefact_toad_header","artefact_beetle_header"],Jz:[uh,wh,yh,Bh,Dh],BT:[th,vh,xh,zh,Ch],fT:["artefact_diamond_name","artefact_butterfly_name","artefact_feather_name","artefact_toad_name","artefact_beetle_name"],RF:[{x:y(-30),y:y(-236)},{x:y(-4),y:y(192)},{x:y(-122),y:y(-172)},{x:y(6),y:y(-212)},{x:y(-188),y:y(-158)}],oR:sh,dG:[{x:y(-256),y:y(-202)},{x:y(238),y:y(-504)},{x:y(-76),y:y(144)},
{x:y(310),y:y(444)},{x:y(-196),y:y(564)}],GJ:[{x:y(0),y:y(-10)},{x:y(0),y:y(-20)},{x:y(0),y:y(-20)},{x:y(0),y:y(-14)},{x:y(26),y:y(-14)}],JE:[{x:y(186),y:y(-124)},{x:y(222),y:y(276)},{x:y(150),y:y(-132)},{x:y(0),y:y(108)},{x:y(6),y:y(-136)}],KE:[],Mz:!1,ui:Fh,hx:Eh,QN:Re,Db:{l:T.l,fontSize:36,fillColor:"#942600"},ue:{l:T.l,fontSize:45,fillColor:"#942600"},P:null,e:[]};function ko(a){this.name="GalleryDialog";this.n(V.p.WP);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(ko,yc);
function gq(a,b){a.kS=Z.ma;a.ki=Z.ca;a.mR=[];for(var c=0;c<a.Jz.length;c++){var d=new u({c:a.oR,x:a.dG[c].x,y:a.dG[c].y}),g=new F({text:E(a.fT[c])+"\n "+Ko(a.ki.artifacts[c].value),x:a.GJ[c].x,y:a.GJ[c].y});a.mR.push(g);var k=new u({c:a.ui,width:a.ui.width/2,height:a.ui.height/2,x:y(-75),y:y(0)}),l=new u({c:a.hx,x:a.JE[c].x,y:a.JE[c].y}),m=new F({text:""+a.ki.artifacts[c].amount,width:a.hx.width,height:a.hx.height,font:ci});a.KE.push(m);l.d(m);d.d(l);d.d(k);d.d(g);g=new u({c:(0<a.ki.artifacts[c].amount?
a.BT:a.Jz)[c],x:a.RF[c].x,y:a.RF[c].y,id:c,value:a.ki.artifacts[c].value,jw:a.ki.artifacts[c].amount,j:function(b){0<b.jw&&!a.Mz&&hq(a,b.c,b.value,b,a.KE[b.id],b.id)}});d.d(g);b.d(d)}}
function hq(a,b,c,d,g,k){a.Ee=new yc({W:-2E3,x:a.x,y:a.y});a.yc=new cm({Rd:.667});a.Ee.d(a.yc);a.RU=new u({c:dh,x:0,y:0,width:y(873),height:y(1168)});a.Ee.d(a.RU);a.TU=new u({c:jh,x:y(0),y:y(360)});a.Ee.d(a.TU);a.Bc=new F({font:a.ue,text:E(a.mw[k]),x:y(0),y:y(-500)});a.Ee.d(a.Bc);b&&(a.UU=new u({c:b,x:y(0),y:y(-160),width:b.width-y(20),height:b.height-y(20)}),a.Ee.d(a.UU));a.Sw=new u({c:a.QN,x:y(-100),y:y(100)});a.Ee.d(a.Sw);a.UN=new F({text:Ko(c),x:y(50),y:y(100),font:a.Db});a.Ee.d(a.UN);a.SU=new D({c:Q,
x:y(0),y:y(300),width:Q.width,height:Q.height,text:E("sellartefact_button_sell"),T:ti,j:function(){a.ki.artifacts[d.id].amount-=1;d.jw--;g.text=""+d.jw;g.Xa();Z.mf&&Bp(a.ki.artifacts[d.id].value);0===a.ki.artifacts[d.id].amount&&(d.c=a.Jz[d.id]);a.Ee.i();a.kS.save()}});a.Ee.d(a.SU);a.xN=new D({c:mf,T:vi,x:y(0),y:y(440),width:mf.width,height:mf.height,text:E("sellartefact_button_back"),j:function(){a.Ee.i()}});a.Ee.d(a.xN);a.Ee.Ia=function(){Fj();a.Gs.ka();a.Mz=!1};a.Mz=!0;a.Gs.ga();a.Ee.show();Ej()}
e=ko.prototype;e.dt=function(){X(this.frame,2)};e.w=function(){var a,b=this;a=!1;Z.yy&&(a=!0);this.tw=new u({c:this.backgroundImage,Ng:a});this.d(this.tw);gq(this,this);this.yV=new u({c:Gh,x:y(0),y:y(728)});this.d(this.yV);this.YS=new F({text:E("ui_sellartefact"),x:y(190),y:y(736)});this.d(this.YS);this.Gs=new D({c:cf,x:y(-300),y:y(736),width:y(314),height:y(121),text:E("extracoins_button_back"),T:ti,j:function(){b.i()}});this.d(this.Gs);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
e.I=function(){this.ya();this.Gs=void 0};e.da=function(){Qb(Z.A)};e.pa=function(){this.Ee&&this.Ee.i();Z.kh();Z.yf();Z.ej.mh();Vb(Z.A)};V.p.fQ={Ra:null,Lc:dh,title:"gameover_txt",Pa:{h:Gl,duration:.8,u:y(-500),G:y(0),o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Ct:!1,nM:!1,CE:eh,P:null,xl:null,su:null,uT:null,Jg:1E3,ue:{l:T.l,fontSize:45,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600",align:"center",ua:"middle"},Ef:0,WG:0,Pd:!1,Ac:null,e:[]};
function mp(a){this.name="GameOverDialog";this.n(V.p.fQ);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(mp,yc);
mp.prototype.w=function(){var a,b=this,c=Z.ma,d=c.db.player.gameoverAd,g=new Date;a=0;d.lastAdTimer+36E5*d.timerRest<=g.getTime()&&0<d.lastAdTimer||0===d.lastAdTimer?this.Pd=!0:a=d.lastAdTimer+36E5*d.timerRest-g.getTime();this.yc=new cm({Rd:.8});this.d(this.yc);this.frame=new s({S:[this.Pa,{h:"nothing",duration:9999999},{h:"fadeOut",u:0,G:r.k.height,duration:1,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.ud=new u({c:this.Lc,x:y(0),y:y(0)});this.frame.d(this.ud);this.PM=new F({text:E("gameover_header"),
font:this.ue,width:this.Lc.width-y(200),x:y(0),y:y(-500)});this.frame.d(this.PM);this.Lz=new u({c:lh,x:y(0),y:y(-30)});this.frame.d(this.Lz);this.Pd||(this.bM=new u({c:this.CE,x:y(0),y:y(105)}),this.frame.d(this.bM),this.Gc=new oo({width:y(600),height:y(200),y:y(90),Db:this.rc,valueType:"time",ec:a/1E3,md:":",ni:-1,Cl:function(a,c){0===c&&(b.Gc.i(),b.Kc.show(),b.Kc.ka())}}),this.frame.d(this.Gc),this.Vi=new F({font:this.rc,text:E("gameover_videoavailable"),width:lh.width-y(50),x:y(0),y:y(37)}),this.frame.d(this.Vi));
this.Lg=new D({c:mf,x:y(0),y:y(400),text:E("help_button_exit"),T:vi,j:function(){b.i();go();vl.Tf()}});this.frame.d(this.Lg);this.Sm=new D({c:Q,x:y(0),y:y(-70),text:E("gameover_button_sell"),T:ti,HM:this.Ct,j:function(a){a.HM&&(b.xl&&b.xl(),b.Ia=function(){(new ko({canvas:b.Ac})).show()},X(b.frame,2))}});this.Tx=new F({font:this.rc,text:E("gameover_noartefacts"),x:y(0),y:y(-70)});this.zM=new u({c:this.CE,x:y(0),y:y(-70)});this.Ct?this.frame.d(this.Sm):(this.frame.d(this.zM),this.frame.d(this.Tx));
this.Bc=new F({text:E(this.title),font:this.rc,x:y(0),y:y(-195)});this.frame.d(this.Bc);this.Kc=new D({c:Q,x:y(0),y:y(100),text:E("gameover_button_video"),T:ti,j:function(){Z.za.Ka(Z.za.no.SK);b.Yj&&b.Yj();c.db.player.gameoverAd.lastAdTimer=g.getTime();c.db.player.gameoverAd.timeToWait=g.getTime()+36E5*d.timerRest;c.save();G.vs(function(){Z.yf(b.Jg);Bp(b.Jg);Z.yf();Z.kh();Vb(Z.A);var a=E("feedback_coinfloater").replace("{0}",b.Jg);new An(a,r.O/2,r.M/2-y(100),200,ki,.6,"#00dfff","#094dc5",-2E3,0,function(){})});
Qb(Z.A);X(b.frame,2)}});this.frame.d(this.Kc);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};mp.prototype.I=function(){this.ya();this.frame=void 0};mp.prototype.da=function(){Ej();this.Pd||this.Kc.i()};mp.prototype.pa=function(){Fj();this.P&&this.P()};
V.p.EU={Ra:null,Lc:dh,icon:fh,placeholder:kh,hm:ff,rh:"Would you like to double up your win?",ue:{l:T.l,fontSize:65,fillColor:"#942600"},PN:{l:T.l,fontSize:40,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600"},mo:0,bZ:!0,DR:0,pW:0,Zj:null,on:null,P:null,l_:null,e:[]};function pp(a){this.name="RewardDialog";this.n(V.p.EU);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(pp,yc);
pp.prototype.w=function(){var a,b=this,c=Z.ma,d=c.db.player.doubleUpAd,g=new Date;a=0;d.lastAdTimer+36E5*d.timerRest<=g.getTime()&&0<d.lastAdTimer||0===d.lastAdTimer?this.Pd=!0:a=d.lastAdTimer+36E5*d.timerRest-g.getTime();this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.yc=new cm({Rd:.667});this.frame.d(this.yc);this.ud=new u({c:this.Lc,
x:y(0),y:y(0)});this.frame.d(this.ud);this.WB=new F({text:E("doubleup_header"),font:this.ue,width:this.Lc.width-y(200),x:y(0),y:y(-480)});this.frame.d(this.WB);this.Xq=new u({c:this.placeholder,x:y(0),y:y(310)});this.frame.d(this.Xq);this.jp=new u({c:this.icon,x:y(0),y:y(-210)});this.frame.d(this.jp);this.RN=new F({font:this.PN,text:Ko(this.mo),x:y(0),y:y(50)});this.frame.d(this.RN);this.Pd&&(this.Bc=new F({font:this.rc,text:E("doubleup_txt"),width:this.placeholder.width-y(100),x:y(0),y:y(160)}),
this.frame.d(this.Bc));this.Pd||(this.Gc=new oo({width:y(600),height:y(200),y:y(310),Db:this.rc,valueType:"time",ec:a/1E3,md:":",ni:-1,Cl:function(a,c){0===c&&(b.Gc.i(),b.Kc.show(),b.Kc.ka())}}),this.frame.d(this.Gc),this.Vi=new F({font:this.rc,text:E("gameover_videoavailable"),x:y(0),y:y(160)}),this.frame.d(this.Vi));this.Lg=new D({c:mf,x:y(0),y:y(440),text:E("doubleup_button_continue"),T:vi,j:function(){if(b.on)b.on();Bp(b.mo);Oo(Z);b.i()}});this.frame.d(this.Lg);this.Kc=new D({c:Q,x:y(0),y:y(280),
text:E("doubleup_button_video"),T:ti,j:function(){Z.za.Ka(Z.za.no.QK);b.Zj&&b.Zj();c.db.player.doubleUpAd.lastAdTimer=g.getTime();c.db.player.doubleUpAd.timeToWait=g.getTime()+36E5*d.timerRest;c.save();G.vs(function(){Vb(Z.A);Bp(2*b.mo);Oo(Z);b.i();var a=E("feedback_coinfloater").replace("{0}",2*b.mo);new An(a,r.O/2,r.M/2-y(100),200,ki,1,"#00dfff","#094dc5",-2E3,0,function(){})},function(){Vb(Z.A);Oo(Z);b.i()});Qb(Z.A)}});this.frame.d(this.Kc);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
pp.prototype.I=function(){this.ya();this.frame=void 0};pp.prototype.da=function(){Ej();this.Pd||this.Kc.i()};pp.prototype.pa=function(){Fj();this.P&&this.P()};V.p.RW={Ra:null,Lc:dh,icon:fh,placeholder:kh,hm:ff,rh:"Would you like to double up your win?",mo:0,DR:0,pW:0,ue:{l:T.l,fontSize:65,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600",align:"center",ua:"middle"},Zj:null,on:null,P:null,e:[]};
function Io(a){this.name="UpgradeDialog";this.n(V.p.RW);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(Io,yc);
Io.prototype.w=function(){var a,b=this;this.frame=new s({S:[{h:"fadeIn",u:r.k.height,G:0,duration:.5,o:ec},{h:"nothing",duration:9999999},{h:"nothing",duration:.5},{h:"fadeOut",u:0,G:r.k.height,duration:.5,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.yc=new cm({Rd:.667});this.frame.d(this.yc);this.ud=new u({c:this.Lc,x:y(0),y:y(0)});this.frame.d(this.ud);this.hm=new F({text:E("levelup_header"),font:this.ue,width:this.Lc.width-y(200),x:y(0),y:y(-500)});this.frame.d(this.hm);this.Xq=new u({c:this.placeholder,
x:y(0),y:y(310)});this.frame.d(this.Xq);this.jp=new u({c:this.icon,x:y(0),y:y(-174)});this.frame.d(this.jp);this.Bc=new F({font:this.rc,text:this.rh,width:this.placeholder.width-y(50),x:y(0),y:y(250)});this.frame.d(this.Bc);this.iw=new D({c:cf,x:y(0),y:y(440),text:E("doubleup_button_continue"),T:ti,j:function(){b.Zj&&b.Zj();X(b.frame,2)}});this.frame.d(this.iw);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};Io.prototype.I=function(){this.ya();this.frame=void 0};Io.prototype.da=function(){Ej()};
Io.prototype.pa=function(){Fj();Vb(Z.A);this.P&&this.P()};
V.p.HW={depth:-3E3,Ra:null,canvas:null,Ya:null,$h:{0:{Bd:[{x:y(0),y:y(0)},{x:y(0),y:y(-300)},{x:y(0),y:y(150)}],ac:[Lf,Lf,Pf],Ed:["start_dia1","start_dia2","start_dia3"],Ge:["dialogue_tapanywhere","dialogue_tapanywhere",""],cf:[1,1,1],df:[1,1,1],ve:[{x:y(-1E4),y:y(0)},{x:y(70),y:y(30)},{x:y(338),y:y(1440)}],gc:{c:[void 0,void 0,mh],position:[{x:y(0),start:y(0),target:y(0)},{x:y(-334),start:y(-600),target:y(-500)},{x:y(0),start:y(500),target:y(600)}]}},1:{Bd:[{x:y(0),y:y(-505)},{x:y(0),y:y(50)}],ac:[Qf,
Uf],Ed:["winlinehit_dia1","winlinehit_dia2"],Ge:["dialogue_tapanywhere","dialogue_tapanywhere"],cf:[3,1],df:[1,1],ve:[{x:y(50),y:y(780)},{x:y(80),y:y(344)}],gc:{c:[void 0,void 0],position:[{x:y(-112),start:y(-226),target:y(-126)},{x:y(-340),start:y(-280),target:y(-180)}]}},2:{Bd:[{x:y(0),y:y(-505)}],ac:[Of],Ed:["scatter_dia1"],Ge:["dialogue_tapanywhere"],cf:[1],df:[1],ve:[{x:y(295),y:y(755)}],gc:{c:[void 0],position:[{x:y(-120),start:y(-240),target:y(-140)}]}},3:{Bd:[{x:y(0),y:y(-505)}],ac:[Qf],Ed:["scattercomplete_dia1"],
Ge:["dialogue_tapanywhere"],cf:[3],df:[1.2],ve:[{x:y(50),y:y(750)}],gc:{c:[void 0],position:[{x:y(-120),start:y(-240),target:y(-140)}]}},4:{Bd:[{x:y(0),y:y(-70)}],ac:[Mf],Ed:["scattercomplete_dia2"],Ge:["dialogue_tapanywhere"],cf:[1],df:[1],ve:[{x:y(180),y:y(130)}],gc:{c:[void 0],position:[{x:y(0),start:y(320),target:y(420)}]}},5:{Bd:[{x:y(0),y:y(250)}],ac:[Kf],Ed:["winlineunlock_dia1"],Ge:[""],cf:[1],df:[1],ve:[{x:y(55),y:y(1470)}],gc:{c:[mh],position:[{x:y(-272),start:y(500),target:y(600)}]}},6:{Bd:[{x:y(0),
y:y(250)}],ac:[Kf],Ed:["betunlock_dia1"],Ge:[""],cf:[1],df:[1],ve:[{x:y(735),y:y(1470)}],gc:{c:[mh],position:[{x:y(410),start:y(500),target:y(600)}]}},7:{Bd:[{x:y(0),y:y(-490)}],ac:[Rf],Ed:["wof_dia1"],Ge:[""],cf:[1],df:[1],ve:[{x:y(538),y:y(903)}],gc:{c:[mh],position:[{x:y(0),start:y(-220),target:y(-120)}]}},8:{Bd:[{x:y(0),y:y(-80)}],ac:[Nf],Ed:["collection_dia1"],Ge:[""],cf:[1],df:[1],ve:[{x:y(744),y:y(8)}],gc:{c:[nh],position:[{x:y(280),start:y(-600),target:y(-500)}]}},9:{Bd:[{x:y(0),y:y(-300)}],
ac:[Lf],Ed:["warning_dia1"],Ge:[""],cf:[1],df:[1],ve:[{x:y(70),y:y(30)}],gc:{c:[void 0],position:[{x:y(0),start:y(0),target:y(0)}]}},10:{Bd:[{x:y(0),y:y(-300)}],ac:[Nf],Ed:["replay_dia1"],Ge:["dialogue_tapanywhere"],cf:[1],df:[1],ve:[{x:y(-1E4),y:y(0)}],gc:{c:[void 0],position:[{x:y(0),start:y(0),target:y(0)}]}}},ac:[Lf,Lf,Kf,Kf,Pf,Qf,Of,Qf,Mf,Rf,Nf],Bd:[{x:y(0),y:y(0)},{x:y(0),y:y(-505)},{x:y(0),y:y(340)},{x:y(0),y:y(340)},{x:y(0),y:y(310)},{x:y(0),y:y(-505)},{x:y(0),y:y(-505)},{x:y(0),y:y(-505)},
{x:y(0),y:y(-200)},{x:y(0),y:y(-505)},{x:y(0),y:y(-300)}],Ed:"Another Explorer! Welcome!;You're going to need some resources. \n Here are some coins to get you started!;Set the number of paylines\n to 10.;Set amount of coins you\n want to put on each payline to 5.;Hit the button to start exploring!;Great! Finding at least 3 identical\n symbols on paylines will earn you coins.;Awesome! Collecting 3 Scatters\n will trigger free spins.;So that's where they are!\n I need those for my research.;I'm going to need quite a few more. With\n your help that shouldn't be a problem!;These artefacts look valuable. Let's find\n out what happens if we push that button!;The artefact is stored in your collection.\n Why don't you go have a look!".split(";"),
Ge:"Tap anywhere to continue.;;;;Tap anywhere to continue.;Tap anywhere to continue.;Tap anywhere to continue.;Tap anywhere to continue.;;".split(";"),iW:hh,hW:rh,cf:[1,1,1,1,1,3,1,3,1,3,1],df:[1,1,1,1,1,1,1,1,1,3,1],WQ:Sf,c:void 0,ve:[{x:y(-1E4),y:y(0)},{x:y(70),y:y(30)},{x:y(57),y:y(1470)},{x:y(735),y:y(1470)},{x:y(338),y:y(1440)},{x:y(50),y:y(780)},{x:y(295),y:y(755)},{x:y(50),y:y(780)},{x:y(180),y:y(130)},{x:y(50),y:y(780)},{x:y(50),y:y(780)}],rc:{l:gi.l,fontSize:19,fillColor:"#76623f"},aW:{l:gi.l,
fontSize:17,fillColor:"#ffffce",stroke:!0,Ti:!0,strokeColor:"#025122",ug:5},SN:500,gc:null,iD:void 0,yc:void 0,pause:!1,c_:null,zl:null,P:null,state:0,id:0,e:[]};function Up(a){this.name="TutorialDialog";this.n(V.p.HW);void 0!==a&&this.f(a)}hm(Up,yc);function iq(a,b){a.Bs&&a.Bs.i();b.c&&(a.Bs=new yc({canvas:a.canvas,depth:-3001,x:r.O/2,y:r.M/2}),a.iD=new jq({c:b.c,aa:b.x,u:b.start,kf:b.target}),a.Bs.d(a.iD),a.Bs.show())}e=Up.prototype;e.$e=function(){};
e.fb=function(a){this.Bd=this.$h[a].Bd;this.Ed=this.$h[a].Ed;this.ac=this.$h[a].ac;this.Ge=this.$h[a].Ge;this.cf=this.$h[a].cf;this.df=this.$h[a].df;this.ve=this.$h[a].ve;this.gc=this.$h[a].gc;this.id=0};e.sp=function(a){var b=gk({wf:Z.Cc,xf:0,uh:r.O,th:r.M});U.play(dj);for(var c=100,d=0;7>d;d++)new Rp({aa:r.O/2-Z.Cc,u:r.M/2,Aa:Z.ui.x,G:Z.ui.y,L:c,$:Ji,clip:"coinspin2",canvas:b,id:d,sq:7,gu:3,Bl:function(){Z.mf.Md(a);Lo(Z.ma,a)},mc:function(){hk(b)}}),c+=100};
e.nr=function(a){this.id=a;0===this.state&&1===this.id&&0>=Z.mf.ea()&&this.sp(this.SN);iq(this,{c:this.gc.c[a],x:this.gc.position[a].x,start:this.gc.position[a].start,target:this.gc.position[a].target});this.wn.x=this.Bd[this.id].x;this.wn.y=this.Bd[this.id].y;this.c=this.ac[this.id];this.text.text=E(this.Ed[this.id]);this.Vi.text=kq(this.Ge[this.id]);this.text.Xa();this.Vi.Xa()};function kq(a){return""===a?"":E(a)}
e.w=function(){var a;this.fb(this.state);iq(this,{c:this.gc.c[this.id],x:this.gc.position[this.id].x,start:this.gc.position[this.id].start,target:this.gc.position[this.id].target});this.c=this.ac[this.id];this.wn=new u({c:this.iW,x:this.Bd[this.id].x,y:this.Bd[this.id].y});this.IM=new u({c:this.hW,x:y(-122),y:y(88),tb:!0,width:y(650)});this.wn.d(this.IM);this.text=new F({font:this.rc,pc:!0,width:y(600),height:y(216),x:y(-135,"round"),y:y(120,"round"),text:E(this.Ed[this.id])});this.wn.d(this.text);
this.Vi=new F({font:this.aW,x:y(40,"round"),y:y(244,"round"),text:kq(this.Ge[this.id])});this.wn.d(this.Vi);this.d(this.wn);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya()};e.da=function(){};e.pa=function(){};V.p.iX={Ra:null,et:!1,zF:og,Qy:Wf,mS:Xf,FG:Yf,Xk:{wv:0,aC:1,cC:2},state:void 0,qq:2.2,rq:4.7,fu:12,Sy:5.25,hn:0,HG:0,time:0,duration:3E3,ME:[2E3,1700,0],Tu:0,iB:3900,Ry:0,IG:0,Dz:null,e:[]};
function aq(a){this.name="WheelEffectDialog";this.n(V.p.iX);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(aq,yc);e=aq.prototype;
e.w=function(){var a,b=this;this.Ya=this.canvas.getContext("2d");this.Ry=this.fu;this.IG=this.Sy-this.Ry;this.frame=new s({gH:function(){b.ro()}});this.XB=new Bc({wr:Ni,No:"wheelOfFortune",play:!1,FF:!1,Tb:function(){for(var a=b.Ra,d=0;d<a.Pr.length;d++)a.Pr[d].start=!0;b.XB.i()}});this.frame.d(this.XB);this.d(this.frame);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.Yq=function(){var a=this.XB;nm(a);a.play=!0};
function $p(a){switch(a.state){case a.Xk.wv:a.hn=a.rq;a.HG=a.Sy-a.rq;break;case a.Xk.aC:a.hn=a.qq;a.HG=a.Sy-a.qq;break;case a.Xk.cC:a.Dz&&a.Dz()}}
e.Dv=function(a){if(void 0!==this.state)switch(this.Tu<this.iB&&(this.Tu=Math.min(this.Tu+a,this.iB)),this.fu=this.Ry+this.Tu/this.iB*this.IG,this.time<this.duration?this.time=Math.min(this.time+a,this.duration):(this.state++,$p(this),this.duration=this.ME[this.state],this.time=0),this.state){case this.Xk.wv:this.rq=this.hn+this.time/this.duration*-this.hn;break;case this.Xk.aC:this.qq=this.hn+this.time/this.duration*-this.hn;break;case this.Xk.cC:break;default:this.et=!1,this.i()}};
e.ro=function(){void 0!==this.state&&(this.et&&(this.Ya.clearRect(0,0,r.O,r.M),this.zF.B(0,y(-2),y(184)),this.Ya.globalCompositeOperation="destination-out",this.Qy.ib(0,y(0),y(92),this.qq,this.qq,0,1),this.Ya.globalCompositeOperation="destination-out",this.FG.ib(0,y(-5),y(-125),this.rq,this.rq,0,1),this.Ya.globalCompositeOperation="destination-out",this.Qy.ib(0,y(0),y(92),this.fu,this.fu,0,1),this.Ya.restore(),this.Ya.globalCompositeOperation="source-over"),gg.B(0,y(-16),y(-338)))};
e.I=function(){this.ya();this.frame=void 0};e.da=function(){};e.pa=function(){};
V.p.KT={uw:ug,j0:tg,Be:0,Vq:[vg,wg,xg,yg,zg],un:[{x:y(-25),y:y(0)},{x:y(0),y:y(0)},{x:y(50),y:y(0)},{x:y(0),y:y(-14)},{x:y(0),y:y(-14)}],frames:[],Pa:{h:Hl,duration:.5,wb:1,o:hc,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},ue:{l:T.l,fontSize:60,fillColor:"#942600",align:"center",ua:"middle"},cc:{l:T.l,fontSize:26,fillColor:"#942600"},RO:{l:Ci.l,fontSize:16,fillColor:"#942600"},Mm:{0:{$u:["help_slot_body","help_slot_body2","help_slot_body3"],Ab:[{x:y(20),y:y(-370)},{x:y(20),y:y(-15)},{x:y(20),y:y(500)}],
font:["detail","detail","detail"]},1:void 0,2:{$u:["help_wild_header","help_wild_body","help_scatter_header","help_scatter_body"],Ab:[{x:y(0),y:y(-550)},{x:y(230),y:y(-340)},{x:y(0),y:y(-50)},{x:y(20),y:y(450)}],font:["title","detail","title","detail"]},3:{$u:["help_collect_header","help_collect_body","help_wheel_header","help_wheel_body"],Ab:[{x:y(20),y:y(-580)},{x:y(20),y:y(-200)},{x:y(20),y:y(-100)},{x:y(20),y:y(0)}],font:["title","detail","title","detail"]},4:void 0},Nm:[],P:null,e:[]};
function ho(a){this.name="PaytableDialog";this.n(V.p.KT);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(ho,yc);e=ho.prototype;e.nextPage=function(){this.Be++;this.Be>this.Vq.length-2&&(this.Hp.show(),this.Hp.ka(),this.Ih.i());this.gh.show();this.gh.ka();lq(this,this.Be);this.If.c=this.Vq[this.Be];this.If.x=this.un[this.Be].x;this.If.y=this.un[this.Be].y};
function mq(a){for(var b=0;b<a.Vq.length;b++){if(void 0===a.Mm[b])var c=new s({});else for(var c=new s({}),d=0;d<a.Mm[b].$u.length;d++){var g;g="detail"===a.Mm[b].font[d]?a.RO:a.cc;g=new F({text:E(a.Mm[b].$u[d]),width:a.uw.width-y(80),x:a.Mm[b].Ab[d].x,y:a.Mm[b].Ab[d].y,font:g});c.d(g)}a.Nm.push(c)}}function lq(a,b){for(var c=0;c<a.Nm.length;c++)a.Nm[c].i();a.Nm[b].show()}e.dt=function(){X(this.frame,2)};
e.w=function(){var a,b=this;mq(this);this.frame=new s({S:[this.Pa,{h:"nothing",duration:9999999},this.sa],yb:function(){b.i()}});this.tw=new u({c:this.uw,x:y(0),y:y(0)});this.frame.d(this.tw);this.IQ=new F({text:E("help_header"),font:this.ue,width:this.uw.width-y(200),height:y(120),x:y(0),y:y(-700)});this.frame.d(this.IQ);this.If=new u({c:this.Vq[this.Be],x:this.un[this.Be].x,y:this.un[this.Be].y});this.frame.d(this.If);this.Hp=new D({c:sg,x:y(280),y:y(660),text:E("help_button_exit"),T:ti,j:function(){b.dt()}});
this.frame.d(this.Hp);this.Ih=new D({c:sg,icon:qg,qa:"center",x:y(280),y:y(660),j:function(){b.nextPage()}});this.frame.d(this.Ih);this.gh=new D({c:sg,icon:rg,qa:"center",x:y(-280),y:y(660),j:function(){b.Be--;1>b.Be&&b.gh.i();b.Ih.show();b.Ih.ka();b.Hp.i();lq(b,b.Be);b.If.c=b.Vq[b.Be];b.If.x=b.un[b.Be].x;b.If.y=b.un[b.Be].y}});this.frame.d(this.gh);for(a=0;a<this.Nm.length;a++)this.frame.d(this.Nm[a]);this.d(this.frame);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya()};
e.da=function(){Ej();this.Hp.i();this.gh.i();lq(this,0)};e.pa=function(){Fj()};V.p.cP={$:Mi,Dm:["leafsClose","leafsOpen"],depth:-5E3,step:0,Tb:null,P:null,e:[]};function Xp(a){this.name="DoorTransitionDialog";this.n(V.p.cP);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(Xp,yc);e=Xp.prototype;e.next=function(a){this.step++;this.HE.Rc(this.Dm[this.step],a)};e.dt=function(){};
e.w=function(){var a;this.frame=new s({});this.HE=new Bc({wr:this.$,No:this.Dm[this.step],Tb:this.Tb});this.frame.d(this.HE);this.d(this.frame);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){this.ya()};e.da=function(){};e.pa=function(){};
V.p.TN={Ra:null,Lc:dh,title:"extracoins_txt",Pa:{h:Gl,duration:.8,u:y(-500),G:y(0),o:ic,K:1.2},sa:{h:Hl,duration:.5,wb:0,o:hc,K:1.2},Ct:!1,nM:!1,P:null,xl:null,su:null,uT:null,Jg:0,ue:{l:T.l,fontSize:65,fillColor:"#942600",align:"center",ua:"middle"},rc:{l:Ci.l,fontSize:22,fillColor:"#942600",align:"center",ua:"middle"},Ef:0,WG:0,Pd:!1,Ac:null,e:[]};function No(a){this.name="CoinRewardDialog";this.n(V.p.TN);void 0!==a&&this.f(a);this.x=r.k.width/2;this.y=r.k.height/2}hm(No,yc);
No.prototype.w=function(){var a,b=this;Qb(Z.A);var c=Z.ma,d=c.db.player.moreCoins,g=new Date;a=0;this.Jg*=d.coinPercentage;d.lastAdTimer+36E5*d.timerRest<=g.getTime()&&0<d.lastAdTimer||0===d.lastAdTimer?this.Pd=!0:a=d.lastAdTimer+36E5*d.timerRest-g.getTime();this.yc=new cm({Rd:.8});this.d(this.yc);this.frame=new s({S:[this.Pa,{h:"nothing",duration:9999999},{h:"fadeOut",u:0,G:r.k.height,duration:1,o:ec}],yb:function(){b.i()}});this.d(this.frame);this.ud=new u({c:this.Lc,x:y(0),y:y(0)});this.frame.d(this.ud);
this.WB=new F({text:E("extracoins_header"),font:this.ue,width:this.Lc.width-y(200),x:y(0),y:y(-480)});this.frame.d(this.WB);this.jp=new u({c:fh,x:y(0),y:y(-200)});this.frame.d(this.jp);this.Lz=new u({c:lh,x:y(0),y:y(260)});this.frame.d(this.Lz);this.Pd||(this.Gc=new oo({width:y(600),height:y(200),y:y(230),Db:this.rc,valueType:"time",ec:a/1E3,md:":",ni:-1,Cl:function(a,c){0===c&&(b.Gc.i(),b.Kc.show(),b.Kc.ka())}}),this.frame.d(this.Gc));this.Lg=new D({c:mf,x:y(0),y:y(400),text:E("extracoins_button_back"),
T:vi,j:function(){X(b.frame,2)}});this.frame.d(this.Lg);this.Kc=new D({c:Q,x:y(0),y:y(240),text:E("extracoins_button_video"),T:ti,j:function(){Z.za.Ka(Z.za.no.RK);b.Yj&&b.Yj();c.db.player.moreCoins.lastAdTimer=g.getTime();c.db.player.moreCoins.timeToWait=g.getTime()+36E5*d.timerRest;c.save();G.vs(function(){Z.yf(b.Jg);Bp(b.Jg);Z.yf();Vb(Z.A);var a=E("feedback_coinfloater").replace("{0}",b.Jg);new An(a,r.O/2,r.M/2-y(100),200,ki,.6,"#00dfff","#094dc5",-2E3,0,function(){})},function(){Vb(Z.A)});Qb(Z.A);
X(b.frame,2)}});this.frame.d(this.Kc);this.Pd||(this.title="extracoins_txtNo");this.Bc=new F({font:this.rc,text:E(this.title),width:lh.width-y(50),x:y(0),y:y(80)});this.frame.d(this.Bc);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};No.prototype.I=function(){this.ya();this.frame=void 0};No.prototype.da=function(){Ej();this.Pd||this.Kc.i()};No.prototype.pa=function(){Fj();Vb(Z.A)};V.J.ZN={duration:800,id:0,c:void 0,time:0,aa:y(0),u:y(0),Xl:y(0),kf:y(0),fe:0,Ld:0,L:200,start:!1,Tb:null,e:[]};
function Zp(a){this.name="CollectableComponent";this.n(V.J.ZN);void 0!==a&&this.f(a)}zl(Zp,s);e=Zp.prototype;e.w=function(){var a;this.fe=this.aa;this.Ld=this.u;this.Zl=new u({c:this.c,x:this.aa,y:this.u});this.d(this.Zl);this.Zf=this.Xl-this.fe;this.Re=this.kf-this.Ld;if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};e.I=function(){};e.da=function(){};e.pa=function(){};e.$f=function(){};
e.sd=function(a){0<this.L&&this.start?this.L-=a:this.start&&(this.fe=this.aa+this.time/this.duration*this.Zf,this.Ld=this.u+this.time/this.duration*this.Re,this.time<this.duration?this.time=Math.min(this.time+a,this.duration):this.Tb&&this.Tb(this.id))};e.$c=function(){};e.Cf=function(){};e.jc=function(){this.c&&(this.Zl.x=this.fe,this.Zl.y=this.Ld)};e.ag=function(){};V.J.MT={duration:1E3,id:0,c:void 0,time:0,aa:y(0),u:y(0),Xl:y(0),kf:y(0),fe:0,Ld:0,L:200,start:!1,cz:-1,Tb:null,e:[]};
function jq(a){this.name="PingPongComponent";this.n(V.J.MT);void 0!==a&&this.f(a)}zl(jq,s);jq.prototype.w=function(){var a;this.fe=this.aa;this.Ld=this.u;this.Zf=this.Xl-this.aa;this.Re=this.kf-this.u;this.Zl=new u({c:this.c,x:this.aa,y:this.u});this.d(this.Zl);if(this.e)for(a=0;a<this.e.length;a+=1)this.d(this.e[a])};
jq.prototype.sd=function(a){this.time<this.duration?this.time=Math.min(this.time+a,this.duration):(this.time=0,this.cz*=-1);this.Ld=-1===this.cz?this.u+this.time/this.duration*this.Re:this.kf+this.time/this.duration*-this.Re};jq.prototype.$c=function(){};jq.prototype.jc=function(){this.c&&(this.Zl.x=this.fe,this.Zl.y=this.Ld)};function jo(){Jj(V,{lf:{name:"<UNKNOWN>",id:"<UNKNOWN>",version:"1.0"},q:{}})}
function nq(){this.na={XK:"Initialize-loading",WK:"Initialize-finished",VK:"Game-loading",UK:"Game-finished",UR:"level-[levelnumber]-start",VR:"level-[levelnumber]-won-[amount of stars]",SR:"level-[levelnumber]-lost",Ky:"level-[levelnumber]-completeonce",TR:"level-[levelnumber]-restart",Gx:"firsttime-initialize",Hx:"firsttime-menu",Np:"firsttime-play",DP:"firsttime-level-[levelnumber]-start",UY:"firsttime-tutorial[tutorialnumber]-step[step number]",EP:"firsttime-level-[levelnumber]-won-[amount of stars]",
IV:"stage-[stagenumber]-start",JV:"stage-[stagenumber]-won",GV:"stage-[stagenumber]-lost",lB:"stage-[stagenumber]-completeonce",HV:"stage-[stagenumber]-restart",Jx:"firsttime-stage-[stagenumber]-start",Kx:"firsttime-stage-[stagenumber]-won",Ix:"firsttime-stage-[stagenumber]-lost",HY:"dailyspin_counter reset_day[number of day]",IY:"dailyspin_day[number of day]\t",M_:"reward_[rewardname]",N_:"reward_no reward",O_:"reward_spin again",u_:"premiumspin_day[number of day]",t_:"premiumreward_[rewardname]",
x_:"purchase_booster_[booster name]_[levelnumber]",r0:"use_booster_[booster name]_[levelnumber]",y_:"purchase_extramoves_[levelnumber]",z_:"purchase_gate unlock_[gate number]",w_:"purchase_adremoval"};oq()}
nq.prototype.Ka=function(a,b){if(void 0===a)console.log("ANALYTICS WARNING: No ID passed");else{var c;c=[];for(var d="[levelnumber];[amount of stars];[tutorialnumber];[number of day];[rewardname];[booster name];[gate number];[stagenumber]".split(";"),g=a,k=0;k<d.length;k++)a.UF(d[k])&&c.push(d[k]);if("[object Array]"===Object.prototype.toString.call(b)&&b.length===c.length)for(k=0;k<c.length;k++)g=g.replace(c[k],b[k].toString());else void 0!==b&&"[object Array]"!==Object.prototype.toString.call(b)&&
1===c.length?g=a.replace(c[0],b.toString()):void 0===b&&0===c.length||console.log("ANALYTICS WARNING: Some arguments are not correct!");c=g;console.log("ID SEND TO ANALYTICS: "+c);try{analytics.customEvent(c)}catch(l){console.log("error calling analytics.menu: "+l)}}};function oq(){String.prototype.UF||(String.prototype.UF=function(a,b){"number"!==typeof b&&(b=0);return b+a.length>this.length?!1:-1!==this.indexOf(a,b)})}var $=new nq,pq=window.publisher,qq=!1,rq=!1,sq=!1,tq=-1;
G.LC=function(){new Cc(pq,G.tQ(),G.ck,G.Mf,G.Pi,this);this.ti($.na.Gx)||($.Ka($.na.Gx),this.Qi($.na.Gx));$.Ka($.na.WK);$.Ka($.na.VK)};
G.uD=function(){$.Ka($.na.XK);var a=window.navigator.userAgent,b=!1,c=/Chrome/.test(window.navigator.userAgent)&&/Google Inc/.test(window.navigator.vendor),d=/SHL24|SHL23|SHL22|SHL25|SHL21/i.test(a)&&!c,a=/SH-01F/i.test(a)&&!c;if(window.ActiveXObject||"ActiveXObject"in window)sq=b=!0;if(d||a)V.Rm.It=!1,V.q.Zt=["load","images","fonts"],V.q.$t=["load","images"];if(b||a||d)V.Rm.It=!1,V.q.Zt=["load","images","fonts"],V.q.$t=["load","images"];ca.U.vB&&(V.Rm.It=!1,V.q.Zt=["load","images","fonts"],V.q.$t=
["load","images"])};G.vD=function(){this.ti($.na.Hx)||($.Ka($.na.Hx),this.Qi($.na.Hx));$.Ka($.na.UK);try{analytics.customEvent("menu")}catch(a){console.log("error calling analytics.menu: "+a)}};G.Rz=function(a,b){var c=this;pq.enableAds&&!qq&&(setTimeout(function(){c.BF()},1E3*pq.firstAd),setTimeout(function(){c.KV()},1E3*pq.firstAd),qq=!0);tq=b?b:-1;this.ti($.na.Np)||($.Ka($.na.Np),this.Qi($.na.Np));this.ti($.na.Np+"_"+tq)||($.Ka($.na.DP,tq),this.Qi($.na.Np+"_"+tq));$.Ka($.na.UR,tq)};
G.KV=function(){var a=this;setInterval(function(){a.BF()},1E3*pq.adFreq)};G.BF=function(){rq=!0};G.EH=function(a,b,c){void 0===c&&(c="undefined stars");$.Ka($.na.VR,[tq,c]);this.ti($.na.Ky+"_"+tq)||($.Ka($.na.Ky,tq),$.Ka($.na.EP,tq,c),this.Qi($.na.Ky+"_"+tq))};G.CH=function(){$.Ka($.na.TR,tq)};G.BH=function(){$.Ka($.na.SR,tq)};
G.AH=function(a){try{var b=Kk(qk).Wn;community.submitScore({score:b,callback:function(){if(rq)try{G.ck(),adSense.showAdvertising({callback:G.Mf}),rq=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),G.Mf()}}});analytics.customEvent("score: "+b)}catch(c){console.log("error submitting highscore: "+b+", "+c)}if(a&&rq)try{G.ck(),adSense.showAdvertising({callback:function(){G.Mf()}}),rq=!1}catch(d){console.log("error calling adSense.showAdvertising: "+d),G.Mf()}};
G.oF=function(a){if(a.failed)try{analytics.customEvent("levelFailed",a.level)}catch(b){console.log("error calling analytics.levelFailed: "+b)}else try{analytics.customEvent("level",a.level)}catch(c){console.log("error calling analytics.level: "+c)}if(rq)try{G.ck(),adSense.showAdvertising({callback:function(){G.Mf();G.Pi()}}),rq=!1}catch(d){console.log("error calling adSense.showAdvertising: "+d),G.Mf(),G.Pi()}else G.Pi()};
G.MA=function(){if(rq)try{G.ck(),adSense.showAdvertising({callback:function(){G.Mf()}}),rq=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),G.Mf()}};G.tQ=function(){return r.O>r.M?"landscape":"portrait"};G.ay=function(){return pq.moreGames?!0:!1};G.yt=function(){if("string"===typeof pq.moreGamesURL&&""!==typeof pq.moreGamesURL)return pq.moreGamesURL;try{moregames.redirect()}catch(a){console.log("error calling moregames.redirect: "+a)}};G.uF=function(){return Cj};
G.JT=function(a){freemium.purchase(void 0,"1.99$","test_item",a,void 0)};G.vs=function(a,b){G.ck();try{Dj.QT(function(){a&&a();G.Mf()},this)}catch(c){b&&b(),G.Mf()}};G.$_=function(){};G.iY=function(){};G.sF=function(){return sq};G.ti=function(a){if(qk.m.zy(a))return!0;!1};G.Qi=function(a){qk.m.Ta(a,"",!0)};
G.e0=function(a,b){switch(a){case "start":$.Ka($.na.IV,b);TG.gl.ti($.na.Jx+" "+b)||($.Ka($.na.Jx,b),TG.gl.Qi($.na.Jx+" "+b));break;case "won":$.Ka($.na.JV,b);TG.gl.ti($.na.Kx+" "+b)||($.Ka($.na.Kx,b),TG.gl.Qi($.na.Kx+" "+b));break;case "lost":$.Ka($.na.GV,b);TG.gl.ti($.na.Ix+" "+b)||($.Ka($.na.Ix,b),TG.gl.Qi($.na.Ix+" "+b));break;case "complete":TG.gl.ti($.na.lB+" "+b)||($.Ka($.na.lB,b),TG.gl.Qi($.na.lB+" "+b));break;case "restart":$.Ka($.na.HV,b)}};Y=Y||{};Y["en-us"]=Y["en-us"]||{};
Y["en-us"].help_header="HOW TO PLAY";Y["en-us"].help_slot_body="Select a number of winlines and a coin bet. The\ncoins are bet on each enabled winline.";Y["en-us"].help_slot_body2="#touch{Click}{Tap} the spin button to spin the reels of the\nslot machine.";Y["en-us"].help_slot_body3="Win coins by scoring at least 3 identical symbols\non any enabled winline. Symbols vary\nin rarity and coin value.";Y["en-us"].help_wild_header="Wild";Y["en-us"].help_wild_body="A wild substitutes any other symbol\nto complete winlines except scatter\nsymbols.";
Y["en-us"].help_scatter_header="Scatter";Y["en-us"].help_scatter_body="Collect 3 scatter symbols to unlock the collectible\nsymbols and trigger Free Spins.";Y["en-us"].help_collect_header="Collectibles";Y["en-us"].help_collect_body="Collect all collectibles in the Free Spins\nto complete the objective.";Y["en-us"].help_wheel_header="Wheel of Fortune";Y["en-us"].help_wheel_body="Complete the collectibles objective to spin the\nWheel of Fortune and collect an artefact.\nTry to collect all 5 artefacts.";
Y["en-us"].help_button_exit="EXIT";Y["en-us"].wheel_button_spin="SPIN";Y["en-us"].ui_paylines="Winlines";Y["en-us"].ui_bet="Coin Bet";Y["en-us"].ui_button_spin="SPIN";Y["en-us"].ui_totalwinnings="Score";Y["en-us"].ui_autospin="AUTO SPIN";Y["en-us"].ui_goodluck="GOOD LUCK!";Y["en-us"].ui_freespinsremaining="{0} Free Spins remaining";Y["en-us"].ui_win="WIN";Y["en-us"].artefact_feather_name="Feather";Y["en-us"].artefact_toad_name="Frog";Y["en-us"].artefact_butterfly_name="Butterfly";
Y["en-us"].artefact_diamond_name="Flower";Y["en-us"].artefact_beetle_name="Beetle";Y["en-us"].artefact_feather_header="FEATHER";Y["en-us"].artefact_toad_header="FROG";Y["en-us"].artefact_butterfly_header="BUTTERFLY";Y["en-us"].artefact_diamond_header="FLOWER";Y["en-us"].artefact_beetle_header="BEETLE";Y["en-us"].sellartefact_button_sell="SELL";Y["en-us"].sellartefact_button_back="CANCEL";Y["en-us"].winartefact_txt="Collect all 5 artefacts at the Wheel of\nFortune";Y["en-us"].about_header="ABOUT";
Y["en-us"].options_header="OPTIONS";Y["en-us"].options_button_resume="RESUME";Y["en-us"].options_button_howtoplay="HOW TO PLAY";Y["en-us"].options_button_moregames="MORE GAMES";Y["en-us"].options_button_quit="QUIT";Y["en-us"].levelup_header="LEVEL UP";Y["en-us"].gameover_header="NOT ENOUGH COINS";Y["en-us"].gameover_txt="Watch a video or sell\nartefacts to continue.";Y["en-us"].gameover_button_video="WATCH VIDEO";Y["en-us"].gameover_noartefacts="No artefacts";Y["en-us"].gameover_button_sell="SELL ARTEFACTS";
Y["en-us"].gameover_videoavailable="Video available in:";Y["en-us"].doubleup_header="DOUBLE UP";Y["en-us"].doubleup_txt="Watch a video to double up\nyour Free Spin winnings!";Y["en-us"].doubleup_button_video="WATCH VIDEO";Y["en-us"].doubleup_button_continue="CONTINUE";Y["en-us"].spinagain_header="SPIN AGAIN";Y["en-us"].spinagain_txt="Watch a video to spin the\nWheel of Fortune again!";Y["en-us"].spinagain_txtNo="Video available in:";Y["en-us"].spinagain_button_video="WATCH VIDEO";
Y["en-us"].spinagain_button_continue="CONTINUE";Y["en-us"].extracoins_header="EXTRA COINS";Y["en-us"].extracoins_txt="Watch a video for extra coins!";Y["en-us"].extracoins_txtNo="Video available in:";Y["en-us"].extracoins_button_video="WATCH VIDEO";Y["en-us"].extracoins_button_back="BACK";Y["en-us"].feedback_notenough="Not enough coins\nadjust your bet.";Y["en-us"].feedback_higherbets="Complete coin win\ngoals to unlock\nmore coin bets.";Y["en-us"].feedback_morepaylines="Complete coin win\ngoals to unlock\nmore winlines.";
Y["en-us"].feedback_betunlock="Higher coin bet unlocked!";Y["en-us"].feedback_paylinesunlock="More winlines unlocked!";Y["en-us"].dialogue_tapanywhere="#touch{Click}{Tap} anywhere to continue.";Y["en-us"].start_dia1="Welcome explorer! You must be searching for treasure and ancient artefacts.";Y["en-us"].start_dia2="You're going to need resources. Here are some coins to get started!";Y["en-us"].start_dia3="#touch{Click}{Tap} the spin button!";Y["en-us"].winlinehit_dia1="Well done!";
Y["en-us"].winlinehit_dia2="Win coins to level up and unlock more betting options.";Y["en-us"].winlineunlock_dia1="You can now increase the number of winlines to bet on!";Y["en-us"].scatter_dia1="A scatter mask! Collect 3 to win free spins.";Y["en-us"].scattercomplete_dia1="You did it!";Y["en-us"].scattercomplete_dia2="Collect all of them to unlock a mini game!";Y["en-us"].betunlock_dia1="You can now increase the amount of coins you bet!";Y["en-us"].wof_dia1="Let's spin it!";
Y["en-us"].collection_dia1="You can find the artefact in your collection.";Y["en-us"].replay_dia1="Welcome back explorer!";Y["en-us"].warning_dia1="Be careful betting too high. Perhaps you should get extra coins!";Y["en-us"].ui_freespins="FREE SPINS";Y["en-us"].feedback_congratulations="Congratulations!\nYou won\n\n{0}";Y["en-us"].ui_sellartefact="#touch{Click}{Tap} on an artefact to sell it.";Y["en-us"].feedback_coinpackage="You won\n{0} coins!";Y["en-us"].feedback_coinfloater="You won\n\n{0}\ncoins!";
Y["jp-jp"]=Y["jp-jp"]||{};Y["jp-jp"].help_header="\u904a\u3073\u65b9";Y["jp-jp"].help_slot_body="\u30e9\u30a4\u30f3\u6570\u3068\u30d9\u30c3\u30c8\u6570\u3092\u9078\u3073\u307e\u3059\n\u30b3\u30a4\u30f3\u306f\u30e9\u30a4\u30f3\u6bce\u306b\u30d9\u30c3\u30c8\u3067\u304d\u307e\u3059";Y["jp-jp"].help_slot_body2="\u30b9\u30d4\u30f3\u30dc\u30bf\u30f3\u3092#touch{\u30af\u30ea\u30c3\u30af}{\u30bf\u30c3\u30d7}\u3057\u3066\n\u30b9\u30ed\u30c3\u30c8\u306e\u30ea\u30fc\u30eb\u3092\u56de\u3057\u307e\u3059";
Y["jp-jp"].help_slot_body3="\u30e9\u30a4\u30f3\u4e0a\u306b3\u3064\u4ee5\u4e0a\n\u30b7\u30f3\u30dc\u30eb\u304c\u63c3\u3046\u3068\n\u30b3\u30a4\u30f3\u3092\u7372\u5f97\u3067\u304d\u307e\u3059\n\u30b7\u30f3\u30dc\u30eb\u6bce\u306b\u30ec\u30a2\u5ea6\u3084\n\u7372\u5f97\u30b3\u30a4\u30f3\u6570\u304c\u7570\u306a\u308a\u307e\u3059";Y["jp-jp"].help_wild_header="\u30ef\u30a4\u30eb\u30c9";Y["jp-jp"].help_wild_body="\u30ef\u30a4\u30eb\u30c9\u30ab\u30fc\u30c9\u306f\n\u30b9\u30ad\u30e3\u30c3\u30bf\u30fc\u30b7\u30f3\u30dc\u30eb\u3092\u9664\u3044\u3066\n\u5168\u3066\u306e\u30b7\u30f3\u30dc\u30eb\u306e\u4ee3\u308f\u308a\u3068\u306a\u308a\u307e\u3059";
Y["jp-jp"].help_scatter_header="\u30b9\u30ad\u30e3\u30c3\u30bf\u30fc";Y["jp-jp"].help_scatter_body="3\u3064\u30b9\u30ad\u30e3\u30c3\u30bf\u30fc\u30b7\u30f3\u30dc\u30eb\u3092\u63c3\u3048\u3066\n\u53ce\u96c6\u7269\u3092\u30a2\u30f3\u30ed\u30c3\u30af\u3057\u305f\u308a\n\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3\u3092\u767a\u52d5\u3055\u305b\u3088\u3046";Y["jp-jp"].help_collect_header="\u53ce\u96c6\u7269";Y["jp-jp"].help_collect_body="\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3\u3067\n\u53ce\u96c6\u7269\u3092\u30b3\u30f3\u30d7\u30ea\u30fc\u30c8\u3057\u3088\u3046";
Y["jp-jp"].help_wheel_header="\u30d5\u30a9\u30fc\u30c1\u30e5\u30f3\u30eb\u30fc\u30ec\u30c3\u30c8";Y["jp-jp"].help_wheel_body="\u53ce\u96c6\u54c1\u3092\u30b3\u30f3\u30d7\u30ea\u30fc\u30c8\u3057\u3066\n\u30d5\u30a9\u30fc\u30c1\u30e5\u30f3\u30eb\u30fc\u30ec\u30c3\u30c8\u3092\u56de\u305d\u3046\n5\u7a2e\u306e\u9aa8\u8463\u54c1\u3092\u5168\u3066\u3092\u96c6\u3081\u3066\u307f\u3088\u3046";Y["jp-jp"].help_button_exit="\u3084\u3081\u308b";Y["jp-jp"].wheel_button_spin="\u30b9\u30d4\u30f3";
Y["jp-jp"].ui_paylines="\u30e9\u30a4\u30f3";Y["jp-jp"].ui_bet="\u30b3\u30a4\u30f3\u6570";Y["jp-jp"].ui_button_spin="\u30b9\u30d4\u30f3";Y["jp-jp"].ui_totalwinnings="\u30b9\u30b3\u30a2";Y["jp-jp"].ui_autospin="\u30aa\u30fc\u30c8\u30b9\u30d4\u30f3";Y["jp-jp"].ui_goodluck="\u30b0\u30c3\u30c9\u30e9\u30c3\u30af\uff01";Y["jp-jp"].ui_freespinsremaining="\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3 \u3042\u3068{0}\u56de";Y["jp-jp"].ui_win="WIN";Y["jp-jp"].artefact_feather_name="\u7fbd";
Y["jp-jp"].artefact_toad_name="\u30ab\u30a8\u30eb";Y["jp-jp"].artefact_butterfly_name="\b\u8776";Y["jp-jp"].artefact_diamond_name="\u82b1";Y["jp-jp"].artefact_beetle_name="\u30ab\u30d6\u30c8\u30e0\u30b7";Y["jp-jp"].artefact_feather_header="\u7fbd";Y["jp-jp"].artefact_toad_header="\u30ab\u30a8\u30eb";Y["jp-jp"].artefact_butterfly_header="\b\u8776";Y["jp-jp"].artefact_diamond_header="\u82b1";Y["jp-jp"].artefact_beetle_header="\u30ab\u30d6\u30c8\u30e0\u30b7";Y["jp-jp"].sellartefact_button_sell="\u58f2\u308b";
Y["jp-jp"].sellartefact_button_back="\u30ad\u30e3\u30f3\u30bb\u30eb";Y["jp-jp"].winartefact_txt="\u9aa8\u8463\u54c1\u30925\u3064\u96c6\u3081\u3066\n\u30d5\u30a9\u30fc\u30c1\u30e5\u30f3\u30eb\u30fc\u30ec\u30c3\u30c8\u3092\u56de\u305d\u3046";Y["jp-jp"].about_header="\u3053\u306e\u30b2\u30fc\u30e0\u306b\u3064\u3044\u3066";Y["jp-jp"].options_header="\u30aa\u30d7\u30b7\u30e7\u30f3";Y["jp-jp"].options_button_resume="\u518d\u958b\u3059\u308b";Y["jp-jp"].options_button_howtoplay="\u904a\u3073\u65b9";
Y["jp-jp"].options_button_moregames="\u305d\u306e\u4ed6\u306e\u30b2\u30fc\u30e0";Y["jp-jp"].options_button_quit="\u3084\u3081\u308b";Y["jp-jp"].levelup_header="\u30ec\u30d9\u30eb\u30a2\u30c3\u30d7";Y["jp-jp"].gameover_header="\u30b3\u30a4\u30f3\u304c\u8db3\u308a\u307e\u305b\u3093";Y["jp-jp"].gameover_txt="\u5e83\u544a\u3092\u89b3\u308b\u304b\n\u9aa8\u8463\u54c1\u3092\u58f2\u3063\u3066\u7d9a\u3051\u308b";Y["jp-jp"].gameover_button_video="\u5e83\u544a\u3092\u307f\u308b";
Y["jp-jp"].gameover_noartefacts="\u9aa8\u8463\u54c1\u304c\u3042\u308a\u307e\u305b\u3093";Y["jp-jp"].gameover_button_sell="\u9aa8\u8463\u54c1\u3092\u58f2\u308b";Y["jp-jp"].gameover_videoavailable="\u5e83\u544a\u8996\u8074\u53ef\u80fd\uff1a";Y["jp-jp"].doubleup_header="\u30c0\u30d6\u30eb\u30a2\u30c3\u30d7";Y["jp-jp"].doubleup_txt="\u5e83\u544a\u3092\u89b3\u3066\u30c0\u30d6\u30eb\u30a2\u30c3\u30d7\n\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3\u3092\u7372\u5f97\u3057\u3088\u3046\uff01";
Y["jp-jp"].doubleup_button_video="\u5e83\u544a\u3092\u307f\u308b";Y["jp-jp"].doubleup_button_continue="\u7d9a\u3051\u308b";Y["jp-jp"].spinagain_header="\u3082\u3046\u4e00\u5ea6\u30b9\u30d4\u30f3";Y["jp-jp"].spinagain_txt="\u5e83\u544a\u3092\u89b3\u3066\n\u3082\u3046\u4e00\u5ea6\n\u30d5\u30a9\u30fc\u30c1\u30e5\u30f3\u30eb\u30fc\u30ec\u30c3\u30c8\u3092\u56de\u305d\u3046\uff01";Y["jp-jp"].spinagain_txtNo="\u5e83\u544a\u8996\u8074\u53ef\u80fd\uff1a";Y["jp-jp"].spinagain_button_video="\u5e83\u544a\u3092\u307f\u308b";
Y["jp-jp"].spinagain_button_continue="\u7d9a\u3051\u308b";Y["jp-jp"].extracoins_header="\u30dc\u30fc\u30ca\u30b9\u30b3\u30a4\u30f3";Y["jp-jp"].extracoins_txt="\u5e83\u544a\u3092\u89b3\u3066\u30b3\u30a4\u30f3\u30dc\u30fc\u30ca\u30b9\u3092\u3082\u3089\u3046";Y["jp-jp"].extracoins_txtNo="\u5e83\u544a\u8996\u8074\u53ef\u80fd\uff1a";Y["jp-jp"].extracoins_button_video="\u5e83\u544a\u3092\u307f\u308b";Y["jp-jp"].extracoins_button_back="\u623b\u308b";Y["jp-jp"].feedback_notenough="\u3053\u306e\u30d9\u30c3\u30c8\u306b\u306f\n\u30b3\u30a4\u30f3\u304c\u8db3\u308a\u307e\u305b\u3093";
Y["jp-jp"].feedback_higherbets="\u4e00\u5b9a\u6570\u306e\n\u30b3\u30a4\u30f3\u3092\u96c6\u3081\u3066\n\u3088\u308a\u9ad8\u3044\u30d9\u30c3\u30c8\u6570\u3092\n\u30a2\u30f3\u30ed\u30c3\u30af\u3057\u3088\u3046";Y["jp-jp"].feedback_morepaylines="\u4e00\u5b9a\u6570\u306e\n\u30b3\u30a4\u30f3\u3092\u96c6\u3081\u3066\n\u3088\u308a\u591a\u3044\u30e9\u30a4\u30f3\u6570\u3092\n\u30a2\u30f3\u30ed\u30c3\u30af\u3057\u3088\u3046";Y["jp-jp"].feedback_betunlock="\u3088\u308a\u9ad8\u3044\u30d9\u30c3\u30c8\u6570\u3092\u30a2\u30f3\u30ed\u30c3\u30af\uff01";
Y["jp-jp"].feedback_paylinesunlock="\u3088\u308a\u591a\u304f\u30e9\u30a4\u30f3\u6570\u3092\u30a2\u30f3\u30ed\u30c3\u30af\uff01";Y["jp-jp"].dialogue_tapanywhere="#touch{\u30af\u30ea\u30c3\u30af\u3057\u3066\u7d9a\u3051\u308b}{\u30bf\u30c3\u30d7\u3057\u3066\u7d9a\u3051\u308b}";Y["jp-jp"].start_dia1="\u53e4\u4ee3\u306e\u5b9d\u7269\u3068\u907a\u7269\u3092\u63a2\u3059\n\u63a2\u691c\u306e\u65c5\u3078\u3088\u3046\u3053\u305d\uff01";Y["jp-jp"].start_dia2="\u305d\u306e\u3046\u3061\u5fc5\u8981\u306b\u306a\u308b\u3060\u308d\u3046\n\u30b9\u30bf\u30fc\u30c8\u8cc7\u91d1\u304c\u3053\u3053\u306b\u3042\u308a\u307e\u3059";
Y["jp-jp"].start_dia3="#touch{\u30b9\u30d4\u30f3\u30dc\u30bf\u30f3\u3092\u30af\u30ea\u30c3\u30af\uff01}{\u30b9\u30d4\u30f3\u30dc\u30bf\u30f3\u3092\u30bf\u30c3\u30d7\uff01}";Y["jp-jp"].winlinehit_dia1="\u3084\u3063\u305f\u306d\uff01";Y["jp-jp"].winlinehit_dia2="\u30b3\u30a4\u30f3\u3092\u96c6\u3081\u3066\u30ec\u30d9\u30eb\u30a2\u30c3\u30d7\u3057\u3066\n\u30d9\u30c3\u30c8\u30aa\u30d7\u30b7\u30e7\u30f3\u3092\n\u30a2\u30f3\u30ed\u30c3\u30af\u3057\u3088\u3046";Y["jp-jp"].winlineunlock_dia1="\u30d9\u30c3\u30c8\u53ef\u80fd\u306a\n\u30e9\u30a4\u30f3\u6570\u304c\u5897\u3048\u307e\u3057\u305f";
Y["jp-jp"].scatter_dia1="\u30b9\u30ad\u30e3\u30c3\u30bf\u30fc\u30de\u30b9\u30af\u30923\u3064\u63c3\u3048\u3066\n\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3\u3092\u30b2\u30c3\u30c8\u3057\u3088\u3046\uff01";Y["jp-jp"].scattercomplete_dia1="\u3084\u3063\u305f\u306d\uff01";Y["jp-jp"].scattercomplete_dia2="\u5168\u3066\u96c6\u3081\u3066\n\u30df\u30cb\u30b2\u30fc\u30e0\u3092\u30a2\u30f3\u30ed\u30c3\u30af\u3057\u3088\u3046\uff01";Y["jp-jp"].betunlock_dia1="\u30d9\u30c3\u30c8\u53ef\u80fd\u306a\n\u30b3\u30a4\u30f3\u30ec\u30fc\u30c8\u304c\u5897\u3048\u307e\u3057\u305f";
Y["jp-jp"].wof_dia1="\u30b9\u30d4\u30f3\u3057\u3088\u3046\uff01";Y["jp-jp"].collection_dia1="\u7372\u5f97\u3057\u305f\u9aa8\u8463\u54c1\u306f\n\u30b3\u30ec\u30af\u30b7\u30e7\u30f3\u3067\u78ba\u8a8d\u3067\u304d\u307e\u3059";Y["jp-jp"].replay_dia1="\u63a2\u691c\u306e\u65c5\u3078\u3088\u3046\u3053\u305d\uff01";Y["jp-jp"].warning_dia1="\u9ad8\u304f\u30d9\u30c3\u30c8\u3057\u3059\u304e\u306a\u3044\u3088\u3046\n\u6c17\u3092\u3064\u3051\u3066\u304f\u3060\u3055\u3044\n\u304a\u305d\u3089\u304f\u30b3\u30a4\u30f3\u30dc\u30fc\u30ca\u30b9\u304c\n\u5fc5\u8981\u3068\u306a\u308a\u307e\u3059";
Y["jp-jp"].ui_freespins="\u30d5\u30ea\u30fc\u30b9\u30d4\u30f3";Y["jp-jp"].feedback_congratulations="\u304a\u3081\u3067\u3068\u3046\uff01\n\n{0}\u3092\u7372\u5f97";Y["jp-jp"].ui_sellartefact="#touch{\u30af\u30ea\u30c3\u30af}{\u30bf\u30c3\u30d7}\u3067\u9aa8\u8463\u54c1\u3092\u58f2\u308b ";Y["jp-jp"].feedback_coinpackage="{0}\n\u30b3\u30a4\u30f3\u3092\u7372\u5f97\uff01";Y["jp-jp"].feedback_coinfloater="{0}\n\n\u30b3\u30a4\u30f3\u3092\u7372\u5f97\uff01";
}());
